<?php

namespace App\Console\Commands\GenerateInvoiceCrons;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Carbon;
use App\Jobs\AdminPanel\SendEmailJob;
use App\Interfaces\ShiftInterface;
use App\Interfaces\ShiftActivityInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\TransactionInterface;
use App\Interfaces\HcpInterface;
use App\Models\CronJob;
use App\Models\Transaction;
use Illuminate\Support\Facades\Storage;
use PDF;
use Mail;

class GenerateFacilityInvoiceCron extends Command
{

    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'generateFacilityInvoiceCron:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'generate facility invoice cron';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(ShiftInterface $shift, ShiftActivityInterface $shiftActivity, FacilityInterface $facility, HcpInterface $hcp, TransactionInterface $transaction)
    {
        parent::__construct();
        $this->shift = $shift;
        $this->shift_activity = $shiftActivity;
        $this->facility = $facility;
        $this->hcp = $hcp;
        $this->transaction = $transaction;
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/generate-invoice.log')]);

        // Current date
        $currentDate = Carbon::now('Australia/Perth')->toDateString();
        $currentTime = Carbon::now();
        $currentDay = strtolower(Carbon::parse($currentDate)->format('l'));
        //-------------

        $shiftUpdate = null;
        $shiftActivity = null;
        $invoiceId = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'facility-generate-invoice-cron')->where('status', 0)->first();
        //----------------

        if (!empty($cronJob)) {

            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now('Australia/Perth')->toDateTimeString();
            $cronJob->save();
            //---------------------------------

            DB::beginTransaction();
            try {
                // Dev Configuration
                $devConfiguration = get_dev_configurations();
                $devConfiguration = (array)json_decode($devConfiguration);
                //----------------------

                if (!empty($devConfiguration) && isset($devConfiguration['invoice_cron_days'])) {
                    $cronDays = explode(",", $devConfiguration['invoice_cron_days']->config_value);

                    if (in_array($currentDay, $cronDays)) {

                        // General Configuration
                        $generalConfiguration = get_general_configuration();
                        $gstPercent = $generalConfiguration['gst_percent'];
                        //----------------------

                        // Last Generated Invoice
                        $generatedInvoice = [
                            'amount_for' => 'facility',
                        ];
                        $lastGeneratedInvoice = $this->transaction->get_last_shift_generated_invoice($generatedInvoice);
                        if (!empty($lastGeneratedInvoice)) {
                            $invoiceStartDate = date('Y-m-d', strtotime($lastGeneratedInvoice['invoice_created_at']));
                        } else {
                            $invoiceStartDate = date('Y-m-d', strtotime("-7 day", strtotime(date('M d, Y'))));
                        }
                        $invoiceEndDate = date('Y-m-d');
                        //-----------------------

                        // Get Facility Statements+
                        $facilityWhere = [];
                        $facilities = $this->facility->get_facility_for_shift_invoice_generate($facilityWhere);
                        if (count($facilities)) {
                            $invoiceId = '';
                            $filename = '';
                            $attach = '';
                            $facilityTotalAmount = 0;
                            $facilityGstAmount = 0;
                            $shiftIds = [];
                            $shifts = [];
                            foreach ($facilities as $facility) {

                                // Get Max Invoice Id
                                $maxInvoiceId = $this->transaction->get_max_invoice_id();
                                if (!empty($maxInvoiceId)) {
                                    $invoiceId = sprintf("%'03d", ($maxInvoiceId['id'] + 1));
                                } else {
                                    $invoiceId = sprintf("%'03d", 1);
                                }
                                $invoiceId = $facility->id . $invoiceId;
                                //-------------------

                                if (count($facility->shifts)) {
                                    // Get Approved Shift
                                    $shiftFilter = [
                                        'current_date' => date('Y-m-d'),
                                        'facility_id' => $facility->id,
                                        'shift_ids' => $facility->shifts->pluck('id'),
                                    ];

                                    $shifts = $this->shift->get_shift_invoice_generate($shiftFilter);
                                    $facilityTotalAmount = $shifts->where('shift_status', '!=', '3')->sum('facility_amount');
                                    $facilityGstAmount = $gstPercent * ($facilityTotalAmount / 100);
                                    $shiftIds = $shifts->pluck('id');
                                    //-------------------
                                } else {
                                    $shifts = [];
                                }

                                if (count($facility->shifts) && count($shifts)) {
                                    Log::channel('cronlog')->info("-----------------------");
                                    Log::channel('cronlog')->info("generate facility invoice cron start");
                                    Log::channel('cronlog')->info("facility id: " . $facility->facility_prefix . $facility->id);
                                    Log::channel('cronlog')->info("facility invoice date range: " . $invoiceStartDate . ' - ' . $invoiceEndDate);
                                    Log::channel('cronlog')->info("facility shift Ids :" . $shiftIds);
                                    Log::channel('cronlog')->info("facility invoice Id " . $maxInvoiceId['invoice_prefix'] . $invoiceId);

                                    // Update Transaction
                                    $filename = strtolower(str_replace(' ', '-', $facility->name . '-invoice-' . $maxInvoiceId['invoice_prefix'] . $invoiceId . '-' . date('Y-m-d'))) . '.pdf';
                                    $transactionUpdateArr = [
                                        'invoice_id' => $invoiceId,
                                        'invoice_created_at' => date('Y-m-d'),
                                        'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                        'invoice_gst_percent' => $gstPercent,
                                        'invoice_gst_amount' => $facilityGstAmount,
                                        'invoice_facility_amount_with_gst' => $facilityTotalAmount + $facilityGstAmount,
                                        'invoice_file_name' => $filename,
                                        'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_facillity_day'] . ' days')),
                                    ];

                                    $transactionWhereArr = ['amount_for' => 'facility', 'invoice_id' => null];
                                    $this->transaction->update_generated_invoice($transactionUpdateArr, $transactionWhereArr, $shiftIds);
                                    //-------------------

                                    // Genrate Invoice PDF
                                    $facilityPdf = PDF::loadView('invoices.facility-invoice', array('shifts' => $shifts, 'facility' => $facility, 'transaction' => $transactionUpdateArr));
                                    $facilityPdf->setOptions(['isPhpEnabled' => true, 'isRemoteEnabled' => true, 'isHtml5ParserEnabled' => true]);
                                    $facilityPdf->setPaper('a4', 'landscape');
                                    $file = Storage::disk(config('filesystems.default'))->put(config('constants.facility.invoice_path') . $filename, $facilityPdf->output());
                                    //--------------------

                                    // Send email notification
                                    if (config('filesystems.default') == config('constants.file_systems.PUBLIC.value')) {
                                        $attach = url('public/storage/' . config('constants.facility.invoice_path')) . '/' . urlencode($filename);
                                    } elseif (config('filesystems.default') == config('constants.file_systems.S3n                                              .value')) {
                                        $bucket = env('AWS_BUCKET');
                                        $region = env('AWS_DEFAULT_REGION');
                                        // $bucketBaseUrl = 'https://s3.' . $region . '.amazonaws.com/'. $bucket.'/';
                                        // $attach = $bucketBaseUrl.config('constants.facility.invoice_path').urlencode($filename);

                                        $S3NewURL = env('AWS_CloudFront_URL') . '/' . config('constants.facility.invoice_path') . urlencode($filename);
                                        $attach = str_replace('#', '%23', $S3NewURL);
                                    }

                                    $emailTemplate = config('constants.admin_email_path') . 'facility-invoice-email';
                                    $emailData = [
                                        'template' => $emailTemplate,
                                        'data' => [
                                            'name' => ucwords($facility['name']),
                                            'email' => env('SHIFT_ACTIVITY_EMAIL'),
                                            'subject' => __('subjects.facility_shift_invoice_generate', ['InvoiceNumber' => $maxInvoiceId['invoice_prefix'] . $invoiceId, 'InvoiceDate' => date('Y-m-d')]),
                                            'InvoiceNumber' => $maxInvoiceId['invoice_prefix'] . $invoiceId,
                                            'StatementDuration' => $invoiceStartDate . ' to ' . $invoiceEndDate,
                                            // 'cc' => $generalConfiguration['facillity_cust_care_email'],
                                            'cc' => $facility['additional_email'],
                                            'filename' => $attach,
                                            'attach' => $attach,
                                        ],
                                    ];

                                    if (config('app.server') == 'AWS') {
                                        SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                                    } else {
                                        $data = $emailData['data'];
                                        Mail::send($emailTemplate, $data, function ($message) use ($data) {
                                            $message->to($data['email']);
                                            $message->subject($data['subject']);
                                            if (!empty($data['cc'])) {
                                                $cc_emails = explode(",", $data['cc']);
                                                foreach ($cc_emails as $cc) {
                                                    $message->cc($cc);
                                                }
                                            }
                                            $message->attach($data['filename']);
                                        });
                                    }
                                    //------------------------

                                    Log::channel('cronlog')->info("generate facility invoice cron completed");
                                    Log::channel('cronlog')->info("-----------------------");
                                }
                            }
                        }
                        //------------------------

                    }
                }

                // Update cron status to completed
                $cronJob->status = 0;
                $cronJob->end_time = Carbon::now('Australia/Perth')->toDateTimeString();
                $cronJob->save();
                //---------------------------------

                DB::commit();
            }catch (\Exception $e) {
                Log::channel('cronlog')->info("-----------------------");
                Log::channel('cronlog')->error('facility invoice error: '.$e->getMessage());
                Log::channel('cronlog')->info("-----------------------");
            }
        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('generate invoice cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
    }
}
