<?php

namespace App\Console\Commands\GenerateInvoiceCrons;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Carbon;
use App\Jobs\AdminPanel\SendEmailJob;
use App\Interfaces\ShiftInterface;
use App\Interfaces\ShiftActivityInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\TransactionInterface;
use App\Interfaces\HcpInterface;
use App\Models\CronJob;
use App\Models\Transaction;
use Illuminate\Support\Facades\Storage;
use PDF;
use Mail;

class GenerateHcpInvoiceCron extends Command
{

    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'generateHcpInvoiceCron:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'generate hcp invoice cron';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(ShiftInterface $shift, ShiftActivityInterface $shiftActivity, FacilityInterface $facility, HcpInterface $hcp, TransactionInterface $transaction)
    {
        parent::__construct();
        $this->shift = $shift;
        $this->shift_activity = $shiftActivity;
        $this->facility = $facility;
        $this->hcp = $hcp;
        $this->transaction = $transaction;
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/generate-invoice.log')]);

        // Current date
        $currentDate = Carbon::now('Australia/Perth')->toDateString();
        $currentTime = Carbon::now();
        $currentDay = strtolower(Carbon::parse($currentDate)->format('l'));
        //-------------

        $shiftUpdate = null;
        $shiftActivity = null;
        $invoiceId = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'hcp-generate-invoice-cron')->where('status', 0)->first();
        //----------------

        if (!empty($cronJob)) {

            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now('Australia/Perth')->toDateTimeString();
            $cronJob->save();
            //---------------------------------

            DB::beginTransaction();
            try {
                // Dev Configuration
                $devConfiguration = get_dev_configurations();
                $devConfiguration = (array)json_decode($devConfiguration);
                //----------------------

                if (!empty($devConfiguration) && isset($devConfiguration['invoice_cron_days'])) {
                    $cronDays = explode(",", $devConfiguration['invoice_cron_days']->config_value);

                    if (in_array($currentDay, $cronDays)) {

                        // Last Generated Invoice
                        $generatedInvoice = [
                            'amount_for' => 'hcp',
                        ];
                        $lastGeneratedInvoice = $this->transaction->get_last_shift_generated_invoice($generatedInvoice);
                        if (!empty($lastGeneratedInvoice)) {
                            $invoiceStartDate = date('Y-m-d', strtotime($lastGeneratedInvoice['invoice_created_at']));
                        } else {
                            $invoiceStartDate = date('Y-m-d', strtotime("-7 day", strtotime(date('M d, Y'))));
                        }
                        $invoiceStartDate = date('Y-m-d', strtotime("-7 day", strtotime(date('M d, Y'))));
                        $invoiceEndDate = date('Y-m-d');
                        //-----------------------

                        // General Configuration
                        $generalConfiguration = get_general_configuration();
                        $gstPercent = $generalConfiguration['gst_percent'];
                        //----------------------

                        // Get Hcp Statements
                        $hcpWhere = [];
                        $hcps = $this->hcp->get_hcp_for_shift_invoice_generate($hcpWhere);
                        if (count($hcps)) {
                            $hcpStatementId = '';
                            $hcpInvoiceId = '';
                            $hcpShiftIds = [];
                            $hcpFilename = '';
                            $hcpAttach = '';
                            foreach ($hcps as $hcp) {
                                if (count($hcp->shifts) || count($hcp->referral_transactions)) {

                                    // Get Max Invoice Id
                                    $hcpMaxInvoiceId = $this->transaction->get_max_invoice_id();
                                    if (!empty($hcpMaxInvoiceId)) {
                                        $hcpStatementId = sprintf("%'03d", ($hcpMaxInvoiceId['id'] + 1));
                                    } else {
                                        $hcpStatementId = sprintf("%'03d", 1);
                                    }
                                    $hcpStatementId = $hcp->id . $hcpStatementId;
                                    //-------------------

                                    // Get Approved Shift
                                    $hcpShiftFilter = [
                                        'shift_status' => '6',
                                        'current_date' => date('Y-m-d'),
                                        'hcp_id' => $hcp->id,
                                        'shift_ids' => $hcp->shifts->pluck('id'),
                                    ];
                                    $hcpShifts = $this->shift->get_shift_invoice_generate($hcpShiftFilter);
                                    $hcpShiftIds = $hcpShifts->pluck('id');
                                    //-------------------

                                    if (count($hcpShifts)) {

                                        $hcpFilename = strtolower(str_replace(' ', '-', $hcp->first_name . '-statement-' . $hcpMaxInvoiceId['statement_prefix'] . $hcpStatementId . '-' . date('Y-m-d'))) . '.pdf';

                                        // Genrate Invoice PDF
                                        $transactionHcpInvoiceArr = [
                                            'statement_id' => $hcpStatementId,
                                            'invoice_created_at' => date('Y-m-d'),
                                            'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                            'invoice_gst_percent' => null,
                                            'invoice_gst_amount' => null,
                                            'invoice_facility_amount_with_gst' => null,
                                            'invoice_file_name' => $hcpFilename,
                                            'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                        ];

                                        $hcpPdf = PDF::loadView('invoices.hcp-invoice', array('shifts' => $hcpShifts, 'hcp' => $hcp, 'transaction' => $transactionHcpInvoiceArr, 'referrals' => $hcp->referral_transactions));
                                        $hcpPdf->setOptions(['isPhpEnabled' => true, 'isRemoteEnabled' => true, 'isHtml5ParserEnabled' => true]);
                                        $hcpPdf->setPaper('a4', 'landscape');
                                        Storage::disk(config('filesystems.default'))->put(config('constants.hcps.invoice_path') . $hcpFilename, $hcpPdf->output());
                                        //--------------------

                                        foreach ($hcpShifts as $hcpShift) {
                                            $generatedInvoices = $this->transaction->get_generated_invoice($hcpShift->id, $hcp->id);
                                            if (!empty($generatedInvoices)) {
                                                $hcpInvoiceId = $generatedInvoices['invoice_id'];
                                            } else {
                                                $hcpInvoiceId = null;
                                            }

                                            Log::channel('cronlog')->info("-----------------------");
                                            Log::channel('cronlog')->info("generate hcp invoice cron start");
                                            Log::channel('cronlog')->info("hcp id: " . $hcp->hcp_prefix . $hcp->id);
                                            Log::channel('cronlog')->info("hcp invoice date range: " . $invoiceStartDate . ' - ' . $invoiceEndDate);
                                            Log::channel('cronlog')->info("hcp shift Ids :" . $hcpShiftIds);
                                            Log::channel('cronlog')->info("hcp invoice id: " . $hcpInvoiceId);
                                            Log::channel('cronlog')->info("hcp statement id: " . $hcpStatementId);

                                            // Update Transaction
                                            $transactionHcpUpdateArr = [
                                                'invoice_id' => $hcpInvoiceId,
                                                'statement_id' => $hcpStatementId,
                                                'invoice_created_at' => date('Y-m-d'),
                                                'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                                'invoice_gst_percent' => null,
                                                'invoice_gst_amount' => null,
                                                'invoice_facility_amount_with_gst' => null,
                                                'invoice_file_name' => $hcpFilename,
                                                'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                            ];
                                            $transactionHcpWhereArr = [
                                                'amount_type' => 'shift',
                                                'amount_for' => 'hcp',
                                                'invoice_id' => null,
                                                'hcp_id' => $hcp->id,
                                                'shift_id' => $hcpShift->id,
                                            ];
                                            $this->transaction->update($transactionHcpUpdateArr, $transactionHcpWhereArr);
                                            //-------------------

                                            // Update referral transactions
                                            if (count($hcp->referral_transactions)) {
                                                foreach ($hcp->referral_transactions as $referral) {
                                                    $this->transaction->update([
                                                        'statement_id' => $hcpStatementId,
                                                        'invoice_created_at' => date('Y-m-d'),
                                                        'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                                        'invoice_gst_percent' => null,
                                                        'invoice_gst_amount' => null,
                                                        'invoice_facility_amount_with_gst' => null,
                                                        'invoice_file_name' => $hcpFilename,
                                                        'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                                    ], [
                                                        'id' => $referral->id,
                                                        'hcp_id' => $hcp->id,
                                                    ]);
                                                }
                                            }
                                            //-----------------------------

                                        }


                                        // Send email notification
                                        if (config('filesystems.default') == config('constants.file_systems.PUBLIC.value')) {
                                            $hcpAttach = url('public/storage/' . config('constants.hcps.invoice_path')) . '/' . urlencode($hcpFilename);
                                        } elseif (config('filesystems.default') == config('constants.file_systems.S3.value')) {
                                            $bucket = env('AWS_BUCKET');
                                            $region = env('AWS_DEFAULT_REGION');
                                            // $bucketBaseUrl = 'https://s3.' . $region . '.amazonaws.com/'. $bucket.'/';
                                            // $hcpAttach = $bucketBaseUrl.config('constants.hcps.invoice_path').urlencode($hcpFilename);

                                            $S3NewURL = env('AWS_CloudFront_URL') . '/' . config('constants.hcps.invoice_path') . urlencode($hcpFilename);
                                            $hcpAttach = str_replace('#', '%23', $S3NewURL);
                                        }

                                        $emailTemplate = config('constants.admin_email_path') . 'hcp-invoice-email';
                                        $emailData = [
                                            'template' => $emailTemplate,
                                            'data' => [
                                                'name' => ucwords($hcp['first_name']),
                                                'email' => $hcp['user']['email'],
                                                'subject' => __('subjects.hcp_shift_invoice_generate', ['InvoiceNumber' => $hcpMaxInvoiceId['statement_prefix'] . $hcpStatementId, 'InvoiceDate' => date('Y-m-d')]),
                                                'InvoiceNumber' => $hcpMaxInvoiceId['statement_prefix'] . $hcpStatementId,
                                                'StatementDuration' => $invoiceStartDate . ' to ' . $invoiceEndDate,
                                                'cc' => $generalConfiguration['hcp_cust_care_email'],
                                                'filename' => $hcpAttach,
                                                'attach' => $hcpAttach,
                                            ],
                                        ];

                                        if (config('app.server') == 'AWS') {
                                            SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                                        } else {
                                            $data = $emailData['data'];
                                            Mail::send($emailTemplate, $data, function ($message) use ($data) {
                                                $message->to($data['email']);
                                                $message->subject($data['subject']);
                                                $message->cc($data['cc']);
                                                $message->attach($data['filename']);
                                            });
                                        }
                                        //------------------------

                                        Log::channel('cronlog')->info("generate hcp invoice cron completed");
                                        Log::channel('cronlog')->info("-----------------------");
                                    }

                                }
                            }
                            $emailTemplate = config('constants.admin_email_path') . 'hcp_invoice_cron_confimation';
                            Mail::send($emailTemplate, ['date' => date('Y-m-d H:i:s')], function ($message) {
                                $message->to('accounts@ishapps.com');
                                $message->subject('hcp_invoice_generation');
                            });
                        }
                        //-------------------

                    }
                }

                // Update cron status to completed
                $cronJob->status = 0;
                $cronJob->end_time = Carbon::now('Australia/Perth')->toDateTimeString();
                $cronJob->save();
                //---------------------------------

                DB::commit();
            }catch (\Exception $e) {
                Log::channel('cronlog')->info("-----------------------");
                Log::channel('cronlog')->error('Hcp invoice error: ' . $e->getMessage());
                Log::channel('cronlog')->info("-----------------------");
            }
        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('hcp generate invoice cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
    }
}
