<?php

namespace App\Console\Commands\ShiftCrons;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Carbon;
use App\Models\CronJob;
use App\Jobs\AdminPanel\ShiftBroadcastJob;
use App\Interfaces\ShiftInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\HcpInterface;
use App\Interfaces\ShiftActivityInterface;
use Illuminate\Http\Request;

class ShiftBroadcastCron extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'shiftBroadcastCron:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Hcp shift broadcast cron';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(ShiftInterface $shift, FacilityInterface $facility, HcpInterface $hcp, ShiftActivityInterface $shiftActivity)
    {
        parent::__construct();
        $this->shift = $shift;
        $this->shiftActivity = $shiftActivity;
        $this->facility = $facility;
        $this->hcp = $hcp;
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/shift-broadcast.log')]);

        // Current date
        $currentDate = Carbon::now()->toDateString();
        $currentTime = Carbon::now()->format('d-m-y H:i');
        //-------------

        $shiftUpdate = null;
        $shiftActivity = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'shift-broadcast-cron')->where('status', 0)->first();
        //----------------

        if (!empty($cronJob)) {

            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

            $hcpFilter = [];
            $favouritesHcpIds = [];
            $ratedHcpIds = [];
            $otherHcpIds = [];
            $allHcpsIds = [];
            $cancelledHcpIds = [];
            $userDeviceIds = [];

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            DB::beginTransaction();
            try {

                // Get Shift
                $shiftWhere = ['shift_status' => '0'];
                $shifts = $this->shift->shift_where($shiftWhere);
                //----------

                if (count($shifts)) {
                    Log::channel('cronlog')->info("-----------------------");
                    Log::channel('cronlog')->info("shift broadcast job start");

                    foreach($shifts as $shift) {

                        // Set time zone
                        date_default_timezone_set($shift->state->time_zone_name);
                        $currentTime = Carbon::now($shift->state->time_zone_name);
                        //--------------

                        $getfacility = $this->facility->find_facility($shift['facility_id']);
                        $hcpFilter['shift_id'] = $shift['id'];
                        $hcpFilter['facility_id'] = $shift['facility_id'];
                        $hcpFilter['state_id'] = $shift['state_id'];
                        $hcpFilter['country_id'] = $shift['country_id'];
                        $hcpFilter['facility_latitude'] = $getfacility['latitude'];
                        $hcpFilter['facility_longitude'] = $getfacility['longitude'];
                        $hcpFilter['category_id'] = $shift['category_id'];
                        $hcpFilter['profession_id'] = $shift['profession_id'];
                        $hcpFilter['level_id'] = $shift['hcp_level_id'];
                        $hcpFilter['shift_start_time'] = $shift['start_time'];
                        $hcpFilter['shift_end_time'] = $shift['end_time'];
                        $hcpFilter['time_zone_name'] = $shift->state->time_zone_name;
                        $hcpFilter['check_transfer_case'] = 'true';
                        $hcpFilter['check_swap_case'] = 'true';

                        // Get Cancelled Hcps
                        $cancelledHcpIds = [];
                        if (count($shift['cancelled_shifts'])) {
                            foreach($shift['cancelled_shifts'] as $cancelledShifts){
                                $cancelledHcpIds[] = $cancelledShifts->hcp_id;
                            }
                            $hcpFilter['cancelled_hcps'] = $cancelledHcpIds;
                        }

                        // Send Notification To Favourites Hcp
                        if($shift['shift_broadcast'] == 'favourite') {
                            $hcpFilter['only_favourites'] = true;
                            $favouritesHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                            $favouritesHcpIds = [];
                            if (count($favouritesHcps)) {
                                foreach($favouritesHcps as $favouritesHcp){
                                    $favouritesHcpIds[] = $favouritesHcp->id;
                                }

                                send_shift_push_notification($shift->id, 'new-shift', array_unique($favouritesHcpIds), null, 'favourite');

                                Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                                Log::channel('cronlog')->info("notification sent to favorite hcp");
                            }

                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'broadcast-to-favourites-hcp',
                                'created_by'    => $shift->created_by,
                                'updated_by'    => $shift->created_by,
                            ];
                            $this->shiftActivity->store($shiftActivityData);

                            Log::channel('cronlog')->info("shift broadcast to favourites hcp");

                            // Update Shift Broadcast
                            $shiftBroadcastWhere = ['id' => $shift['id']];

                            if(count($favouritesHcps)) {
                                $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_mint']);
                            } else {
                                $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes(1);
                            }

                            $this->shift->update(['shift_broadcast' => 'rated', 'shift_rebroadcast_time' => $shiftRebroadcastTime], $shiftBroadcastWhere);
                            //-----------------------
                        }
                        //------------------------------------

                        // Send Notification To Rated Hcp
                        else if($shift['shift_broadcast'] == 'rated' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                            $hcpFilter['only_ratings'] = true;
                            $ratedHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                            $ratedHcpIds = [];
                            if (count($ratedHcps)) {
                                foreach($ratedHcps as $ratedHcp){
                                    $ratedHcpIds[] = $ratedHcp->id;
                                }

                                send_shift_push_notification($shift->id, 'new-shift', array_unique($ratedHcpIds), null, 'rated');

                                Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                                Log::channel('cronlog')->info("notification sent to rated Hcp");
                            }

                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'broadcast-to-rated-hcp',
                                'created_by'    => $shift->created_by,
                                'updated_by'    => $shift->created_by,
                            ];
                            $this->shiftActivity->store($shiftActivityData);

                            Log::channel('cronlog')->info("shift broadcast to rated hcp");

                            // Update Shift Broadcast
                            $shiftBroadcastWhere = ['id' => $shift['id']];

                            if(count($ratedHcps)) {
                                $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_mint']);
                            } else {
                                $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes(1);
                            }

                            $this->shift->update(['shift_broadcast' => 'other', 'shift_rebroadcast_time' => $shiftRebroadcastTime] ,$shiftBroadcastWhere);
                            //-----------------------
                        }
                        //--------------------------------

                        // Send Notification To Other Hcp
                        else if($shift['shift_broadcast'] == 'other' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                            $otherHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                            $otherHcpIds = [];
                            if (count($otherHcps)) {
                                foreach($otherHcps as $otherHcp){
                                    $otherHcpIds[] = $otherHcp->id;
                                }

                                send_shift_push_notification($shift->id, 'new-shift', array_unique($otherHcpIds), null, 'other');

                                Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                                Log::channel('cronlog')->info("notification sent to other hcp");
                            }

                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'broadcast-to-other-hcp',
                                'created_by'    => $shift->created_by,
                                'updated_by'    => $shift->created_by,
                            ];
                            $this->shiftActivity->store($shiftActivityData);

                            Log::channel('cronlog')->info("shift broadcast to other hcp");

                            // Check Time Diff
                            $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);

                            $to = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name);
                            $from = Carbon::parse($currentTime);
                            $timeDiff = $to->diffInHours($from);
                            //----------------

                            if($timeDiff < $generalConfiguration['rebroadcast_to_all_before_shift_start']) {
                                $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours(1);
                            } else {
                                $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);
                            }

                            // Update Shift Broadcast
                            $shiftBroadcastWhere = ['id' => $shift['id']];
                            $this->shift->update(['shift_broadcast' => 'all', 'shift_rebroadcast_time' => $nextReabroadcast] ,$shiftBroadcastWhere);
                            //-----------------------
                        }
                        //-------------------------------

                        // Send Notification To All Hcp
                        else if($shift['shift_broadcast'] == 'all' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                            $allHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                            $allHcpsIds = [];
                            if (count($allHcps)) {
                                foreach($allHcps as $allHcp){
                                    $allHcpsIds[] = $allHcp->id;
                                }

                                send_shift_push_notification($shift->id, 'new-shift', array_unique($allHcpsIds), null, 'all');

                                Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                                Log::channel('cronlog')->info("notification sent to all hcp");
                            }

                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'broadcast-to-all-hcp',
                                'created_by'    => $shift->created_by,
                                'updated_by'    => $shift->created_by,
                            ];
                            $this->shiftActivity->store($shiftActivityData);

                            Log::channel('cronlog')->info("shift broadcast to all hcp");

                            // Update Shift Broadcast
                            $shiftBroadcastWhere = ['id' => $shift['id']];
                            $this->shift->update(['shift_broadcast' => 'all', 'shift_rebroadcast_time' => Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_to_all_mint'])] ,$shiftBroadcastWhere);
                            //-----------------------
                        }
                        //-------------------------------
                    }

                    Log::channel('cronlog')->info("shift broadcast job end");
                    Log::channel('cronlog')->info("-----------------------");
                }

                // // Shift Broadcast Job
                // ShiftBroadcastJob::dispatch();
                // //--------------------

                DB::commit();

            } catch (\Exception $e) {
                Log::channel('cronlog')->info("-----------------------");
                Log::channel('cronlog')->error('shift broadcast cron error: '.$e->getMessage());
                Log::channel('cronlog')->info("-----------------------");
            }

            // Update cron status to completed
            $cronJob->status = 0;
            $cronJob->end_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('shift broadcast cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
    }
}
