<?php

namespace App\Console\Commands\ShiftCrons;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Carbon;
use App\Jobs\AdminPanel\SendEmailJob;
use App\Interfaces\ShiftInterface;
use App\Interfaces\ShiftActivityInterface;
use App\Interfaces\BuddyShiftRequestInterface;
use App\Models\CronJob;
use Mail;

class ShiftEndCron extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'shiftEndCron:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Hcp shift end cron';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(ShiftInterface $shift, ShiftActivityInterface $shiftActivity, BuddyShiftRequestInterface $buddyShiftRequest)
    {
        parent::__construct();
        $this->shift = $shift;
        $this->shift_activity = $shiftActivity;
        $this->buddy_shift_request = $buddyShiftRequest;
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/shift-cron.log')]);

        $shiftUpdate = null;
        $shiftActivity = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'shift-end-cron')->where('status', 0)->first();
        //----------------

        if (!empty($cronJob)) {

            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

            DB::beginTransaction();
            try {

                // Get Shifts
                $shiftWhere = ['shift_status' => '2'];
                $shifts = $this->shift->get_shift_for_cron($shiftWhere);
                //-----------

                if(count($shifts)){
                    foreach($shifts as $shift){

                        // Set time zone
                        date_default_timezone_set($shift->state->time_zone_name);
                        //--------------

                        // Current date
                        $currentDate = Carbon::now($shift->state->time_zone_name)->toDateString();
                        $currentTime = Carbon::now($shift->state->time_zone_name);
                        //-------------

                        if(strtotime($currentTime) >= strtotime($shift->end_time)) {

                            Log::channel('cronlog')->info("-----------------------");
                            Log::channel('cronlog')->info("current time: ". $currentTime);
                            Log::channel('cronlog')->info("shift end time: ". $shift->end_time);

                            // Update Shift
                            $shiftData = ['shift_status' => '4', 'hcp_shift_end_time' => $currentTime];
                            $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
                            //-------------

                            // Update buddy shift request
                            if(!empty($shift) &&  $shift->shift_type == 'buddy'){
                                $this->buddy_shift_request->update(['status' => 'completed'], ['shift_id' => $shift->id]);
                            }
                            //---------------------------

                            // Shift Activity
                            $getShiftActivity = $this->shift_activity->find_shift_activity(['shift_id' => $shift->id, 'activity' => 'shift-end']);
                            if(empty($getShiftActivity)) {
                                    $shiftActivityData = [
                                        'hcp_id'        => $shift->hcp_id,
                                        'shift_id'      => $shift->id,
                                        'activity'      => 'shift-end',
                                        'created_by'    => $shift->created_by,
                                        'updated_by'    => $shift->updated_by,
                                    ];
                                    $shiftActivity = $this->shift_activity->store($shiftActivityData);
                                }
                            //---------------

                            if (!empty($shift['hcp_id'])) {
                                $hcpId = $shift['hcp_id'];
                                send_shift_push_notification($shift->id, 'shift-completed', $hcpId);
                            }

                            // Send Admin Notification
                            send_admin_notification('admin-hcp-shift-completed', 'admin', $shift->id);
                            send_admin_notification('facility-hcp-shift-completed', 'facility', $shift->id, null, $shift->facility_id);
                            //------------------------

                            Log::channel('cronlog')->info("shift id: ". $shift->shift_prefix.$shift->id.' completed');
                            Log::channel('cronlog')->info("shift end cron completed");
                            Log::channel('cronlog')->info("-----------------------");
                        }
                    }

                }

                DB::commit();

            } catch (\Exception $e) {
                Log::channel('cronlog')->info("-----------------------");
                Log::channel('cronlog')->error('shift end cron error: '.$e->getMessage());
                Log::channel('cronlog')->info("-----------------------");
            }

            // Update cron status to completed
            $cronJob->status = 0;
            $cronJob->end_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('shift end cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
    }
}
