<?php

namespace App\Console\Commands\ShiftCrons;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Carbon;
use App\Jobs\AdminPanel\SendEmailJob;
use App\Interfaces\ShiftInterface;
use App\Interfaces\ShiftActivityInterface;
use App\Models\CronJob;
use Mail;

class ShiftReminderCron extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'shiftReminderCron:cron';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Hcp shift reminder cron';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(ShiftInterface $shift, ShiftActivityInterface $shiftActivity)
    {
        parent::__construct();
        $this->shift = $shift;
        $this->shift_activity = $shiftActivity;
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/shift-cron.log')]);

        $shiftUpdate = null;
        $shiftActivity = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'shift-reminder-cron')->where('status', 0)->first();
        //----------------

        if (!empty($cronJob)) {
            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

            DB::beginTransaction();
            try {

                // General Configuration
                $generalConfiguration = get_general_configuration();
                //----------------------

                // Get Shifts
                $shiftWhere = ['shift_status' => '1'];
                $shifts = $this->shift->get_shift_for_cron($shiftWhere);
                //-----------

                if(count($shifts)){
                    foreach($shifts as $shift){
                        // Set time zone
                        date_default_timezone_set($shift->state->time_zone_name);
                        //--------------

                        // Current date
                        $currentDate = Carbon::now($shift->state->time_zone_name)->toDateString();
                        $currentTime = Carbon::now($shift->state->time_zone_name);
                        //-------------

                        $shiftTime = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subMinutes(10);
                        $reminderTime = Carbon::parse($shift->start_time)
                                        ->setTimezone($shift->state->time_zone_name)
                                        ->subMinutes($generalConfiguration['reminder_job_in_minutes']);
                        $shiftTime2 = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subMinutes(5);

                        if (strtotime($currentTime) >= strtotime($reminderTime) && strtotime($currentTime) <= strtotime($shiftTime) && $shift->reminder_notification_sent_count == 0) {
                            $this->shift->update(['reminder_notification_sent_count' => 1], ['id' => $shift->id]);

                            send_shift_push_notification($shift['id'], 'shift-reminder', $shift['hcp_id']);

                            Log::channel('cronlog')->info("-----------------------");
                            Log::channel('cronlog')->info("shift reminder time: ".$reminderTime);
                            Log::channel('cronlog')->info("shift reminder notification sent");
                            Log::channel('cronlog')->info("-----------------------");
                        } else if(strtotime($currentTime) >= strtotime($shiftTime2) && $shift->reminder_notification_sent_count < 2) {
                            $this->shift->update(['reminder_notification_sent_count' => 2], ['id' => $shift->id]);
                            send_shift_push_notification($shift['id'], 'shift-reminder', $shift['hcp_id']);

                            Log::channel('cronlog')->info("-----------------------");
                            Log::channel('cronlog')->info("shift reminder time: ".$reminderTime);
                            Log::channel('cronlog')->info("shift reminder notification sent");
                            Log::channel('cronlog')->info("-----------------------");
                        }

                        //     if ($shift->reminder_notification_sent_count < 2) {
                        //         if ($shift->reminder_notification_sent_count == 0) {
                        //             $reminderTime = Carbon::parse($shift->start_time)
                        //                             ->setTimezone($shift->state->time_zone_name)
                        //                             ->subMinutes($generalConfiguration['reminder_job_in_minutes']);
                        //         } else if ($shift->reminder_notification_sent_count == 1) {
                        //             $reminderTime = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subMinutes(5);
                        //         }

                        //         if(strtotime($currentTime) >= strtotime($reminderTime)) {
                        //             $this->shift->update(['reminder_notification_sent_count' => $shift->reminder_notification_sent_count+1], ['id' => $shift->id]);

                        //             send_shift_push_notification($shift['id'], 'shift-reminder', $shift['hcp_id']);

                        //             Log::channel('cronlog')->info("-----------------------");
                        //             Log::channel('cronlog')->info("shift reminder time: ".$reminderTime);
                        //             Log::channel('cronlog')->info("shift reminder notification sent");
                        //             Log::channel('cronlog')->info("-----------------------");
                        //         }
                        //     }

                        if(strtotime($currentTime) >= strtotime(Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->addMinutes(5)) && $shift->time_over_notification_sent == 'no') {
                            Log::channel('cronlog')->info("-----------------------");

                            send_shift_push_notification($shift->id, 'hcp-shift-start-time-over', $shift->hcp_id);
                            send_admin_notification('facility-shift-start-time-over', 'facility', $shift->id, null, $shift->facility_id);
                            send_admin_notification('admin-shift-start-time-over', 'admin', $shift->id);

                            $this->shift->update(['time_over_notification_sent' => 'yes'], ['id' => $shift->id]);

                            Log::channel('cronlog')->info("shift start time over notification sent");
                            Log::channel('cronlog')->info("-----------------------");
                        }
                    }
                }

                DB::commit();

            } catch (\Exception $e) {
                Log::channel('cronlog')->info("-----------------------");
                Log::channel('cronlog')->error("shift reminder error: ".$e->getMessage());
                Log::channel('cronlog')->info("-----------------------");
            }

            // Update cron status to completed
            $cronJob->status = 0;
            $cronJob->end_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('shift reminder cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
    }
}
