<?php

namespace App\Console;

use Illuminate\Console\Scheduling\Schedule;
use Illuminate\Foundation\Console\Kernel as ConsoleKernel;

class Kernel extends ConsoleKernel
{
    /**
     * The Artisan commands provided by your application.
     *
     * @var array
     */
    protected $commands = [
        Commands\DocumentExpiryCron\DocumentExpiryNotificationCron::class,
        Commands\DocumentExpiryCron\DocumentExpiryCron::class,
        Commands\ShiftCrons\ShiftStartCron::class,
        Commands\ShiftCrons\ShiftEndCron::class,
        Commands\ShiftCrons\ShiftReminderCron::class,
        Commands\ShiftCrons\ShiftBroadcastCron::class,
        Commands\CreateRepositoryCommand::class,
        Commands\CreateInterfaceCommand::class,
        Commands\CreateServiceCommand::class,
        Commands\CreateServiceCommand::class,
        Commands\FacilityPlanCron\PlanExpiryNotificationCron::class,
        Commands\FacilityPlanCron\PlanExpiryCron::class,
        Commands\ShiftCrons\ShiftCancelCron::class,
        Commands\GenerateInvoiceCrons\GenerateFacilityInvoiceCron::class,
        Commands\GenerateInvoiceCrons\GenerateHcpInvoiceCron::class,
        Commands\GenerateInvoiceCrons\InvoiceOverdueCron::class,
        Commands\Others\UpdateCronStatus::class,
    ];

    /**
     * Define the application's command schedule.
     *
     * @param  \Illuminate\Console\Scheduling\Schedule  $schedule
     * @return void
     */
    protected function schedule(Schedule $schedule)
    {
        // Shift start (2 every mint)
        $schedule->command('shiftStartCron:cron')->everyTwoMinutes();
        //-------------------------

        // Shift end (every mint)
        $schedule->command('shiftEndCron:cron')->everyMinute();
        //-----------------------

        // Shift reminder (every mint)
        $schedule->command('shiftReminderCron:cron')->everyTwoMinutes();
        //----------------------------

        // Shift broadcast (every mint)
        $schedule->command('shiftBroadcastCron:cron')->everyMinute();
        //-----------------------------

        // Shift cancel (every mint)
        $schedule->command('shiftCancelCron:cron')->everyMinute();
        //--------------------------

        // Generate Invoice Every Monday
        // $schedule->command('generateFacilityInvoiceCron:cron')->wednesdays()->at('00:05')->timezone('Australia/Perth');
        // $schedule->command('generateHcpInvoiceCron:cron')->wednesdays()->at('00:10')->timezone('Australia/Perth');

        // $schedule->command('generateFacilityInvoiceCron:cron')->fridays()->at('00:05')->timezone('Australia/Perth');
        // $schedule->command('generateHcpInvoiceCron:cron')->fridays()->at('00:15')->timezone('Australia/Perth');

        // Generate Invoice Every Day
        $schedule->command('generateFacilityInvoiceCron:cron')->dailyAt('00:05')->timezone('Australia/Perth');
        $schedule->command('generateHcpInvoiceCron:cron')->dailyAt('00:15')->timezone('Australia/Perth');
        $schedule->command('invoiceOverdueCron:cron')->dailyAt('00:25')->timezone('Australia/Perth');
        //----------------------------

        // Plan Expiry Notification Cron
        $schedule->command('PlanExpiryNotificationCron:cron')->dailyAt('00:30')->timezone('Australia/Perth');
        $schedule->command('PlanExpiryCron:cron')->dailyAt('00:35')->timezone('Australia/Perth');
        //-------------------------------

        // Document expiry notification (every day)
        $schedule->command('documentExpiryNotification:cron')->dailyAt('09:00')->timezone('Australia/Perth');
        //-----------------------------------------

        // Document expiry (every day)
        $schedule->command('documentExpiryCron:cron')->dailyAt('09:20')->timezone('Australia/Perth');
        //----------------------------

        // Updte cron status
        $schedule->command('updateCronStatus:cron')->dailyAt('03:00')->timezone('Australia/Perth');
        //-------------------

    }

    /**
     * Register the commands for the application.
     *
     * @return void
     */
    protected function commands()
    {
        $this->load(__DIR__.'/Commands');

        require base_path('routes/console.php');
    }

}
