<?php

namespace App\Exports;

use App\Models\Facility;
use App\Interfaces\ShiftInterface;
use App\Interfaces\BuddyShiftRequestInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class BuddyShiftExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(BuddyShiftRequestInterface $buddyShiftRequest, $where, $request)
    {
        $this->buddy_shift_request = $buddyShiftRequest;
        $this->request = $request ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $status = '';
        $this->request['request']['shift_export'] = $this->request['shift_export'];

        $buddyShiftRequests = $this->buddy_shift_request->getAll($this->where, true, $this->request['request']);

        if (!empty($buddyShiftRequests)) {
            foreach ($buddyShiftRequests as $buddyShiftRequest)
            {
                if($buddyShiftRequest->status == 'requested') {
                    $status = 'Requested';
                } else if ($buddyShiftRequest->status == 'completed') {
                    $status = 'Completed';
                } else if ($buddyShiftRequest->status == 'cancelled') {
                    $status = 'Cancelled';
                } else if ($buddyShiftRequest->status == 'pending') {
                    $status = 'Pending';
                } else if ($buddyShiftRequest->status == 'scheduled') {
                    $status = 'Scheduled';
                } else if ($buddyShiftRequest->status == 'approved') {
                    $status = 'Approved';
                }

                $output[] = [
                    $buddyShiftRequest->shift ? $buddyShiftRequest->shift->shift_prefix.$buddyShiftRequest->shift->id : 'N/A',
                    $buddyShiftRequest->buddy_hcp->hcp_prefix.$buddyShiftRequest->buddy_hcp->id,
                    $buddyShiftRequest->buddy_hcp ? ucwords($buddyShiftRequest->buddy_hcp->first_name.' '.$buddyShiftRequest->buddy_hcp->last_name) : 'N/A',
                    $buddyShiftRequest->category ? ucwords($buddyShiftRequest->category->name) : 'N/A',
                    $buddyShiftRequest->profession ? ucwords($buddyShiftRequest->profession->name) : 'N/A',
                    $buddyShiftRequest->level ? ucwords($buddyShiftRequest->level->name) : 'N/A',
                    date("d M Y", strtotime($buddyShiftRequest->created_at)),
                    $buddyShiftRequest->shift ? ucwords($buddyShiftRequest->shift->facility->name) : 'N/A',
                    $buddyShiftRequest->shift ? ucwords($buddyShiftRequest->shift->facility->suburb_name) : 'N/A',
                    $buddyShiftRequest->shift ? ucwords($buddyShiftRequest->shift->facility->state->short_form) : 'N/A',
                    $buddyShiftRequest->shift ? ucwords($buddyShiftRequest->shift->facility->address) : 'N/A',
                    $status
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Shift ID',
            'HCP ID',
            'HCP Name',
            'Category',
            'Profession',
            'Level',
            'Request Date',
            'Facility Name',
            'Suburb',
            'State',
            'Address',
            'Status'
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
