<?php

namespace App\Exports;

use App\Interfaces\CategoryInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class CategoryExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(CategoryInterface $category, $where, $request)
    {
        $this->category = $category;
        $this->request = $request ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];

        $categories = $this->category->get_category_with_pagination($this->where, true, $this->request);

        if (!empty($categories)) {
            foreach ($categories as $category)
            {
                $output[] = [
                    $category->category_prefix.$category->id,
                    ucwords($category->name),
                    $category->comments ?? 'N/A',
                    $category->status ?? ucwords(str_replace("-", " ", $category->status)) ,
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Category ID',
            'Name',
            'Comment',
            'Status'
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
