<?php

namespace App\Exports;

use App\Interfaces\DocumentInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class DocumentsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
    public function __construct(DocumentInterface $document, $where, $request)
    {
        $this->document = $document;
        $this->request = $request['request'] ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $documents = $this->document->get($this->where, true, $this->request);
        if (!empty($documents)) {
            foreach ($documents as $document)
            {
                $output[] = [
                    $document->document_prefix.$document->id,
                    ucwords($document->name),
                    ucwords($document->required_for) ?? 'N/A',
                    ucwords($document->mandatory_status) ?? 'N/A',
                    ucwords($document->expiry_date_mandatory) ?? 'N/A',
                    $document->doc_type ? ucwords(str_replace('-', ' ',$document->doc_type)) : 'N/A',
                    $document->status ?? ucwords(str_replace("-", " ", $document->status)) ,
                ];
            }
        }

        return collect($output);
    }

    public function headings(): array
    {
        return [
            'Document ID',
            'Document Name',
            'Required For',
            'Mandatory Status',
            'Expiry Date',
            'Document Type',
            'Status'
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
