<?php

namespace App\Exports;

use App\Interfaces\DocumentHcpInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class ExpiringDocExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(DocumentHcpInterface $documentHcp, $request)
    {
        $this->documentHcp = $documentHcp;
        $this->request = $request['request'] ?? null;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $expiringDocuments = $this->documentHcp->get_expiring_documents($this->request);

        if (!empty($expiringDocuments)) {
            foreach ($expiringDocuments as $expiringDocument)
            {
                $output[] = [
                    $expiringDocument->hcp['hcp_prefix'] . $expiringDocument->hcp_id,
                    ucwords($expiringDocument->hcp['first_name']. ' ' . $expiringDocument->hcp['last_name']),
                    $expiringDocument->hcp['user']->email,
                    $expiringDocument->hcp['contact_number'] ?? 'N/A',
                    $expiringDocument->document['name'],
                    $expiringDocument->expiry_date ? date("d F Y", strtotime($expiringDocument->expiry_date)) : '',
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Hcp ID',
            'Hcp',
            'Hcp Email',
            'Hcp Contact No',
            'Document Name',
            'Expiry Date',
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
