<?php

namespace App\Exports;

use App\Models\Facility;
use App\Interfaces\FacilityInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class FacilitiesExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(FacilityInterface $facility, $where, $request)
    {
        $this->facility = $facility;
        $this->request = $request['request'] ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $facilities = $this->facility->get_facility_with_pagination($this->where, $this->request);

        if (!empty($facilities)) {
            foreach ($facilities as $facility)
            {

                $output[] = [
                    $facility->facility_prefix.$facility->id,
                    ucwords($facility->name),
                    $facility->address ?? 'N/A',
                    $facility->suburb_name ?? 'N/A',
                    $facility->state ? $facility->state->short_form : 'N/A',
                    $facility->user->email,
                    count($facility->plans) ? $facility->plans[0]->name : 'N/A',
                    count($facility->plans) ? ucwords(str_replace("_", " ", $facility->plans[0]->pivot->plan_cycle)) : 'N/A',
                    count($facility->plans) ? $facility->plans[0]->pivot->expiry_date : 'N/A',
                    $facility->status ?? ucwords(str_replace("-", " ", $facility->status)) ,
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Facility ID',
            'Name',
            'Address',
            'Suburb',
            'State',
            'Email',
            'Plan Type',
            'Plan Cycle',
            'Subs. End Date',
            'Status'
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
