<?php

namespace App\Exports;

use App\Interfaces\FacilityGroupInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class FacilitiesGroupsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(FacilityGroupInterface $facilityGroup, $where, $request)
    {
        $this->facility_group = $facilityGroup;
        $this->request = $request ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];

        $facilityGroups = $this->facility_group->getAll($this->where, true, $this->request);

        if (!empty($facilityGroups)) {
            foreach ($facilityGroups as $facilityGroup)
            {
                $output[] = [
                    $facilityGroup->facility_group_prefix . $facilityGroup->id,
                    ucwords($facilityGroup->name),
                    $facilityGroup->facilities_count ?? 'N/A',
                    $facilityGroup->status ?? ucwords(str_replace("-", " ", $facilityGroup->status)) ,
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Group ID',
            'Group Name',
            'Number of Hospitals',
            'Status'
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
