<?php

namespace App\Exports;

use App\Interfaces\FacilityNameInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class FacilitiesNameExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(FacilityNameInterface $facilityName, $where, $request)
    {
        $this->facility_name = $facilityName;
        $this->request = $request ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];

        $facilityNames = $this->facility_name->getAll($this->where, true, $this->request);

        if (!empty($facilityNames)) {
            foreach ($facilityNames as $facilityName)
            {
                $output[] = [
                    $facilityName->facility_name_prefix.$facilityName->id,
                    $facilityName->facility_group ? ucwords($facilityName->facility_group->name) : 'N/A',
                    ucwords($facilityName->name),
                    $facilityName->address ?? 'N/A',
                    $facilityName->suburb_name ?? 'N/A',
                    $facilityName->state ? $facilityName->state->short_form : 'N/A',
                    $facilityName->status ?? ucwords(str_replace("-", " ", $facilityName->status)) ,
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Facility Name ID',
            'Facility Group Name',
            'Name',
            'Address',
            'Suburb',
            'State',
            'Status'
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
