<?php

namespace App\Exports;

use App\Interfaces\DocumentInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class FacilityDocumentsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
    public function __construct(DocumentInterface $document, $where, $request, $id)
    {
        $this->document = $document;
        $this->request = $request['request'] ?? null;
        $this->where = $where;
        $this->id = $id;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $documents = $this->document->get_documents_facility_with_pagination($this->where, $this->id, $this->request);
        if (!empty($documents)) {
            foreach ($documents as $document)
            {
                $output[] = [
                    $document->document_prefix.$document->id,
                    ucwords($document->name),
                    $document->facility_document->expiry_date ? date("d F Y", strtotime($document->facility_document->expiry_date)) : 'N/A',
                    $document->status ?? ucwords(str_replace("-", " ", $document->status)) ,
                ];
            }
        }

        return collect($output);
    }

    public function headings(): array
    {
        return [
            'Document ID',
            'Document Name',
            'Expiry Date',
            'Status'
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
