<?php

namespace App\Exports;

use App\Interfaces\HcpInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class FacilityHcpExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(HcpInterface $hcp, $where, $request, $facility, $type)
    {
        $this->hcp = $hcp;
        $this->where = $where;
        $this->request = $request['request'] ?? null;
        $this->facility = $facility;
        $this->type = $type;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $hcps = $this->hcp->get_hcp_marked_by_facility($this->where, $this->request, $this->facility, $this->type);

        if (!empty($hcps)) {
            foreach ($hcps as $hcp)
            {
                $output[] = [
                    $hcp->hcp_prefix.$hcp->id,
                    ucwords($hcp->first_name.' '.$hcp->last_name),
                    $hcp->hcp_professions ? $hcp->hcp_professions[0]['category']['name'] : 'N/A',
                    $hcp->hcp_professions ? $hcp->hcp_professions[0]['profession']['name'] : 'N/A',
                    $hcp->contact_number ?? 'N/A',
                    $hcp->user->email ?? 'N/A',
                    $hcp->suburb_name ?? 'N/A',
                    $hcp->state ? $hcp->state->short_form : 'N/A',
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Hcp ID',
            'Name',
            'Category',
            'Profession',
            'Contact Number',
            'Email',
            'Suburb',
            'State',
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
