<?php

namespace App\Exports;

use App\Interfaces\RatingReviewInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class FacilityRatingsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(RatingReviewInterface $ratingReview, $request)
    {
        $this->ratingReview = $ratingReview;
        $this->request = $request['request'] ?? null;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $ratings = $this->ratingReview->get_facility_ratings($this->request);

        if (!empty($ratings)) {
            foreach ($ratings as $rating)
            {
                $output[] = [
                    $rating->shift->shift_prefix . $rating->shift_id,
                    ucwords($rating->facility->name),
                    $rating['hcp'] ? ucwords($rating['hcp']->first_name.' '.$rating['hcp']->last_name) : '',
                    $rating->facility_rating,
                    ucwords($rating->profession->name),
                    ucwords($rating->category->name),
                    date("d M Y H:i", strtotime($rating->date_time)),
                    ucwords($rating->comment),
                    ucwords($rating->status),
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Shift ID',
            'Facility',
            'Hcp',
            'Rating By Hcp',
            'Category',
            'Profession',
            'Date & Time',
            'Comments',
            'Status',
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
