<?php

namespace App\Exports;

use App\Interfaces\HcpInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;
use App\Interfaces\TransactionInterface;

class FacilitySubscriptionExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(TransactionInterface $transaction, $where, $request)
    {
        $this->transaction = $transaction;
        $this->where = $where;
        $this->request = $request['request'] ?? null;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $transactions = $this->transaction->get_subscription_transactions_with_pagination($this->where, $this->request);

        $status = '';
        $planDetails = '';
        $subscription = null;
        if (!empty($transactions)) {
            foreach ($transactions as $transaction)
            {
                if (!empty($transaction->facility_plan) && $transaction->facility_plan['plan_id'] != 4) {
                    $stripe = new \Stripe\StripeClient(env('STRIPE_SECRET'));
                    $subscription = $stripe->subscriptions->retrieve(
                        $transaction->facility_plan['stripe_subscriptions_id'],
                        []
                    );
                } else {
                    $subscription = null;
                }

                if (!is_null($subscription)) {
                   $nextDate = date("d M, Y", $subscription['current_period_end']);
                } else {
                    $nextDate = 'N/A';
                }

                $planDetails = json_decode($transaction->facility_plan_json, true);
                if ($transaction->status == 'completed') {
                    $status = __("language.account_status_completed");
                } else if ($transaction->status == 'pending') {
                    $status = __("language.account_status_pending");
                } else if ($transaction == 'cancelled') {
                    $status = __("language.account_status_cancelled");
                }
                $output[] = [
                    $transaction->invoice_prefix.$transaction->invoice_id,
                    ucwords($planDetails['name']),
                    ucwords($planDetails['plan_cycle']),
                    $nextDate,
                    date("d M, Y", strtotime($transaction->created_at)) ,
                    '$'.$transaction->total_facility_amount,
                    $status,
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Invoice Id',
            'Plan Name',
            'Plan Cycle',
            'Expiry Date',
            'Purchased Date',
            'Amount',
            'Status',
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
