<?php

namespace App\Exports;

use App\Models\Transaction;
use App\Interfaces\TransactionInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class FacilityTransactionDetailsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
	protected $filter;
	public function __construct(TransactionInterface $transaction, $request)
    {
        $this->transaction = $transaction;
        $this->filter = $request;
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {

        if(isset($this->filter['request'])) {
            $requestArr = $this->filter['request'];
        } else {
            $requestArr = $this->filter;
        }

        $details = $this->transaction->get_transaction_details($requestArr);
        $output = [];

        if (isset($this->filter['facility_export']) && !empty($this->filter['facility_export'])) {
            $status = '';
            $mentorName = '';
            $mentorHcp = '';
            $trainneName = '';
            $trainneBuddyShiftId = '';
            $loadingPay = '';
            foreach ($details as $detail) {
                if (is_numeric($detail['shift']->shift_loading)) {
                    $loadingPay = ($detail['shift']->shift_loading*($detail['shift']->facility_per_rate/100))*$detail['shift']->working_hours;
                } else {
                    $loadingPay = 0;
                }

                if ($detail->status == 'completed') {
                    $status = __("language.account_status_completed");
                } else if ($detail->invoice_id != '' && $detail->status == 'pending') {
                    $status = __("language.account_status_invoiced");
                }  else if ($detail->status == 'pending') {
                    $status = __("language.account_status_approved");
                } else if ($detail->status == 'cancelled') {
                    $status = __("language.account_status_cancelled");
                } else if ($detail->status == 'overdue') {
                    $status = __("language.account_status_overdue");
                }

                if(!empty($detail['shift']->mentor_hcp_name) && $detail['shift']->shift_type == 'buddy'){
                    $mentorName = ucwords($detail['shift']->mentor_hcp_name);
                    $mentorHcp = $detail['shift']->mentor_hcp_id ? '#HCP'.$detail['shift']->mentor_hcp_id : '';
                } else {
                    $mentorName = '';
                    $mentorHcp = '';
                }

                if(!empty($detail['shift']->trainee_hcp_name) && $detail['shift']->shift_type != 'buddy'){
                    $trainneName = ucwords($detail['shift']->trainee_hcp_name);
                    $trainneBuddyShiftId = '#SFI'.$detail['shift']->trainee_buddy_shift_id;
                } else {
                    $trainneName = '';
                    $trainneBuddyShiftId = '';
                }

                $output[] = [
                    $detail['shift']->shift_prefix.$detail['shift']->id,
                    date("d M, Y", strtotime($detail['shift']->created_at)),
                    ucwords($detail['shift']->shift_type),
                    ucwords($detail['shift']->category->name),
                    ucwords($detail['shift']->profession->name),
                    $detail['shift']->level ? ucwords($detail['shift']->level->name) : 'N/A',
                    $detail['shift']['facility']->name,
                    $detail['shift']['hcp']->first_name.' '.$detail['shift']['hcp']->last_name,
                    $mentorName,
                    $mentorHcp,
                    $trainneName,
                    $trainneBuddyShiftId,
                    date("d M, Y H:i:A", strtotime($detail['shift']->approved_shift_start_time)),
                    date("d M, Y H:i:A", strtotime($detail['shift']->approved_shift_end_time)),
                    $detail['shift']->working_hours.'Hrs',
                    '$'.$detail['shift']->facility_per_rate,
                    '$'.$detail['shift']->facility_per_rate*$detail['shift']->working_hours,
                    $detail['shift']->shift_loading.'%',
                    '$'.$loadingPay,
                    '$'.$detail['shift']->facility_amount,
                    date("d M, Y", strtotime($detail['shift']->shift_approved_time)),
                    $detail->invoice_id ? $detail->invoice_prefix.$detail->invoice_id : '----',
                    $detail->invoice_created_at ? date("d M, Y", strtotime($detail->invoice_created_at)) : '----',
                    $detail->paid_on ? date("d M, Y", strtotime($detail->paid_on)) : '----',
                    $status
                ];
            }

        } else {
            $status = '';
            $mentorName = '';
            $mentorHcp = '';
            $trainneName = '';
            $trainneBuddyShiftId = '';
            $loadingPay = '';
            foreach ($details as $detail) {
                if (is_numeric($detail['shift']->shift_loading)) {
                    $loadingPay = ($detail['shift']->shift_loading*($detail['shift']->facility_per_rate/100))*$detail['shift']->working_hours;
                } else {
                    $loadingPay = 0;
                }

                if(!empty($detail['shift']->mentor_hcp_name) && $detail['shift']->shift_type == 'buddy'){
                    $mentorName = ucwords($detail['shift']->mentor_hcp_name);
                    $mentorHcp = $detail['shift']->mentor_hcp_id ? '#HCP'.$detail['shift']->mentor_hcp_id : '';
                } else {
                    $mentorName = '';
                    $mentorHcp = '';
                }

                if(!empty($detail['shift']->trainee_hcp_name) && $detail['shift']->shift_type != 'buddy'){
                    $trainneName = ucwords($detail['shift']->trainee_hcp_name);
                    $trainneBuddyShiftId = '#SFI'.$detail['shift']->trainee_buddy_shift_id;
                } else {
                    $trainneName = '';
                    $trainneBuddyShiftId = '';
                }

                if ($detail->status == 'completed') {
                    $status = __("language.account_status_completed");
                } else if ($detail->invoice_id != '' && $detail->status == 'pending') {
                    $status = __("language.account_status_invoiced");
                }  else if ($detail->status == 'pending') {
                    $status = __("language.account_status_approved");
                } else if ($detail->status == 'cancelled') {
                    $status = __("language.account_status_cancelled");
                } else if ($detail->status == 'overdue') {
                    $status = __("language.account_status_overdue");
                }

                $output[] = [
                    $detail['shift']->shift_prefix.$detail['shift']->id,
                    date("d M, Y", strtotime($detail['shift']->created_at)),
                    ucwords($detail['shift']->shift_type),
                    ucwords($detail['shift']->category->name),
                    ucwords($detail['shift']->profession->name),
                    $detail['shift']->level ? ucwords($detail['shift']->level->name) : 'N/A',
                    $detail['shift']['facility']->name,
                    $detail['shift']['hcp']->first_name.' '.$detail['shift']['hcp']->last_name,
                    $mentorName,
                    $mentorHcp,
                    $trainneName,
                    $trainneBuddyShiftId,
                    date("d M, Y H:i:A", strtotime($detail['shift']->approved_shift_start_time)),
                    date("d M, Y H:i:A", strtotime($detail['shift']->approved_shift_end_time)),
                    $detail['shift']->working_hours.'Hrs',
                    '$'.$detail['shift']->facility_per_rate,
                    '$'.$detail['shift']->facility_per_rate*$detail['shift']->working_hours,
                    $detail['shift']->shift_loading.'%',
                    '$'.$loadingPay,
                    '$'.$detail['shift']->facility_amount,
                    date("d M, Y", strtotime($detail['shift']->shift_approved_time)),
                    $detail->invoice_id ? $detail->invoice_prefix.$detail->invoice_id : '----',
                    $detail->invoice_created_at ? date("d M, Y", strtotime($detail->invoice_created_at)) : '----',
                    $detail->paid_on ? date("d M, Y", strtotime($detail->paid_on)) : '----',
                    $status
                ];
            }
        }
        return collect($output);
    }

    public function headings(): array
    {
        $requestArr = $this->filter;
        if (isset($requestArr['facility_export']) && !empty($requestArr['facility_export'])) {
            return [
                'Shift ID',
                'Date',
                'Shift Type',
                'Category',
                'Profession',
                'Level',
                'Facility Name',
                'HCP Name',
                'Mentor Name',
                'Mentor HCP ID',
                'Trainne Name',
                'Trainne Buddy Shift ID',
                'Shift Start',
                'Shift End',
                'Hours',
                'Base Pay',
                'Base Rate',
                'Loading',
                'Loading Pay',
                'Total Pay',
                'Approve Date',
                'Invoice Id',
                'Invoice Date',
                'Paid Date',
                'Status',
            ];
        } else {
            return [
                'Shift ID',
                'Date',
                'Shift Type',
                'Category',
                'Profession',
                'Level',
                'Facility Name',
                'HCP Name',
                'Mentor Name',
                'Mentor HCP ID',
                'Trainne Name',
                'Trainne Buddy Shift ID',
                'Shift Start',
                'Shift End',
                'Hours',
                'Base Pay',
                'Base Rate',
                'Loading',
                'Loading Pay',
                'Total Pay',
                'Approve Date',
                'Invoice Id',
                'Invoice Date',
                'Paid Date',
                'Status',
            ];
        }
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
