<?php

namespace App\Exports;

use App\Models\Transaction;
use App\Interfaces\TransactionInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class FacilityTransactionExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
	protected $filter;
	public function __construct(TransactionInterface $transaction,$where,$request)
    {
        $this->transaction = $transaction;
        $this->filter = $request;
        $this->whereFilter = $where;
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        if(isset($this->filter['request'])) {
            $requestArr = $this->filter['request'];
        } else {
            $requestArr = $this->filter;
        }
        $whereArr = $this->whereFilter;

        $transactions = $this->transaction->get_facility_transactions_with_pagination($whereArr, $requestArr);
        $output = [];

        $status = '';
        if (isset($this->filter['facility_export']) && !empty($this->filter['facility_export'])) {
            foreach ($transactions as $transaction) {

                if ($transaction->status == 'completed') {
                    $status = __("language.account_status_completed");
                } else if ($transaction->invoice_id != '' && $transaction->status == 'pending') {
                    $status = __("language.account_status_invoiced");
                } else if ($transaction->status == 'pending') {
                    $status =  __("language.account_status_approved");
                } else if ($transaction->status == 'cancelled') {
                    $status = __("language.account_status_cancelled");
                } else if ($transaction->status == 'overdue') {
                    $status = __("language.account_status_overdue");
                }

                $output[] = [
                    $transaction->invoice_id ? $transaction->invoice_prefix.$transaction->invoice_id : '----',
                    $transaction->invoice_created_at ? date("d M, Y", strtotime($transaction->invoice_created_at)) : '----',
                    $transaction->invoice_overdue_date ? date('d M, Y', strtotime($transaction->invoice_overdue_date)) : '----',
                    (!empty($transaction->paid_on)?date("d M, Y", strtotime($transaction->paid_on)):'N/A'),
                    '$'.$transaction->total_facility_amount,
                    $status
                ];
            }
        } else {
            foreach ($transactions as $transaction){

                if ($transaction->status == 'completed') {
                    $status = __("language.account_status_completed");
                } else if ($transaction->invoice_id != '' && $transaction->status == 'pending') {
                    $status = __("language.account_status_invoiced");
                }  else if ($transaction->status == 'pending') {
                    $status =  __("language.account_status_approved");
                } else if ($transaction->status == 'cancelled') {
                    $status = __("language.account_status_cancelled");
                } else if ($transaction->status == 'overdue') {
                    $status = __("language.account_status_overdue");
                }

                $output[] = [
                    $transaction->invoice_id ? $transaction->invoice_prefix.$transaction->invoice_id : '----',
                    $transaction['facility']->name,
                    $transaction->invoice_created_at ? date("d M, Y", strtotime($transaction->invoice_created_at)) : '----',
                    $transaction->invoice_overdue_date ? date('d M, Y', strtotime($transaction->invoice_overdue_date)) : '----',
                    (!empty($transaction->paid_on)?date("d M, Y", strtotime($transaction->paid_on)):'N/A'),
                    '$'.$transaction->total_facility_amount,
                    (!empty($transaction->final_total_admin_fees_with_loadingfinal_total_admin_fees_with_loading)?'$'.$transaction->final_total_admin_fees_with_loading:'N/A'),
                    $status
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        if (isset($this->filter['facility_export']) && !empty($this->filter['facility_export'])) {
            return [
                'Invoice ID',
                'Invoice Date',
                'Due Date',
                'Paid Date',
                'Amount',
                'Status'
            ];
        } else {
            return [
                'Invoice ID',
                'Facility Name',
                'Invoice Date',
                'Due Date',
                'Paid Date',
                'Amount',
                'Admin Fees',
                'Status'
            ];
        }
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
