<?php

namespace App\Exports;

use App\Models\Transaction;
use App\Interfaces\TransactionInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class HcpTransactionDetailsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
	protected $filter;
	public function __construct(TransactionInterface $transaction, $request)
    {
        $this->transaction = $transaction;
        $this->filter = $request;
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {

        if(isset($this->filter['request'])) {
            $requestArr = $this->filter['request'];
        } else {
            $requestArr = $this->filter;
        }

        $details = $this->transaction->get_hcp_transaction_details($requestArr);
        $output = [];

        $status = '';
        $hcpStatus = '';
        $mentorName = '';
        $mentorHcp = '';
        $trainneName = '';
        $trainneBuddyShiftId = '';
        foreach ($details as $detail)
        {

            if ($detail->status == 'completed') {
                $status = __("language.account_status_completed");
            } else if ($detail->invoice_id != '' && $detail->status == 'pending') {
                $status = __("language.account_status_invoiced");
            }  else if ($detail->status == 'pending') {
                $status = __("language.account_status_approved");
            } else if ($detail == 'cancelled') {
                $status = __("language.account_status_cancelled");
            } else if ($detail == 'overdue') {
                $status = __("language.account_status_overdue");
            }

            if ($detail->hcp_payment_status == 'completed') {
                $hcpStatus = __("language.account_status_completed");
            } else if ($detail->statement_id != '' && $detail->hcp_payment_status == 'pending') {
                $hcpStatus = __("language.account_status_approved");
            }  else if ($detail->hcp_payment_status == 'pending') {
                $hcpStatus = __("language.account_status_approved");
            } else if ($detail->hcp_payment_status == 'cancelled') {
                $hcpStatus = __("language.account_status_cancelled");
            } else if ($detail->hcp_payment_status == 'overdue') {
                $hcpStatus = __("language.account_status_overdue");
            }

            if(!empty($detail['shift']->mentor_hcp_name) && $detail['shift']->shift_type == 'buddy'){
                $mentorName = ucwords($detail['shift']->mentor_hcp_name);
                $mentorHcp = $detail['shift']->mentor_hcp_id ? '#HCP'.$detail['shift']->mentor_hcp_id : '';
            } else {
                $mentorName = '';
                $mentorHcp = '';
            }

            if(!empty($detail['shift']->trainee_hcp_name) && $detail['shift']->shift_type != 'buddy'){
                $trainneName = ucwords($detail['shift']->trainee_hcp_name);
                $trainneBuddyShiftId = '#SFI'.$detail['shift']->trainee_buddy_shift_id;
            } else {
                $trainneName = '';
                $trainneBuddyShiftId = '';
            }

            $output[] = [
                $detail['shift']->shift_prefix.$detail['shift']->id,
                ucwords($detail['shift']->shift_type),
                ucwords($detail['shift']->category->name),
                ucwords($detail['shift']->profession->name),
                $detail['shift']->level ? ucwords($detail['shift']->level->name) : 'N/A',
                ucwords($detail['shift']['facility']->name),
                ucwords($detail['shift']['hcp']->first_name.' '.$detail['shift']['hcp']->last_name),
                $detail['shift']['hcp']->hcp_prefix.$detail['shift']['hcp']->id,
                $mentorName,
                $mentorHcp,
                $trainneName,
                $trainneBuddyShiftId,
                date("d M, Y h:i A", strtotime($detail['shift']->approved_shift_start_time)),
                date("d M, Y h:i A", strtotime($detail['shift']->approved_shift_end_time)),
                date("d M, Y", strtotime($detail['shift']->shift_approved_time)),
                $detail->invoice_prefix.$detail->invoice_id,
                $status,
                $detail['shift']->working_hours.'Hrs',
                '$'.$detail['shift']->hcp_per_rate,
                $detail['shift']->shift_loading.'%',
                '$'.number_format($detail['shift']->shift_loading*($detail['shift']->hcp_per_rate/100), 2),
                '$'.number_format($detail['shift']->hcp_amount, 2),
                ucwords($hcpStatus),
                $detail['shift']['hcp']->bsb_number ? $detail['shift']['hcp']->bsb_number : 'N/A',
                $detail['shift']['hcp']->account_number ? $detail['shift']['hcp']->account_number : 'N/A',
                $detail['shift']['hcp']->bank_name ? $detail['shift']['hcp']->bank_name : 'N/A',
                $detail['shift']['hcp']->superannuation_detail_membership_no ? $detail['shift']['hcp']->superannuation_detail_membership_no : 'N/A',
                $detail['shift']['hcp']->superannuation_detail_fund_name ? $detail['shift']['hcp']->superannuation_detail_fund_name : 'N/A',
                $detail['shift']['hcp']->state ? $detail['shift']['hcp']->state->short_form : 'N/A',
            ];
        }
        return collect($output);
    }

    public function headings(): array
    {
        return [
            'Shift ID',
            'Shift Type',
            'Category',
            'Profession',
            'Level',
            'Facility Name',
            'Hcp Name',
            'Hcp ID',
            'Mentor Name',
            'Mentor HCP ID',
            'Trainne Name',
            'Trainne Buddy Shift ID',
            'Shift Start',
            'Shift End',
            'Approved Date',
            'Facility Invoice Id',
            'Facility Invoice Status',
            'Hours',
            'Base Rate',
            'Loading',
            'Loading Pay',
            'Total Pay',
            'Hcp Status',
            'BSB',
            'Bank Account No',
            'Bank Name',
            'Superannuation No',
            'Fund Name',
            'State',
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:Z1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
