<?php

namespace App\Exports;

use App\Models\Transaction;
use App\Interfaces\TransactionInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class HcpTransactionExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
	protected $filter;
	public function __construct(TransactionInterface $transaction,$where,$request)
    {
        $this->transaction = $transaction;
        $this->filter = $request;
        $this->whereFilter = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $requestArr = $this->filter;
        $whereArr = $this->whereFilter;

        $transactions=$this->transaction->get_hcp_tranactions_with_pagination($whereArr, $requestArr['request']);
        $output = [];

	    foreach ($transactions as $transaction)
	    {
            if ($transaction->hcp_payment_status == 'completed') {
                $status = __("language.account_status_completed");
            } else if ($transaction->statement_id != '' && $transaction->hcp_payment_status == 'pending') {
                $status = __("language.account_status_approved");
            } else if ($transaction->hcp_payment_status == 'pending') {
                $status =  __("language.account_status_approved");
            } else if ($transaction->hcp_payment_status == 'cancelled') {
                $status = __("language.account_status_cancelled");
            } else if ($transaction->hcp_payment_status == 'overdue') {
                $status = __("language.account_status_overdue");
            } else {
                $status = '';
            }

            $output[] = [
                $transaction->statement_prefix.$transaction->statement_id,
                $transaction['hcp']->hcp_prefix.$transaction['hcp']->id,
                $transaction['hcp']->first_name.' '.$transaction['hcp']->last_name,
                $transaction->invoice_generated_date_range,
                $transaction['hcp']->account_number ? $transaction['hcp']->account_number : 'N/A',
                $transaction['hcp']->bank_name ? ucwords($transaction['hcp']->bank_name) : 'N/A',
                $transaction->hcp_paid_on ? date("d M, Y", strtotime($transaction->hcp_paid_on)) : 'N/A',
                '$'.$transaction->total_hcp_amount,
                $status
            ];
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Statement ID',
            'Hcp ID',
            'Hcp Name',
            'Statement Duration',
            'Hcp Account No',
            'Hcp Bank Name',
            'Hcp Paid Date',
            'Amount',
            'Status'
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
