<?php

namespace App\Exports;

use App\Interfaces\HcpInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class HcpsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(HcpInterface $hcp, $where, $request)
    {
        $this->hcp = $hcp;
        $this->where = $where;
        $this->request = $request['request'] ?? null;
        $this->request_all = $request ?? null;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $status = '';

        if(isset($this->where['status']) && $this->where['status'] == 'incomplete') {
            $this->where['status'] = 'pending-approval';
            $this->where[] = ['app_registration_screen', '!=', '0'];
        }
        $hcps = $this->hcp->get_hcp_with_pagination($this->where, $this->request);
        if (!empty($hcps)) {
            foreach ($hcps as $hcp)
            {
                if(!empty($this->request_all['hcp_list'])) {
                    $status = $hcp->status;
                }

                $output[] = [
                    $hcp->hcp_prefix.$hcp->id,
                    ucwords($hcp->first_name.' '.$hcp->last_name),
                    count($hcp->hcp_professions) ? $hcp->hcp_professions[0]['category']['name'] : 'N/A',
                    count($hcp->hcp_professions) ? $hcp->hcp_professions[0]['profession']['name'] : 'N/A',
                    $hcp->contact_number ?? 'N/A',
                    $hcp->user->email ?? 'N/A',
                    $hcp->suburb_name ?? 'N/A',
                    $hcp->state ? $hcp->state->short_form : 'N/A',
                    $status ?? 'N/A',
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        if(!empty($this->request_all['hcp_list'])) {
            return [
                'Hcp ID',
                'Name',
                'Category',
                'Profession',
                'Contact Number',
                'Email',
                'Suburb',
                'State',
                'Status',
            ];
        } else {
            return [
                'Hcp ID',
                'Name',
                'Category',
                'Profession',
                'Contact Number',
                'Email',
                'Suburb',
                'State',
            ];
        }
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
