<?php

namespace App\Exports;

use App\Interfaces\LevelInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class LevelExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(LevelInterface $level, $where, $request)
    {
        $this->level = $level;
        $this->request = $request ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];

        // General Configuration
        $generalConfiguration = get_general_configuration();
        $adminFees;
        //----------------------

        $levelsData = $this->level->get_level_with_pagination($this->where, true, $this->request);
        $adminFees = '';
        $facilityPerRate = '';
        if (!empty($levelsData)) {
            foreach ($levelsData as $level)
            {
                if (!empty($level->hcp_per_rate) && !empty($generalConfiguration['admin_fee'])){
                    $adminFees = '$'.number_format($generalConfiguration['admin_fee'], 2);
                } else {
                    $adminFees = 'N/A';
                }

                if (!empty($level->hcp_per_rate) && !empty($generalConfiguration['admin_fee'])){
                    $facilityPerRate = '$'.number_format($level->hcp_per_rate + $generalConfiguration['admin_fee'], 2);
                } else {
                    $facilityPerRate = 'N/A';
                }

                $output[] = [
                    $level->level_prefix.$level->id,
                    ucwords($level->name),
                    $level->category ? ucwords($level->category->name) : 'N/A',
                    $level->profession ? ucwords($level->profession->name) : 'N/A',
                    $level->hcp_per_rate ? '$'.$level->hcp_per_rate : 'N/A',
                    $adminFees,
                    $facilityPerRate,
                    $level->comments ? ucwords($level->comments) : 'N/A',
                    $level->status ?? ucwords(str_replace("-", " ", $level->status)) ,
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Level ID',
            'Level',
            'Category',
            'Profession',
            'Hcp Rate (Per Hour)',
            'Admin Fees',
            'Facility Rate (Per Hour)',
            'Comment',
            'Status'
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
