<?php

namespace App\Exports;

use App\Interfaces\ProfessionInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class ProfessionExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(ProfessionInterface $profession, $where, $request)
    {
        $this->profession = $profession;
        $this->request = $request ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];

        // General Configuration
        $generalConfiguration = get_general_configuration();
        $adminFees;
        //----------------------

        $professions = $this->profession->get_profession_with_pagination($this->where, $this->request);
        $levels = '';
        $adminFees = '';
        $facilityPerRate = '';

        if (!empty($professions)) {
            foreach ($professions as $profession)
            {
                if (count($profession->levels)) {
                    foreach ($profession->levels as $level) {
                        $levels .= ucwords($level->name).', ';
                    }
                } else {
                    $levels = '';
                }

                if (!empty($profession->hcp_per_rate) && !empty($generalConfiguration['admin_fee'])){
                    $adminFees = '$'.number_format($generalConfiguration['admin_fee'], 2);
                } else {
                    $adminFees = 'N/A';
                }

                if (!empty($profession->hcp_per_rate) && !empty($generalConfiguration['admin_fee'])){
                    $facilityPerRate = '$'.number_format($profession->hcp_per_rate + $generalConfiguration['admin_fee'], 2);
                } else {
                    $facilityPerRate = 'N/A';
                }

                $output[] = [
                    $profession->profession_prefix.$profession->id,
                    ucwords($profession->name),
                    $profession->category ? ucwords($profession->category->name) : 'N/A',
                    $profession->has_levels ? ucwords($profession->has_levels) : 'N/A',
                    $levels,
                    $profession->hcp_per_rate ? '$'.$profession->hcp_per_rate : 'N/A',
                    $adminFees,
                    $facilityPerRate,
                    $profession->comments ? ucwords($profession->comments) : 'N/A',
                    $profession->status ?? ucwords(str_replace("-", " ", $profession->status)) ,
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Profession ID',
            'Name',
            'Category',
            'Has Levels',
            'Levels',
            'Hcp Rate (Per Hour)',
            'Admin Fees',
            'Facility Rate (Per Hour)',
            'Comment',
            'Status'
        ];
    }


    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
