<?php

namespace App\Exports;

use App\Interfaces\HcpProfessionRequestInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class ProfessionPendingApprovalHcpExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(HcpProfessionRequestInterface $hcpProfessionRequest, $where, $request)
    {
        $this->hcp_profession_request = $hcpProfessionRequest;
        $this->where = $where;
        $this->request = $request['request'] ?? null;
        $this->request_all = $request ?? null;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $status = '';
        $levelUpdate = '';
        $hcpDocumentsName = '';
        $professionRequestType = '';

        $professionRequests = $this->hcp_profession_request->get_hcp_profession_requests_with_pagination($this->where, $this->request);
        if (!empty($professionRequests)) {
            foreach ($professionRequests as $professionRequest)
            {
                if($professionRequest->type == 'level-update'){
                    if (!empty($professionRequest->previous_level)) {
                        $levelUpdate .= 'Previous Level: '.ucwords($professionRequest->previous_level['name']);
                    }
                    if (!empty($professionRequest->level)) {
                        $levelUpdate .= ', New Level: '.ucwords($professionRequest->level['name']);
                    }
                }

                if($professionRequest->type == 'level-update'){
                    $hcpDocumentsName = '';
                    if (!empty($professionRequest->hcp_document_ids)) {
                        $hcpDocuments = get_hcp_doucments_by_ids($professionRequest->hcp_document_ids);
                        if (count($hcpDocuments)) {
                            foreach ($hcpDocuments as $hcpDocument) {
                                $hcpDocumentsName .= ucwords($hcpDocument->document['name']).', ';
                            }
                        }
                    }
                }

                if($professionRequest->type == 'document-expired'){
                    $professionRequestType = 'Profession Document Expired';
                } else if($professionRequest->type == 'level-update') {
                    $professionRequestType = 'Level Update';
                } else if($professionRequest->type == 'profession-added') {
                    $professionRequestType = 'New Profession Added';
                } else {
                    $professionRequestType = 'N/A';
                }

                if($professionRequest->status == 'approved'){
                    $status = __("language.table_hcp_profession_request_approve_status");
                } else if($professionRequest->status == 'pending') {
                    $status = __("language.table_hcp_profession_request_pending_status");
                } else if($professionRequest->status == 'rejected') {
                    $status = __("language.table_hcp_profession_request_reject_status");
                }

                $output[] = [
                    ucwords($professionRequest->hcp->first_name . ' ' . $professionRequest->hcp->last_name),
                    $professionRequest->hcp->user->email ?? 'N/A',
                    $professionRequest->hcp->contact_number ?? 'N/A',
                    $professionRequest->hcp->state ? $professionRequest->hcp->state->short_form : 'N/A',
                    $professionRequest->category ? $professionRequest->category['name'] : 'N/A',
                    $professionRequest->profession ? $professionRequest->profession['name'] : 'N/A',
                    $levelUpdate,
                    $hcpDocumentsName,
                    $professionRequestType,
                    $status,
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Name',
            'Email',
            'Contact Number',
            'State',
            'Category',
            'Profession',
            'Level',
            'Document Name',
            'Type',
            'Status',
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
