<?php

namespace App\Exports;

use App\Interfaces\PublicHolidayInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class PublicHolidayExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(PublicHolidayInterface $publicHoliday, $state, $request)
    {
        $this->public_holiday = $publicHoliday;
        $this->state = $state;
        $this->filter = $request;
        $this->request = $request['request'] ?? null;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {

        if (isset($this->filter['facility_export']) && !empty($this->filter['facility_export'])) {
            $output = [];
            $publicHolidays = $this->public_holiday->get_public_holiday_by_state_with_pagination([], $this->state, $this->request);

            if (!empty($publicHolidays)) {
                foreach ($publicHolidays as $publicHoliday)
                {
                    $output[] = [
                        ucwords($publicHoliday->name),
                        date("l dS F Y", strtotime($publicHoliday->holiday_date)),
                        ucwords($publicHoliday->status),
                    ];
                }
            }

            return collect($output);
        } else {
            $output = [];
            $publicHolidays = $this->public_holiday->getAll([], true, $this->request);

            if (!empty($publicHolidays)) {
                foreach ($publicHolidays as $publicHoliday)
                {
                    $output[] = [
                        ucwords($publicHoliday->name),
                        date("l dS F Y", strtotime($publicHoliday->holiday_date)),
                        ucwords($publicHoliday->status),
                    ];
                }
            }

            return collect($output);
        }

    }

    public function headings(): array
    {
        return [
            'Holiday Name',
            'Holiday Date',
            'Status',
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
