<?php

namespace App\Exports;

use App\Interfaces\DocumentHcpInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class RecentDocExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct($getDate, $currentDate, DocumentHcpInterface $documentHcp, $request)
    {
        $this->documentHcp = $documentHcp;
        $this->request = $request['request'] ?? null;
        $this->getDate = $getDate;
        $this->currentDate = $currentDate;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $recentDocuments = $this->documentHcp->get_last_submitted_documents($this->getDate, $this->currentDate, $this->request);

        if (!empty($recentDocuments)) {

            $status = '';
            foreach ($recentDocuments as $recentDocument)
            {
                if ($recentDocument->document_approval == 'approved') {
                    $status = __("language.document_approved");
                } else if ($recentDocument->document_approval == 'pending') {
                    $status = __("language.document_pending");
                } else if ($recentDocument->document_approval == 'pending-reapproval') {
                    $status = __("language.document_pending_approved");
                } else if ($recentDocument->document_approval == 'reapproved') {
                    $status = __("language.document_reapproved");
                }

                $output[] = [
                    $recentDocument->hcp['hcp_prefix'] . $recentDocument->hcp_id,
                    ucwords($recentDocument->hcp['first_name']. ' ' . $recentDocument->hcp['last_name']),
                    $recentDocument->hcp['user']->email,
                    $recentDocument->hcp['contact_number'] ?? 'N/A',
                    $recentDocument->document['name'],
                    $recentDocument->expiry_date ? date("d F Y", strtotime($recentDocument->expiry_date)) : '',
                    ucwords($status),
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Hcp ID',
            'Hcp',
            'Hcp Email',
            'Hcp Contact No',
            'Document Name',
            'Expiry Date',
            'Status',
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
