<?php

namespace App\Exports;

use App\Models\Transaction;
use App\Interfaces\TransactionInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class RevenueStatementExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
	protected $filter;
	public function __construct(TransactionInterface $transaction,$where,$request)
    {
        $this->transaction = $transaction;
        $this->filter = $request;
        $this->whereFilter = $where;
    }
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        if(isset($this->filter['request'])) {
            $requestArr = $this->filter['request'];
        } else {
            $requestArr = $this->filter;
        }

        $whereArr = $this->whereFilter;

        $transactions = $this->transaction->get_revenue_statement($whereArr, $requestArr);
        $output = [];

        $status = '';
        foreach ($transactions as $transaction){

            if ($transaction->status == 'completed') {
                $status = __("language.account_status_completed");
            } else if ($transaction->invoice_id != '' && $transaction->status == 'pending') {
                $status = __("language.account_status_invoiced");
            }  else if ($transaction->status == 'pending') {
                $status =  __("language.account_status_approved");
            } else if ($transaction == 'cancelled') {
                $status = __("language.account_status_cancelled");
            } else if ($transaction == 'overdue') {
                $status = __("language.account_status_overdue");
            }

            $output[] = [
                $transaction['facility']->name,
                $transaction['facility']->contact_number,
                $transaction->invoice_id ? $transaction->invoice_prefix.$transaction->invoice_id : '----',
                $transaction->invoice_created_at ? date("d M, Y", strtotime($transaction->invoice_created_at)) : '----',
                $transaction->invoice_overdue_date ? date('d M, Y', strtotime($transaction->invoice_overdue_date)) : '----',
                (!empty($transaction->paid_on)?date("d M, Y", strtotime($transaction->paid_on)):'N/A'),
                '$'.$transaction->total_facility_amount,
                (!empty($transaction->total_admin_fees_with_loading)?'$'.$transaction->total_admin_fees_with_loading:'N/A'),
            ];
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Facility Name',
            'Facility Contact No',
            'Invoice ID',
            'Invoice Date',
            'Due Date',
            'Paid Date',
            'Amount',
            'Admin Fees',
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
