<?php

namespace App\Exports;

use App\Models\Facility;
use App\Interfaces\ShiftInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class ShiftsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(ShiftInterface $shift, $where, $request)
    {
        $this->shift = $shift;
        $this->request = $request ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $status = '';
        $this->request['request']['status'] = $this->request['status'];
        $this->request['request']['shift_export'] = $this->request['shift_export'];

        $shifts = $this->shift->getAll($this->where, true, $this->request['request']);
        if (!empty($shifts)) {
            foreach ($shifts as $shift)
            {
                if($shift['shift_status'] == '0') {
                    $status = __("language.shift_status_pending");
                } else if ($shift['shift_status'] == '1') {
                    $status = __("language.shift_status_scheduled");
                } else if ($shift['shift_status'] == '2') {
                    $status = __("language.shift_status_running");
                } else if ($shift['shift_status'] == '3') {
                    $status = __("language.shift_status_cancelled");
                } else if ($shift['shift_status'] == '4') {
                    $status = __("language.shift_status_completed");
                } else if ($shift['shift_status'] == '5') {
                    $status = __("language.shift_status_transfered");
                } else if ($shift['shift_status'] == '6') {
                    $status = __("language.shift_status_past");
                }

                $output[] = [
                    $shift->shift_prefix.$shift->id,
                    date("d M Y", strtotime($shift->created_at)),
                    $shift->shift_type ? ucwords($shift->shift_type) : 'N/A',
                    $shift->category ? ucwords($shift->category->name) : 'N/A',
                    $shift->profession ? ucwords($shift->profession->name) : 'N/A',
                    $shift->level ? ucwords($shift->level->name) : 'N/A',
                    $shift->facility ? ucwords($shift->facility->name) : 'N/A',
                    $shift->hcp ? ucwords($shift->hcp->first_name.' '.$shift->hcp->last_name) : 'N/A',
                    $shift->word_wing,
                    date("d M", strtotime($shift->start_time)).' '.date("H:i", strtotime($shift->start_time)),
                    date("d M", strtotime($shift->end_time)).' '.date("H:i", strtotime($shift->end_time)),
                    $shift->hours.' Hrs',
                    $shift->facility ? ucwords($shift->facility->suburb_name) : 'N/A',
                    $shift->facility->state ? ucwords($shift->facility->state->short_form) : 'N/A',
                    $status
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Shift ID',
            'Date',
            'Shift Type',
            'Category',
            'Profession',
            'Level',
            'Facility Name',
            'Hcp Name',
            'Ward/Wing',
            'Shift Start',
            'Shift End',
            'Hours',
            'Suburb',
            'State',
            'Status'
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
