<?php

namespace App\Exports;

use App\Interfaces\SubAdminInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class SubAdminExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(SubAdminInterface $sub_admin, $request)
    {
        $this->sub_admin = $sub_admin;
        $this->request = $request['request'] ?? null;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $subAdmins = $this->sub_admin->getAll([], true, $this->request);
        $permissions = '';
        if (!empty($subAdmins)) {
            foreach ($subAdmins as $subAdmin)
            {
                if (!empty($subAdmin->user->getPermissionNames())) {
                    foreach ($subAdmin->user->getPermissionNames() as $permissions) {
                        $permissions .= ', '.$permissions;
                    }
                }
                $output[] = [
                    $subAdmin->sub_admin_prefix . $subAdmin->id,
                    ucwords($subAdmin->name),
                    date("d M Y", strtotime($subAdmin->created_at)),
                    $permissions,
                    $subAdmin->user->email,
                    $subAdmin->contact_number,
                    ucwords($subAdmin->status),
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Sub Admin ID',
            'Name',
            'Added On',
            'Permissions Granted',
            'Email',
            'Contact Number',
            'Status',
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
