<?php

namespace App\Exports;

use App\Models\Facility;
use App\Interfaces\ShiftInterface;
use App\Interfaces\ShiftTransferInterface;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use DB;

class TransferredShiftsExport implements FromCollection, WithHeadings, ShouldAutoSize, WithEvents
{
    protected $request;
	public function __construct(ShiftTransferInterface $shiftTransfer, $where, $request)
    {
        $this->shift_transfer = $shiftTransfer;
        $this->request = $request ?? null;
        $this->where = $where;
    }

    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $output = [];
        $status = '';
        $this->request['request']['shift_export'] = $this->request['shift_export'];

        $shiftTransfers = $this->shift_transfer->getAll($this->where, true, $this->request['request']);
        if (!empty($shiftTransfers)) {
            foreach ($shiftTransfers as $shiftTransfer)
            {
                if($shiftTransfer->status == 'accept') {
                    $status = 'Accepted';
                } else if ($shiftTransfer->status == 'reject') {
                    $status = 'Rejected';
                }else if ($shiftTransfer->status == 'cancelled') {
                    $status = 'Cancelled';
                } else if ($shiftTransfer->status == 'pending') {
                    $status = 'Pending';
                }

                $output[] = [
                    $shiftTransfer->shift->shift_prefix.$shiftTransfer->shift->id,
                    date("d M Y", strtotime($shiftTransfer->shift->created_at)),
                    $shiftTransfer->hcp ? ucwords($shiftTransfer->hcp->first_name.' '.$shiftTransfer->hcp->last_name) : 'N/A',
                    $shiftTransfer->transfer_hcp ? ucwords($shiftTransfer->transfer_hcp->first_name.' '.$shiftTransfer->transfer_hcp->last_name) : 'N/A',
                    $shiftTransfer->shift->shift_type ? ucwords($shiftTransfer->shift->shift_type) : 'N/A',
                    $shiftTransfer->shift->category ? ucwords($shiftTransfer->shift->category->name) : 'N/A',
                    $shiftTransfer->shift->profession ? ucwords($shiftTransfer->shift->profession->name) : 'N/A',
                    $shiftTransfer->shift->level ? ucwords($shiftTransfer->shift->level->name) : 'N/A',
                    $shiftTransfer->shift->facility ? ucwords($shiftTransfer->shift->facility->name) : 'N/A',
                    $shiftTransfer->shift->word_wing,
                    date("d M", strtotime($shiftTransfer->shift->start_time)).' '.date("H:i", strtotime($shiftTransfer->shift->start_time)),
                    date("d M", strtotime($shiftTransfer->shift->end_time)).' '.date("H:i", strtotime($shiftTransfer->shift->end_time)),
                    $shiftTransfer->shift->hours.' Hrs',
                    $shiftTransfer->shift->facility ? ucwords($shiftTransfer->shift->facility->suburb_name) : 'N/A',
                    $shiftTransfer->shift->facility->state ? ucwords($shiftTransfer->shift->facility->state->short_form) : 'N/A',
                    $status
                ];
            }
        }

	    return collect($output);
    }

    public function headings(): array
    {
        return [
            'Shift ID',
            'Date',
            'Transferred From',
            'Transferred To',
            'Shift Type',
            'Category',
            'Profession',
            'Level',
            'Facility Name',
            'Ward/Wing',
            'Shift Start',
            'Shift End',
            'Hours',
            'Suburb',
            'State',
            'Status'
        ];
    }

    /**
     * @return array
     */
    public function registerEvents(): array
    {
        return [
            AfterSheet::class    => function(AfterSheet $event) {
                $cellRange = 'A1:W1'; // All headers
                $style = [
                    //Set font style
                    'font' => [
                        'bold'      =>  true,
                    ],
                ];
                $event->sheet->getDelegate()->getStyle($cellRange)->applyFromArray($style);

            },
        ];
    }
}
