<?php

namespace App\Http\Controllers\API\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\API\Auth\Register;
use App\Http\Traits\GetUserData;
use App\Role;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;

class RegisterController extends Controller
{
    use GetUserData;

    /**
     * Create an controller instance.
     */
    public function __construct()
    {
        //
    }

    /**
     * Create an account.
     *
     * @param  Register  $request
     * @return \Illuminate\Http\Response|\Illuminate\Contracts\Routing\ResponseFactory
     */
    public function create(Register $request)
    {
        $token = null;
        $user = null;
        $one_time_password = null;

        DB::beginTransaction();

        try {
            // Store user
            if (!is_null($request['uuid_token'])) {
                $user = User::updateOrCreate([
                    'uuid' => $request['uuid_token'],
                    'email' => null,
                    'mobile_number' => null,
                    'social_id' => null,
                ], [
                    'name' => $request['name'],
                    'email' => $request['email'],
                    'mobile_number' => $request['mobile_number'],
                    'password' => bcrypt($request['password']),
                    'platform' => $request['platform'],
                    'uuid' => $request['uuid_token'],
                ]);
            } else {
                $user = User::create([
                    'name' => $request['name'],
                    'email' => $request['email'],
                    'mobile_number' => $request['mobile_number'],
                    'password' => bcrypt($request['password']),
                    'platform' => $request['platform'],
                ]);
            }
            //-----------

            // Get student role
            $role = Role::where([
                'type' => config('constants.users.types.STUDENT.value'),
                'status' => config('constants.statuses.ACTIVE.value'),
            ])->first();
            //-----------------

            // Assign student role to user
            if (!is_null($user) && !is_null($role)) {
                $user->assignRole($role->id);
            }
            //----------------------------

            // Store one time password
            /*
            $one_time_password = OneTimePassword::create([
            'user_id'           => $user->id,
            'one_time_password' => rand(100000, 999999),
            'type'              => config('constants.one_time_password_types.VERIFICATION.value'),
            'request_token'     => (string) Str::uuid(),
            'expires_at'        => Carbon::now()->addHours(24)
            ]);
            //------------------------
             */

            DB::commit();
        } catch (\Exception $e) {
            $user = null;
            $one_time_password = null;

            DB::rollBack();
        }

        if (!is_null($user)) {
            // Send email verification mail
            if (!is_null($one_time_password)) {
                $this->sendVerificationMail($user, $one_time_password);
            }
            //-----------------------------

            // Login user
            auth()->login($user);
            //-----------

            // Get token
            $token = auth()->user()->createToken(config('app.key'));
            //----------
        }

        // Set response
        if (!is_null($user) && !is_null($token)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.account_created'),
                '_data' => [
                    'access_token' => $token->accessToken,
                    'user' => $this->getUserAllData($user->fresh()),
                ],
            ];
        } else {
            $response = [
                '_status' => false,
                '_message' => __('messages.account_creation_failed'),
                '_data' => null,
            ];
        }

        return response()->json($response, 200);
    }

    /**
     * Send verification mail.
     *
     * @param      object  $user
     * @param      object  $one_time_password
     * @return     void
     * @created_at 25 July 2019
     */
    private function sendVerificationMail($user, $one_time_password)
    {
        // Set email data
        $emailData['message'] = __('messages.verification_mail_subject');
        $emailData['subject'] = __('messages.verification_mail_subject');
        $emailData['sender'] = __('messages.verification_mail_subject');
        $emailData['email'] = $user->email;
        $emailData['receiver'] = $user->name;
        $emailData['otp'] = $one_time_password->one_time_password;

        // Send email
        Mail::send('emails.verify-email-app', $emailData, function ($message) use ($emailData) {
            $message->to($emailData['email'], $emailData['receiver'])->subject($emailData['subject']);
        });
    }
}
