<?php

namespace App\Http\Controllers\API\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\API\Auth\ResetPassword;
use App\OneTimePassword;
use App\User;
use Illuminate\Foundation\Auth\ResetsPasswords;

class ResetPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset requests
    | and uses a simple trait to include this behavior. You're free to
    | explore this trait and override any methods you wish to tweak.
    |
     */

    use ResetsPasswords;

    /**
     * Where to redirect users after roldOtp->esetting their password.
     *
     * @var string
     */
    protected $redirectTo = '/home';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Reset password.
     *
     * @param  ResetPassword  $request
     * @return \Illuminate\Http\Response|\Illuminate\Contracts\Routing\ResponseFactory
     *
     * @author Sumit
     * @created_at 24 July 2019
     */
    public function resetPassword(ResetPassword $request)
    {
        $one_time_password = null;
        $password_updated = false;

        // Get one time password and user
        try {
            $one_time_password = OneTimePassword::with('user')
                ->where([
                    'request_token' => $request['request_token'],
                    'one_time_password' => $request['one_time_password'],
                ])
                ->first();
        } catch (\Exception $e) {
            $one_time_password = null;
        }
        //-------------------------------

        if (!is_null($one_time_password) && !is_null($one_time_password->user)) {
            if ($one_time_password->user->is_active) {
                // Update user password
                $password_updated = User::where('id', $one_time_password->user->id)->update([
                    'password' => bcrypt($request['password']),
                ]);
                //---------------------
            } else {
                // Set response
                $response = [
                    '_status' => false,
                    '_message' => __('messages.account_inactive'),
                    '_data' => null,
                ];
                //-------------
            }
        }

        if ($password_updated) {
            // Set response
            $response = [
                '_status' => true,
                '_message' => __('messages.user_password_reset'),
                '_data' => null,
            ];
            //-------------
        }

        return response()->json($response, 200);
    }
}
