<?php

namespace App\Http\Controllers\API\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\API\Auth\VerifyOTP;
use App\Http\Traits\GetUserData;
use App\OneTimePassword;
use App\User;
use Auth;
use Illuminate\Foundation\Auth\VerifiesEmails;
use Illuminate\Support\Carbon;
use Illuminate\Support\Str;

class VerificationController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Email Verification Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling email verification for any
    | user that recently registered with the application. Emails may also
    | be re-sent if the user didn't receive the original email message.
    |
     */

    use VerifiesEmails, GetUserData;

    /**
     * Where to redirect users after verification.
     *
     * @var string
     */
    protected $redirectTo = '/home';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        // $this->middleware('auth:api');
    }

    /**
     * Verify OTP
     * @param otp,type
     * @return response
     * @author Pratyush
     * @created_at 23 july 2019
     */
    public function verifyOtp(VerifyOTP $request)
    {
        $resultData = [];
        $arrResponse = [];
        $responseCode = 200;
        $otp = $request['one_time_password'];
        $type = $request['type'];
        $mobile_number = $request['mobile_number'];
        $request_token = $request['request_token'];

        $getOtp = OneTimePassword::where(function ($query) use ($otp, $type, $request_token) {
            $query->where('one_time_password', $otp);
            $query->where('request_token', $request_token);
            $query->where('expires_at', '>', Carbon::now()->toDateTimeString());

            if ($type == config('constants.one_time_password_types.VERIFICATION.value')) {
                $query->where('type', config('constants.one_time_password_types.VERIFICATION.value'));
            } elseif ($type == config('constants.one_time_password_types.RESET.value')) {
                $query->where('type', config('constants.one_time_password_types.RESET.value'));
            } elseif ($type == config('constants.one_time_password_types.MOBILE_VERIFICATION.value')) {
                $query->where('type', config('constants.one_time_password_types.MOBILE_VERIFICATION.value'));
            }
        })->first();

        // Set response
        if (!is_null($getOtp)) {
            $user = User::find($getOtp->user_id);
            if ($type == config('constants.one_time_password_types.VERIFICATION.value')) {
                User::where('id', $getOtp->user_id)->update(['email_verified_at' => Carbon::now()->toDateTimeString()]);

                // Deleting old OTP
                $getOtp->delete();

                $response = [
                    '_status' => true,
                    '_message' => __('messages.account_verified'),
                    '_data' => [
                        'user' => $this->getUserAllData($user),
                    ],
                ];
            } elseif ($type == config('constants.one_time_password_types.RESET.value')) {

                $response = [
                    '_status' => true,
                    '_message' => __('messages.success'),
                    '_data' => null,
                ];
            } elseif ($type == config('constants.one_time_password_types.MOBILE_VERIFICATION.value')) {
                User::where('id', $getOtp->user_id)->update(['mobile_number_verified_at' => Carbon::now()->toDateTimeString()]);
                // Deleting old OTP
                $getOtp->delete();

                $response = [
                    '_status' => true,
                    '_message' => __('messages.account_verified'),
                    '_data' => [
                        'user' => $this->getUserAllData($user->fresh()),
                    ],
                ];
            }

        } else {
            $responseCode = 422;
            $response = [
                '_status' => false,
                '_message' => __('messages.invalid_one_time_password'),
                '_data' => null,
                'errors' => [
                    'otp' => [
                        __('messages.invalid_one_time_password'),
                    ],
                ],
            ];
        }

        return response()->json($response, $responseCode);
    }
}
