<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Interfaces\FacilityInterface;
use Illuminate\Support\Facades\Hash;
use Carbon\Carbon;

class FacilityController extends Controller
{
    private $facility;

    /**
     * Create an controller instance.
     */
    public function __construct(FacilityInterface $facility){
        $this->facility = $facility;
        $this->middleware('auth:api');
    }

    /**
     * Get facilities.
     *
     * @return \Illuminate\Http\Response|\Illuminate\Contracts\Routing\ResponseFactory
     */
    public function getFacilities(Request $request)
    {
        $responseCode = 200;
        $errorMessage = null;
        $facilities = null;
        $where = [];

        DB::beginTransaction();
        try {

            $where = ['status' => 'active'];
            $facilities = $this->facility->getAll($where, true, $request)->toArray();

            DB::commit();
        } catch (\Exception $e) {
            $facilities = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        // Set response
        if (!empty($facilities)) {

            $response = [
                'status' => true,
                'message' => __('messages.records_found', ['records' => 'Facility']),
                'data' => [
                    'facilities'  => $facilities,
                ],
            ];

        } else if(empty($facilities) && is_null($errorMessage)) {

            $response = [
                'status' => false,
                'message' => __('messages.records_not_found', ['records' => 'Facility']),
                'data' => null,
            ];

        } else {

            // Set response code
            $responseCode = 500;
            //------------------

            $response = [
                'status' => false,
                'message' => __('messages.something_went_wrong'),
                'data' => null,
            ];
        }
        //-------------

        return response()->json($response, $responseCode);
    }

}
