<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Interfaces\FacilityInterface;
use App\Interfaces\HcpInterface;
use App\Interfaces\TransactionInterface;
use App\Interfaces\ShiftInterface;
use App\Interfaces\StateInterface;
use App\Interfaces\CategoryInterface;
use App\Interfaces\ProfessionInterface;
use App\Interfaces\ReferralInterface;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use App\Models\Transaction;
use Carbon\Carbon;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\FacilityTransactionExport;
use App\Exports\FacilityTransactionDetailsExport;
use App\Exports\HcpTransactionExport;
use App\Exports\HcpTransactionDetailsExport;
use App\Exports\FacilitySubscriptionExport;
use App\Exports\HcpExportCompletedShift;
use App\Exports\RevenueStatementExport;
use App\Exports\RevenueStatementDetailsExport;
use App\Exports\ReferralsExport;
use App\Exports\FacilityExportCompletedShift;
use App\Jobs\AdminPanel\SendEmailJob;
use Mail;
use PDF;
use App\Interfaces\FacilityGroupInterface;

class AccountController extends Controller
{
    private $facility;

    public function __construct(FacilityInterface $facility, TransactionInterface $transaction,ShiftInterface $shift,HcpInterface $hcp, StateInterface $state, CategoryInterface $category,ProfessionInterface $profession, ReferralInterface $referral,FacilityGroupInterface $facilityGroupInterface) {
        $this->facility = $facility;
        $this->transaction = $transaction;
        $this->shiftInterface = $shift;
        $this->hcpInterface = $hcp;
        $this->state = $state;
        $this->category = $category;
        $this->profession = $profession;
        $this->referral = $referral;
        $this->facility_group = $facilityGroupInterface;
    }

    /**
     * Facility Account.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 16 Dec 2020
     */
    public function facility(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facilities
            $facilities = $this->facility->getAll(['status' => 'active'], true);
            //---------------

            // Get Transactions
            $where=[];
            if (!empty($authUser->facility)) {
                $where['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $where['facility_id'] = $authUser->sub_admin->facility_id;
            }
            $transactions = $this->transaction->get_facility_transactions_with_pagination($where,$request);

            $data = $request->all();
            $data['export'] = true;
            $shiftDetails = $this->transaction->get_facility_transactions_with_pagination($where, $data);
            //-----------------

            // Completed Shifts
            $shiftWhere = ['shift_status' => '6'];
            //$completedShifts = $this->shiftInterface->shift_where($shiftWhere);
            //$totalCompletedShifts = count($completedShifts);
            //-----------------

            // Get States
            $shiftStatus = '6';
            $states = $this->state->getAll(['status' => 'active'], true, null);
            //-----------

            // Request
            $request = $request->all();
            //--------

            //return view('admin-panel.accounts.facility',compact('facilities','request', 'authUser','transactions', 'states', 'completedShifts', 'shiftDetails'));
            return view('admin-panel.accounts.facility',compact('facilities','request', 'authUser','transactions', 'states', 'shiftDetails'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Transaction Details.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 16 Dec 2020
     */
    public function details(Request $request, $facilityId = null, $invoiceId = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request['invoice_id'] = $invoiceId ? dv($invoiceId) : null;
            $request['facility_id'] = $facilityId ? dv($facilityId) : null;

            // Get Transaction Details
            $details = $this->transaction->get_transaction_details($request);
            $data = $request->all();
            $data['export'] = true;
            $shiftDetails = $this->transaction->get_transaction_details($data);
            //-------------------------

            // Get Facility
            $facility = $this->facility->find_facility($request['facility_id']);
            //-------------

            // Get Last Invoice Generated Date
            $lastInvoice = $this->transaction->get_generated_invoice(null, null, $request['facility_id']);
            //--------------------------------

            // Set Date Range
            if (!empty($request['invoice_id'])) {
                if (!empty($request['date_from']) && !empty($request['date_to'])) {
                    $startDate = $request['date_from'];
                    $endDate = $request['date_to'];
                } else {
                    if(count($details)) {
                        $dateRange = explode(' - ', $details[0]->invoice_generated_date_range);
                        $startDate = $dateRange[0];
                        $endDate = $dateRange[1];
                    } else {
                        $startDate = null;
                        $endDate = null;
                    }
                }

                // Total Shifts
                $totalShiftWhere = [
                    'facility_id' => $facility->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                ];
                $totalShifts = $this->shiftInterface->get_shift_for_account_card($totalShiftWhere)->count();
                //-------------

                // Completed Shifts
                $completedShiftWhere = [
                    'facility_id' => $facility->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '4',
                ];
                $completedShifts = $this->shiftInterface->get_shift_for_account_card($completedShiftWhere)->count();
                //-----------------

                // Approved Shifts
                $approvedShiftWhere = [
                    'facility_id' => $facility->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '6',
                ];
                $approvedShifts = $this->shiftInterface->get_shift_for_account_card($approvedShiftWhere)->count();
                //-----------------

                // Cancelled Shifts
                $cancelledShiftWhere = [
                    'facility_id' => $facility->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '3',
                ];
                $cancelledShifts = $this->shiftInterface->get_shift_for_account_card($cancelledShiftWhere)->count();
                //-----------------
            } else {
                if (!empty($request['date_from']) && !empty($request['date_to'])) {
                    $startDate = $request['date_from'];
                    $endDate = $request['date_to'];
                } else {
                    if(!empty($lastInvoice)) {
                        $startDate = $lastInvoice['invoice_created_at'];
                        $endDate = date('Y-m-d');
                    } else {
                        $startDate = null;
                        $endDate = date('Y-m-d');
                    }
                }

                // Total Shifts
                $totalShiftWhere = [
                    'facility_id' => $facility->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'invoice_status' => 'pending',
                    'invoice_id' => 0,
                ];
                $totalShifts = $this->shiftInterface->get_shift_for_account_card($totalShiftWhere)->count();
                //-------------

                // Completed Shifts
                $completedShiftWhere = [
                    'facility_id' => $facility->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '4',
                    'invoice_status' => 'pending',
                    'invoice_id' => 0,
                ];
                $completedShifts = $this->shiftInterface->get_shift_for_account_card($completedShiftWhere)->count();
                //-----------------

                // Approved Shifts
                $approvedShiftWhere = [
                    'facility_id' => $facility->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '6',
                    'invoice_status' => 'pending',
                    'invoice_id' => 0,
                ];
                $approvedShifts = $this->shiftInterface->get_shift_for_account_card($approvedShiftWhere)->count();
                //-----------------

                // Cancelled Shifts
                $cancelledShiftWhere = [
                    'facility_id' => $facility->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '3',
                ];
                $cancelledShifts = $this->shiftInterface->get_shift_for_account_card($cancelledShiftWhere)->count();
                //-----------------
            }
            //---------------
            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.accounts.details',compact('request', 'authUser','details','totalShifts','completedShifts','cancelledShifts', 'facility', 'approvedShifts', 'shiftDetails'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Payment.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 19 Dec 2020
     */
    public function pay(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        DB::beginTransaction();

        $result = null;

        try {
            $invoiceId = explode(',', $request['id']);

            if(is_array($invoiceId)){
                foreach($invoiceId as $invoice){
                    $where = ['invoice_id' => $invoice];
                    $updateColumns = ['paid_on' => date('Y-m-d'), 'paid_by' => $authUser->id, 'status' => 'completed'];
                    $result = $this->transaction->update($updateColumns,$where);
                    DB::commit();
                }
            } else {
                $where = ['invoice_id' => dv($invoiceId)];
                $updateColumns = ['paid_on' => date('Y-m-d'), 'paid_by' => $authUser->id, 'status' => 'completed'];
                $result = $this->transaction->update($updateColumns,$where);
            }

            DB::commit();
        } catch (\Exception $exception) {
            $result = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($result)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

        }


        return response()->json($notification, 200);
    }

    /**
     * Export Facility Accounts.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 19 Dec 2020
     */
    public function facilityExport(Request $request){
        // Get users
        $authUser = auth()->user();
        //----------

        try {
            $request = $request->all();
            $where = [];

            if (!empty($authUser->facility)) {
                $where['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $where['facility_id'] = $authUser->sub_admin->facility_id;
            }
            $request['export'] = true;
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new FacilityTransactionExport($this->transaction,$where,$request), 'facility_statement.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Export Facility Details Accounts.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 19 Dec 2020
     */
    public function facilityDetailsExport($id = null, Request $request) {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['export'] = true;
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new FacilityTransactionDetailsExport($this->transaction, $request), 'facility_statement_details.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Facility Send Reminder.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author sumit
     * @created 10 Jan 2021
     */
    public function facilitySendReminder(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        DB::beginTransaction();

        $result = null;

        try {
            $invoiceIds = explode(',', $request['id']);

            // Invoice
            $filter = [
                'invoice_ids' => $invoiceIds
            ];
            $invoices = $this->transaction->get_overdue_invoice($filter);
            //--------

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            if (count($invoices)) {
                foreach ($invoices as $invoice) {
                    $facility = $invoice['facility'];

                    // Send email notification
                    $filename = $invoice['invoice_file_name'];

                    if (config('filesystems.default') == config('constants.file_systems.PUBLIC.value')) {
                        $attach = url('public/storage/' . config('constants.facility.invoice_path')) . '/'.urlencode($filename);
                    } elseif (config('filesystems.default') == config('constants.file_systems.S3.value')) {
                        $bucket = env('AWS_BUCKET');
                        $region = env('AWS_DEFAULT_REGION');
                        // $bucketBaseUrl = 'https://s3.' . $region . '.amazonaws.com/'. $bucket.'/';
                        // $attach = $bucketBaseUrl.config('constants.facility.invoice_path').urlencode($filename);

                        $S3NewURL = env('AWS_CloudFront_URL').'/'.config('constants.facility.invoice_path').urlencode($filename);
                        $attach = str_replace('#', '%23', $S3NewURL);
                    }

                    $emailTemplate = config('constants.admin_email_path') . 'facility-invoice-overdue-email';
                    $emailData = [
                        'template' => $emailTemplate,
                        'data' => [
                            'name' => ucwords($facility['name']),
                            'email' => 'sumit.v2rsolution@gmail.com', //$facility['user']['email']
                            'subject' => __('subjects.facility_shift_invoice_overdue', ['InvoiceNumber' => $invoice['invoice_prefix'].$invoice['invoice_id'], 'InvoiceDate' => date('Y-m-d')]),
                            'invoiceNumber' => $invoice['invoice_prefix'].$invoice['invoice_id'],
                            'StatementDuration' => $invoice['invoice_generated_date_range'],
                            'invoiceOverdueDate' => $invoice['invoice_overdue_date'],
                            'cc' => $generalConfiguration['facillity_cust_care_email'],
                            'filename' => $attach,
                            'attach' => $attach,
                        ],
                    ];

                    if(config('app.server') == 'AWS' ) {
                        SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                    } else {
                        $data = $emailData['data'];
                        Mail::send($emailTemplate, $data, function ($message) use ($data) {
                            $message->to($data['email']);
                            $message->subject($data['subject']);
                            $message->cc($data['cc']);
                            $message->attach($data['filename']);
                        });
                    }
                    //------------------------

                    $result = true;
                }
            }

            DB::commit();
        } catch (\Exception $exception) {
            $result = null;
            $errorMessage = $exception->getMessage();
            DB::rollback();
        }

        if (!is_null($result)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

        }


        return response()->json($notification, 200);
    }

    /**
     * HCP Account.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 16 Dec 2020
     */
    public function hcp(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------
        try {

            // Get HCPs
            $HCPS = $this->hcpInterface->getAll(['status' => 'active'], true);
            //----------

            // Completed Shifts
            $shiftWhere = ['shift_status' => '6'];
            //$completedShifts = $this->shiftInterface->shift_where($shiftWhere);
            //$totalCompletedShifts = count($completedShifts);
            //-----------------

            // Get Transactions
            $where = [];
            if(!isset($request['status']) && empty($request['status'])) {
                $request['status'] = 'pending';
            }
            $transactions = $this->transaction->get_hcp_tranactions_with_pagination($where,$request);

            $data = $request->all();
            $data['export'] = true;
            $shiftDetails = $this->transaction->get_hcp_tranactions_with_pagination($where,$data);
            //-----------------

            // Get States
            $states = $this->state->getAll(['status' => 'active'], true, null);
            //-----------

            // Request
            $request = $request->all();
            //--------
	
            //return view('admin-panel.accounts.hcp',compact('HCPS','request', 'authUser','transactions', 'completedShifts', 'totalCompletedShifts', 'states', 'shiftDetails'));
            return view('admin-panel.accounts.hcp',compact('HCPS','request', 'authUser','transactions', 'states', 'shiftDetails'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * HCP Completed Shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author sumit
     * @created 12 Jan 2020
     */
    public function hcpCompletedShift(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {
            // Get Facility
            $facilities = $this->facility->getAll(['status' => 'active'], true);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = '6';
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Transaction Details
            if(!isset($request['status']) && empty($request['status'])) {
                $request['status'] = 'pending';
            }
            $details = $this->transaction->get_all_hcp_transaction_details($request);

            $data = $request->all();
            $data['export'] = false;
            $shiftDetails = $this->transaction->get_all_hcp_transaction_details($data);
            //------------------------

            // Completed Shifts
            $shiftWhere = ['shift_status' => '6'];
            //$completedShifts = $this->shiftInterface->shift_where($shiftWhere);
            //$totalCompletedShifts = count($completedShifts);
            //-----------------

            // Request
            $request = $request->all();
            //--------

            //return view('admin-panel.accounts.hcp-completed-shifts',compact('request', 'authUser', 'details', 'completedShifts','totalCompletedShifts', 'states', 'categories', 'professions', 'facilities', 'shiftDetails'));
            return view('admin-panel.accounts.hcp-completed-shifts',compact('request', 'authUser', 'details', 'states', 'categories', 'professions', 'facilities', 'shiftDetails'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Export HCP Completed Shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 12 Jan 2020
     */
    public function hcpCompletedShiftExport(Request $request){

        // Get users
        $authUser = auth()->user();
        //----------

        try {
            $request = $request->all();
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new HcpExportCompletedShift($this->transaction, $request), 'hcp_detailed.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Hcp Payment.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 19 Dec 2020
     */
    public function hcpPay(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        DB::beginTransaction();

        $result = null;
        $statementIds = '';

        try {
            $statementId = explode(',', $request['id']);
            if(is_array($statementId)){
                foreach($statementId as $statement){
                    $where = ['statement_id' => $statement];

                    // Get Statement details
                    $transaction = $this->transaction->get_transaction($where);
                    //---------------------

                    if(!empty($transaction)) {
                        $statementIds = $transaction['statement_prefix'].$transaction['statement_id'];

                        // Send Notification
                        send_other_push_notification($transaction['hcp_id'], 'hcp-statement-paid', 'hcp', null, null, null, null, $statementIds, null, $transaction['statement_id']);
                        //------------------
                    }

                    $updateColumns = ['hcp_paid_on' => date('Y-m-d'), 'hcp_paid_by' => $authUser->id, 'hcp_payment_status' => 'completed'];
                    $result = $this->transaction->update($updateColumns,$where);

                    DB::commit();
                }
            } else {
                $where = ['statement_id' => dv($invoiceId)];

                // Get Statement details
                $transaction = $this->transaction->get_transaction($where);
                //---------------------

                if(!empty($transaction)) {
                    $statementIds = $transaction['statement_prefix'].$transaction['statement_id'];

                    // Send Notification
                    send_other_push_notification($transaction['hcp_id'], 'hcp-statement-paid', 'hcp', null, null, null, null, $statementIds, null, $transaction['statement_id']);
                    //------------------
                }

                $updateColumns = ['hcp_paid_on' => date('Y-m-d'), 'hcp_paid_by' => $authUser->id, 'hcp_payment_status' => 'completed'];
                $result = $this->transaction->update($updateColumns,$where);
            }


            DB::commit();
        } catch (\Exception $exception) {
            $result = null;
            $errorMessage = $exception->getMessage();
            DB::rollback();
        }

        if (!is_null($result)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

        }


        return response()->json($notification, 200);
    }

    /**
     * HCP Account.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author sumit
     * @created 11 Feb 2021
     */
    public function hcpDetails(Request $request, $hcpId = null, $statementId = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request['statement_id'] = $statementId ? dv($statementId) : null;
            $request['hcp_id'] = $hcpId ? dv($hcpId) : null;

            // Get Transaction Details
            $details = $this->transaction->get_hcp_transaction_details($request);
            $referralsDetails = $this->transaction->get_hcp_referrals_transaction_details($request);

            $data = $request->all();
            $data['export'] = true;
            $shiftDetails = $this->transaction->get_hcp_transaction_details($data);
            //------------------------

            // Get Hcp
            $hcp = $this->hcpInterface->find_hcp($request['hcp_id']);
            //--------


            // Get Last Invoice Generated Date
            $lastInvoice = $this->transaction->get_generated_invoice(null, $request['hcp_id'], null);
            //--------------------------------


            // Set Date Range
            if (!empty($request['statement_id'])) {
                if (!empty($request['date_from']) && !empty($request['date_to'])) {
                    $startDate = $request['date_from'];
                    $endDate = $request['date_to'];
                } else {
                    if(count($details)) {
                        $dateRange = explode(' - ', $details[0]->invoice_generated_date_range);
                        $startDate = $dateRange[0];
                        $endDate = $dateRange[1];
                    } else {
                        $startDate = null;
                        $endDate = null;
                    }
                }

                // Total Shifts
                $totalShiftWhere = [
                    'hcp_id' => $hcp->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                ];
                $totalShifts = $this->shiftInterface->get_shift_for_account_card($totalShiftWhere)->count();
                //-------------

                // Completed Shifts
                $completedShiftWhere = [
                    'hcp_id' => $hcp->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '4',
                ];
                $completedShifts = $this->shiftInterface->get_shift_for_account_card($completedShiftWhere)->count();
                //-----------------

                // Approved Shifts
                $approvedShiftWhere = [
                    'hcp_id' => $hcp->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '6',
                ];
                $approvedShifts = $this->shiftInterface->get_shift_for_account_card($approvedShiftWhere)->count();
                //-----------------
                // p($approvedShifts );

                // Cancelled Shifts
                $cancelledShiftWhere = [
                    'hcp_id' => $hcp->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '3',
                ];
                $cancelledShifts = $this->shiftInterface->get_shift_for_account_card($cancelledShiftWhere)->count();
                //-----------------
            } else {
                if (!empty($request['date_from']) && !empty($request['date_to'])) {
                    $startDate = $request['date_from'];
                    $endDate = $request['date_to'];
                } else {
                    $startDate = $lastInvoice ? $lastInvoice['invoice_created_at'] : null;
                    $endDate = date('Y-m-d');
                }

                // Total Shifts
                $totalShiftWhere = [
                    'hcp_id' => $hcp->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'statement_status' => 'pending',
                    'statement_id' => 0,
                ];
                $totalShifts = $this->shiftInterface->get_shift_for_account_card($totalShiftWhere)->count();
                //-------------

                // Completed Shifts
                $completedShiftWhere = [
                    'hcp_id' => $hcp->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '4',
                    'statement_status' => 'pending',
                    'statement_id' => 0,
                ];
                $completedShifts = $this->shiftInterface->get_shift_for_account_card($completedShiftWhere)->count();
                //-----------------

                // Approved Shifts
                $approvedShiftWhere = [
                    'hcp_id' => $hcp->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '6',
                    'statement_status' => 'pending',
                    'statement_id' => 0,
                ];
                $approvedShifts = $this->shiftInterface->get_shift_for_account_card($approvedShiftWhere)->count();
                //-----------------

                // Cancelled Shifts
                $cancelledShiftWhere = [
                    'hcp_id' => $hcp->id,
                    'start_date' => $startDate,
                    'end_date' => $endDate,
                    'shift_status' => '3',
                ];
                $cancelledShifts = $this->shiftInterface->get_shift_for_account_card($cancelledShiftWhere)->count();
                //-----------------
            }
            //---------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.accounts.hcp-details',compact('request', 'authUser', 'details', 'totalShifts', 'completedShifts','cancelledShifts', 'hcp', 'approvedShifts', 'shiftDetails', 'referralsDetails'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * HCP Referrals.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author sumit
     * @created 11 Feb 2021
     */
    public function hcpReferrals(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Transaction Details
            if(!isset($request['status']) && empty($request['status'])) {
                $request['status'] = 'pending';
            }
            $referralsDetails = $this->transaction->get_hcp_referrals_transaction_details($request);
            //------------------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.includes.accounts.hcp-referrals',compact('request', 'authUser', 'referralsDetails'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * HCP Shift Details.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author sumit
     * @created 11 Feb 2021
     */
    public function shiftDetails($id = null){
        try {

            // Get Shift
            $shift = $this->shiftInterface->find_shift(dv($id));
            //----------

            return view('admin-panel.accounts.shift-details', compact('shift'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * HCP Account Export.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 16 Dec 2020
     */
    public function hcpExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new HcpTransactionExport($this->transaction,$where,$request), 'hcp_statement.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Export HCP Details Accounts.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 19 Dec 2020
     */
    public function hcpDetailsExport(Request $request){

        // Get users
        $authUser = auth()->user();
        //----------

        try {
            $request = $request->all();
            $request['export'] = true;
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new HcpTransactionDetailsExport($this->transaction, $request), 'hcp_statement_details.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Facility Shift Account.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 14 Jan 2021
     */
    public function facilityShiftAccount(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facilities
            $facilities = $this->facility->getAll(['status' => 'active'], true);
            //---------------

            // Get Transactions
            $where=[];
            if (!empty($authUser->facility)) {
                $where['facility_id'] = $authUser->facility->id;
                $request['facility'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $where['facility_id'] = $authUser->sub_admin->facility_id;
                $request['facility'] = $authUser->sub_admin->facility_id;
            }
            elseif($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
                $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);
                $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
                $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();
                $request['facilities'] = $facilities;
            }

            if (!isset($request['status']) && empty($request['status'])) {
                $request['status'] = 'facility-all';
            }

            $transactions = $this->transaction->get_facility_transactions_with_pagination($where, $request);
            //-----------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.accounts.facility-shift-account',compact('facilities','request', 'authUser','transactions'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Export Facility Shift Accounts.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 14 Jan 2021
     */
    public function exportfacilityShiftAccount(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['facility_export'] = true;
            $request['export'] = true;
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            $where=[];
            if (!empty($authUser->facility)) {
                $where['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $where['facility_id'] = $authUser->sub_admin->facility_id;
            }
            if (!isset($request['status']) && empty($request['status'])) {
                $request['status'] = 'facility-all';
            }

            return Excel::download(new FacilityTransactionExport($this->transaction,$where,$request), 'facility_transactions.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Facility Shift Account Details.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 14 Jan 2021
     */
    public function facilityShiftAccountDetails(Request $request, $facilityId = null, $invoiceId = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {
            $request['invoice_id'] = $invoiceId ? dv($invoiceId) : null;
            $request['facility_id'] = $facilityId ? dv($facilityId) : null;

            // Get Transaction Details
            $details = $this->transaction->get_transaction_details($request);
            //-------------------------

            // Get Facility
            $facility = $this->facility->find_facility($request['facility_id']);
            //-------------

            // Total Shifts
            $shiftWhere = ['facility_id' => $facility->id];
            $totalShifts = $this->shiftInterface->getAll($shiftWhere, true, [])->total();
            //-------------

            // Completed Shifts
            $shiftWhere = ['facility_id' => $facility->id, 'shift_status' => '4'];
            $completedShifts = $this->shiftInterface->shift_where($shiftWhere);
            $totalCompletedShifts = count($completedShifts);
            //-----------------

            // Approved Shifts
            $shiftWhere = ['facility_id' => $facility->id, 'shift_status' => '6'];
            $approvedShifts = $this->shiftInterface->shift_where($shiftWhere);
            //-----------------

            // Cancelled Shifts
            $shiftWhere = ['facility_id' => $facility->id, 'shift_status' => '3'];
            $cancelledShifts = $this->shiftInterface->getAll($shiftWhere, true, [])->total();
            //-----------------

            // Facility Revenue
            $facilityRevenue = $this->shiftInterface->calculate_facility_revenue($facility->id);
            //-----------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.accounts.facility-shift-account-details',compact('request', 'authUser','details','totalShifts','completedShifts','cancelledShifts','facilityRevenue', 'facility', 'totalCompletedShifts', 'approvedShifts'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Export Facility Shift Account Details.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 14 Jan 2021
     */
    public function exportfacilityShiftAccountDetails(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['export'] = true;
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new FacilityTransactionDetailsExport($this->transaction, $request), 'facility_transactions_details.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Facility Subscription Account.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 14 Jan 2021
     */
    public function facilitySubscriptionAccount(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facilities
            $facilities = $this->facility->getAll(['status' => 'active'], true);
            //---------------

            // Get Transactions
            $where=[];
            if (!empty($authUser->facility)) {
                $where['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $where['facility_id'] = $authUser->sub_admin->facility_id;
            }
            elseif($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
                $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);
                $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
                $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();
                $request['facilities'] = $facilities;
            }
            $transactions = $this->transaction->get_subscription_transactions_with_pagination($where,$request);
            //-----------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.accounts.facility-subscription-transactions',compact('facilities','request', 'authUser','transactions'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Facility Subscription Account Export.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 14 Jan 2021
     */
    public function facilitySubscriptionAccountExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['facility_export'] = true;

            $where=[];
            if (!empty($authUser->facility)) {
                $where['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $where['facility_id'] = $authUser->sub_admin->facility_id;
            }

            return Excel::download(new FacilitySubscriptionExport($this->transaction,$where,$request), 'subscription_transactions.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Revenue Statement.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author sumit
     * @created 12 Jan 2021
     */
    public function revenueStatement(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facilities
            $facilities = $this->facility->getAll(['status' => 'active'], true);
            //---------------

            // Get Transactions
            $where = [];
            $transactions = $this->transaction->get_revenue_statement($where,$request);
            $data = $request->all();
            $data['export'] = true;
            $shiftDetails = $this->transaction->get_revenue_statement($where,$data);
            //-----------------

            // Completed Shifts
            $completedShifts = $this->shiftInterface->get_paid_facility_invoice();
            $totalCompletedShifts = count($completedShifts);
            //-----------------

            // Get States
            $shiftStatus = '6';
            $states = $this->state->getAll(['status' => 'active'], true, null);
            //-----------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.accounts.revenue-statement',compact('facilities','request', 'authUser','transactions', 'states', 'completedShifts', 'shiftDetails'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Revenue Statement.
     *
     * @author sumit
     * @created 12 Jan 2021
     */
    public function revenueStatementExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['request']['export'] = true;
            $where = [];
            return Excel::download(new RevenueStatementExport($this->transaction,$where,$request), 'revenue_statement.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Revenue Statement Details.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author sumit
     * @created 12 Jan 2021
     */
    public function revenueStatementDetails(Request $request, $facilityId = null, $invoiceId = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------
        try {

            $request['invoice_id'] = $invoiceId ? dv($invoiceId) : null;
            $request['facility_id'] = $facilityId ? dv($facilityId) : null;

            // Get Transaction Details
            $details = $this->transaction->get_revenue_statement_details($request);
            $data = $request->all();
            $data['export'] = true;
            $shiftDetails = $this->transaction->get_revenue_statement_details($data);
            //-------------------------

            // Get Facility
            $facility = $this->facility->find_facility($request['facility_id']);
            //-------------

            // Total Shifts
            $shiftWhere = ['facility_id' => $facility->id];
            $totalShifts = $this->shiftInterface->getAll($shiftWhere, true, [])->total();
            //-------------

            // Completed Shifts
            $filter = ['facility_id' => $facility->id];
            $completedShifts = $this->shiftInterface->get_paid_facility_invoice($filter);
            $totalCompletedShifts = count($completedShifts);
            //-----------------

            // Cancelled Shifts
            $shiftWhere = ['facility_id' => $facility->id, 'shift_status' => '3'];
            $cancelledShifts = $this->shiftInterface->getAll($shiftWhere, true, [])->total();
            //-----------------

            // Facility Revenue
            $facilityRevenue = $this->shiftInterface->calculate_facility_revenue($facility->id);
            //-----------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.accounts.revenue-statement-details',compact('request', 'authUser','details','totalShifts','completedShifts','cancelledShifts','facilityRevenue', 'facility', 'totalCompletedShifts', 'shiftDetails'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Export Revenue Statement Details.
     *
     * @author sumit
     * @created 12 Jan 2021
     */
    public function revenueStatementDetailsExport(Request $request){
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['request']['export'] = true;

            return Excel::download(new RevenueStatementDetailsExport($this->transaction, $request), 'revenue_statement_details.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * View Referrals.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 16 Dec 2020
     */
    public function viewReferrals(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------
        try {

            // Request
            $request = $request->all();
            //--------

            // Get Refer And Earn
            $where = [];
            if(!isset($request['status']) && empty($request['status'])) {
                $request['status'] = 'pending';
            }
            $referrals = $this->transaction->get_referrals_transactions_with_pagination($where, $request);
            //-------------------

            // Get States
            $states = $this->state->getAll(['status' => 'active'], true, null);
            //-----------

            return view('admin-panel.accounts.view-referrals',compact('referrals','request', 'states', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * View Referrals Export.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 16 Dec 2020
     */
    public function viewReferralsExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Request
            $request = $request->all();
            //--------

            $request['request']['export'] = true;
            $where = [];

            return Excel::download(new ReferralsExport($this->transaction, $where, $request), 'referrals_details.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }


    /**
     * Facility Completed Shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author sumit
     * @created 12 Jan 2020
     */
    public function facilityCompletedShift(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {
            // Get Facility
            $facilities = $this->facility->getAll(['status' => 'active'], true);
            //-------------
	
            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = '6';
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Transaction Details
            $details = $this->transaction->get_all_facility_transaction_details($request);


            $data = $request->all();
            $data['export'] = false;
            $shiftDetails = $this->transaction->get_all_facility_transaction_details($data);
            //------------------------
	
            // Completed Shifts
            $shiftWhere = ['shift_status' => '6'];
            //$completedShifts = $this->shiftInterface->shift_where($shiftWhere);
            //$totalCompletedShifts = count($completedShifts);
	 $totalCompletedShifts = 0;
            //-----------------

            // Request
            $request = $request->all();
            //--------

            //return view('admin-panel.accounts.facility-completed-shifts',compact('request', 'authUser', 'details', 'completedShifts','totalCompletedShifts', 'states', 'categories', 'professions', 'facilities', 'shiftDetails'));
	return view('admin-panel.accounts.facility-completed-shifts',compact('request', 'authUser', 'details', 'states', 'categories', 'professions', 'facilities', 'shiftDetails'));

        } catch (\Exception $exception) {
            p($exception->getMessage());
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Export Facility Completed Shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author yamini
     * @created 12 Jan 2020
     */
    public function facilityCompletedShiftExport(Request $request){

        // Get users
        $authUser = auth()->user();
        //----------

        try {
            $request = $request->all();
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new FacilityExportCompletedShift($this->transaction, $request), 'facility_detailed.xlsx');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }


}
