<?php

namespace App\Http\Controllers\AdminPanel\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Http\Request;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = '/admin-panel/dashboard';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth.admin.guest')->except('logout');
    }

    /**
     * View login.
     *
     * @summary custom login page UI.
     * @author Sumit
     * @created 06 May 2020
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     */
    public function showLoginForm()
    {
        return view('admin-panel.auth.login');
    }

    /**
     * Logout.
     *
     * @summary custom logout.
     * @author Sumit
     * @created 06 May 2020
     * @return void
     */
    public function logout(Request $request)
    {
        auth()->logout();
        return redirect()->route('adminPanel.login');
    }

    /**
     * Authenticated.
     *
     * @summary custom authenticated function to check role.
     * @author Sumit
     * @created 06 May 2020
     * @return void
     */
    public function authenticated(Request $request, $user)
    {
        if ($user->hasRole('Facility') == true) {
            if ($user->facility->status == 'archived') {
                auth()->logout();
                return back()->with('account_disabled_error', __('error_messages.account_disabled'));
            } else {
                return redirect()->route('adminPanel.dashboard');
            }
        }
        elseif ($user->hasRole('Facility Group Admin') == true) {
            if ($user->facility_group_admin->status == 'archived') {
                auth()->logout();
                return back()->with('account_disabled_error', __('error_messages.account_disabled'));
            } else {
                return redirect()->route('adminPanel.dashboard');
            }
        }
        elseif ($user->hasRole('Facility Group') == true) {
            if ($user->facility_group->status == 'archived') {
                auth()->logout();
                return back()->with('account_disabled_error', __('error_messages.account_disabled'));
            } else {
                return redirect()->route('adminPanel.dashboard');
            }
        } 
        else {
            if ($user->status == 'inactive') {
                auth()->logout();
                return back()->with('account_disabled_error', __('error_messages.account_disabled'));
            } else {
                if ($user->hasRole('Super Admin') == true || $user->hasRole('Sub Admin') == true || $user->hasRole('Facility') == true || $user->hasRole('Facility Sub Admin') == true || $user->hasRole('Facility Group Sub Admin') == true) {
                    return redirect()->route('adminPanel.dashboard');
                } else {
                    auth()->logout();
                    return back()->with('access_denied_error', __('error_messages.access_denied'));
                }
            }
        }

    }


}
