<?php

namespace App\Http\Controllers\AdminPanel;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\ShiftInterface;
use App\Interfaces\StateInterface;
use App\Interfaces\HcpInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\FacilityGroupInterface;
use App\Interfaces\FacilityPlanInterface;
use App\Interfaces\ProfessionInterface;
use App\Models\Shift;
use App\User;
use DB;
use Illuminate\Support\Carbon;
use App\Models\CronJob;
use Illuminate\Support\Facades\Log;

class DashboardController extends Controller
{
    /**
     * @var array
     */
    public $viewData = [];

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(ShiftInterface $shiftInterface,StateInterface $stateInterface,HcpInterface $hcpInterface,FacilityInterface $facilityInterface, FacilityPlanInterface $facilityPlan, ProfessionInterface $profession, FacilityGroupInterface $facilityGroupInterface)
    {
        $this->middleware('auth.admin');
        $this->shiftInterface = $shiftInterface;
        $this->stateInterface = $stateInterface;
        $this->hcpInterface = $hcpInterface;
        $this->facilityInterface = $facilityInterface;
        $this->facility_plan = $facilityPlan;
        $this->profession = $profession;
        $this->facilityGroupInterface = $facilityGroupInterface;
    }

    /**
     * View dashboard.
     *
     * @summary dashboard.
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     * @author Sumit
     * @created 07 May 2020
     */

     public function index_new(){
	config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/shift-broadcast.log')]);

        // Current date
        $currentDate = Carbon::now()->toDateString();
        $currentTime = Carbon::now()->format('d-m-y H:i');
        //-------------

        $shiftUpdate = null;
        $shiftActivity = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'shift-broadcast-cron')->where('status', 0)->first();
        //----------------

        if (!empty($cronJob)) {

            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now()->toDateTimeString();
            //$cronJob->save();
            //---------------------------------

            $hcpFilter = [];
            $favouritesHcpIds = [];
            $ratedHcpIds = [];
            $otherHcpIds = [];
            $allHcpsIds = [];
            $cancelledHcpIds = [];
            $userDeviceIds = [];

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            DB::beginTransaction();
            try {

                // Get Shift
                $shiftWhere = ['shift_status' => '0'];
                //$shifts = $this->shiftInterface->shift_where($shiftWhere);
	$shifts = $this->shiftInterface->get_shift_for_broadcast($shiftWhere);
	p($shifts);
                //----------

                if (count($shifts)) {
                    Log::channel('cronlog')->info("-----------------------");
                    Log::channel('cronlog')->info("shift broadcast job start");

                    foreach($shifts as $shift) {

                        // Set time zone
                        date_default_timezone_set($shift->state->time_zone_name);
                        $currentTime = Carbon::now($shift->state->time_zone_name);
                        //--------------
	
                        $getfacility = $this->facilityInterface->find_facility($shift['facility_id']);
                        $hcpFilter['shift_id'] = $shift['id'];
                        $hcpFilter['facility_id'] = $shift['facility_id'];
                        $hcpFilter['state_id'] = $shift['state_id'];
                        $hcpFilter['country_id'] = $shift['country_id'];
                        $hcpFilter['facility_latitude'] = $getfacility['latitude'];
                        $hcpFilter['facility_longitude'] = $getfacility['longitude'];
                        $hcpFilter['category_id'] = $shift['category_id'];
                        $hcpFilter['profession_id'] = $shift['profession_id'];
                        $hcpFilter['level_id'] = $shift['hcp_level_id'];
                        $hcpFilter['shift_start_time'] = $shift['start_time'];
                        $hcpFilter['shift_end_time'] = $shift['end_time'];
                        $hcpFilter['time_zone_name'] = $shift->state->time_zone_name;
                        $hcpFilter['check_transfer_case'] = 'true';
                        $hcpFilter['check_swap_case'] = 'true';

                        // Get Cancelled Hcps
                        $cancelledHcpIds = [];
                        if (count($shift['cancelled_shifts'])) {
                            foreach($shift['cancelled_shifts'] as $cancelledShifts){
                                $cancelledHcpIds[] = $cancelledShifts->hcp_id;
                            }
                            $hcpFilter['cancelled_hcps'] = $cancelledHcpIds;
                        }
		
                        // Send Notification To Favourites Hcp
                        if($shift['shift_broadcast'] == 'favourite') {
                            $hcpFilter['only_favourites'] = true;
                            $favouritesHcps = $this->hcpInterface->get_hcp_listing_for_shift($hcpFilter);
		p($favouritesHcps);
                            $favouritesHcpIds = [];
                            if (count($favouritesHcps)) {
                                foreach($favouritesHcps as $favouritesHcp){
                                    $favouritesHcpIds[] = $favouritesHcp->id;
                                }

                                send_shift_push_notification($shift->id, 'new-shift', array_unique($favouritesHcpIds), null, 'favourite');

                                Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                                Log::channel('cronlog')->info("notification sent to favorite hcp");
                            }

                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'broadcast-to-favourites-hcp',
                                'created_by'    => $shift->created_by,
                                'updated_by'    => $shift->created_by,
                            ];
                            $this->shiftActivity->store($shiftActivityData);

                            Log::channel('cronlog')->info("shift broadcast to favourites hcp");

                            // Update Shift Broadcast
                            $shiftBroadcastWhere = ['id' => $shift['id']];

                            if(count($favouritesHcps)) {
                                $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_mint']);
                            } else {
                                $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes(1);
                            }

                            $this->shift->update(['shift_broadcast' => 'rated', 'shift_rebroadcast_time' => $shiftRebroadcastTime], $shiftBroadcastWhere);
                            //-----------------------
                        }
                        //------------------------------------

                        // Send Notification To Rated Hcp
                        else if($shift['shift_broadcast'] == 'rated' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                            $hcpFilter['only_ratings'] = true;
                            $ratedHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                            $ratedHcpIds = [];
                            if (count($ratedHcps)) {
                                foreach($ratedHcps as $ratedHcp){
                                    $ratedHcpIds[] = $ratedHcp->id;
                                }

                                send_shift_push_notification($shift->id, 'new-shift', array_unique($ratedHcpIds), null, 'rated');

                                Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                                Log::channel('cronlog')->info("notification sent to rated Hcp");
                            }

                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'broadcast-to-rated-hcp',
                                'created_by'    => $shift->created_by,
                                'updated_by'    => $shift->created_by,
                            ];
                            $this->shiftActivity->store($shiftActivityData);

                            Log::channel('cronlog')->info("shift broadcast to rated hcp");

                            // Update Shift Broadcast
                            $shiftBroadcastWhere = ['id' => $shift['id']];

                            if(count($ratedHcps)) {
                                $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_mint']);
                            } else {
                                $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes(1);
                            }

                            $this->shift->update(['shift_broadcast' => 'other', 'shift_rebroadcast_time' => $shiftRebroadcastTime] ,$shiftBroadcastWhere);
                            //-----------------------
                        }
                        //--------------------------------

                        // Send Notification To Other Hcp
                        else if($shift['shift_broadcast'] == 'other' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                            $otherHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                            $otherHcpIds = [];
                            if (count($otherHcps)) {
                                foreach($otherHcps as $otherHcp){
                                    $otherHcpIds[] = $otherHcp->id;
                                }

                                send_shift_push_notification($shift->id, 'new-shift', array_unique($otherHcpIds), null, 'other');

                                Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                                Log::channel('cronlog')->info("notification sent to other hcp");
                            }

                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'broadcast-to-other-hcp',
                                'created_by'    => $shift->created_by,
                                'updated_by'    => $shift->created_by,
                            ];
                            $this->shiftActivity->store($shiftActivityData);

                            Log::channel('cronlog')->info("shift broadcast to other hcp");

                            // Check Time Diff
                            $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);

                            $to = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name);
                            $from = Carbon::parse($currentTime);
                            $timeDiff = $to->diffInHours($from);
                            //----------------

                            if($timeDiff < $generalConfiguration['rebroadcast_to_all_before_shift_start']) {
                                $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours(1);
                            } else {
                                $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);
                            }

                            // Update Shift Broadcast
                            $shiftBroadcastWhere = ['id' => $shift['id']];
                            $this->shift->update(['shift_broadcast' => 'all', 'shift_rebroadcast_time' => $nextReabroadcast] ,$shiftBroadcastWhere);
                            //-----------------------
                        }
                        //-------------------------------

                        // Send Notification To All Hcp
                        else if($shift['shift_broadcast'] == 'all' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                            $allHcps = $this->hcpInterface->get_hcp_listing_for_shift($hcpFilter);
		p($hcpFilter);
                            $allHcpsIds = [];
                            if (count($allHcps)) {
                                foreach($allHcps as $allHcp){
                                    $allHcpsIds[] = $allHcp->id;
                                }

                                send_shift_push_notification($shift->id, 'new-shift', array_unique($allHcpsIds), null, 'all');

                                Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                                Log::channel('cronlog')->info("notification sent to all hcp");
                            }

                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'broadcast-to-all-hcp',
                                'created_by'    => $shift->created_by,
                                'updated_by'    => $shift->created_by,
                            ];
                            $this->shiftActivity->store($shiftActivityData);

                            Log::channel('cronlog')->info("shift broadcast to all hcp");

                            // Update Shift Broadcast
                            $shiftBroadcastWhere = ['id' => $shift['id']];
                            $this->shift->update(['shift_broadcast' => 'all', 'shift_rebroadcast_time' => Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_to_all_mint'])] ,$shiftBroadcastWhere);
                            //-----------------------
                        }
                        //-------------------------------
                    }

                    Log::channel('cronlog')->info("shift broadcast job end");
                    Log::channel('cronlog')->info("-----------------------");
                }

                // // Shift Broadcast Job
                // ShiftBroadcastJob::dispatch();
                // //--------------------

                DB::commit();

            } catch (\Exception $e) {
                Log::channel('cronlog')->info("-----------------------");
                Log::channel('cronlog')->error('shift broadcast cron error: '.$e->getMessage());
                Log::channel('cronlog')->info("-----------------------");
            }

            // Update cron status to completed
            $cronJob->status = 0;
            $cronJob->end_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('shift broadcast cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
     }    

    public function index(Request $request)
    {
        // Get User
        $authUser = auth()->user();

        //---------
        // p($authUser);
        if($authUser->hasRole('Super Admin') == true || $authUser->hasRole('Sub Admin') == true) {
            try{
                // Get States
                $states = $this->stateInterface->getAll(['status'=>'active'], true, $request);
                //-----------

                // Pending Shifts
                $shiftWhere = ['shift_status' => '0'];
                $pendingShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
                //---------------

                // Running Shifts
                $shiftWhere = ['shift_status' => '2'];
                $runningShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
                //---------------

                // Completed Shifts
                $shiftWhere = ['shift_status' => '4'];
                $completedShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
                //-----------------

                // Canceled Shifts
                $shiftWhere = ['shift_status' => '3'];
                $canceledShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
                //----------------

                // Buddy Shifts
                $shiftWhere = ['shift_type' => 'buddy'];
                $buddyShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
                //-------------

                // Schedule Shifts
                $shiftWhere = ['shift_status' => '1'];
                $scheduleShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
                //-------------

                // Shifts Requested Last 30 days
                $last30DaysShift = count($this->shiftInterface->get_shift_as_date(date('Y-m-d',strtotime("-30 day",strtotime(date('M d, Y')))),date('Y-m-d'),$request));
                //------------------------------

                // Registered HCPS
                $hcps = count($this->hcpInterface->getAll(['status' => 'active'], true, $request));
                //----------------

                // Active HCP
                $hcpWhere = ['status' => 'active'];
                $activeHcps = $this->hcpInterface->getAll($hcpWhere, true, $request);
                $activeHcpsCount=count($activeHcps);
                //-----------

                // Blocked HCP
                $hcpWhere = ['status' => 'blocked'];
                $blockedHcps = count($this->hcpInterface->getAll($hcpWhere, true, $request));
                //------------

                // Pending HCP
                $hcpWhere = ['status' => 'pending-approval'];
                $pendingHcps = count($this->hcpInterface->getAll($hcpWhere, true, $request));
                //------------

                // Active Facilities
                $facilityWhere = ['status' => 'active'];
                $facilities = $this->facilityInterface->getAll($facilityWhere, true, $request);
                $facilitiesCount=count($facilities);
                //------------------

                // Get Shifts
                $shifts = $this->shiftInterface->get_shift_as_date_with_pagination(date('Y-m-d',strtotime("-6 day",strtotime(date('M d, Y')))), date('Y-m-d'), $request);
                //-----------

                // Get Professions
                $professions = $this->profession->getAll(['status' => 'active'], true);
                //----------------

                // HCP Statics Chart Data
                $hcpStatisticsLabels = array('Active HCP','Blocked HCP','Pending Approvals');
                $hcpStatisticsDataset[] = array(
                    'data' => array($activeHcpsCount,$blockedHcps,$pendingHcps),
                    'backgroundColor' => config('constants.chart_colors')
                );
                $hcpStatisticsOptions = [];
                //-----------------------

                // Get top 5 facilty according to shift count
                $topFacilities = Shift::select('facility_id', DB::raw('count(*) as shift_count'))
                    ->where(function ($query) use ($request) {

                        if(!empty($request['state_id'])) {
                            $query->where('state_id', $request['state_id']);
                        }

                        if(!empty($request['profession_id'])) {
                            $query->where('profession_id', $request['profession_id']);
                        }

                    })
                    ->with(['facility' => function ($query) use($request) {
                        $query->select('id', 'facility_prefix', 'name');
                    }])
                    ->whereDate('start_time', '>', $this->get_date())
                    ->groupBy('facility_id')
                    ->orderBy('shift_count', 'DESC')
                    ->take(5)
                    ->get();

                $topFacilitiesData = [];
                if(count($topFacilities)) {
                    foreach ($topFacilities as $topFacility) {
                        $topFacilitiesData[] = [
                            'y' => $topFacility['shift_count'],
                            'label' => $topFacility['facility']['name'],
                        ];
                    }
                }
                //-------------------------------------------


                // Get top 5 professions according to shift count
                $topProfessions = Shift::select('facility_id', 'state_id', 'hcp_id', 'profession_id', DB::raw('count(*) as shift_count'))
                    ->where(function ($query) use ($request) {

                        if(!empty($request['state_id'])) {
                            $query->where('state_id', $request['state_id']);
                        }

                        if(!empty($request['facility_id'])) {
                            $query->where('facility_id', $request['facility_id']);
                        }

                    })
                    ->with(['facility' => function ($query) use($request) {
                        $query->select('id', 'facility_prefix', 'name');
                    }])
                    ->with(['profession' => function ($query) use($request) {
                        $query->select('id', 'name');
                    }])
                    ->whereDate('start_time', '>', $this->get_date())
                    ->groupBy('profession_id')
                    ->orderBy('shift_count', 'DESC')
                    ->take(5)
                    ->get();

                $topProfessionsData = [];
                if(count($topProfessions)) {
                    foreach ($topProfessions as $topProfession) {
                        $topProfessionsData[] = [
                            'y' => $topProfession['shift_count'],
                            'label' => $topProfession['profession']['name'],
                        ];
                    }
                }
                //-----------------------------------------------

                // Shift Count Chart Data
                $shiftCountChartLabels=array();
                $shiftCountChartDataset=array();
                $dates=array();
                $facilityCount = [];
                foreach($topFacilities as $key => $topFacility){
                    if($key==0){
                        $color='#0DDC60';
                    }
                    elseif($key==1){
                        $color='#1F81CC';
                    }
                    elseif($key==2){
                        $color='#EC9718';
                    }
                    elseif($key==3){
                        $color='#886CE5';
                    }
                    elseif($key==4){
                        $color='#59951B';
                    }

                    $startDate=$this->get_date();
                    $dates[]=$startDate;
                    $facilityCount = [];

                    while($startDate<=date('Y-m-d')){
                        if($key==0){
                            $shiftCountChartLabels[]=$startDate;
                        }
                        $topFacilitiesList = Shift::where('facility_id',$topFacility['facility']->id)
                            ->where(function ($query) use ($request) {
                                if(!empty($request['state_id'])) {
                                    $query->where('state_id', $request['state_id']);
                                }
                                if(!empty($request['facility_id'])) {
                                    $query->where('facility_id', $request['facility_id']);
                                }

                                if(!empty($request['hcp_id'])) {
                                    $query->where('hcp_id', $request['hcp_id']);
                                }

                            })
                            ->whereDate('hcp_shift_start_time', '=', $startDate)
                            ->count();

                        $newDate=strtotime("+1 day",strtotime($startDate));
                        $startDate=date('Y-m-d',$newDate);
                        $facilityCount[] = $topFacilitiesList;
                    }

                    $shiftCountChartDataset[]=array(
                        'label' => $topFacility['facility']->name,
                        'borderColor' => $color,
                        'backgroundColor' => $color,
                        'data' => $facilityCount,
                        'fill'=> false,
                    );
                }

                $shiftCountChartOptions=array(
                    'responsive'=>true,
                    'tooltips'=>array('mode'=>'index'),
                    'hover'=>array('mode'=>'index'),
                    'elements'=>array(
                        'line'=>array(
                            'tension'=> 0.000001
                        )
                    ),
                    'scales'=>array(
                        'xAxes'=>array(
                            array(
                                'scaleLabel'=>array(
                                    'display'=>false,
                                ),
                                'type'=>'time',
                                'time'=> array(
                                    'unit'=>'day',
                                    'unitStepSize'=>5
                                )
                            ),

                        ),
                        'yAxes'=>array(
                            array(
                                'stacked'=>true,
                                'scaleLabel'=>array(
                                    'display'=>false,
                                ),
                                'ticks'=>array(
                                    'stepSize'=>1,
                                ),
                            ))
                    ),
                    'layout'=>array(
                        'padding'=>array(
                            'left'=>30,
                            'right'=>30
                        )
                    )
                );
                //-----------------------

                $this->viewData['request'] = $request->all();
                $this->viewData['states'] = $states;
                $this->viewData['pendingShiftsCount'] = $pendingShifts;
                $this->viewData['runningShiftsCount'] = $runningShifts;
                $this->viewData['completedShiftsCount'] = $completedShifts;
                $this->viewData['canceledShiftsCount'] = $canceledShifts;
                $this->viewData['buddyShiftsCount'] = $buddyShifts;
                $this->viewData['scheduleShiftsCount'] = $scheduleShifts;
                $this->viewData['hcpCount'] = $hcps;
                $this->viewData['facilityCount'] = $facilitiesCount;
                $this->viewData['last30DaysShift'] = $last30DaysShift;
                $this->viewData['hcpStatisticsLabels'] = json_encode($hcpStatisticsLabels);
                $this->viewData['hcpStatisticsDataset'] = json_encode($hcpStatisticsDataset);
                $this->viewData['hcpStatisticsOptions'] = json_encode($hcpStatisticsOptions);
                $this->viewData['shiftCountChartLabels'] = json_encode($shiftCountChartLabels);
                $this->viewData['shiftCountChartDataset'] = json_encode($shiftCountChartDataset);
                $this->viewData['shiftCountChartOptions'] = json_encode($shiftCountChartOptions);
                $this->viewData['shifts'] = $shifts;
                $this->viewData['authUser'] = $authUser;
                $this->viewData['facilityList'] = $facilities;
                $this->viewData['hcpList'] = $activeHcps;
                $this->viewData['topFacilitiesData'] = $topFacilitiesData;
                $this->viewData['topProfessionsData'] = $topProfessionsData;
                $this->viewData['professions'] = $professions;

                return view('admin-panel.dashboard.super-admin-dashboard')->with($this->viewData);
            }catch (\Exception $e) {
                p($e->getMessage());
            }


        } else if($authUser->hasRole('Facility') == true || $authUser->hasRole('Facility Sub Admin') == true) {

            if (!empty($authUser->facility)) {
                $request['facility'] = $authUser->facility->id;
                $request['state_id'] = $authUser->facility->state_id;
            } else {
                $request['facility'] = $authUser->sub_admin->facility_id;
                $request['state_id'] = $authUser->sub_admin->facility->state_id;
            }

            // Get Facility Plan
            $facilityPlan = $this->facility_plan->get_facility_plan($request['facility']);
            //------------------

            // Get State
            $state = $this->stateInterface->find_state($request['state_id']);
            //-----------

            // Pending Shifts
            $shiftWhere = ['shift_status' => '0'];
            $pendingShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //---------------

            // Running Shifts
            $shiftWhere = ['shift_status' => '2'];
            $runningShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //---------------

            // Completed Shifts
            $shiftWhere = ['shift_status' => '4'];
            $completedShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //-----------------

            // Canceled Shifts
            $shiftWhere = ['shift_status' => '3'];
            $canceledShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //-----------------

            // Buddy Shifts
            $shiftWhere = ['shift_type' => 'buddy'];
            $buddyShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //-------------

            // Schedule Shifts
            $shiftWhere = ['shift_status' => '1'];
            $scheduleShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //-------------

            // Shifts Requested Last 30 days
            $request['shift_type_not_buddy'] = true;
            $last30DaysShift = count($this->shiftInterface->get_shift_as_date($this->get_date(),date('Y-m-d'),$request));
            //------------------------------

            // Registered HCPS
            $hcps = count($this->hcpInterface->getAll(['status' => 'active'], true, $request));
            //----------------

            // Active HCP
            $hcpWhere = ['status' => 'active'];
            $activeHcps = count($this->hcpInterface->getAll($hcpWhere, true, $request));
            //-----------

            // Blocked HCP
            $hcpWhere = ['status' => 'blocked'];
            $blockedHcps = count($this->hcpInterface->getAll($hcpWhere, true, $request));
            //------------

            // Pending HCP
            $hcpWhere = ['status' => 'pending-approval'];
            $pendingHcps = count($this->hcpInterface->getAll($hcpWhere, true, $request));
            //------------

            // Active Facilities
            $facilityWhere = ['status' => 'active'];
            $facilities = count($this->facilityInterface->getAll($facilityWhere, true, $request));
            //------------------

            // Get Shifts
            $shifts = $this->shiftInterface->get_shift_as_date_with_pagination(date('Y-m-d',strtotime("-7 day",strtotime(date('M d, Y')))), date('Y-m-d'), $request);
            //-----------

            // Facility Profession
            $facilityProfession = [];
            $professionShiftsArr = [];
            if(!empty($facilityPlan['plan'])){
                foreach($facilityPlan['plan']['professions'] as $profession){
                    $facilityProfession[] = $profession['name'];

                    // Get profession shift
                    $shiftWhere = ['profession_id' => $profession['id'], 'facility_id' => $request['facility']];
                    $professionShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
                    //---------------------

                    $professionShiftsArr[] = $professionShifts;
                }
            }
            //--------------------

            // Facility Profession
            $shiftCountChartLabels = array();
            $shiftCountChartDataset = array();
            $dates = array();
            $colorArr = config('constants.chart_colors');
            $facilityCount = [];
            $professionName = '';
            if(!empty($facilityPlan['plan'])){
                foreach($facilityPlan['plan']['professions'] as $key => $profession){
                    $startDate = $this->get_date();

                    if(strlen($profession->name) > 18) {
                        $professionName = substr($profession->name,0,18)."...";
                    } else {
                        $professionName = $profession->name;
                    }

                    $shiftData = Shift::where('facility_id', $request['facility'])
                    ->where(function ($query) use ($request, $profession) {
                        if(!empty($profession['id'])) {
                            $query->where('profession_id', $profession['id']);
                        }

                        if(!empty($profession['category_id'])) {
                            $query->where('category_id', $profession['category_id']);
                        }
                    })
                    ->whereDate('start_time', '>', $startDate)->count();

                    $shiftCountChartDataset[] = array(
                        'label' => $professionName,
                        'y' => $shiftData,
                    );
                }
            }

            usort($shiftCountChartDataset, function ($item1, $item2) {
                return $item2['y'] <=> $item1['y'];
            });
            //--------------------

            $shiftCountChartOptions=array(
                'responsive'=>true,
                'tooltips'=>array('mode'=>'index'),
                'hover'=>array('mode'=>'index'),
                'elements'=>array(
                    'line'=>array(
                        'tension'=> 0.000001
                    )
                ),
                'scales'=>array(
                    'xAxes'=>array(
                      array(
                        'scaleLabel'=>array(
                            'display'=>false,
                        ),
                        'type'=>'time',
                        'time'=> array(
                            'unit'=>'day',
                            'unitStepSize'=>5
                        )
                    ),
                ),
                'yAxes'=>array(
                    array(
                        'stacked'=>true,
                        'scaleLabel'=>array(
                            'display'=>false,
                        ),
                        'ticks'=>array(
                            'stepSize'=>1,
                        ),
                    ))
                ),
                'layout'=>array(
                    'padding'=>array(
                        'left'=>30,
                        'right'=>30
                    )
                )
          );

            // Shift Profession Statics Chart Data
            $shiftStatisticsLabels = $facilityProfession;
            $shiftStatisticsDataSet[] = array(
                'data' => $professionShiftsArr,
                'backgroundColor' => config('constants.chart_colors')
            );
            $shiftStatisticsOptions = [];
            //------------------------------------
            $this->viewData['request'] = $request->all();
            $this->viewData['state'] = $state;
            $this->viewData['pendingShiftsCount'] = $pendingShifts;
            $this->viewData['runningShiftsCount'] = $runningShifts;
            $this->viewData['completedShiftsCount'] = $completedShifts;
            $this->viewData['canceledShiftsCount'] = $canceledShifts;
            $this->viewData['buddyShiftsCount'] = $buddyShifts;
            $this->viewData['scheduleShiftsCount'] = $scheduleShifts;
            $this->viewData['hcpCount'] = $hcps;
            $this->viewData['facilityCount'] = $facilities;
            $this->viewData['last30DaysShift'] = $last30DaysShift;
            $this->viewData['shiftCountChartDataset'] = array_slice($shiftCountChartDataset, 0, 5);

            $this->viewData['shiftStatisticsLabels'] = json_encode($shiftStatisticsLabels);
            $this->viewData['shiftStatisticsDataSet'] = json_encode($shiftStatisticsDataSet);
            $this->viewData['shiftStatisticsOptions'] = json_encode($shiftStatisticsOptions);
            $this->viewData['shiftCountChartLabels'] = json_encode($shiftCountChartLabels);
            $this->viewData['shiftCountChartOptions'] = json_encode($shiftCountChartOptions);

            $this->viewData['shifts'] = $shifts;
            $this->viewData['authUser'] = $authUser;
            $topFacilitiesData[] = [ ];
            $this->viewData['topFacilitiesData'] = $topFacilitiesData;
            return view('admin-panel.dashboard.facility-dashboard')->with($this->viewData);
        }else if($authUser->hasRole('Facility Group Admin') == true || $authUser->hasRole('Facility Group') == true|| $authUser->hasRole('Facility Group Sub Admin') == true) {

            if($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
//                // Get States
                $facility_groups = $this->facilityGroupInterface->get_facility_group_without_pagination(['status'=>'active'], true, $request);

                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                if(!empty($request['selected_facility_group_id']) && !empty($request['facility'])){
                    $facilities_arr = $this->facilityInterface->getAll(['status'=>'active','facility_group_id'=>$request['selected_facility_group_id']], true, $request);
                }
            }
            elseif($authUser->hasRole('Facility Group') == true){
                // $request->request->add(['facility_group_id'=>$authUser->facility_group->id]);
                // Get States
                $facilities_arr = $this->facilityInterface->getAll(['status'=>'active','facility_group_id'=>$authUser->facility_group->id], true, $request);
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);
                // Get States
                $facilities_arr = $this->facilityInterface->getAll(['status'=>'active'], true, $request);
            }

            // Get Facility Plan
            if(!empty($request['facility'])){
                $facilityPlan = $this->facility_plan->get_facility_plan($request['facility']);
            }
            //------------------

            // Pending Shifts
            $shiftWhere = ['shift_status' => '0'];
            $pendingShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //---------------

            // Running Shifts
            $shiftWhere = ['shift_status' => '2'];
            $runningShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //---------------

            // Completed Shifts
            $shiftWhere = ['shift_status' => '4'];
            $completedShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //-----------------

            // Canceled Shifts
            $shiftWhere = ['shift_status' => '3'];
            $canceledShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //-----------------

            // Buddy Shifts
            $shiftWhere = ['shift_type' => 'buddy'];
            $buddyShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //-------------

            // Schedule Shifts
            $shiftWhere = ['shift_status' => '1'];
            $scheduleShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
            //-------------

            // Shifts Requested Last 30 days
            $request['shift_type_not_buddy'] = true;
            $last30DaysShift = count($this->shiftInterface->get_shift_as_date($this->get_date(),date('Y-m-d'),$request));
            //------------------------------

            // Registered HCPS
            $hcps = count($this->hcpInterface->getAll(['status' => 'active'], true, $request));
            //----------------

            // Active HCP
            $hcpWhere = ['status' => 'active'];
            $activeHcps = count($this->hcpInterface->getAll($hcpWhere, true, $request));
            //-----------

            // Blocked HCP
            $hcpWhere = ['status' => 'blocked'];
            $blockedHcps = count($this->hcpInterface->getAll($hcpWhere, true, $request));
            //------------

            // Pending HCP
            $hcpWhere = ['status' => 'pending-approval'];
            $pendingHcps = count($this->hcpInterface->getAll($hcpWhere, true, $request));
            //------------

            // Active Facilities
            $facilityWhere = ['status' => 'active'];
            $facilities = count($this->facilityInterface->getAll($facilityWhere, true, $request));
            //------------------

            // Get Shifts
            $shifts = $this->shiftInterface->get_shift_as_date_with_pagination(date('Y-m-d',strtotime("-7 day",strtotime(date('M d, Y')))), date('Y-m-d'), $request);
            //-----------


            // Get top 5 facilty according to shift count
            if($authUser->hasRole('Facility Group Admin') == true || $authUser->hasRole('Facility Group') == true || $authUser->hasRole('Facility Group Sub Admin') == true ){
                // $topFacilities
                $query = Shift::select('facility_id', DB::raw('count(*) as shift_count'))
                ->where(function ($query) use ($request) {

                    if(!empty($request['state_id'])) {
                        $query->where('state_id', $request['state_id']);
                    }

                    if(!empty($request['profession_id'])) {
                        $query->where('profession_id', $request['profession_id']);
                    }

                })
                ->with(['facility' => function ($query) use($request) {
                    $query->select('id', 'facility_prefix', 'name');
                }]);
                $query->whereDate('start_time', '>', $this->get_date());
                if($authUser->hasRole('Facility Group') == true){
                    $query->where('facility_group_id', $authUser->facility_group->id);
                }
                elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                    $query->whereIn('facility_id', json_decode($authUser->sub_admin->assigned_facilities));

                }
                elseif($authUser->hasRole('Facility Group Admin') == true){
                    $query->whereIn('facility_group_id', $facility_group_ids);
                }
                $topFacilities = $query->groupBy('facility_id')
                ->orderBy('shift_count', 'DESC')
                ->take(5)
                ->get();
                // p($topFacilities);
                $topFacilitiesData = [];
                if(count($topFacilities)) {
                    foreach ($topFacilities as $topFacility) {
                        $topFacilitiesData[] = [
                            'y' => $topFacility['shift_count'],
                            'label' => $topFacility['facility']['name'],
                        ];
                    }
                }
            }


            // Shift Count Chart Data
            $shiftCountChartLabels=array();
            $shiftCountChartDataset=array();
            $dates=array();
            $facilityCount = [];
            foreach($topFacilities as $key => $topFacility){
                if($key==0){
                   $color='#0DDC60';
                }
                elseif($key==1){
                    $color='#1F81CC';
                }
                elseif($key==2){
                    $color='#EC9718';
                }
                elseif($key==3){
                    $color='#886CE5';
                }
                elseif($key==4){
                    $color='#59951B';
                }

                $startDate=$this->get_date();
                $dates[]=$startDate;
                $facilityCount = [];

                while($startDate<=date('Y-m-d')){
                    if($key==0){
                        $shiftCountChartLabels[]=$startDate;
                    }
                    $topFacilitiesList = Shift::where('facility_id',$topFacility['facility']->id)
                    ->where(function ($query) use ($request) {
                        if(!empty($request['state_id'])) {
                            $query->where('state_id', $request['state_id']);
                        }
                        if(!empty($request['facility_id'])) {
                            $query->where('facility_id', $request['facility_id']);
                        }

                        if(!empty($request['hcp_id'])) {
                            $query->where('hcp_id', $request['hcp_id']);
                        }

                    })
                    ->whereDate('hcp_shift_start_time', '=', $startDate)
                    ->count();

                    $newDate=strtotime("+1 day",strtotime($startDate));
                    $startDate=date('Y-m-d',$newDate);
                    $facilityCount[] = $topFacilitiesList;
                }

                $shiftCountChartDataset[]=array(
                    'label' => $topFacility['facility']->name,
                    'borderColor' => $color,
                    'backgroundColor' => $color,
                    'data' => $facilityCount,
                    'fill'=> false,
                );
            }

            $shiftCountChartOptions=array(
                  'responsive'=>true,
                  'tooltips'=>array('mode'=>'index'),
                  'hover'=>array('mode'=>'index'),
                  'elements'=>array(
                    'line'=>array(
                        'tension'=> 0.000001
                    )
                  ),
                  'scales'=>array(
                    'xAxes'=>array(
                        array(
                            'scaleLabel'=>array(
                                'display'=>false,
                            ),
                            'type'=>'time',
                            'time'=> array(
                                'unit'=>'day',
                                'unitStepSize'=>5
                            )
                        ),

                    ),
                    'yAxes'=>array(
                    array(
                        'stacked'=>true,
                        'scaleLabel'=>array(
                            'display'=>false,
                        ),
                        'ticks'=>array(
                            'stepSize'=>1,
                        ),
                    ))
                ),
                'layout'=>array(
                    'padding'=>array(
                        'left'=>30,
                        'right'=>30
                    )
                )
            );



            if(isset($request['facility']) && !empty($request['facility'])){
                // Facility Profession
                $facilityProfession = [];
                $professionShiftsArr = [];
                if(!empty($facilityPlan['plan'])){
                    foreach($facilityPlan['plan']['professions'] as $profession){
                        $facilityProfession[] = $profession['name'];

                        // Get profession shift
                        $shiftWhere = ['profession_id' => $profession['id'], 'facility_id' => $request['facility']];
                        $professionShifts = $this->shiftInterface->getAll($shiftWhere, true, $request)->total();
                        //---------------------

                        $professionShiftsArr[] = $professionShifts;
                    }
                }
                //--------------------

                // Facility Profession
                $shiftCountChartLabels = array();
                $shiftCountChartDataset = array();
                $dates = array();
                $colorArr = config('constants.chart_colors');
                $facilityCount = [];
                $professionName = '';
                if(!empty($facilityPlan['plan'])){
                    foreach($facilityPlan['plan']['professions'] as $key => $profession){
                        $startDate = $this->get_date();

                        if(strlen($profession->name) > 18) {
                            $professionName = substr($profession->name,0,18)."...";
                        } else {
                            $professionName = $profession->name;
                        }

                        $shiftData = Shift::where('facility_id', $request['facility'])
                        ->where(function ($query) use ($request, $profession) {
                            if(!empty($profession['id'])) {
                                $query->where('profession_id', $profession['id']);
                            }

                            if(!empty($profession['category_id'])) {
                                $query->where('category_id', $profession['category_id']);
                            }
                        })
                        ->whereDate('start_time', '>', $startDate)->count();

                        $shiftCountChartDataset[] = array(
                            'label' => $professionName,
                            'y' => $shiftData,
                        );
                    }
                }

                usort($shiftCountChartDataset, function ($item1, $item2) {
                    return $item2['y'] <=> $item1['y'];
                });
                //--------------------

                $shiftCountChartOptions=array(
                    'responsive'=>true,
                    'tooltips'=>array('mode'=>'index'),
                    'hover'=>array('mode'=>'index'),
                    'elements'=>array(
                        'line'=>array(
                            'tension'=> 0.000001
                        )
                    ),
                    'scales'=>array(
                        'xAxes'=>array(
                          array(
                            'scaleLabel'=>array(
                                'display'=>false,
                            ),
                            'type'=>'time',
                            'time'=> array(
                                'unit'=>'day',
                                'unitStepSize'=>5
                            )
                        ),
                    ),
                    'yAxes'=>array(
                        array(
                            'stacked'=>true,
                            'scaleLabel'=>array(
                                'display'=>false,
                            ),
                            'ticks'=>array(
                                'stepSize'=>1,
                            ),
                        ))
                    ),
                    'layout'=>array(
                        'padding'=>array(
                            'left'=>30,
                            'right'=>30
                        )
                    )
              );

                // Shift Profession Statics Chart Data
                $shiftStatisticsLabels = $facilityProfession;
                $shiftStatisticsDataSet[] = array(
                    'data' => $professionShiftsArr,
                    'backgroundColor' => config('constants.chart_colors')
                );
                $shiftStatisticsOptions = [];
            }



            //------------------------------------
            $this->viewData['request'] = $request->all();
            $this->viewData['state'] = isset($state)?$state:'';
            $this->viewData['facility_groups'] = isset($facility_groups)?$facility_groups:'';
            $this->viewData['facilities'] = isset($facilities_arr)?$facilities_arr:'';
            $this->viewData['pendingShiftsCount'] = $pendingShifts;
            $this->viewData['runningShiftsCount'] = $runningShifts;
            $this->viewData['completedShiftsCount'] = $completedShifts;
            $this->viewData['canceledShiftsCount'] = $canceledShifts;
            $this->viewData['buddyShiftsCount'] = $buddyShifts;
            $this->viewData['scheduleShiftsCount'] = $scheduleShifts;
            $this->viewData['hcpCount'] = $hcps;
            $this->viewData['facilityCount'] = $facilities;
            $this->viewData['last30DaysShift'] = $last30DaysShift;
            $this->viewData['shiftCountChartDataset'] = array_slice($shiftCountChartDataset, 0, 5);

            $this->viewData['shiftStatisticsLabels'] = isset($shiftStatisticsLabels)?json_encode($shiftStatisticsLabels):'';
            $this->viewData['shiftStatisticsDataSet'] = isset($shiftStatisticsDataSet)?json_encode($shiftStatisticsDataSet):'';
            $this->viewData['shiftStatisticsOptions'] = isset($shiftStatisticsOptions)?json_encode($shiftStatisticsOptions):'';
            $this->viewData['shiftCountChartLabels'] = json_encode($shiftCountChartLabels);
            $this->viewData['shiftCountChartOptions'] = json_encode($shiftCountChartOptions);

            $this->viewData['topFacilitiesData'] = $topFacilitiesData;
            $this->viewData['shifts'] = $shifts;
            $this->viewData['authUser'] = $authUser;
            // p($this->viewData);
            return view('admin-panel.dashboard.facility-dashboard')->with($this->viewData);
        }

    }


    /**
     * Check user email.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 10 Aug 2020
     */
    public function checkUserEmail(Request $request)
    {
        $status = false;

        if (!is_null($request->email)) {
            $user = User::where('email', $request['email'])->first();

            if (!is_null($user)) {
                if ($request->filled('id') && $user->id == $request['id']) {
                    $status = true;
                } else {
                    $status = false;
                }
            } else {
                $status = true;
            }
        }

        return response()->json($status, 200);
    }

    /**
     * Get Date From last seven days
     *
     * @return date
     *
     * @author Yamini
     * @created 3 Dec 2020
     */
    private function get_date(){
        $date = strtotime("-90 day",strtotime(date('M d, Y')));
        return date('Y-m-d', $date);
    }
}
