<?php

namespace App\Http\Controllers\AdminPanel;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;
use App\Models\DevConfiguration;

class DevConfigurationController extends Controller
{
    /**
     * @var array
     */
    public $viewData = [];

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth.admin');
    }

    /**
     * Edit dev configuration.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 12 Aug 2020
     */
    public function edit(Request $request)
    {
        // Get dev configuration
        $configurations = DevConfiguration::all();
        //----------------------

        $this->viewData['configurations'] = $configurations;

        return view('admin-panel.dev-configuration.edit')->with($this->viewData);

    }

    /**
     * Update dev configuration.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 12 Aug 2020
     */
    public function update(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $devConfigurationUpdate = false;
        $errorMessage = null;

        // Update dev configuration
        DB::beginTransaction();
        try {


            if(!empty($request['dev_configuration'])){
                foreach($request['dev_configuration'] as $configuration){
                    DevConfiguration::where('id', $configuration['id'])->update(['config_value' => $configuration['value']]);
                }
            }


            DB::commit();
        } catch (\Exception $e) {
            $devConfigurationUpdate = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }
        //-------------------------

        if (!is_null($devConfigurationUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Dev Configuration']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.dev-configuration.edit')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Dev Configuration']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.dev-configuration.edit')->with(['notification' => $notification]);
        }

    }

}
