<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Interfaces\DocumentConfigInterface;
use App\Interfaces\DocumentInterface;
use App\Interfaces\ProfessionInterface;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;

class DocumentConfigurationController extends Controller
{
    private $documentConfig,$document,$profession;
    public function __construct(DocumentConfigInterface $documentConfig, DocumentInterface $document, ProfessionInterface $profession){
        $this->documentConfig = $documentConfig;
        $this->document = $document;
        $this->profession = $profession;
    }

    public function index()
    {
        try {

            $documents   = $this->document->get(['required_for' => 'hcp', 'doc_type' => 'profession'], true);
            $professions = $this->profession->get(['status' => 'active'], true);
            $documentConfiguration = $this->documentConfig->get([]);

            return view('admin-panel.documentConfigurations.index', compact('documents', 'professions', 'documentConfiguration'));

        } catch(\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    public function edit(Request $request, $docId = null)
    {
        try {

            // Get Document
            $document = $this->document->find_document(dv($docId));
            //-------------

            // Get Professions
            $professions = $this->profession->get(['status' => 'active']);
            //----------------

            $documentConfiguration = $this->documentConfig->get([]);

            return view('admin-panel.documentConfigurations.edit', compact('document', 'professions', 'documentConfiguration'));

        } catch(\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    public function update(Request $request, $docId = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $documentConfiguration = null;
        $professionData = [];

        DB::beginTransaction();
        try {
            if(!empty($request['profession'])) {
                $this->documentConfig->delete_document(dv($docId));
                foreach($request['profession'] as $profession){
                    $checkProfessionData = [
                        'document_id' => dv($docId),
                        'profession_id' => $profession,
                    ];

                    $professionData = [
                        'document_id' => dv($docId),
                        'profession_id' => $profession,
                    ];

                    $documentConfiguration = $this->documentConfig->update_or_insert($checkProfessionData, $professionData);
                }
            }

            DB::commit();

        } catch(\Exception $exception){
            $documentConfiguration = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($documentConfiguration)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Document Configuration']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.document-config.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Document Configuration']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.document-config.edit', ['docId' => $docId])->withInput()->with(['notification' => $notification]);
        }
    }
}
