<?php

namespace App\Http\Controllers\AdminPanel;
use App\Interfaces\DocumentHcpInterface;
use App\Interfaces\DocumentNotificationInterface;
use App\Interfaces\HcpInterface;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Input;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\ExpiringDocExport;
use App\Exports\RecentDocExport;

class DocumentNotificationController extends Controller
{
    private $documentNotification,$documentHcp;
    public function __construct(DocumentNotificationInterface $documentNotification,DocumentHcpInterface $documentHcp,HcpInterface $hcp){
        $this->documentNotification = $documentNotification;
        $this->documentHcp = $documentHcp;
        $this->hcp = $hcp;
    }

    /**
     * View Document Notifications.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Yamini
     * @created 3 Dec 2020
     */
    public function index(Request $request){
        try {

            // Expiring Documents
            $expiringDocuments = $this->documentHcp->get_expiring_documents($request);
            //-------------------

            // Last Submitted Documents
            $hcpDocuments = $this->documentHcp->get_last_submitted_documents($this->get_date(), date('Y-m-d'), $request);
            //-------------------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.documentNotifications.index',compact('expiringDocuments', 'hcpDocuments', 'request'));

        }catch(\Exception $exception){
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Export Expiring Documents.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 13 Feb 2021
     */
    public function expiringDocExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['export'] = true;
            $request['request']['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new ExpiringDocExport($this->documentHcp, $request), 'expiring-document.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Export Recent Documents.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 13 Feb 2021
     */
    public function recentDocExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['export'] = true;
            $request['request']['export'] = true;
            unset($request['request']['recent_per_page']);

            return Excel::download(new RecentDocExport($this->get_date(), date('Y-m-d'), $this->documentHcp, $request), 'recent-document.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }


    /**
     * Get Date From last seven days
     *
     * @return date
     *
     * @author Yamini
     * @created 3 Dec 2020
     */
    private function get_date(){
        $date = strtotime("-7 day",strtotime(date('M d, Y')));
        return date('Y-m-d', $date);
    }


}
