<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\AdminPanel\ValidateFacility;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Mail;
use App\Http\Traits\UploadImage;
use App\Http\Traits\UploadFile;
use App\Interfaces\HcpInterface;
use App\Interfaces\FavouritesAndBlocklistInterface;
use App\Interfaces\FacilityGroupInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\StateInterface;
use App\Interfaces\PlanInterface;
use App\Interfaces\ShiftInterface;
use App\Interfaces\DocumentInterface;
use App\Interfaces\FacilityDocumentInterface;
use App\Interfaces\CountryInterface;
use App\Interfaces\CityInterface;
use App\Interfaces\SuburbInterface;
use App\Interfaces\FacilityNameInterface;
use App\Interfaces\FacilityActivityInterface;
use App\Interfaces\CategoryInterface;
use App\Interfaces\ProfessionInterface;
use App\Interfaces\TransactionInterface;
use App\Interfaces\FacilityPlanInterface;
use App\Models\Facility;
use App\Models\FacilityDocument;
use App\Models\Plan;
use App\Models\Country;
use App\Models\State;
use App\Models\City;
use App\Models\Hcp;
use App\Models\FavouritesAndBlocklist;
use Spatie\Permission\Models\Permission;
use App\User;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\FacilitiesExport;
use App\Exports\FacilityHcpExport;
use App\Models\FacilityPlan;
use App\Models\Transaction;
use App\Interfaces\SupportingPageInterface;
use Stripe;
use Session;
use Exception;

class FacilityController extends Controller
{

    use UploadImage, UploadFile;

    private $hcp, $favouritesAndBlocklist, $facilityGroup, $facility, $state, $plan, $document, $facilityDocument, $countries, $cities, $suburbs, $facilityName, $facilityActivity, $transaction, $facilityPlan;

    /**
     * @var array
     */
    public $viewData = [];

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(HcpInterface $hcp, FavouritesAndBlocklistInterface $favouritesAndBlocklist, FacilityGroupInterface $facilityGroup, FacilityInterface $facility, CountryInterface $countries, StateInterface $state, CityInterface $cities, SuburbInterface $suburbs, PlanInterface $plan, ShiftInterface $shift, DocumentInterface $document, FacilityDocumentInterface $facilityDocument, FacilityNameInterface $facilityName, FacilityActivityInterface $facilityActivity, CategoryInterface $category, ProfessionInterface $profession, TransactionInterface $transaction, FacilityPlanInterface $facilityPlan, SupportingPageInterface $supportingPage)
    {
        $this->middleware('auth.admin');
        $this->hcp = $hcp;
        $this->favouritesAndBlocklist = $favouritesAndBlocklist;
        $this->facility_group = $facilityGroup;
        $this->facility = $facility;
        $this->state = $state;
        $this->countries = $countries;
        $this->cities = $cities;
        $this->suburbs = $suburbs;
        $this->plan = $plan;
        $this->shift = $shift;
        $this->document = $document;
        $this->facility_document = $facilityDocument;
        $this->facility_name = $facilityName;
        $this->facility_activity = $facilityActivity;
        $this->category = $category;
        $this->profession = $profession;
        $this->transaction = $transaction;
        $this->facility_plan = $facilityPlan;
        $this->supporting_page = $supportingPage;
    }

    /**
     * View facilities.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 6 Aug 2020
     */
    public function active(Request $request)
    {
        // Facilities
        $where = [['status', '!=', 'archived']];
        
        $request->request->add(['shortby_filter'=>"2"]);

        $facilities = $this->facility->get_facility_with_pagination($where, $request);
        //-----------

        // Get States
        $whereState = ['status' => 'active', 'country_id' => 1];
        $states = $this->state->getAll($whereState);
        //-----------

        // Get Plans
        $planWhere = [];
        $plans = $this->plan->getAll($planWhere);
        //----------

        $this->viewData['facilities'] = $facilities;
        $this->viewData['states'] = $states;
        $this->viewData['plans'] = $plans;
        $this->viewData['request'] = $request->all();

        return view('admin-panel.facilities.active')->with($this->viewData);
    }

    /**
     * View archived facilities.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 13 Aug 2020
     */
    public function archived(Request $request)
    {
        // Facilities
        $facilities = $this->facility->get_facility_with_pagination(['status' => 'archived'], $request);
        //-----------

        // Get States
        $whereState = ['status' => 'active', 'country_id' => 1];
        $states = $this->state->getAll($whereState);
        //-----------

        // Get Plans
        $planWhere = [];
        $plans = $this->plan->getAll($planWhere);
        //----------

        $this->viewData['facilities'] = $facilities;
        $this->viewData['states'] = $states;
        $this->viewData['plans'] = $plans;
        $this->viewData['request'] = $request->all();

        return view('admin-panel.facilities.archived')->with($this->viewData);
    }

    /**
     * View pending approval facilities.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 13 Aug 2020
     */
    public function pendingApproval(Request $request)
    {
        // Facilities
        $facilities = $this->facility->get_facility_with_pagination(['status' => 'pending-approval'], $request);
        //-----------

        // Get States
        $whereState = ['status' => 'active', 'country_id' => 1];
        $states = $this->state->getAll($whereState);
        //-----------

        // Get Plans
        $planWhere = [];
        $plans = $this->plan->getAll($planWhere);
        //----------

        $this->viewData['facilities'] = $facilities;
        $this->viewData['states'] = $states;
        $this->viewData['plans'] = $plans;
        $this->viewData['request'] = $request->all();

        return view('admin-panel.facilities.pending-approval')->with($this->viewData);
    }

    /**
     * Change status.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 6 Aug 2020
     */
    public function changeStatus(Request $request, $id, $status)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $facility = null;
        $data = [];
        $where = [];

        DB::beginTransaction();
        try {

            $where = ['id' => dv($id)];

            $data = [
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $facility = $this->facility->update($data, $where);

            // Facility Activity
            create_facility_activity(dv($id), 'status-change', __('facility_activities.status_change', ['status' => $request['status']]), $authUser->id);
            //------------------

            DB::commit();
        } catch (\Exception $exception) {
            $facility = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($facility)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }
        return response()->json($response, 200);
    }


    /**
     * View create facility.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 6 Aug 2020
     */
    public function create()
    {
        // Get Plans
        $plans = Plan::active()->get();
        //----------

        // Get Country
        $countries = Country::active()->get();
        //------------

        // Get States
        $states = State::active()->orderBy('name', 'ASC')->get();
        //-----------

        // Get facility group
        $facilityGroups = $this->facility_group->get_list(['status' => 'active']);
        //-------------------

        // Get facility documents
        $documents = $this->document->get(['required_for' => 'facility'], true);
        //-----------------------

        // Get facility name
        $facilityNames = $this->facility_name->get_list(['status' => 'active']);
        //------------------

        $this->viewData['plans'] = $plans;
        $this->viewData['countries'] = $countries;
        $this->viewData['facilityGroups'] = $facilityGroups;
        $this->viewData['documents'] = $documents;
        $this->viewData['states'] = $states;
        $this->viewData['facilityNames'] = $facilityNames;

        return view('admin-panel.facilities.create')->with($this->viewData);
    }

    /**
     * Store facilities.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 6 Aug 2020
     */
    public function store(ValidateFacility $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        $facility = null;
        $errorMessage = null;
        $randomPassword = str_random(8);

        DB::beginTransaction();

        // Create Facility
        try {

            // User data
            $data = [
                'name' => $request['name'],
                'email' => $request['email'],
                'password' => bcrypt($randomPassword),
                'role_name' => 'facility',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];
            $user = User::create($data);
            //----------

            // facility data
            $facilityData = [
                'name' => $request['name'],
                'legal_entity_name' => $request['legal_entity_name'],
                'user_id' => $user->id,
                'contact_number' => $request['contact_number'],
                'mobile_number' => $request['mobile_number'],
                'address' => $request['address'],
                'state_id' => $request['state_id'],
                'country_id' => 1,
                'suburb_name' => $request['suburb_name'],
                'city_name' => $request['city_name'],
                'post_code' => $request['post_code'],
                'latitude' => $request['latitude'],
                'longitude' => $request['longitude'],
                'facility_group_id' => $request['facility_group'],
                'contact_person' => $request['contact_person'],
                'plan_auto_renewal' => $request['plan_auto_renewal'],
                'card_number' => $request['card_number'],
                'card_expiry_date' => $request['card_expiry_date'],
                'card_cvv' => $request['card_cvv'],
                'additional_email' => $request['additional_email'],
                'additional_nurse_email' => $request['additional_nurse_email'],
                'status' => 'active',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];
            $facility = Facility::create($facilityData);
            //--------------

            // Assign role
            $user->assignRole('Facility');
            //------------

            // Assign admin permission to user
            $permissions = Permission::where('panel_permissions', 'facility')->get()->toArray();
            if (!is_null($authUser) && !is_null($permissions)) {
                foreach($permissions as $permission){
                    $user->givePermissionTo($permission['name']);
                }
            }
            //--------------------------------

            // Add Plan
            if (isset($request['plan'])) {
                // Get Plan Details
                $plan = Plan::where('id', $request['plan'])->first();
                //-----------------

                // Set Plan
                $planDetails = [
                    'name' => $plan->name,
                    'description' => $plan->description,
                    'plan_cycle' => $request['plan_cycle'],
                    'start_date' => $request['plan_start_date'],
                    'expiry_date' => $request['plan_end_date'],
                    'monthly_price' => $plan['monthly_price'],
                    '6_month_price' => $plan['6_month_price'],
                    'yearly_price' => $plan['yearly_price'],
                ];

                $planData = [];
                $paymentAmount = 0;
                $trialShiftPostingLimit = null;
                $trialDayOfShiftPostingLimit = null;
                if (!is_null($request['plan'])) {

                    if($request['plan'] == 4) {

                        // Get Trial Plan
                        $trialPlan = get_trial_plan_configurations();
                        //---------------

                        $trialShiftPostingLimit = $trialPlan['shift_posting_limit_in_trial_acc'];
                        $trialDayOfShiftPostingLimit = $trialPlan['days_of_shift_posting_limit_in_trial_acc'];
                    }

                    if ($request['plan_cycle'] == 'monthly') {
                        $paymentAmount = $plan['monthly_price'];
                        $notificationDate =  date('Y-m-d', strtotime('-7 days', strtotime($request['plan_end_date'])));
                    } else if($request['plan_cycle'] == 'yearly') {
                        $paymentAmount = $plan['yearly_price'];
                        $notificationDate =  date('Y-m-d', strtotime('-1 months', strtotime($request['plan_end_date'])));
                    } else {
                        $paymentAmount = 0;
                        $notificationDate = null;
                    }


                    $planData[$request['plan']] = [
                        'start_date' => $request['plan_start_date'],
                        'expiry_date' => $request['plan_end_date'],
                        'plan_cycle' => $request['plan_cycle'],
                        'shift_posting_limit_in_trial_account' => $trialShiftPostingLimit,
                        'days_of_shift_posting_limit_in_trial_account' => $trialDayOfShiftPostingLimit,
                        'payment_amount' => $paymentAmount,
                        'notification_date' => $notificationDate,
                        'last_payment_date' => now(),
                        'status' => 'active',
                        'plan_details' => json_encode($planDetails, true),
                        'created_by' => $authUser->id,
                        'updated_by' => $authUser->id,
                    ];
                    $facility->plans()->attach($planData);
                }
            }
            //---------

            // Upload facility documents
            $documentsData = [];
            $documentName = null;

            if (isset($request['documents']) && count($request['documents'])) {
                foreach ($request['documents'] as $document) {

                    $name = strtolower(str_replace(' ', '-', $document['document_name']));

                    // Upload hcp file
                    if (!empty($document['file']) && file_exists($document['file'])) {
                        $path = config('constants.facility.facility_path') . '/' . $facility->facility_prefix . $facility->id . '/documents/';
                        $file = $this->uploadFile($document['file'], $path, 75, $name);

                        if ($file['_status']) {
                            $documentName = $file['_data'];
                        }
                    } else {
                        $documentName = ($document['file'] ?? null);
                    }
                    //----------------

                    if ( isset($document['expiry_date']) && !empty($document['expiry_date'])) {
                        if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 60 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 60 days'));
                        } else if(strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 30 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 30 days'));
                        } else if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 7 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 7 days'));
                        } else if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 1 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 1 days'));
                        } else {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date']));
                        }
                    } else {
                        $sendNotificationDate = null;
                    }

                    if (!empty($document['file'])) {

                        $facilityDocument = FacilityDocument::updateOrCreate([
                            'document_id' => $document['document_id'] ?? null,
                            'facility_id' => $facility->id,
                        ], [
                            'document_name' => $documentName,
                            'expiry_date' => $document['expiry_date'] ?? null,
                            'send_notification_date' => $sendNotificationDate,
                            'document_approval' => 'approved',
                            'show_in_document_approval' => 'no',
                            'show_in_notification' => 'no',
                            'created_by' => $authUser->id,
                            'updated_by' => $authUser->id,
                            'created_at' => now(),
                            'updated_at' => now(),
                        ]);
                    }
                }
            }
            //--------------------------

            // Send user email with password
            if (!empty($user)) {
                $emailTemplate = config('constants.admin_email_path') . 'user-welcome-email';
                $emailData = [
                    'template' => $emailTemplate,
                    'data' => [
                        'name' => ucwords($request['name']),
                        'email' => $request['email'],
                        'subject' => __('subjects.user_welcome', ['app_name' => config('app.name')]),
                        'password' => $randomPassword,
                    ],
                ];

                if (config('app.server') == 'AWS') {
                    SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                } else {
                    $data = $emailData['data'];
                    Mail::send($emailTemplate, $data, function ($message) use ($data) {
                        $message->to($data['email']);
                        $message->subject($data['subject']);
                    });
                }
            }
            //------------------------------

            // Facility Activity
            create_facility_activity($facility->id, 'account-created', __('facility_activities.account_created'), $authUser->id);
            //------------------

            DB::commit();
        } catch (\Exception $e) {
            $facility = null;
            $errorMessage = $e->getMessage();
            p($e->getMessage());
            DB::rollback();
        }
        //----------------

        if (!is_null($facility)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Facility']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.active')->with(['notification' => $notification]);
        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_creation_failed', ['record' => 'Facility']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.create')->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Edit facilities.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 11 Aug 2020
     */
    public function edit(Request $request, $id)
    {
        // Get facility
        $facility = Facility::with('country', 'state', 'city', 'user')
            ->with(['plans' => function ($query) {
                $query->where('plans.status', 'active');
            }])->where('id', dv($id))->first();
        //-------------

        // Get Plans
        $plans = Plan::active()->get();
        //----------

        // Get Country
        $countries = $this->countries->getAll(['status' => 'active'], true);
        //------------

        // Get State
        $states = $this->state->getAll(['status' => 'active', 'country_id' => $facility->country_id], true);
        //----------

        // Get City
        $cities = $this->cities->getAll(['status' => 'active', 'state_id' => $facility->state_id], true);
        //---------

        // Get Suburbs
        $suburbs = $this->suburbs->getAll(['status' => 'active', 'city_id' => $facility->city_id], true);
        //------------

        // Get facility group
        $facilityGroups = $this->facility_group->get_list(['status' => 'active']);
        //-------------------

        // Get facility name
        $facilityNames = $this->facility_name->get_list(['status' => 'active']);
        //------------------

        // Get facility documents
        $documents = $this->document->get(['required_for' => 'facility'], true);
        //-----------------------

        $this->viewData['plans'] = $plans;
        $this->viewData['facility'] = $facility;
        $this->viewData['countries'] = $countries;
        $this->viewData['states'] = $states;
        $this->viewData['cities'] = $cities;
        $this->viewData['suburbs'] = $suburbs;
        $this->viewData['facilityGroups'] = $facilityGroups;
        $this->viewData['facilityNames'] = $facilityNames;
        $this->viewData['documents'] = $documents;

        return view('admin-panel.facilities.edit')->with($this->viewData);
    }

    /**
     * Update facilities.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 11 Aug 2020
     */
    public function update(ValidateFacility $request, $id)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $facilityUpdate = false;
        $errorMessage = null;
        $randomPassword = str_random(8);

        // Get facility
        $facility = Facility::where('id', dv($id))->first();
        //-------------

        // Update Facility
        DB::beginTransaction();
        try {

            $facility->name = $request['name'];
            $facility->updated_by = $authUser->id;
            $facilityUpdate = $facility->save();

            // User data
            $user = User::where('id', $facility->user_id)->first();
            $user->name = $request['name'];
            $user->email = $request['email'];
            $user->updated_by = $authUser->id;
            if(!empty($request->password)){
                $user->password = bcrypt($request->password);
            }
            $user->save();
            //----------
            
            // facility data
            $facility->name = $request['name'];
            $facility->legal_entity_name = $request['legal_entity_name'];
            $facility->contact_number = $request['contact_number'];
            $facility->mobile_number = $request['mobile_number'];
            $facility->address = $request['address'];
            $facility->state_id = $request['state_id'];
            $facility->country_id = 1;
            $facility->city_name = $request['city_name'];
            $facility->suburb_name = $request['suburb_name'];
            $facility->latitude = $request['latitude'];
            $facility->longitude = $request['longitude'];
            $facility->facility_group_id = $request['facility_group'];
            $facility->contact_person = $request['contact_person'];
            $facility->plan_auto_renewal = $request['plan_auto_renewal'];
            $facility->card_number = $request['card_number'];
            $facility->card_expiry_date = $request['card_expiry_date'];
            $facility->card_cvv = $request['card_cvv'];
            $facility->post_code = $request['post_code'];
            $facility->additional_email = $request['additional_email'];
            $facility->additional_nurse_email = $request['additional_nurse_email'];
            $facility->updated_by = $authUser->id;
            $facility->save();
            //--------------
            
            // Add Plan
            if (isset($request['plan'])) {
                // Get Plan Details
                $plan = Plan::where('id', $request['plan'])->first();
                //-----------------

                // Set Plan
                $planDetails = [
                    'name' => $plan->name,
                    'description' => $plan->description,
                    'plan_cycle' => $request['plan_cycle'],
                    'start_date' => $request['plan_start_date'],
                    'expiry_date' => $request['plan_end_date'],
                    'monthly_price' => $plan['monthly_price'],
                    '6_month_price' => $plan['6_month_price'],
                    'yearly_price' => $plan['yearly_price'],
                ];

                $planData = [];
                $paymentAmount = 0;
                $trialShiftPostingLimit = null;
                $trialDayOfShiftPostingLimit = null;
                if (!is_null($request['plan'])) {
                    if($request['plan'] == 4) {

                        // Get Trial Plan
                        $trialPlan = get_trial_plan_configurations();
                        //---------------

                        $trialShiftPostingLimit = $trialPlan['shift_posting_limit_in_trial_acc'];
                        $trialDayOfShiftPostingLimit = $trialPlan['days_of_shift_posting_limit_in_trial_acc'];
                    }

                    if ($request['plan_cycle'] == 'monthly') {
                        $paymentAmount = $plan['monthly_price'];
                        $notificationDate =  date('Y-m-d', strtotime('-7 days', strtotime($request['plan_end_date'])));
                    } else if($request['plan_cycle'] == 'yearly') {
                        $paymentAmount = $plan['yearly_price'];
                        $notificationDate =  date('Y-m-d', strtotime('-1 months', strtotime($request['plan_end_date'])));
                    } else {
                        $paymentAmount = 0;
                        $notificationDate = null;
                    }

                    $planData[$request['plan']] = [
                        'start_date' => $request['plan_start_date'],
                        'expiry_date' => $request['plan_end_date'],
                        'plan_cycle' => $request['plan_cycle'],
                        'shift_posting_limit_in_trial_account' => $trialShiftPostingLimit,
                        'days_of_shift_posting_limit_in_trial_account' => $trialDayOfShiftPostingLimit,
                        'payment_amount' => $paymentAmount,
                        'notification_date' => $notificationDate,
                        'last_payment_date' => now(),
                        'status' => 'active',
                        'plan_details' => json_encode($planDetails, true),
                        'updated_by' => $authUser->id,
                    ];
                    $facility->plans()->sync($planData);
                }
            }
            //---------

            // Assign admin permission to user
            if(count($user->permissions) == 0) {
                $permissions = Permission::where('panel_permissions', 'facility')->get()->toArray();
                if (!is_null($user) && !is_null($permissions)) {
                    foreach($permissions as $permission){
                        $user->givePermissionTo($permission['name']);
                    }
                }
            }
            //--------------------------------

            // Upload facility documents
            $documentsData = [];
            $documentName = null;

            if (isset($request['documents']) && count($request['documents'])) {
                foreach ($request['documents'] as $document) {

                    $name = strtolower(str_replace(' ', '-', $document['document_name']));

                    // Upload hcp file
                    if (!empty($document['file']) && file_exists($document['file'])) {
                        $path = config('constants.facility.facility_path') . '/' . $facility->facility_prefix . $facility->id . '/documents/';
                        $file = $this->uploadFile($document['file'], $path, 75, $name);

                        if ($file['_status']) {
                            $documentName = $file['_data'];
                        }
                    } else {
                        $documentName = ($document['file'] ?? null);
                    }
                    //----------------

                    if ( isset($document['expiry_date']) && !empty($document['expiry_date'])) {
                        if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 60 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 60 days'));
                        } else if(strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 30 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 30 days'));
                        } else if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 7 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 7 days'));
                        } else if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 1 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 1 days'));
                        } else {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date']));
                        }
                    } else {
                        $sendNotificationDate = null;
                    }

                    if (!empty($document['file'])) {

                        $facilityDocument = FacilityDocument::updateOrCreate([
                            'document_id' => $document['document_id'] ?? null,
                            'facility_id' => $facility->id,
                        ], [
                            'document_name' => $documentName,
                            'expiry_date' => $document['expiry_date'] ?? null,
                            'send_notification_date' => $sendNotificationDate,
                            'document_approval' => 'approved',
                            'show_in_document_approval' => 'no',
                            'show_in_notification' => 'no',
                            'updated_by' => $authUser->id,
                            'updated_at' => now(),
                        ]);
                    }
                }
            }
            //--------------------------

            // Send user email with password
            if ($user->email != $request['email']) {
                if (!empty($user)) {
                    $emailTemplate = config('constants.admin_email_path') . 'user-welcome-email';
                    $emailData = [
                        'template' => $emailTemplate,
                        'data' => [
                            'name' => ucwords($request['name']),
                            'email' => $request['email'],
                            'subject' => __('subjects.user_welcome', ['app_name' => config('app.name')]),
                            'password' => $randomPassword,
                        ],
                    ];

                    if (config('app.server') == 'AWS') {
                        SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                    } else {
                        $data = $emailData['data'];
                        Mail::send($emailTemplate, $data, function ($message) use ($data) {
                            $message->to($data['email']);
                            $message->subject($data['subject']);
                        });
                    }
                }
            }
            //------------------------------

            // Facility Activity
            create_facility_activity($facility->id, 'account-updated', __('facility_activities.account_updated'), $authUser->id);
            //------------------

            DB::commit();
        } catch (\Exception $e) {
            $facilityUpdate = null;
            $errorMessage = $e->getMessage();
            p($errorMessage);
            DB::rollback();
        }
        //----------------

        if (!is_null($facilityUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Facility']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.active')->with(['notification' => $notification]);
        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Facility']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.edit', ['id' => ev($facility->id)])->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * View facility details.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 12 Aug 2020
     */
    public function details(Request $request, $id)
    {
        // Get facility
        $facility = Facility::with('country', 'state', 'city', 'user', 'facility_group', 'activities')
            ->with(['plans' => function ($query) {
                $query->where('plans.status', 'active');
            }])->where('id', dv($id))->first();

        //-------------

        // Get facility favourites
        $hcpFavourites = $this->favouritesAndBlocklist->get_facilities_favourites($facility->id);
        //------------------------

        // Get facility blocklist
        $hcpBlocklist = $this->favouritesAndBlocklist->get_facilities_blocklist($facility->id);
        //-----------------------

        // Get Shifts
        $shiftWhere = ['facility_id' => $facility->id];
        $shifts = $this->shift->getAll($shiftWhere, true, $request);
        //-----------

        // Get Documents
        $documents = $this->facility_document->find_facility_document_paginate($facility->id, $request);
        //--------------

        // Get facility activities
        $facilityActivityWhere = ['facility_id' => $facility->id];
        $facilityActivities = $this->facility_activity->getAll($facilityActivityWhere, true);
        //------------------------

        // Get Current Plan
        $facilityActivePlan = get_facility_active_plan($facility->id);
        //-----------------


        // Get Current Plan
        if (!empty($facilityActivePlan) && $facilityActivePlan['plan_id'] != 4 && !empty($facilityActivePlan['stripe_subscriptions_id'])) {
            $stripe = new \Stripe\StripeClient(env('STRIPE_SECRET'));
            $subscription = $stripe->subscriptions->retrieve(
                $facilityActivePlan['stripe_subscriptions_id'],
                []
            );
        } else {
            $subscription = null;
        }
        //-----------------

        $this->viewData['facility'] = $facility;
        $this->viewData['hcpFavourites'] = $hcpFavourites;
        $this->viewData['hcpBlocklist'] = $hcpBlocklist;
        $this->viewData['shifts'] = $shifts;
        $this->viewData['documents'] = $documents;
        $this->viewData['facilityActivities'] = $facilityActivities;
        $this->viewData['request'] = $request->all();
        $this->viewData['subscription'] = $subscription;

        return view('admin-panel.facilities.details')->with($this->viewData);
    }

    /**
     * View all favorites hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 29 Dec 2020
     */
    public function viewAllFavoritesHcps(Request $request, $id)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get facility
        $facility = Facility::with('country', 'state', 'city', 'user', 'facility_group', 'activities')
            ->with(['plans' => function ($query) {
                $query->where('plans.status', 'active');
            }])->where('id', dv($id))->first();

        //-------------

        // Get Categories
        $categories = $this->category->get(['status' => 'active']);
        //---------------

        // Get Professions
        $professions = $this->profession->get(['status' => 'active']);
        //----------------

        // Get facility favourites
        $where = [];
        $hcps = $this->hcp->get_hcp_marked_by_facility($where, $request, dv($id), 'favourite');
        //------------------------

        // Get States
        $states = State::active()->orderBy('name', 'ASC')->get();
        //-----------

        $this->viewData['authUser'] = $authUser;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['facility'] = $facility;
        $this->viewData['states'] = $states;
        $this->viewData['request'] = $request->all();

        return view('admin-panel.facilities.view-all-favorites-hcps')->with($this->viewData);
    }

    /**
     * View all favorites hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 29 Dec 2020
     */
    public function viewAllBlockedHcps(Request $request, $id)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get facility
        $facility = Facility::with('country', 'state', 'city', 'user', 'facility_group', 'activities')
            ->with(['plans' => function ($query) {
                $query->where('plans.status', 'active');
            }])->where('id', dv($id))->first();

        //-------------

        // Get Categories
        $categories = $this->category->get(['status' => 'active']);
        //---------------

        // Get Professions
        $professions = $this->profession->get(['status' => 'active']);
        //----------------

        // Get facility favourites
        $where = [];
        $hcps = $this->hcp->get_hcp_marked_by_facility($where, $request, dv($id), 'blocked');
        //------------------------

        // Get States
        $states = State::active()->orderBy('name', 'ASC')->get();
        //-----------

        $this->viewData['authUser'] = $authUser;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['facility'] = $facility;
        $this->viewData['states'] = $states;
        $this->viewData['request'] = $request->all();

        return view('admin-panel.facilities.view-all-blocked-hcps')->with($this->viewData);
    }

    /**
     * View all hcps for favorites & blocklist.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 22 Sep 2020
     */
    public function viewAllHcpForFavoritesAndBlocklist(Request $request, $facilityId)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get facility
        $facility = Facility::where('id', dv($facilityId))->first();
        //-------------

        // Get hcps
        $hcps = $this->hcp->get_hcp_without_marked_by_facility(dv($facilityId), $facility->state_id);
        //---------

        $this->viewData['authUser'] = $authUser;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['facilityId'] = $facilityId;

        return view('admin-panel.hcps.view-all-for-favorites-blocklist')->with($this->viewData);
    }

    /**
     * Add hcp to favorites.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Sep 2020
     */
    public function addHcpFavorites(Request $request, $hcpId, $facilityId)
    {

        // Get User
        $authUser = auth()->user();
        //---------

        $favourite = null;
        $data = [];

        // Add to blocklist
        DB::beginTransaction();
        try {

            $data = [
                'facility_id' => dv($facilityId),
                'hcp_id' => $hcpId,
                'marked_by' => 'facility',
                'type' => 'favourite',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            $favourite = $this->favouritesAndBlocklist->store($data);

            // Send Notification
            send_other_push_notification($hcpId, 'facility-marked-as-favourite', 'hcp', null, null, null, null, null, dv($facilityId));
            //------------------

            // Facility Activity
            create_facility_activity(dv($facilityId), 'mark-as-favourite', __('facility_activities.hcp_mark_as_favourite', ['hcp' => get_hcp_name($hcpId)]), $authUser->id);
            //------------------

            DB::commit();
        } catch (\Exception $exception) {
            $favourite = null;
            DB::rollback();
            return dashboard_redirect($exception);
        }
        //-----------------

        if (!is_null($favourite)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.favourite_removed'),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.favourite_removed_failed'),
                '_type' => 'error',
            ];
            //-----------------
        }

        return response()->json($notification, 200);
    }

    /**
     * Remove hcp to favourite.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Sep 2020
     */
    public function removeFavouriteHcp(Request $request, $id, $facilityId)
    {
        $getRecord = $this->favouritesAndBlocklist->find($id);

        // Send Notification
        if(!empty($getRecord)) {
            send_other_push_notification($getRecord['hcp_id'], 'facility-remove-favourite', 'hcp', null, null, null, null, null, dv($facilityId));
        }
        //------------------


        // Remove facility favourites
        $favourites = $this->favouritesAndBlocklist->delete($id);
        //---------------------------

        if ($favourites == true) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.favourite_removed'),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.details', ['id' => ev($facilityId), 'tabId' => '#favourite'])->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.favourite_removed_failed'),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.details', ['id' => ev($facilityId), 'tabId' => '#favourite'])->withInput()->with(['notification' => $notification]);
        }

    }

    /**
     * Add hcp to blocklist.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Sep 2020
     */
    public function addHcpBlocklist(Request $request, $hcpId, $facilityId)
    {

        // Get User
        $authUser = auth()->user();
        //---------

        $blocklist = null;
        $data = [];

        // Add to blocklist
        DB::beginTransaction();
        try {

            $data = [
                'facility_id' => dv($facilityId),
                'hcp_id' => $hcpId,
                'marked_by' => 'facility',
                'type' => 'blocked',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            $blocklist = $this->favouritesAndBlocklist->store($data);

            // Send Notification
            send_other_push_notification($hcpId, 'facility-added-on-blocklist', 'hcp', null, null, null, null, null, dv($facilityId));
            //------------------

            // Facility Activity
            create_facility_activity(dv($facilityId), 'mark-as-block', __('facility_activities.hcp_mark_as_block', ['hcp' => get_hcp_name($hcpId)]), $authUser->id);
            //------------------

            DB::commit();
        } catch (\Exception $exception) {
            $blocklist = null;
            DB::rollback();
            return dashboard_redirect($exception);
        }
        //-----------------

        if (!is_null($blocklist)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.blocklist_added'),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.blocklist_added_failed'),
                '_type' => 'error',
            ];
            //-----------------
        }

        return response()->json($notification, 200);

    }

    /**
     * Remove hcp to blocklist.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Sep 2020
     */
    public function removeBlocklistHcp(Request $request, $id, $facilityId)
    {
        $getRecord = $this->favouritesAndBlocklist->find($id);

        // Send Notification
        if(!empty($getRecord)) {
            send_other_push_notification($getRecord['hcp_id'], 'facility-remove-from-blocklist', 'hcp', null, null, null, null, null, $facilityId);
        }
        //------------------

        // Remove facility blocklist
        $blocklist = $this->favouritesAndBlocklist->delete($id);
        //---------------------------

        if ($blocklist == true) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.blocklist_removed'),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.details', ['id' => ev($facilityId), 'tabId' => '#blocklist'])->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.blocklist_removed_failed'),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.details', ['id' => ev($facilityId), 'tabId' => '#blocklist'])->withInput()->with(['notification' => $notification]);
        }

    }

    /**
     * Export Facility.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 06 Jan 2021
     */
    public function facilityExport(Request $request, $status = null)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['request']['export'] = true;
            unset($request['request']['page']);
            unset($request['per_page']);

            if($request['status'] == 'active') {
                $where = [['status', '!=', 'archived']];
            } else {
                $where['status'] = $request['status'];
            }
            return Excel::download(new FacilitiesExport($this->facility,$where,$request), 'facility.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Export Facility.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 08 Jan 2021
     */
    public function facilityHcpExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['facility_hcp_export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new FacilityHcpExport($this->hcp,$where,$request,$request['facilityId'], $request['type']), 'hcps.xls');

        } catch (\Exception $exception) {

            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Change Plan.
     *
     * @author Yamini
     * @created 6 Jan 2021
     */
    public function currentPlan(){
        try {
            // Get users
            $authUser = auth()->user();
            //----------

            if (!empty($authUser->facility) && $authUser->facility->status != 'active') {
                return dashboard_redirect(__('messages.facility_page_access_error'));
            } else if(!empty($authUser->facility)) {
                $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
                if (empty($facilityActivePlan)) {
                    return redirect()->route('adminPanel.facilities.selectPlan')->with('error', __('messages.facility_plan_expiry_error'));
                }
            }

            // Get Current Plan
            $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
            //-----------------

            // Get Current Plan
            if (!empty($facilityActivePlan) && $facilityActivePlan['plan_id'] != 4 && !empty($facilityActivePlan['stripe_subscriptions_id'])) {
                $stripe = new \Stripe\StripeClient(env('STRIPE_SECRET'));
                $subscription = $stripe->subscriptions->retrieve(
                    $facilityActivePlan['stripe_subscriptions_id'],
                    []
                );
            } else {
                $subscription = null;
            }
            //-----------------

            // Get Current Shift Count
            $shiftCount = $this->shift->shift_where(['facility_id' => $authUser->facility->id])->count();
            //------------------------

            // Get Plans
            $planWhere = [];
            $plans = $this->plan->getAll($planWhere);
            //----------

            // Get Professions
            $professionWhere = [
                'status' => 'active'
            ];
            $professions = $this->profession->getAll($professionWhere, true);
            //----------------

            $profile = $this->facility->find_facility($authUser->facility->id);

            return view('admin-panel.facilities.plan', compact('plans', 'professions','profile', 'subscription', 'shiftCount', 'facilityActivePlan'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    /**
     * Current Plan.
     *
     * @author Yamini
     * @created 6 Jan 2021
     */
    public function changePlan(){
        try {
            // Get users
            $authUser = auth()->user();
            //----------

            // Get Current Plan
            $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
            //-----------------

            // Get Current Plan
            $stripe = new \Stripe\StripeClient(env('STRIPE_SECRET'));
            $subscription = $stripe->subscriptions->retrieve(
                $facilityActivePlan['stripe_subscriptions_id'],
                []
            );
            //-----------------

            // Get Plans
            $planWhere = [['id', '!=', '4'], ['id', '>', $facilityActivePlan['plan_id']]];
            $plans = $this->plan->getAll($planWhere, true);
            //----------------

            $profile = $this->facility->find_facility($authUser->facility->id);

            return view('admin-panel.facilities.changePlan', compact('plans','profile', 'facilityActivePlan', 'subscription'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    /**
     * Update Facility Plan.
     *
     * @author Yamini
     * @created 6 Jan 2021
     */
    public function updatePlan(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $facilityPlan = null;
        $sessionId = null;
        $startDate = date('Y-m-d');
        $notificationDate = null;
        $amount = null;
        $priceKey = null;
        $productKey = null;

        DB::beginTransaction();
        try {

            // Get Current Plan
            $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
            //-----------------

            if ($facilityActivePlan['plan_cycle'] == $request['plan_cycle'] && $facilityActivePlan['plan_id'] == $request['plan_id']) {
                return redirect()->route('adminPanel.facilities.changePlan')->with(['error' => __('messages.facillity_plan_cant_buy_same_plan')]);
            }

            // Get Plan Details
            $plan = Plan::where('id', $request['plan_id'])->first();
            //-----------------

            if($request['plan_cycle'] == 'yearly') {
                $endDate = date('Y-m-d',strtotime("+1 year", strtotime($startDate)));
                $notificationDate =  date('Y-m-d', strtotime('-1 months', strtotime($endDate)));
                $priceKey = $plan['stripe_yearly_price_key'];
                $amount = $plan['yearly_price'];
            } else {
                $endDate = date('Y-m-d',strtotime("+1 month", strtotime($startDate)));
                $notificationDate =  date('Y-m-d', strtotime('-7 days', strtotime($endDate)));
                $priceKey = $plan['stripe_monthly_price_key'];
                $amount = $plan['monthly_price'];
            }

            // Set Key
            \Stripe\Stripe::setApiKey(env('STRIPE_SECRET'));
            //--------

            $subscription = \Stripe\Subscription::retrieve($facilityActivePlan['stripe_subscriptions_id']);
            $subscriptionUpdated = \Stripe\Subscription::update($facilityActivePlan['stripe_subscriptions_id'],
            [
                'cancel_at_period_end' => false,
                'proration_behavior' => 'create_prorations',
                'items' => [
                    [
                        'id' => $subscription->items->data[0]->id,
                        'price' => $priceKey,
                    ],
                ],
            ]);

            // Set Plan
            $planDetailsJson = [
                'plan_id' => $request['plan_id'],
                'name' => $plan->name,
                'description' => $plan->description,
                'plan_cycle'  => $request['plan_cycle'],
                'start_date'  => $startDate,
                'expiry_date' => $endDate,
                'monthly_price' => $plan['monthly_price'],
                '6_month_price' => $plan['6_month_price'],
                'yearly_price' => $plan['yearly_price'],
                'payment_amount' => $amount,
                'notification_date' => $notificationDate,
                'facility_id' => $authUser->facility->id,
                'price_key' => $priceKey,
                'facility_id' => $authUser->facility->id,
                'last_payment_date' => now(),
            ];
            //----------

            // Set Plan
            $planDetails = [
                'plan_id' => $request['plan_id'],
                'plan_cycle'  => $request['plan_cycle'],
                'start_date'  => $startDate,
                'plan_details'  => json_encode($planDetailsJson, true),
                'expiry_date' => null,
                'payment_amount' => $amount,
                'notification_date' => $notificationDate,
            ];
            //----------

            $this->facility_plan->update($planDetails, ['id' => $facilityActivePlan['id']]);

            // Facility Activity
            create_facility_activity($authUser->facility->id, 'plan-update', __('facility_activities.plan_update'), $authUser->id);
            //------------------

            DB::commit();
        } catch (\Exception $exception) {
            $subscriptionUpdated = null;

            DB::rollback();
        }

        if(!is_null($subscriptionUpdated)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.facility_plan_update_successfully'),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.profile.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.facility_plan_update_failed'),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.facilities.changePlan')->with(['notification' => $notification]);
        }
    }

    /**
     * Disable Current Plan.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 14 Jan 2021
     */
    public function disablePlan(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $facilityPlan = null;

        DB::beginTransaction();
        try {

            // Get Current Plan
            $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
            //-----------------

            // Update Plan
            $data = [
                'status' => 'disable',
                'disable_date' => now(),
                'updated_by' => $authUser->id,
            ];
            $facilityPlan = FacilityPlan::where('id', $facilityActivePlan->id)->update($data);
            //------------

            DB::commit();
        } catch (\Exception $exception) {
            $facilityPlan = null;
            DB::rollback();
        }

        if (!is_null($facilityPlan)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }
        return response()->json($response, 200);
    }

    /**
     * Reactive Plan.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 14 Jan 2021
     */
    public function reactivePlan(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $facilityPlan = null;

        DB::beginTransaction();
        try {

            // Get Current Plan
            $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
            //-----------------

            // Update Plan
            $data = [
                'status' => 'active',
                'disable_date' => null,
                'updated_by' => $authUser->id,
            ];
            $facilityPlan = FacilityPlan::where('id', $facilityActivePlan->id)->update($data);
            //------------

            DB::commit();
        } catch (\Exception $exception) {
            $facilityPlan = null;
            DB::rollback();
        }

        if (!is_null($facilityPlan)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }
        return response()->json($response, 200);
    }

    /**
     * Select Plan.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Feb 2021
     */
    public function selectPlan(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Plans
            $planWhere = [];
            $plans = $this->plan->getAll($planWhere, true);
            //----------

            // Get Professions
            $professionWhere = [
                'status' => 'active'
            ];
            $professions = $this->profession->getAll($professionWhere, true);
            //----------------

            // Free Plan
            $freePlan = get_trial_plan_configurations();
            //----------

            // Get Supporting Page
            $supportingPage = $this->supporting_page->getAll([]);
            //--------------------

            return view('admin-panel.facilities.select-plan', compact('plans', 'professions', 'freePlan', 'supportingPage', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Buy Plan.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Feb 2021
     */
    public function buyPlan(Request $request, Response $response)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $errorMessage = null;
        $sessionId = null;
        $startDate = date('Y-m-d');
        $notificationDate = null;
        $amount = null;
        $priceKey = null;
        $productKey = null;

        try {

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Set Key
            \Stripe\Stripe::setApiKey(env('STRIPE_SECRET'));
            //--------

            // Update Pending Transaction
            $this->transaction->update(['status' => 'cancelled'], ['facility_id' => $authUser->facility->id, 'amount_for' => 'facility', 'amount_type' => 'subscription', 'status' => 'pending']);
            //---------------------------

            // Get Plan Details
            $plan = Plan::where('id', $request['planId'])->first();
            //-----------------

            if($request['planType'] == 'yearly') {
                $endDate = date('Y-m-d',strtotime("+1 year", strtotime($startDate)));
                $notificationDate =  date('Y-m-d', strtotime('-1 months', strtotime($endDate)));
                $priceKey = $plan['stripe_yearly_price_key'];
                $amount = $plan['yearly_price'];
            } else {
                $endDate = date('Y-m-d',strtotime("+1 month", strtotime($startDate)));
                $notificationDate =  date('Y-m-d', strtotime('-7 days', strtotime($endDate)));
                $priceKey = $plan['stripe_monthly_price_key'];
                $amount = $plan['monthly_price'];
            }

            // Set Plan
            $planDetails = [
                'plan_id' => $request['planId'],
                'name' => $plan->name,
                'description' => $plan->description,
                'plan_cycle'  => $request['planType'],
                'start_date'  => $startDate,
                'expiry_date' => $endDate,
                'monthly_price' => $plan['monthly_price'],
                '6_month_price' => $plan['6_month_price'],
                'yearly_price' => $plan['yearly_price'],
                'payment_amount' => $amount,
                'notification_date' => $notificationDate,
                'facility_id' => $authUser->facility->id,
                'price_key' => $priceKey,
                'facility_id' => $authUser->facility->id,
                'last_payment_date' => now(),
            ];
            //----------

            // Checkout page session
            $checkoutSession = Stripe\Checkout\Session::create([
                'success_url' => route('adminPanel.facilities.payment-success').'?session_id={CHECKOUT_SESSION_ID}',
                'cancel_url' => route('adminPanel.facilities.payment-cancel').'?session_id={CHECKOUT_SESSION_ID}',
                'payment_method_types' => ['card'],
                'mode' => 'subscription',
                'customer_email' => $authUser->email,
                'allow_promotion_codes' => 'true',
                'line_items' => [[
                    'price' => $priceKey,
                    'quantity' => 1,
                    'tax_rates' => [$generalConfiguration['stripe_tax_rates_key']],
                ]]
            ]);
            $sessionId = $checkoutSession['id'];
            //----------------------

            // Store transaction
            $maxInvoiceId = $this->transaction->get_max_invoice_id();
            if (!empty($maxInvoiceId)) {
                $invoiceId = sprintf("%'03d", ($maxInvoiceId['id']+1));
            } else {
                $invoiceId = sprintf("%'03d", 1);
            }
            $invoiceId = $authUser->facility->id.$invoiceId;

            $transactionData = [
                'facility_id' => $authUser->facility->id,
                'facility_plan_id' => null,
                'invoice_id' => $invoiceId,
                'facility_plan_json' => json_encode($planDetails, true),
                'facility_amount' => $amount,
                'amount_for' => 'facility',
                'amount_type' => 'subscription-temp',
                'status' => 'pending',
                'stripe_payment_session_id' => $sessionId,
            ];
            $transaction = $this->transaction->store($transactionData);
            //------------------

        } catch (\Exception $exception) {
            return response()->json(['error' => [
                'message' => $exception->getMessage(),
            ]], 200);
        }

        return response()->json(['sessionId' => $sessionId], 200);
    }

    /**
     * Plan Payment Success.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 25 Feb 2021
     */
    public function paymentSuccuess(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Set Key
        \Stripe\Stripe::setApiKey(env('STRIPE_SECRET'));
        //--------

        // Get Current Plan
        $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
        //-----------------

        // Get payment details
        $id = $request['session_id'];
        $checkoutSession = \Stripe\Checkout\Session::retrieve($id);
        //--------------------

        // Get transaction
        $transaction = $this->transaction->find_transaction_with_stripe_session($id);
        //----------------

        // Plan
        $plan = json_decode($transaction->facility_plan_json, true);
        //-----

        // Update Facility
        $facility = $this->facility->update(['stripe_customer_id' => $checkoutSession['customer']], ['id' => $authUser->facility->id]);
        //----------------

        // Expired Old Plan
        $this->facility_plan->update(['status' => 'expired', 'expiry_date' => date('Y-m-d'), 'notification_date' => null], ['facility_id' => $authUser->facility->id]);
        //-----------------

        // Save Facility Plan
        $payAmount = number_format($checkoutSession['amount_total']/100, 2);
        $planData = [
            'plan_id' => $plan['plan_id'],
            'facility_id' => $plan['facility_id'],
            'start_date' => $plan['start_date'],
            'expiry_date' => null,
            'plan_cycle' => $plan['plan_cycle'],
            'plan_details' => $transaction->facility_plan_json,
            'payment_amount' => $payAmount,
            'last_payment_date' => now(),
            'notification_date' => $plan['notification_date'],
            'stripe_subscriptions_id' => $checkoutSession['subscription'],
            'status' => 'active',
            'created_by' => $authUser->id,
            'updated_by' => $authUser->id,
        ];
        $facilityPlan = $this->facility_plan->store($planData);
        //-------------------

        // Facility Activity
        if (empty($facilityActivePlan)) {
            create_facility_activity($authUser->facility->id, 'plan-added', __('facility_activities.plan_added'), $authUser->id);
        } else {
            create_facility_activity($authUser->facility->id, 'plan-updated', __('facility_activities.plan_update'), $authUser->id);
        }
        //------------------

        // Transaction update
        $this->transaction->update(['transaction_id' => $checkoutSession['id'], 'facility_amount' => $payAmount, 'status' => 'completed'], ['id' => $transaction->id]);
        //-------------------

        $this->viewData['checkoutSession'] = $checkoutSession;
        $this->viewData['transaction'] = $transaction;

        return view('admin-panel.payment.succuess')->with($this->viewData);
    }

    /**
     * Plan Payment Success.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 25 Feb 2021
     */
    public function paymentCancel(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Set Key
        \Stripe\Stripe::setApiKey(env('STRIPE_SECRET'));
        //--------

        // Get payment details
        $id = $request['session_id'];
        $checkoutSession = \Stripe\Checkout\Session::retrieve($id);
        //--------------------

        // Get transaction
        $transaction = $this->transaction->find_transaction_with_stripe_session($id);
        //----------------

        // transaction update
        $this->transaction->update(['transaction_id' => $checkoutSession['id'], 'status' => 'cancelled'], ['id' => $transaction->id]);
        //-------------------

        $this->viewData['checkoutSession'] = $checkoutSession;
        $this->viewData['transaction'] = $transaction;

        return view('admin-panel.payment.cancel')->with($this->viewData);
    }

    /**
     * Cancel Current Plan.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 05 March 2021
     */
    public function cancelPlan(Request $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        $facilityPlan = null;

        DB::beginTransaction();
        try {

            // Set Key
            \Stripe\Stripe::setApiKey(env('STRIPE_SECRET'));
            //--------

            // Get Current Plan
            $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
            //-----------------

            // Cancel Subscriptions
            $stripe = new \Stripe\StripeClient(env('STRIPE_SECRET'));
            $subscription = $stripe->subscriptions->retrieve(
                $facilityActivePlan['stripe_subscriptions_id'],
                []
            );

            \Stripe\Subscription::update(
                $facilityActivePlan['stripe_subscriptions_id'],
                [
                  'cancel_at_period_end' => true,
                ]
            );
            //---------------------

            // Update Plan
            $data = [
                'status' => 'cancel',
                'expiry_date' => date("Y-m-d", $subscription['current_period_end']),
                'disable_date' => now(),
                'updated_by' => $authUser->id,
            ];
            $facilityPlan = FacilityPlan::where('id', $facilityActivePlan->id)->update($data);
            //------------

            DB::commit();
        } catch (\Exception $exception) {
            $facilityPlan = null;
            DB::rollback();
        }

        if (!is_null($facilityPlan)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }

        return response()->json($response, 200);
    }

    /**
     * Trial Plan.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Feb 2021
     */
    public function buyTrialPlan(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $errorMessage = null;
        $sessionId = null;
        $startDate = date('Y-m-d');
        $notificationDate = null;
        $amount = 0;
        $priceKey = null;
        $productKey = null;
        $facilityPlan = null;

        DB::beginTransaction();
        try {
            // Free Plan
            $freePlan = get_trial_plan_configurations();
            //----------

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Get Plan Details
            $plan = Plan::where('id', $request['plan_id'])->first();
            //-----------------

            $endDate = date('Y-m-d',strtotime("+".$freePlan['days_of_shift_posting_limit_in_trial_acc']." day", strtotime($startDate)));
            $notificationDate =  date('Y-m-d', strtotime('-1 days', strtotime($endDate)));

            // Set Plan
            $planDetails = [
                'plan_id' => $request['plan_id'],
                'name' => $plan->name,
                'description' => $plan->description,
                'plan_cycle'  => null,
                'start_date'  => $startDate,
                'expiry_date' => $endDate,
                'monthly_price' => $plan['monthly_price'],
                '6_month_price' => $plan['6_month_price'],
                'yearly_price' => $plan['yearly_price'],
                'payment_amount' => $amount,
                'notification_date' => $notificationDate,
                'facility_id' => $authUser->facility->id,
                'price_key' => $priceKey,
                'facility_id' => $authUser->facility->id,
                'last_payment_date' => now(),
            ];
            //----------

            // Store Plan
            $planData = [
                'plan_id' => $request['plan_id'],
                'facility_id' => $authUser->facility->id,
                'start_date' => $startDate,
                'expiry_date' => $endDate,
                'plan_cycle' => null,
                'plan_details' => json_encode($planDetails, true),
                'payment_amount' => $amount,
                'last_payment_date' => now(),
                'notification_date' => $notificationDate,
                'stripe_subscriptions_id' => null,
                'status' => 'active',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
                'shift_posting_limit_in_trial_account' => $freePlan['shift_posting_limit_in_trial_acc'],
                'days_of_shift_posting_limit_in_trial_account' => $freePlan['days_of_shift_posting_limit_in_trial_acc'],

            ];

            $facilityPlan = $this->facility_plan->store($planData);
            //-----------

            // Facility Activity
            create_facility_activity($authUser->facility->id, 'plan-added', __('facility_activities.plan_added'), $authUser->id);
            //------------------


            DB::commit();
        } catch (\Exception $e) {
            $facilityPlan = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($facilityPlan)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_saved', ['records' => 'Plan']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.dashboard')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_saving_failed', ['records' => 'Plan']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.dashboard')->withInput()->with(['notification' => $notification]);
        }

    }

    /**
     * Accept Term Condition.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 15 March 2021
     */
    public function acceptTermCondition(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $facility = null;

        DB::beginTransaction();
        try {

            // Update Facility
            $facility = $this->facility->update(['term_condition_accept' => 1], ['id' => $request['facility_id']]);
            //----------------

            DB::commit();
        } catch (\Exception $exception) {
            $facility = null;
            DB::rollback();
        }

        if (!is_null($facility)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.records_saved'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.records_saving_failed'),
                '_type' => 'error',
            ];
        }
        return response()->json($response, 200);
    }

    public function modifyTrialPlan(Request $request){
        // Get users
        $authUser = auth()->user();
        //----------

        $errorMessage = null;
        $sessionId = null;
        $startDate = date('Y-m-d');
        $notificationDate = null;
        $amount = 0;
        $priceKey = null;
        $productKey = null;
        $facilityPlan = null;

        DB::beginTransaction();
        try {
            // Free Plan
            $freePlan = get_trial_plan_configurations();
            //----------

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Get Plan Details
            $plan = Plan::where('id', $request['plan_id'])->first();
            //-----------------
            $endDate = $request->modify_expire_date;
            $notificationDate =  date('Y-m-d', strtotime('-1 days', strtotime($endDate)));

            // Set Plan
            $planDetails = [
                'plan_id' => $request['plan_id'],
                'name' => $plan->name,
                'description' => $plan->description,
                'plan_cycle'  => null,
                'start_date'  => $startDate,
                'expiry_date' => $endDate,
                'monthly_price' => $plan['monthly_price'],
                '6_month_price' => $plan['6_month_price'],
                'yearly_price' => $plan['yearly_price'],
                'payment_amount' => $amount,
                'notification_date' => $notificationDate,
                'facility_id' => $request->facility_id,
                'price_key' => $priceKey,
                'facility_id' => $request->facility_id,
                'last_payment_date' => now(),
            ];
            //----------
            
            // Store Plan
            $planData = [
                'plan_id' => $request['plan_id'],
                'facility_id' => $request->facility_id,
                'start_date' => $startDate,
                'expiry_date' => $endDate,
                'plan_cycle' => null,
                'plan_details' => json_encode($planDetails, true),
                'payment_amount' => $amount,
                'last_payment_date' => now(),
                'notification_date' => $notificationDate,
                'stripe_subscriptions_id' => null,
                'status' => 'active',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
                'shift_posting_limit_in_trial_account' => $freePlan['shift_posting_limit_in_trial_acc'],
                'days_of_shift_posting_limit_in_trial_account' => $freePlan['days_of_shift_posting_limit_in_trial_acc'],

            ];

            $facilityPlan = $this->facility_plan->update($planData,['id'=>$request->facility_plan_id]);
            //-----------

            // Facility Activity
            create_facility_activity($request->facility_id, 'trial-plan-modified', __('facility_activities.trial-plan-modified'), $authUser->id);
            //------------------


            DB::commit();
        } catch (\Exception $e) {
            $facilityPlan = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($facilityPlan)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_saved', ['records' => 'Plan']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.dashboard')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_saving_failed', ['records' => 'Plan']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.dashboard')->withInput()->with(['notification' => $notification]);
        }
    }
}
