<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Interfaces\FacilityGroupInterface;
use App\Interfaces\FacilityInterface;
use App\Http\Requests\AdminPanel\ValidateFacilityGroup;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use App\Exports\FacilitiesGroupsExport;
use Excel;
use App\Interfaces\FacilityGroupAdminInterface;
use App\User;
use Illuminate\Support\Facades\Mail;
use Spatie\Permission\Models\Permission;

class FacilityGroupController extends Controller
{

    private $facilityGroup, $facility;
    public function __construct(FacilityGroupInterface $facilityGroup, FacilityInterface $facility,FacilityGroupAdminInterface $facilityGroupAdminInterface){
        $this->middleware('auth.admin');
        $this->facility_group = $facilityGroup;
        $this->facility = $facility;
        $this->facility_group_admin = $facilityGroupAdminInterface;
    }

    /**
     * View Facility Group.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 03 Oct 2020
    */
    public function index(Request $request)
    {
        try {

            // Get Facility Group
            $where = [];
            $facilityGroups = $this->facility_group->getAll($where, true, $request);
            //-------------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.facility-groups.index', compact('facilityGroups', 'request'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }


    /**
     * View create facility group.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 03 Oct 2020
    */
    public function create()
    {
        try {
            // Get Facility Group Admin
            $where = [];

//            $facilityGroupAdmin = $this->facility_group_admin->get_list(['status' => 'active']);
            // p($facilityGroupAdmin);
            return view('admin-panel.facility-groups.create');
        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Store facility group.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 03 Oct 2020
    */
    public function store(ValidateFacilityGroup $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $facilityGroup = null;
        $facilityGroupData = [];
        // $randomPassword = str_random(8);
        $randomPassword = "12345678";

        DB::beginTransaction();
        try {
            // User data
//            $data = [
//                'name' => $request['name'],
//                'email' => $request['email'],
//                'password' => bcrypt($randomPassword),
//                'role_name' => 'facility-group',
//                'created_by' => $authUser->id,
//                'updated_by' => $authUser->id,
//            ];
//            $user = User::create($data);

            $facilityGroupData = [
//                'facility_group_admin_id' => json_encode($request['facility_group_admin']),
                'name' => $request['name'],
//                'user_id' => $user->id,
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            $facilityGroup = $this->facility_group->store($facilityGroupData);

            // Assign role
//            $user->assignRole('Facility Group');
//            // Assign admin permission to user
//            $permissions = Permission::where('panel_permissions', 'facility-group')->get()->toArray();
//            if (!is_null($authUser) && !is_null($permissions)) {
//                foreach($permissions as $permission){
//                    $user->givePermissionTo($permission['name']);
//                }
//            }
//            //--------------------------------
//            // Send user email with password
//            if (!empty($user)) {
//                $emailTemplate = config('constants.admin_email_path') . 'user-welcome-email';
//                $emailData = [
//                    'template' => $emailTemplate,
//                    'data' => [
//                        'name' => ucwords($request['name']),
//                        'email' => $request['email'],
//                        'subject' => __('subjects.user_welcome', ['app_name' => config('app.name')]),
//                        'password' => $randomPassword,
//                    ],
//                ];
//
//                if (config('app.server') == 'AWS') {
//                    SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
//                } else {
//                    $data = $emailData['data'];
//                    Mail::send($emailTemplate, $data, function ($message) use ($data) {
//                        $message->to($data['email']);
//                        $message->subject($data['subject']);
//                    });
//                }
//            }
            //------------------------------

            DB::commit();
        } catch (\Exception $exception) {
	p($exception->getMessage());
            $facilityGroup = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if(!is_null($facilityGroup)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Facility Group']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.facility-groups.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_creation_failed', ['record' => 'Facility Group']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.facility-groups.index')->with(['notification' => $notification]);
        }

    }

    /**
     * View edit facility group.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 03 Oct 2020
    */
    public function edit(Request $request, $id)
    {
        try {

            // Get facility group
            $facilityGroup = $this->facility_group->find_facility_group($id);
            //-------------------
//            $facilityGroupAdmin = $this->facility_group_admin->get_list(['status' => 'active']);

            return view('admin-panel.facility-groups.edit', compact('facilityGroup'));
        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Update facility group.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 03 Oct 2020
    */
    public function update(ValidateFacilityGroup $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $facilityGroup = null;
        $facilityGroupUpdate = null;
        $facilityGroupData = [];

        DB::beginTransaction();
        try {
            $facilityGroup = $this->facility_group->find_facility_group(dv($id));
            $facilityGroupData = [
                'name' => $request['name'],
//                'facility_group_admin_id' => json_encode($request['facility_group_admin']),
//                'email' => $request->email,
                'updated_by' => $authUser->id,
            ];

//            $user = $facilityGroup->User;
//            if(empty($user)){
//                // $randomPassword = str_random(8);
//                $randomPassword = "12345678";
//                // User data
//                $data = [
//                    'name' => $request['name'],
//                    'email' => $request['email'],
//                    'password' => bcrypt($randomPassword),
//                    'role_name' => 'facility-group',
//                    'created_by' => $authUser->id,
//                    'updated_by' => $authUser->id,
//                ];
//                $user = User::create($data);
//
//                $facilityGroupData['user_id'] = $user->id;
//
//                // Assign role
//                $user->assignRole('Facility Group');
//                // Assign admin permission to user
//                $permissions = Permission::where('panel_permissions', 'facility-group')->get()->toArray();
//                if (!is_null($authUser) && !is_null($permissions)) {
//                    foreach($permissions as $permission){
//                        $user->givePermissionTo($permission['name']);
//                    }
//                }
//                //--------------------------------
//                // Send user email with password
//                if (!empty($user)) {
//                    $emailTemplate = config('constants.admin_email_path') . 'user-welcome-email';
//                    $emailData = [
//                        'template' => $emailTemplate,
//                        'data' => [
//                            'name' => ucwords($request['name']),
//                            'email' => $request['email'],
//                            'subject' => __('subjects.user_welcome', ['app_name' => config('app.name')]),
//                            'password' => $randomPassword,
//                        ],
//                    ];
//
//                    if (config('app.server') == 'AWS') {
//                        SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
//                    } else {
//                        $data = $emailData['data'];
//                        Mail::send($emailTemplate, $data, function ($message) use ($data) {
//                            $message->to($data['email']);
//                            $message->subject($data['subject']);
//                        });
//                    }
//                }
//                //------------------------------
//            }

            $facilityGroupUpdate = $this->facility_group->update($facilityGroupData, ['id' => dv($id)]);

            DB::commit();
        } catch (\Exception $exception) {
            $facilityGroupUpdate = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }


        if (!is_null($facilityGroupUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Facility Group']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.facility-groups.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Facility Group']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.facility-groups.index')->with(['notification' => $notification]);
        }


    }

    /**
     * Change status.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 03 Oct 2020
    */
    public function changeStatus(Request $request, $id, $status)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $facilityGroup = null;
        $data = [];
        $where = [];

        DB::beginTransaction();
        try {

            $where = [
                'id' => dv($id)
            ];

            $data = [
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $facilityGroup = $this->facility_group->update($data, $where);

        DB::commit();
        } catch (\Exception $exception) {
            $facilityGroup = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($facilityGroup)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];
            //-----------------

            return response()->json($notification, 200);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
            //-----------------

            return response()->json($notification, 200);
        }
    }

    /**
     * View Facilities.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 03 Oct 2020
    */
    public function viewFacilities(Request $request, $id)
    {
        try {

            // Get facility group
            $facilityGroup = $this->facility_group->find_facility_group(dv($id));
            //------------------

            // Get Facilities
            $where = ['facility_group_id' => dv($id)];
            $facilities = $this->facility->get_facility_with_pagination($where);
            //---------------

            return view('admin-panel.facility-groups.view-facilities', compact('facilities', 'facilityGroup'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Get facilities.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 31 Oct 2020
     */
    public function getFacilities(Request $request)
    {
        // Get Facilities
        $where = ['facility_group_id' => $request['facility_group_id'], 'status' => 'active'];
        $facilities = $this->facility->getAll($where, true);
        //---------------

        // Set response
        if (count($facilities)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.record_found', ['record' => 'Facilities']),
                '_data' => $facilities,
            ];
        } else {
            $response = [
                '_status' => false,
                '_message' => __('messages.record_not_found', ['record' => 'Facilities']),
                '_data' => [],
            ];
        }
        //-------------

        return response()->json($response, 200);
    }

    /**
     * Get facilities for shift.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 31 Oct 2020
     */
    public function getFacilitiesForShift(Request $request)
    {
        // Get Facilities
        $request['profession_id'] = $request['profession_id'];
        $request['category_id'] = $request['category_id'];
        $request['level_id']  = $request['level_id'];
        $request['latitude']  = $request['hcp_latitude'];
        $request['longitude'] = $request['hcp_longitude'];
        $request['radius'] = $request['radius'];
        $request['facility_group_id'] = $request['facility_group_id'];
        $request['state_id'] = $request['hcp_state_id'];

        $facilities = $this->facility->get_facility_for_shift($request);
        //---------------

        // Set response
        if (count($facilities)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.record_found', ['record' => 'Facilities']),
                '_data' => $facilities,
            ];
        } else {
            $response = [
                '_status' => false,
                '_message' => __('messages.record_not_found', ['record' => 'Facilities']),
                '_data' => [],
            ];
        }
        //-------------

        return response()->json($response, 200);
    }

    /**
     * Export Facility.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 06 Jan 2021
     */
    public function export(Request $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new FacilitiesGroupsExport($this->facility_group,$where,$request), 'facility-groups.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }
}
