<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\AdminPanel\ValidateFacility;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Mail;
use App\Http\Traits\UploadImage;
use App\Http\Traits\UploadFile;
use App\Interfaces\HcpInterface;
use App\Interfaces\FavouritesAndBlocklistInterface;
use App\Interfaces\FacilityGroupInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\StateInterface;
use App\Interfaces\PlanInterface;
use App\Interfaces\ShiftInterface;
use App\Interfaces\DocumentInterface;
use App\Interfaces\FacilityDocumentInterface;
use App\Interfaces\CountryInterface;
use App\Interfaces\CityInterface;
use App\Interfaces\SuburbInterface;
use App\Interfaces\FacilityPlanInterface;
use App\Models\Facility;
use App\Models\FacilityDocument;
use App\Models\Plan;
use App\Models\Country;
use App\Models\State;
use App\Models\City;
use App\Models\Hcp;
use App\Models\FavouritesAndBlocklist;
use App\User;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\DocumentsExport;
use App\Exports\FacilityDocumentsExport;

class FacilityManageDocumentController extends Controller
{

    use UploadImage, UploadFile;

    private $hcp, $favouritesAndBlocklist, $facilityGroup, $facility, $state, $plan, $document, $facilityDocument, $countries, $cities, $suburbs;

    /**
     * @var array
     */
    public $viewData = [];

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(HcpInterface $hcp, FavouritesAndBlocklistInterface $favouritesAndBlocklist, FacilityGroupInterface $facilityGroup, FacilityInterface $facility, CountryInterface $countries, StateInterface $state, CityInterface $cities, SuburbInterface $suburbs, PlanInterface $plan, ShiftInterface $shift, DocumentInterface $document, FacilityDocumentInterface $facilityDocument, FacilityPlanInterface $facilityPlan)
    {
        $this->middleware('auth.admin');
        $this->hcp = $hcp;
        $this->favouritesAndBlocklist = $favouritesAndBlocklist;
        $this->facility_group = $facilityGroup;
        $this->facility = $facility;
        $this->state = $state;
        $this->countries = $countries;
        $this->cities = $cities;
        $this->suburbs = $suburbs;
        $this->plan = $plan;
        $this->shift = $shift;
        $this->document = $document;
        $this->facility_document = $facilityDocument;
        $this->facility_plan = $facilityPlan;
    }

    /**
     * View manange documents.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 11 Dec 2020
     */
    public function index(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Request
        $request = $request->all();
        //--------

        if (!empty($authUser->facility)) {
            $request['facility'] = $authUser->facility->id;
            $request['state_id'] = $authUser->facility->state_id;
            $this->viewData['facility'] = $authUser->facility;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $request['facility'] = $authUser->sub_admin->facility_id;
            $request['state_id'] = $authUser->sub_admin->facility->state_id;
            $this->viewData['facility'] = $authUser->sub_admin->facility;
        }

        // Get Facility Plan
        $facilityPlan = $this->facility_plan->get_facility_plan($request['facility']);
        //------------------

        // Documents
        $professionsIds = [];
        if (!empty($facilityPlan)) {
            foreach ($facilityPlan['plan']['professions'] as $professions) {
                $professionsIds[] = $professions['id'];
            }
            $request['professions'] = $professionsIds;
        }
        $where = [];
        $documents = $this->document->get_documents_facility_with_pagination($where, $request['facility'], $request);
        //----------

        $this->viewData['documents'] = $documents;
        $this->viewData['request'] = $request;

        return view('admin-panel.facility-manange-documents.index')->with($this->viewData);
    }


    /**
     * Upload document modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 11 Dec 2020
     */
    public function uploadDocumentModal(Request $request, $documentId)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Document
        $document = $this->document->find_document($documentId);
        //---------

        return view('admin-panel.includes.facilities.upload-document-modal', compact('document'));

    }

    /**
     * Upload document.
     *
     * @author Sumit
     * @created 11 Dec 2020
     */
    public function uploadDocument(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get facility
        $facility = $authUser->facility;
        //-------------

        $documentName = null;
        $facilityDocument = null;

        DB::beginTransaction();

        // Update Facility
        try {
            $name = strtolower(str_replace(' ', '-', $request['document_name']));

            // Upload file
            if (!empty($request['document_file']) && file_exists($request['document_file'])) {
                $path = config('constants.facility.facility_path') . '/' . $facility->facility_prefix . $facility->id . '/documents/';
                $file = $this->uploadFile($request['document_file'], $path, 75, $name);

                if ($file['_status']) {
                    $documentName = $file['_data'];
                }
            } else {
                $documentName = ($document['file'] ?? null);
            }
            //------------

            if (isset($request['expiry_date']) && !empty($request['expiry_date'])) {
                if (strtotime($request['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 60 days')))) {
                    $sendNotificationDate = date('Y-m-d', strtotime($request['expiry_date'] . ' - 60 days'));
                } else if(strtotime($request['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 30 days')))) {
                    $sendNotificationDate = date('Y-m-d', strtotime($request['expiry_date'] . ' - 30 days'));
                } else if (strtotime($request['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 7 days')))) {
                    $sendNotificationDate = date('Y-m-d', strtotime($request['expiry_date'] . ' - 7 days'));
                } else if (strtotime($request['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 1 days')))) {
                    $sendNotificationDate = date('Y-m-d', strtotime($request['expiry_date'] . ' - 1 days'));
                } else {
                    $sendNotificationDate = date('Y-m-d', strtotime($request['expiry_date']));
                }
            } else {
                $sendNotificationDate = null;
            }

            if (!empty($request['document_file'])) {

                $facilityDocument = FacilityDocument::updateOrCreate([
                    'document_id' => $request['document_id'] ?? null,
                    'facility_id' => $facility->id,
                ], [
                    'document_name' => $documentName,
                    'expiry_date' => $request['expiry_date'] ?? null,
                    'profession_id' => $request['profession_id'] ?? null,
                    'send_notification_date' => $sendNotificationDate,
                    'document_approval' => 'approved',
                    'show_in_document_approval' => 'no',
                    'show_in_notification' => 'no',
                    'created_by' => $authUser->id,
                    'updated_by' => $authUser->id,
                    'created_at' => now(),
                    'updated_at' => now(),
                ]);

            }

            DB::commit();
        } catch (\Exception $e) {
            $facilityDocument = null;
            $errorMessage = $e->getMessage();
            p($errorMessage );
            DB::rollback();
        }
        //----------------

        if (!is_null($facilityDocument)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_upload', ['records' => 'Document']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.facility-manage-document.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_upload_failed', ['records' => 'Document']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.facility-manage-document.index')->withInput()->with(['notification' => $notification]);
        }

    }


    /**
     * Facility Documents Export
     *
     * @return Excel
     *
     * @author Sumit
     * @created 26 Jan 2021
     */
    public function facilityDocumentsExport(Request $request, $id = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new FacilityDocumentsExport($this->document,$where,$request,$id), 'documents.xls');

        } catch (\Exception $exception) {

            return dashboard_redirect($exception->getMessage());
        }
    }
}
