<?php

namespace App\Http\Controllers\AdminPanel;

use App\Http\Controllers\Controller;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Carbon;
use App\Jobs\AdminPanel\SendEmailJob;
use App\Interfaces\ShiftInterface;
use App\Interfaces\ShiftActivityInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\TransactionInterface;
use App\Interfaces\HcpInterface;
use App\Models\CronJob;
use App\Models\Transaction;
use Illuminate\Support\Facades\Storage;
use PDF;
use Mail;
use Illuminate\Http\Request;
use App\Models\Facility;
use App\Models\Onesignal;

class GenerateInvoiceController extends Controller
{
    public function __construct(ShiftInterface $shift, ShiftActivityInterface $shiftActivity, FacilityInterface $facility, HcpInterface $hcp, TransactionInterface $transaction)
    {
        $this->shift = $shift;
        $this->shift_activity = $shiftActivity;
        $this->facility = $facility;
        $this->hcp = $hcp;
        $this->transaction = $transaction;
    }


    public function facility(Request $request)
    {

        //     $res=LogEntry::whereDate('created_at','<','2022-01-01')->delete();
        // p($res);
        // $log_entries=LogEntry::where('created_at','like','2022-01-15 07:31%')->where('user_id',652)->paginate(2);
        // p($log_entries);

        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/generate-invoice.log')]);

        // Current date
        $currentDate = Carbon::now()->toDateString();
        $currentTime = Carbon::now();
        $currentDay = strtolower(Carbon::parse($currentDate)->format('l'));
        //-------------

        $shiftUpdate = null;
        $shiftActivity = null;
        $invoiceId = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'facility-generate-invoice-cron')->where('status', 0)->first();
        //----------------

        if (!empty($cronJob)) {


            // Dev Configuration
            $devConfiguration = get_dev_configurations();
            $devConfiguration = (array)json_decode($devConfiguration);
            //----------------------

            if (!empty($devConfiguration) && isset($devConfiguration['invoice_cron_days'])) {
                $cronDays = explode(",", $devConfiguration['invoice_cron_days']->config_value);

                // if(in_array($currentDay, $cronDays)) {
                //     p('true');
                // } else {
                //     p('false');
                // }

            }

            //p($currentDay);

            // // Update cron status in processing
            // $cronJob->status = 1;
            // $cronJob->start_time = Carbon::now()->toDateTimeString();
            // $cronJob->save();
            // //---------------------------------

            // General Configuration
            $generalConfiguration = get_general_configuration();
            $gstPercent = $generalConfiguration['gst_percent'];
            //----------------------

            // Last Generated Invoice
            $generatedInvoice = [
                'amount_for' => 'facility',
            ];
            $lastGeneratedInvoice = $this->transaction->get_last_shift_generated_invoice();
            if (!empty($lastGeneratedInvoice)) {
                $invoiceStartDate = date('Y-m-d', strtotime($lastGeneratedInvoice['invoice_created_at']));
            } else {
                $invoiceStartDate = date('Y-m-d', strtotime("-7 day", strtotime(date('M d, Y'))));
            }
            $invoiceStartDate = "2024-12-01";
            $invoiceEndDate = "2024-12-20";
            // $invoiceEndDate = date('Y-m-d');
            //-----------------------

            // Get Facility Statements
            $facilityWhere = [
                //'shift_approved_time' => '2022-12-15',
                'id' => 1
            ];
            $facilities = $this->facility->get_facility_for_shift_invoice_generate($facilityWhere);

            //p($facilities);
//            dd($facilities);
            if (count($facilities)) {
                $invoiceId = '';
                $filename = '';
                $attach = '';
                $facilityTotalAmount = 0;
                $facilityGstAmount = 0;
                $shiftIds = [];
                $shifts = [];
                foreach ($facilities as $facility) {
                    // Get Max Invoice Id
                    $maxInvoiceId = $this->transaction->get_max_invoice_id();
                    if (!empty($maxInvoiceId)) {
                        $invoiceId = sprintf("%'03d", ($maxInvoiceId['id'] + 1));
                    } else {
                        $invoiceId = sprintf("%'03d", 1);
                    }
                    $invoiceId = $facility->id . $invoiceId;
                    //-------------------
                    if (count($facility->shifts)) {
                        // Get Approved Shift
                        $shiftFilter = [
                            // 'current_date' => date('Y-m-d'),
                            'current_date' => "2025-03-11",
                            'facility_id' => $facility->id,
                            'shift_ids' => $facility->shifts->pluck('id'),
                        ];
                        //p($shiftFilter);
                        $shifts = $this->shift->get_shift_invoice_generate($shiftFilter);
                        $facilityTotalAmount = $shifts->where('shift_status', '!=', '3')->sum('facility_amount');
                        $facilityGstAmount = $gstPercent * ($facilityTotalAmount / 100);
                        $shiftIds = $shifts->pluck('id');
                        //-------------------
                    } else {
                        $shifts = [];
                    }
                    //p($shifts);
                    if (count($facility->shifts) && count($shifts)) {
                        Log::channel('cronlog')->info("-----------------------");
                        Log::channel('cronlog')->info("generate facility invoice cron start");
                        Log::channel('cronlog')->info("facility id: " . $facility->facility_prefix . $facility->id);
                        Log::channel('cronlog')->info("facility invoice date range: " . $invoiceStartDate . ' - ' . $invoiceEndDate);
                        Log::channel('cronlog')->info("facility shift Ids :" . $shiftIds);
                        Log::channel('cronlog')->info("facility invoice Id " . $maxInvoiceId['invoice_prefix'] . $invoiceId);

                        // Update Transaction
                        //$filename = strtolower(str_replace(' ', '-', $facility->name.'-invoice-'.$maxInvoiceId['invoice_prefix'].$invoiceId.'-'.date('Y-m-d'))).'.pdf';
                        $filename = 'test-invoicess.pdf';

                        $transactionUpdateArr = [
                            'invoice_id' => $invoiceId,
                            'invoice_created_at' => date('Y-m-d'),
                            'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                            'invoice_gst_percent' => $gstPercent,
                            'invoice_gst_amount' => $facilityGstAmount,
                            'invoice_facility_amount_with_gst' => $facilityTotalAmount + $facilityGstAmount,
                            'invoice_file_name' => $filename,
                            'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_facillity_day'] . ' days')),
                        ];
//                        dd($transactionUpdateArr);
                        $transactionWhereArr = ['amount_for' => 'facility', 'invoice_id' => null];
//                        $this->transaction->update_generated_invoice($transactionUpdateArr,  $transactionWhereArr, $shiftIds);
                        //-------------------
//                        dd("done of of the shift", $transactionUpdateArr);
                        // Genrate Invoice PDF
                        $facilityPdf = PDF::loadView('invoices.facility-invoice', array('shifts' => $shifts, 'facility' => $facility, 'transaction' => $transactionUpdateArr));
                        $facilityPdf->setOptions(['isPhpEnabled' => true, 'isRemoteEnabled' => true]);
                        $facilityPdf->setPaper('a4', 'landscape');
                        return $facilityPdf->stream();
                        //return $facilityPdf->download('sample-invoice.pdf');

//p('done-downoad');
                        $file = Storage::disk(config('filesystems.default'))->put(config('constants.facility.invoice_path') . $filename, $facilityPdf->output());
                        //--------------------

                        // Send email notification
                        if (config('filesystems.default') == config('constants.file_systems.PUBLIC.value')) {
                            $attach = url('public/storage/' . config('constants.facility.invoice_path')) . '/' . urlencode($filename);
                        } elseif (config('filesystems.default') == config('constants.file_systems.S3.value')) {
                            $bucket = env('AWS_BUCKET');
                            $region = env('AWS_DEFAULT_REGION');
                            // $bucketBaseUrl = 'https://s3.' . $region . '.amazonaws.com/'. $bucket.'/';

                            $S3NewURL = env('AWS_CloudFront_URL') . '/' . config('constants.facility.invoice_path') . urlencode($filename);
                            $attach = str_replace('#', '%23', $S3NewURL);
                        }

                        $emailTemplate = config('constants.admin_email_path') . 'facility-invoice-email';
                        $emailData = [
                            'template' => $emailTemplate,
                            'data' => [
                                'name' => ucwords($facility['name']),
                                'email' => 'ayushsingh@apporio.in',
                                'subject' => __('subjects.facility_shift_invoice_generate', ['InvoiceNumber' => $maxInvoiceId['invoice_prefix'] . $invoiceId, 'InvoiceDate' => date('Y-m-d')]),
                                'InvoiceNumber' => $maxInvoiceId['invoice_prefix'] . $invoiceId,
                                'StatementDuration' => $invoiceStartDate . ' to ' . $invoiceEndDate,
                                //'cc' => $generalConfiguration['facillity_cust_care_email'],
                                'filename' => $attach,
                                'attach' => $attach,
                            ],
                        ];

                        if (config('app.server') == 'AWS') {
                            SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                        } else {
                            $data = $emailData['data'];
                            Mail::send($emailTemplate, $data, function ($message) use ($data) {
                                $message->to($data['email']);
                                $message->subject($data['subject']);
                                //$message->cc($data['cc']);
                                $message->attach($data['filename']);
                            });
                        }


                        //------------------------
//		p($emailData);
                        Log::channel('cronlog')->info("generate facility invoice cron completed");
                        Log::channel('cronlog')->info("-----------------------");
                    }
                }
            }
            //------------------------

            dd('done inovicing');

            // // Update cron status to completed
            // $cronJob->status = 0;
            // $cronJob->end_time = Carbon::now()->toDateTimeString();
            // $cronJob->save();
            // //---------------------------------

        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('facility generate invoice cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
    }

    public function hcpOld(Request $request)
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/generate-invoice.log')]);

        // Current date
        $currentDate = Carbon::now('Australia/Perth')->toDateString();
        $currentTime = Carbon::now();
        $currentDay = strtolower(Carbon::parse($currentDate)->format('l'));
        //-------------

        $shiftUpdate = null;
        $shiftActivity = null;
        $invoiceId = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'hcp-generate-invoice-cron')->where('status', 0)->first();
        //----------------

        if (!empty($cronJob)) {

            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now('Australia/Perth')->toDateTimeString();
            $cronJob->save();
            //---------------------------------

            // Dev Configuration
            $devConfiguration = get_dev_configurations();
            $devConfiguration = (array)json_decode($devConfiguration);
            //----------------------

            if (!empty($devConfiguration) && isset($devConfiguration['invoice_cron_days'])) {
                $cronDays = explode(",", $devConfiguration['invoice_cron_days']->config_value);

                if (in_array($currentDay, $cronDays)) {

                    // Last Generated Invoice
                    $generatedInvoice = [
                        'amount_for' => 'hcp',
                    ];
                    $lastGeneratedInvoice = $this->transaction->get_last_shift_generated_invoice($generatedInvoice);
                    if (!empty($lastGeneratedInvoice)) {
                        $invoiceStartDate = date('Y-m-d', strtotime($lastGeneratedInvoice['invoice_created_at']));
                    } else {
                        $invoiceStartDate = date('Y-m-d', strtotime("-7 day", strtotime(date('M d, Y'))));
                    }
                    $invoiceStartDate = date('Y-m-d', strtotime("-7 day", strtotime(date('M d, Y'))));
                    $invoiceEndDate = date('Y-m-d');
                    //-----------------------

                    // General Configuration
                    $generalConfiguration = get_general_configuration();
                    $gstPercent = $generalConfiguration['gst_percent'];
                    //----------------------

                    // Get Hcp Statements
                    $hcpWhere = [];
                    $hcps = $this->hcp->get_hcp_for_shift_invoice_generate($hcpWhere);
                    if (count($hcps)) {
                        $hcpStatementId = '';
                        $hcpInvoiceId = '';
                        $hcpShiftIds = [];
                        $hcpFilename = '';
                        $hcpAttach = '';
                        foreach ($hcps as $hcp) {
                            if (count($hcp->shifts) || count($hcp->referral_transactions)) {

                                // Get Max Invoice Id
                                $hcpMaxInvoiceId = $this->transaction->get_max_invoice_id();
                                if (!empty($hcpMaxInvoiceId)) {
                                    $hcpStatementId = sprintf("%'03d", ($hcpMaxInvoiceId['id'] + 1));
                                } else {
                                    $hcpStatementId = sprintf("%'03d", 1);
                                }
                                $hcpStatementId = $hcp->id . $hcpStatementId;
                                //-------------------

                                // Get Approved Shift
                                $hcpShiftFilter = [
                                    'shift_status' => '6',
                                    'current_date' => date('Y-m-d'),
                                    'hcp_id' => $hcp->id,
                                    'shift_ids' => $hcp->shifts->pluck('id'),
                                ];
                                $hcpShifts = $this->shift->get_shift_invoice_generate($hcpShiftFilter);
                                $hcpShiftIds = $hcpShifts->pluck('id');
                                //-------------------

                                if (count($hcpShifts)) {

                                    $hcpFilename = strtolower(str_replace(' ', '-', $hcp->first_name . '-statement-' . $hcpMaxInvoiceId['statement_prefix'] . $hcpStatementId . '-' . date('Y-m-d'))) . '.pdf';

                                    // Genrate Invoice PDF
                                    $transactionHcpInvoiceArr = [
                                        'statement_id' => $hcpStatementId,
                                        'invoice_created_at' => date('Y-m-d'),
                                        'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                        'invoice_gst_percent' => null,
                                        'invoice_gst_amount' => null,
                                        'invoice_facility_amount_with_gst' => null,
                                        'invoice_file_name' => $hcpFilename,
                                        'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                    ];

                                    $hcpPdf = PDF::loadView('invoices.hcp-invoice', array('shifts' => $hcpShifts, 'hcp' => $hcp, 'transaction' => $transactionHcpInvoiceArr, 'referrals' => $hcp->referral_transactions));
                                    $hcpPdf->setOptions(['isPhpEnabled' => true, 'isRemoteEnabled' => true, 'isHtml5ParserEnabled' => true]);
                                    $hcpPdf->setPaper('a4', 'landscape');
                                    Storage::disk(config('filesystems.default'))->put(config('constants.hcps.invoice_path') . $hcpFilename, $hcpPdf->output());
                                    //--------------------

                                    foreach ($hcpShifts as $hcpShift) {
                                        $generatedInvoices = $this->transaction->get_generated_invoice($hcpShift->id, $hcp->id);
                                        if (!empty($generatedInvoices)) {
                                            $hcpInvoiceId = $generatedInvoices['invoice_id'];
                                        } else {
                                            $hcpInvoiceId = null;
                                        }

                                        Log::channel('cronlog')->info("-----------------------");
                                        Log::channel('cronlog')->info("generate hcp invoice cron start");
                                        Log::channel('cronlog')->info("hcp id: " . $hcp->hcp_prefix . $hcp->id);
                                        Log::channel('cronlog')->info("hcp invoice date range: " . $invoiceStartDate . ' - ' . $invoiceEndDate);
                                        Log::channel('cronlog')->info("hcp shift Ids :" . $hcpShiftIds);
                                        Log::channel('cronlog')->info("hcp invoice id: " . $hcpInvoiceId);
                                        Log::channel('cronlog')->info("hcp statement id: " . $hcpStatementId);

                                        // Update Transaction
                                        $transactionHcpUpdateArr = [
                                            'invoice_id' => $hcpInvoiceId,
                                            'statement_id' => $hcpStatementId,
                                            'invoice_created_at' => date('Y-m-d'),
                                            'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                            'invoice_gst_percent' => null,
                                            'invoice_gst_amount' => null,
                                            'invoice_facility_amount_with_gst' => null,
                                            'invoice_file_name' => $hcpFilename,
                                            'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                        ];
                                        $transactionHcpWhereArr = [
                                            'amount_type' => 'shift',
                                            'amount_for' => 'hcp',
                                            'invoice_id' => null,
                                            'hcp_id' => $hcp->id,
                                            'shift_id' => $hcpShift->id,
                                        ];
                                        $this->transaction->update($transactionHcpUpdateArr, $transactionHcpWhereArr);
                                        //-------------------

                                        // Update referral transactions
                                        if (count($hcp->referral_transactions)) {
                                            foreach ($hcp->referral_transactions as $referral) {
                                                $this->transaction->update([
                                                    'statement_id' => $hcpStatementId,
                                                    'invoice_created_at' => date('Y-m-d'),
                                                    'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                                    'invoice_gst_percent' => null,
                                                    'invoice_gst_amount' => null,
                                                    'invoice_facility_amount_with_gst' => null,
                                                    'invoice_file_name' => $hcpFilename,
                                                    'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                                ], [
                                                    'id' => $referral->id,
                                                    'hcp_id' => $hcp->id,
                                                ]);
                                            }
                                        }
                                        //-----------------------------

                                    }


                                    // Send email notification
                                    if (config('filesystems.default') == config('constants.file_systems.PUBLIC.value')) {
                                        $hcpAttach = url('public/storage/' . config('constants.hcps.invoice_path')) . '/' . urlencode($hcpFilename);
                                    } elseif (config('filesystems.default') == config('constants.file_systems.S3.value')) {
                                        $bucket = env('AWS_BUCKET');
                                        $region = env('AWS_DEFAULT_REGION');
                                        // $bucketBaseUrl = 'https://s3.' . $region . '.amazonaws.com/'. $bucket.'/';
                                        // $hcpAttach = $bucketBaseUrl.config('constants.hcps.invoice_path').urlencode($hcpFilename);

                                        $S3NewURL = env('AWS_CloudFront_URL') . '/' . config('constants.hcps.invoice_path') . urlencode($hcpFilename);
                                        $hcpAttach = str_replace('#', '%23', $S3NewURL);
                                    }

                                    $emailTemplate = config('constants.admin_email_path') . 'hcp-invoice-email';
                                    $emailData = [
                                        'template' => $emailTemplate,
                                        'data' => [
                                            'name' => ucwords($hcp['first_name']),
                                            'email' => $hcp['user']['email'],
                                            'subject' => __('subjects.hcp_shift_invoice_generate', ['InvoiceNumber' => $hcpMaxInvoiceId['statement_prefix'] . $hcpStatementId, 'InvoiceDate' => date('Y-m-d')]),
                                            'InvoiceNumber' => $hcpMaxInvoiceId['statement_prefix'] . $hcpStatementId,
                                            'StatementDuration' => $invoiceStartDate . ' to ' . $invoiceEndDate,
                                            'cc' => $generalConfiguration['hcp_cust_care_email'],
                                            'filename' => $hcpAttach,
                                            'attach' => $hcpAttach,
                                        ],
                                    ];

                                    if (config('app.server') == 'AWS') {
                                        SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                                    } else {
                                        $data = $emailData['data'];
                                        Mail::send($emailTemplate, $data, function ($message) use ($data) {
                                            $message->to($data['email']);
                                            $message->subject($data['subject']);
                                            $message->cc($data['cc']);
                                            $message->attach($data['filename']);
                                        });
                                    }
                                    //------------------------

                                    Log::channel('cronlog')->info("generate hcp invoice cron completed");
                                    Log::channel('cronlog')->info("-----------------------");
                                }

                            }
                        }
                    }
                    //-------------------

                }
            }

            // Update cron status to completed
            $cronJob->status = 0;
            $cronJob->end_time = Carbon::now('Australia/Perth')->toDateTimeString();
            $cronJob->save();
            //---------------------------------

        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('hcp generate invoice cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }

    }

    public function hcp()
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/generate-invoice.log')]);

        // Current date
        $currentDate = Carbon::now('Australia/Perth')->toDateString();
        $currentTime = Carbon::now();
        $currentDay = strtolower(Carbon::parse($currentDate)->format('l'));
        //-------------

        $shiftUpdate = null;
        $shiftActivity = null;
        $invoiceId = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'hcp-generate-invoice-cron')->where('status', 0)->first();
//        dd($cronJob);
        //----------------
//        dd($cronJob, $currentDate, $currentTime, $currentDay);
        if (!empty($cronJob)) {
            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now('Australia/Perth')->toDateTimeString();
            //$cronJob->save();
            //---------------------------------

            // Dev Configuration
            $devConfiguration = get_dev_configurations();
            $devConfiguration = (array)json_decode($devConfiguration);
            //----------------------

            if (!empty($devConfiguration) && isset($devConfiguration['invoice_cron_days'])) {
                $cronDays = explode(",", $devConfiguration['invoice_cron_days']->config_value);

                //if(in_array($currentDay, $cronDays))
                {

                    // Last Generated Invoice
                    $generatedInvoice = [
                        'amount_for' => 'hcp',
                    ];
                    $lastGeneratedInvoice = $this->transaction->get_last_shift_generated_invoice($generatedInvoice);
                    if (!empty($lastGeneratedInvoice)) {
                        $invoiceStartDate = date('Y-m-d', strtotime($lastGeneratedInvoice['invoice_created_at']));
                    } else {
                        $invoiceStartDate = date('Y-m-d', strtotime("-7 day", strtotime(date('M d, Y'))));
                    }
                    $invoiceStartDate = date('Y-m-d', strtotime("-7 day", strtotime(date('M d, Y'))));
                    $invoiceEndDate = date('Y-m-d');
                    $invoiceStartDate = '2024-09-20';
                    $invoiceEndDate = '2024-09-27';
                    //-----------------------

                    // General Configuration
                    $generalConfiguration = get_general_configuration();
                    $gstPercent = $generalConfiguration['gst_percent'];
                    //----------------------

                    // Get Hcp Statements
                    $hcpWhere = [];
                    $hcps = $this->hcp->get_hcp_for_shift_invoice_generate($hcpWhere);
                    //p($hcps);
                    if (count($hcps)) {
                        $hcpStatementId = '';
                        $hcpInvoiceId = '';
                        $hcpShiftIds = [];
                        $hcpFilename = '';
                        $hcpAttach = '';
                        foreach ($hcps as $hcp) {
                            if (count($hcp->shifts) || count($hcp->referral_transactions)) {

                                // Get Max Invoice Id
                                $hcpMaxInvoiceId = $this->transaction->get_max_invoice_id();
                                if (!empty($hcpMaxInvoiceId)) {
                                    $hcpStatementId = sprintf("%'03d", ($hcpMaxInvoiceId['id'] + 1));
                                } else {
                                    $hcpStatementId = sprintf("%'03d", 1);
                                }
                                $hcpStatementId = $hcp->id . $hcpStatementId;
                                //-------------------

                                // Get Approved Shift
                                $hcpShiftFilter = [
                                    'shift_status' => '6',
                                    // 'current_date' => date('Y-m-d'),
                                    'current_date' => '2024-10-07',
                                    'hcp_id' => $hcp->id,
                                    'shift_ids' => $hcp->shifts->pluck('id'),
                                ];
                                $hcpShifts = $this->shift->get_shift_invoice_generate($hcpShiftFilter);
                                $hcpShiftIds = $hcpShifts->pluck('id');
                                //-------------------

                                if (count($hcpShifts)) {

                                    $hcpFilename = strtolower(str_replace(' ', '-', $hcp->first_name . '-statement-' . $hcpMaxInvoiceId['statement_prefix'] . $hcpStatementId . '-' . date('Y-m-d'))) . '.pdf';
                                    $hcpFilename = 'demo-hcp-invoice.pdf';

                                    // Genrate Invoice PDF
                                    $transactionHcpInvoiceArr = [
                                        'statement_id' => $hcpStatementId,
                                        'invoice_created_at' => date('Y-m-d'),
                                        'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                        'invoice_gst_percent' => null,
                                        'invoice_gst_amount' => null,
                                        'invoice_facility_amount_with_gst' => null,
                                        'invoice_file_name' => $hcpFilename,
                                        'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                    ];

                                    $hcpPdf = PDF::loadView('invoices.hcp-invoice', array('shifts' => $hcpShifts, 'hcp' => $hcp, 'transaction' => $transactionHcpInvoiceArr, 'referrals' => $hcp->referral_transactions));
                                    $hcpPdf->setOptions(['isPhpEnabled' => true, 'isRemoteEnabled' => true, 'isHtml5ParserEnabled' => true]);
                                    $hcpPdf->setPaper('a4', 'landscape');
//		return $hcpPdf->stream();
                                    Storage::disk(config('filesystems.default'))->put(config('constants.hcps.invoice_path') . $hcpFilename, $hcpPdf->output());
                                    //--------------------

                                    foreach ($hcpShifts as $hcpShift) {
                                        $generatedInvoices = $this->transaction->get_generated_invoice($hcpShift->id, $hcp->id);
                                        if (!empty($generatedInvoices)) {
                                            $hcpInvoiceId = $generatedInvoices['invoice_id'];
                                        } else {
                                            $hcpInvoiceId = null;
                                        }
//                                        dd($hcpInvoiceId, $generatedInvoices);

                                        Log::channel('cronlog')->info("-----------------------");
                                        Log::channel('cronlog')->info("generate hcp invoice cron start");
                                        Log::channel('cronlog')->info("hcp id: " . $hcp->hcp_prefix . $hcp->id);
                                        Log::channel('cronlog')->info("hcp invoice date range: " . $invoiceStartDate . ' - ' . $invoiceEndDate);
                                        Log::channel('cronlog')->info("hcp shift Ids :" . $hcpShiftIds);
                                        Log::channel('cronlog')->info("hcp invoice id: " . $hcpInvoiceId);
                                        Log::channel('cronlog')->info("hcp statement id: " . $hcpStatementId);

                                        // Update Transaction
                                        $transactionHcpUpdateArr = [
                                            'invoice_id' => $hcpInvoiceId,
                                            'statement_id' => $hcpStatementId,
                                            'invoice_created_at' => date('Y-m-d'),
                                            'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                            'invoice_gst_percent' => null,
                                            'invoice_gst_amount' => null,
                                            'invoice_facility_amount_with_gst' => null,
                                            'invoice_file_name' => $hcpFilename,
                                            'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                        ];
                                        $transactionHcpWhereArr = [
                                            'amount_type' => 'shift',
                                            'amount_for' => 'hcp',
                                            'invoice_id' => null,
                                            'hcp_id' => $hcp->id,
                                            'shift_id' => $hcpShift->id,
                                        ];
                                        $this->transaction->update($transactionHcpUpdateArr, $transactionHcpWhereArr);
                                        //-------------------

                                        // Update referral transactions
                                        if (count($hcp->referral_transactions)) {
                                            foreach ($hcp->referral_transactions as $referral) {
                                                $this->transaction->update([
                                                    'statement_id' => $hcpStatementId,
                                                    'invoice_created_at' => date('Y-m-d'),
                                                    'invoice_generated_date_range' => $invoiceStartDate . ' - ' . $invoiceEndDate,
                                                    'invoice_gst_percent' => null,
                                                    'invoice_gst_amount' => null,
                                                    'invoice_facility_amount_with_gst' => null,
                                                    'invoice_file_name' => $hcpFilename,
                                                    'invoice_overdue_date' => date('Y-m-d', strtotime(date('Y-m-d') . ' + ' . $generalConfiguration['invoice_overdue_hcp_day'] . ' days')),
                                                ], [
                                                    'id' => $referral->id,
                                                    'hcp_id' => $hcp->id,
                                                ]);
                                            }
                                        }
                                        //-----------------------------

                                    }


                                    // Send email notification
                                    if (config('filesystems.default') == config('constants.file_systems.PUBLIC.value')) {
                                        $hcpAttach = url('public/storage/' . config('constants.hcps.invoice_path')) . '/' . urlencode($hcpFilename);
                                    } elseif (config('filesystems.default') == config('constants.file_systems.S3.value')) {
                                        $bucket = env('AWS_BUCKET');
                                        $region = env('AWS_DEFAULT_REGION');
                                        // $bucketBaseUrl = 'https://s3.' . $region . '.amazonaws.com/'. $bucket.'/';
                                        // $hcpAttach = $bucketBaseUrl.config('constants.hcps.invoice_path').urlencode($hcpFilename);

                                        $S3NewURL = env('AWS_CloudFront_URL') . '/' . config('constants.hcps.invoice_path') . urlencode($hcpFilename);
                                        $hcpAttach = str_replace('#', '%23', $S3NewURL);
                                    }

                                    // $emailTemplate = config('constants.admin_email_path') . 'hcp-invoice-email';
                                    // $emailData = [
                                    //     'template' => $emailTemplate,
                                    //     'data' => [
                                    //         'name' => ucwords($hcp['first_name']),
                                    //         'email' => $hcp['user']['email'],
                                    //         'subject' => __('subjects.hcp_shift_invoice_generate', ['InvoiceNumber' => $hcpMaxInvoiceId['statement_prefix'].$hcpStatementId, 'InvoiceDate' => date('Y-m-d')]),
                                    //         'InvoiceNumber' => $hcpMaxInvoiceId['statement_prefix'].$hcpStatementId,
                                    //         'StatementDuration' => $invoiceStartDate.' to '.$invoiceEndDate,
                                    //         'cc' => $generalConfiguration['hcp_cust_care_email'],
                                    //         'filename' => $hcpAttach,
                                    //         'attach' => $hcpAttach,
                                    //     ],
                                    // ];

                                    // if(config('app.server') == 'AWS' ) {
                                    //     SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                                    // } else {
                                    //     $data = $emailData['data'];
                                    //     Mail::send($emailTemplate, $data, function ($message) use ($data) {
                                    //         $message->to($data['email']);
                                    //         $message->subject($data['subject']);
                                    //         $message->cc($data['cc']);
                                    //         $message->attach($data['filename']);
                                    //     });
                                    // }
                                    //------------------------

                                    Log::channel('cronlog')->info("generate hcp invoice cron completed");
                                    Log::channel('cronlog')->info("-----------------------");
                                }

                            }
                        }
                    }
                    //-------------------

                }
            }

            // Update cron status to completed
            $cronJob->status = 0;
            $cronJob->end_time = Carbon::now('Australia/Perth')->toDateTimeString();
            $cronJob->save();
            //---------------------------------
            $emailTemplate = config('constants.admin_email_path') . 'hcp_invoice_cron_confimation';
            Mail::send($emailTemplate, ['date' => date('Y-m-d H:i:s')], function ($message) {
                $message->to('yamini@apporio.com');
                $message->subject('hcp_invoice_generation');
                $message->cc('sameergulati@apporio.com');
                $message->cc('sumit.v2rsolution@gmail.com');
            });

        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('hcp generate invoice cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
    }

    public function hcpNew()
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/cron-logs/shift-cron.log')]);

        $shiftUpdate = null;
        $shiftActivity = null;

        // Get cron status
        $cronJob = CronJob::where('name', '=', 'shift-end-cron')->where('status', 0)->first();
        //----------------
        // p($cronJob);
        if (!empty($cronJob)) {

            // Update cron status in processing
            $cronJob->status = 1;
            $cronJob->start_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

            DB::beginTransaction();
            try {

                // Get Shifts
                $shiftWhere = ['shift_status' => '2'];
                $shifts = $this->shift->get_shift_for_cron($shiftWhere);
                //-----------
                // p($shifts);
                if (count($shifts)) {
                    foreach ($shifts as $shift) {

                        // Set time zone
                        date_default_timezone_set($shift->state->time_zone_name);
                        //--------------

                        // Current date
                        $currentDate = Carbon::now($shift->state->time_zone_name)->toDateString();
                        $currentTime = Carbon::now($shift->state->time_zone_name);
                        //-------------

                        if (strtotime($currentTime) >= strtotime($shift->end_time)) {

                            Log::channel('cronlog')->info("-----------------------");
                            Log::channel('cronlog')->info("current time: " . $currentTime);
                            Log::channel('cronlog')->info("shift end time: " . $shift->end_time);

                            // Update Shift
                            $shiftData = ['shift_status' => '4', 'hcp_shift_end_time' => $currentTime];
                            $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
                            //-------------

                            // Update buddy shift request
                            if (!empty($shift) && $shift->shift_type == 'buddy') {
                                $this->buddy_shift_request->update(['status' => 'completed'], ['shift_id' => $shift->id]);
                            }
                            //---------------------------

                            // Shift Activity
                            $getShiftActivity = $this->shift_activity->find_shift_activity(['shift_id' => $shift->id, 'activity' => 'shift-end']);
                            if (empty($getShiftActivity)) {
                                $shiftActivityData = [
                                    'hcp_id' => $shift->hcp_id,
                                    'shift_id' => $shift->id,
                                    'activity' => 'shift-end',
                                    'created_by' => $shift->created_by,
                                    'updated_by' => $shift->updated_by,
                                ];
                                $shiftActivity = $this->shift_activity->store($shiftActivityData);
                            }
                            //---------------

                            if (!empty($shift['hcp_id'])) {
                                $hcpId = $shift['hcp_id'];
                                send_shift_push_notification($shift->id, 'shift-completed', $hcpId);
                            }

                            // Send Admin Notification
                            send_admin_notification('admin-hcp-shift-completed', 'admin', $shift->id);
                            send_admin_notification('facility-hcp-shift-completed', 'facility', $shift->id, null, $shift->facility_id);
                            //------------------------

                            Log::channel('cronlog')->info("shift id: " . $shift->shift_prefix . $shift->id . ' completed');
                            Log::channel('cronlog')->info("shift end cron completed");
                            Log::channel('cronlog')->info("-----------------------");
                        }
                    }

                }

                DB::commit();

            } catch (\Exception $e) {
                Log::channel('cronlog')->info("-----------------------");
                Log::channel('cronlog')->error('shift end cron error: ' . $e->getMessage());
                Log::channel('cronlog')->info("-----------------------");
            }

            // Update cron status to completed
            $cronJob->status = 0;
            $cronJob->end_time = Carbon::now()->toDateTimeString();
            $cronJob->save();
            //---------------------------------

        } else {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->warning('shift end cron already running...');
            Log::channel('cronlog')->info("-----------------------");
        }
    }

    public function generateMissingInvoice()
    {
        $facility = $this->facility->find_facility(15);
        $transactionWhereArr = ['amount_for' => 'facility', 'invoice_id' => '1520813'];
        $transactions = $this->transaction->getAll($transactionWhereArr, true);
        $shift_ids = $transactions->pluck('shift_id');
        //p($shift_ids);
        $shiftFilter = [
            'current_date' => date('Y-m-d'),
            'facility_id' => 15,
            'shift_ids' => $shift_ids,
        ];

        $shifts = $this->shift->get_shift_invoice_generate($shiftFilter);
        //p($shifts);
        $filename = 'brightwater-kingsley-invoice-#inv1520813-2023-06-16.pdf';
        $transactionUpdateArr = [
            'invoice_id' => '1520813',
            'invoice_created_at' => "2023-06-16",
            'invoice_generated_date_range' => '2023-06-08 - 2023-06-15',
            'invoice_gst_percent' => '10',
            'invoice_gst_amount' => '1952.76',
            'invoice_facility_amount_with_gst' => '21480.34',
            'invoice_file_name' => $filename,
            'invoice_overdue_date' => '2023-06-30',
        ];
        // Genrate Invoice PDF
        $facilityPdf = PDF::loadView('invoices.facility-invoice', array('shifts' => $shifts, 'facility' => $facility, 'transaction' => $transactionUpdateArr));
        $facilityPdf->setOptions(['isPhpEnabled' => true, 'isRemoteEnabled' => true, 'isHtml5ParserEnabled' => true]);
        $facilityPdf->setPaper('a4', 'landscape');
        $file = Storage::disk(config('filesystems.default'))->put(config('constants.facility.invoice_path') . $filename, $facilityPdf->output());
        p('done');
    }

}
