<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\AdminPanel\ValidateHcp;
use App\Http\Requests\AdminPanel\ValidateLmsUrl;
use App\Jobs\AdminPanel\SendEmailJob;
use App\Http\Traits\UploadImage;
use App\Http\Traits\UploadFile;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Mail;
use App\Interfaces\CategoryInterface;
use App\Interfaces\LevelInterface;
use App\Interfaces\ProfessionInterface;
use App\Interfaces\StateInterface;
use App\Interfaces\HcpInterface;
use App\Interfaces\HcpBlockTimeInterface;
use App\Interfaces\FavouritesAndBlocklistInterface;
use App\Interfaces\DocumentHcpInterface;
use App\Interfaces\ShiftInterface;
use App\Interfaces\LmsUrlInterface;
use App\Interfaces\ReferralInterface;
use App\Interfaces\CountryInterface;
use App\Interfaces\CityInterface;
use App\Interfaces\SuburbInterface;
use App\Interfaces\DocumentInterface;
use App\Interfaces\HcpActivityInterface;
use App\Interfaces\HcpProfessionInterface;
use App\Interfaces\HcpProfessionRequestInterface;
use Carbon\Carbon;
use App\Models\Country;
use App\Models\State;
use App\Models\City;
use App\User;
use App\Models\Category;
use App\Models\Document;
use App\Models\HcpProfession;
use App\Models\Hcp;
use App\Models\DocumentHcp;
use App\Models\DocumentConfiguration;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\HcpsExport;
use App\Exports\ProfessionPendingApprovalHcpExport;
use Twilio\Rest\Client;
use Illuminate\Support\Str;
use App\Models\HcpProfessionRequest;
use App\Interfaces\FacilityInterface;

class HCPController extends Controller
{
    use UploadImage, UploadFile;
    public $viewData = [];

    private $category, $profession, $state, $hcp, $favouritesAndBlocklist, $lmsUrl, $countries, $states, $cities, $suburbs, $document;

    public function __construct(HcpInterface $hcp, CategoryInterface $category, ProfessionInterface $profession, StateInterface $state, HcpBlockTimeInterface $hcpBlockTime, FavouritesAndBlocklistInterface $favouritesAndBlocklist, DocumentHcpInterface $documentHcp, ShiftInterface $shift, LmsUrlInterface $lmsUrl, ReferralInterface $referral, CountryInterface $countries, StateInterface $states, CityInterface $cities, SuburbInterface $suburbs, DocumentInterface $document, HcpActivityInterface $hcpActivity, HcpProfessionInterface $hcpProfession, LevelInterface $level, HcpProfessionRequestInterface $hcpProfessionRequest, FacilityInterface $facility){
        $this->hcp = $hcp;
        $this->category = $category;
        $this->profession = $profession;
        $this->state = $state;
        $this->hcp_block_time = $hcpBlockTime;
        $this->favouritesAndBlocklist = $favouritesAndBlocklist;
        $this->document_hcp = $documentHcp;
        $this->shift = $shift;
        $this->lms_url = $lmsUrl;
        $this->referral = $referral;
        $this->countries = $countries;
        $this->states = $states;
        $this->cities = $cities;
        $this->suburbs = $suburbs;
        $this->document = $document;
        $this->hcp_activity = $hcpActivity;
        $this->hcp_profession = $hcpProfession;
        $this->level = $level;
        $this->hcp_profession_request = $hcpProfessionRequest;
        $this->facility = $facility;
        $this->middleware('auth.admin');
    }

    /**
     * View hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 20 Aug 2020
     */
    public function activeHcps(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        if (!empty($authUser->facility)) {
            $request['facility'] = $authUser->facility->id;
            $request['state_id'] = $authUser->facility->state_id;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $request['facility'] = $authUser->sub_admin->facility_id;
            $request['state_id'] = $authUser->sub_admin->facility->state_id;
        }

        // Get Categories
        $categories = $this->category->get(['status' => 'active']);
        //---------------

        // Get Professions
        $professions = $this->profession->get(['status' => 'active']);
        //----------------

        // Get States
        $hcpStatus = 'active';
        $states = $this->state->getAll(['status' => 'active'], true, null, null, null, null, null, $hcpStatus);
        //-----------

        $request->request->add(['shortby_filter'=>"2"]);

        // Get Hcp
        $hcps = $this->hcp->get_hcp_with_pagination(['status' => 'active'], $request);
        //--------

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['states'] = $states;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['request'] = $request->all();
        $this->viewData['authUser'] = $authUser;

        return view('admin-panel.hcps.active')->with($this->viewData);
    }

    /**
     * View archived hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 20 Aug 2020
     */
    public function archived(Request $request)
    {
        // Get Categories
        $categories = $this->category->get();
        //---------------

        // Get Professions
        $professions = $this->profession->get();
        //----------------

        // Get States
        $hcpStatus = 'archived';
        $states = $this->state->getAll(['status' => 'active'], true, null, null, null, null, null, $hcpStatus);
        //-----------
        $request->request->add(['shortby_filter'=>"2"]);
        // Hcps
        $hcps = $this->hcp->get_hcp_with_pagination(['status' => 'archived'], $request);
        //-----

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['states'] = $states;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['request'] = $request->all();

        return view('admin-panel.hcps.archived')->with($this->viewData);
    }

    /**
     * View pending approval hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 13 Aug 2020
     */
    public function pendingApprovalHcps(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get Categories
        $categories = $this->category->get();
        //---------------

        // Get Professions
        $professions = $this->profession->get();
        //----------------

        // Get States
        $hcpStatus = 'pending-approval';
        $states = $this->state->getAll(['status' => 'active'], true, null, null, null, null, null, $hcpStatus);
        //-----------

        // Hcps
        $where = [['status', '!=', 'active'], ['status', '!=', 'archived'], ['status', '!=', 'blocked'], ['status', '!=', 'rejected'], ['app_registration_screen', '=', '0']];
        $request->request->add(['shortby_filter'=>"2"]);
        $hcps = $this->hcp->get_hcp_with_pagination($where, $request);
        //-----

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['states'] = $states;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['request'] = $request->all();
        $this->viewData['authUser'] = $authUser;

        return view('admin-panel.hcps.pending-approval')->with($this->viewData);
    }

    /**
     * View incomplete profile hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 15 March 2021
     */
    public function incompleProfileHcps(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get Categories
        $categories = $this->category->get();
        //---------------

        // Get Professions
        $professions = $this->profession->get();
        //----------------

        // Get States
        $hcpStatus = 'pending-approval';
        $states = $this->state->getAll(['status' => 'active'], true, null, null, null, null, null, $hcpStatus);
        //-----------

        // Hcps
        $where = [['status', '!=', 'active'], ['status', '!=', 'archived'], ['status', '!=', 'blocked'], ['app_registration_screen', '!=', '0']];
        $request->request->add(['shortby_filter'=>"2"]);
        $hcps = $this->hcp->get_hcp_with_pagination($where, $request);
        //-----

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['states'] = $states;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['request'] = $request->all();
        $this->viewData['authUser'] = $authUser;

        return view('admin-panel.hcps.incomplete-profile')->with($this->viewData);
    }

    /**
     * View rejected hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 13 Aug 2020
     */
    public function rejectedHcps(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get Categories
        $categories = $this->category->get();
        //---------------

        // Get Professions
        $professions = $this->profession->get();
        //----------------

        // Get States
        $hcpStatus = 'rejected';
        $states = $this->state->getAll(['status' => 'active'], true, null, null, null, null, null, $hcpStatus);
        //-----------

        // Hcps
        $where = [['status', '=', 'rejected']];
        $request->request->add(['shortby_filter'=>"2"]);
        $hcps = $this->hcp->get_hcp_with_pagination($where, $request);
        //-----

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['states'] = $states;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['request'] = $request->all();
        $this->viewData['authUser'] = $authUser;

        return view('admin-panel.hcps.rejected')->with($this->viewData);
    }

    /**
     * View blocked hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 15 Aug 2020
     */
    public function blockedHcps(Request $request)
    {
        // Get Categories
        $categories = $this->category->get();
        //---------------

        // Get Professions
        $professions = $this->profession->get();
        //----------------

        // Get States
        $states = $this->state->getAll([]);

        // Get States
        $hcpStatus = 'blocked';
        $states = $this->state->getAll(['status' => 'active'], true, null, null, null, null, null, $hcpStatus);
        //-----------

        $request->request->add(['shortby_filter'=>"2"]);
        // Hcps
        $hcps = $this->hcp->get_hcp_with_pagination(['status' => 'blocked'], $request);
        //-----

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['states'] = $states;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['request'] = $request->all();

        return view('admin-panel.hcps.blocked')->with($this->viewData);
    }

    /**
     * Change status.
     *
     * @return \Illuminate\Http\JsonResponse
     *
     * @author Sumit
     * @created 21 Aug 2020
     */
    public function changeStatus(Request $request)
    {
        $hcp = Hcp::whereIn('id', $request['ids'])->update(['status' => 'active', 'show_approved_screen' => 1]);

        // Set response
        if (!is_null($hcp)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];
        }else{
            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }
        return response()->json($response, 200);
    }

    /**
     * Move to archived status.
     *
     * @return \Illuminate\Http\JsonResponse
     *
     * @author Sumit
     * @created 21 Aug 2020
     */
    public function moveToArchived(Request $request)
    {
        $hcp = Hcp::whereIn('id', $request['ids'])->update(['status' => 'archived']);

        // Set response
        if (!is_null($hcp)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];
        }else{
            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }
        return response()->json($response, 200);
    }

    /**
     * View create hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 20 Aug 2020
     */
    public function create(){
        $countries = Country::active()->get();
        $states = State::active()->orderBy('name', 'ASC')->get();
        $categories = Category::active()->get();
        $documents = Document::where('required_for', 'hcp')->orderBy('name', 'ASC')->active()->get();
        $this->viewData['states'] = $states;
        $this->viewData['categories'] = $categories;
        $this->viewData['documents'] = $documents;
        return view('admin-panel.hcps.create')->with($this->viewData);
    }

    /**
     * Store hcps.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 20 Aug 2020
     */
    public function store(ValidateHcp $request)
    {
        $authUser = auth()->user();
        $hcp = null;
        $errorMessage = null;
        $randomPassword = str_random(8);
        $currentTime = Carbon::now();
        $imageName = null;
        $attachmentName = null;
        DB::beginTransaction();

        // General Configuration
        $generalConfiguration = get_general_configuration();
        //----------------------

        // Create Hcp
        try {
            $hcp = new Hcp();
            $user = new User();

            // Create user
            $user->name = $request['first_name'] . ' ' . $request['last_name'];
            $user->email = $request['email'];
            $user->password = bcrypt($randomPassword);
            $user->email_verified_at = $currentTime->toDateTimeString();
            $user->role_name = 'hcp';
            $user->created_by = $authUser->id;
            $user->updated_by = $authUser->id;
            $user->save();
            //------------

            // Assign role
            $user->assignRole('HCP');
            //------------

            // Create hcp
            $hcp->first_name = $request['first_name'];
            $hcp->last_name = $request['last_name'];
            $hcp->contact_number = $request['contact_number'];
            $hcp->next_of_kin = $request['next_of_kin'];
            $hcp->date_of_birth = $request['dob'];
            $hcp->gender = $request['gender'];
            $hcp->country_id = 1;
            $hcp->state_id = $request['state_id'];
            $hcp->address = $request['address'];
            $hcp->city_name = $request['city_name'];
            $hcp->suburb_name = $request['suburb_name'];
            $hcp->post_code = $request['postcode'];
            $hcp->registration_number = $request['registration_number'];
            $hcp->abn_number = $request['abn_number'];
            $hcp->tfn_number = $request['tfn_number'];
            $hcp->notes = $request['notes'];
            $hcp->about_me = $request['about_me'];
            $hcp->latitude = $request['latitude'];
            $hcp->longitude = $request['longitude'];
            $hcp->points = $generalConfiguration['hcp_signup_awarded_points'];
            $hcp->maximum_distance = $generalConfiguration['radius_km_for_shift_broadcast'];
            $hcp->user_id = $user->id;
            $hcp->status = 'pending-approval';
            $hcp->referral_code = Str::upper(generate_random_string(8));
            $hcp->created_by = $authUser->id;
            $hcp->updated_by = $authUser->id;
            $hcp->save();
            //-----------

            // Update Hcp
            $appRegistrationScreen = '1';
            if (isset($appRegistrationScreen) && $appRegistrationScreen != '') {
                if ($appRegistrationScreen == 0) {
                    $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                } else if($request['app_registration_screen'] > $hcp->app_registration_screen) {
                    $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                } else if($hcp->app_registration_screen == null || $hcp->app_registration_screen == '') {
                    $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                }
            }
            //-----------

            // Upload hcp image
            if ($request->hasFile('image')) {
                $path  = config('constants.hcps.hcps_path') . '/' . $hcp->hcp_prefix . $hcp->id . '/image/';
                $image = $this->uploadImage($request->file('image'), $path, 75, strtolower($hcp->first_name));
                if ($image['_status']) {
                    $imageName = $image['_data'];
                }
            }

            if ($request->hasFile('attachment')) {
                $path  = config('constants.hcps.hcps_path') . '/' . $hcp->hcp_prefix . $hcp->id . '/cv/';
                $file = $this->uploadFile($request->file('attachment'), $path, 75, strtolower('cv'));
                if ($file['_status']) {
                    $attachmentName = $file['_data'];
                }
            }

            if (!is_null($imageName)) {
                $hcp->image = $imageName;
            }

            if (!is_null($attachmentName)) {
                $hcp->cv = $attachmentName;
            }
            $hcp->save();

            // Send hcp email with password
            $emailTemplate = config('constants.admin_email_path') . 'hcp-welcome-email';
            $emailData = [
                'template' => $emailTemplate,
                'data' => [
                    'name' => ucwords($request['first_name'] . ' ' . $request['last_name']),
                    'email' => $request['email'],
                    'subject' => __('subjects.user_welcome', ['app_name' => config('app.name')]),
                    'password' => $randomPassword,
                ],
            ];

            if (config('app.server') == 'AWS') {
                SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
            } else {
                $data = $emailData['data'];
                Mail::send($emailTemplate, $data, function ($message) use ($data) {
                    $message->to($data['email']);
                    $message->subject($data['subject']);
                });
            }
            //-----------------------------

            // Hcp Activity
            create_hcp_activity($hcp->id, 'account-created', __('hcp_activities.account_created'), $authUser->id);
            //-------------

            DB::commit();
        } catch (\Exception $e) {
            $hcp = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }
        //-----------

        if (!is_null($hcp)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Hcp']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.edit', ['id' => ev($hcp->id)])->with(['notification' => $notification]);
        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_creation_failed', ['record' => 'Hcp']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.create')->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Edit hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 20 Aug 2020
     */
    public function edit(Request $request, $id)
    {
        // Get hcp
        $hcp = $this->hcp->find_hcp(dv($id));
        //--------

        // Get Country
        $countries = $this->countries->getAll(['status' => 'active'], true);
        //------------

        // Get State
        $states = $this->states->getAll(['status' => 'active', 'country_id' => 1], true);
        //----------

        // Get City
        $cities = $this->cities->getAll(['status' => 'active', 'state_id' => $hcp->state_id], true);
        //---------

        // Get Suburbs
        $suburbs = $this->suburbs->getAll(['status' => 'active', 'city_id' => $hcp->city_id], true);
        //------------

        // Get Category
        $categories = $this->category->getAll(['status' => 'active'], true);
        //-------------

        // Get Document
        $documents = $this->document->get(['required_for' => 'hcp', 'doc_type' => 'general-statement'], true);
        //-------------

        $this->viewData['countries'] = $countries;
        $this->viewData['states'] = $states;
        $this->viewData['cities'] = $cities;
        $this->viewData['suburbs'] = $suburbs;
        $this->viewData['categories'] = $categories;
        $this->viewData['documents'] = $documents;
        $this->viewData['hcp'] = $hcp;

        return view('admin-panel.hcps.edit')->with($this->viewData);
    }

    /**
     * Update hcps.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 20 Aug 2020
     */
    public function update(ValidateHcp $request, $id)
    {
	
        // Get users
        $authUser = auth()->user();
        //----------

        $hcp = null;
        $user = null;
        $errorMessage = null;
        $currentTime = Carbon::now();
        $imageName = null;
        $attachmentName = null;
        $hcpUpdate = null;

        DB::beginTransaction();
        try {
            $acceptLowerjobStatus = get_accept_lower_job_checkbox_status();

            $hcp = Hcp::where('id', dv($id))->first();
            $user = User::where('id', $hcp->user_id)->first();

            // Update user
            $user->name = $request['first_name'] . ' ' . $request['last_name'];
            $user->email = $request['email'];
            $user->updated_by = $authUser->id;
            if(!empty($request->password)){
                $user->password = bcrypt($request->password);
            }
            $user->save();
            //------------

            // Update hcp
            $hcp->first_name = $request['first_name'];
            $hcp->last_name = $request['last_name'];
            $hcp->contact_number = $request['contact_number'];
            $hcp->next_of_kin = $request['next_of_kin'];
            $hcp->date_of_birth = $request['dob'];
            $hcp->gender = $request['gender'];
            $hcp->country_id = 1;
            $hcp->state_id = $request['state_id'];
            $hcp->city_name = $request['city_name'];
            $hcp->suburb_name = $request['suburb_name'];
            $hcp->address = $request['address'];
            $hcp->post_code = $request['postcode'];
            $hcp->notes = $request['notes'];
            $hcp->about_me = $request['about_me'];
            $hcp->latitude = $request['latitude'];
            $hcp->longitude = $request['longitude'];
            $hcp->registration_number = $request['registration_number'];

            if($acceptLowerjobStatus['show_accept_lower_level_job_checkbox'] == '1') {
                $hcp->accept_lower_level_job = $request['accept_lower_level_job'] ? 1 : 0;
            }

            $hcp->abn_number = $request['abn_number'];
            $hcp->tfn_number = $request['tfn_number'];
            $hcp->updated_by = $authUser->id;
            $hcpUpdate =  $hcp->save();
            //-----------

            // Upload hcp image
            if ($request->hasFile('image')) {
                $path  = config('constants.hcps.hcps_path') . '/' . $hcp->hcp_prefix . $hcp->id . '/image/';
                $image = $this->uploadImage($request->file('image'), $path, 75, strtolower($hcp->first_name));

                if ($image['_status']) {
                    $imageName = $image['_data'];
                }
            } else {
                $imageName = $hcp->image;
            }
            //-----------------

            // Upload hcp attachment
            if ($request->hasFile('attachment')) {
                $path  = config('constants.hcps.hcps_path') . '/' . $hcp->hcp_prefix . $hcp->id . '/cv/';
                $file = $this->uploadFile($request->file('attachment'), $path, 75, strtolower('cv'));

                if ($file['_status']) {
                    $attachmentName = $file['_data'];
                }
            } else {
                $attachmentName = $hcp->cv;
            }
            //----------------------

            if (!is_null($imageName)) {
                $hcp->image = $imageName;
            }

            if (!is_null($attachmentName)) {
                $hcp->cv = $attachmentName;
            }

            $hcp->save();

            // Check Accept Lower Level Job
            if($acceptLowerjobStatus['show_accept_lower_level_job_checkbox'] == '1') {
                if ($request['accept_lower_level_job'] == 1) {
                    $hcpProfessions = $this->hcp_profession->getAll(['hcp_id' => dv($id)], true);
                    if (count($hcpProfessions)) {
                        foreach($hcpProfessions as $hcpProfession){
                            if (!is_null($hcpProfession->level_id)) {
                                $levelWhere = [
                                    'status' => 'active',
                                    'category_id' => $hcpProfession->category_id,
                                    'profession_id' => $hcpProfession->profession_id,
                                    ['id', '<=', $hcpProfession->level_id]
                                ];
                                $hcplevels = $this->level->getAll($levelWhere, true)->pluck('id');
                                if (count($hcplevels)) {
                                    $this->hcp_profession->update(['accept_level_ids' => implode(',', $hcplevels->toArray())], ['id' => $hcpProfession->id]);
                                }
                            }
                        }
                    }
                } else {
                    $hcpProfessions = $this->hcp_profession->getAll(['hcp_id' => dv($id)], true);
                    if(count($hcpProfessions)) {
                        foreach($hcpProfessions as $hcpProfession){
                            if (!is_null($hcpProfession->level_id)) {
                                $this->hcp_profession->update(['accept_level_ids' => $hcpProfession->level_id], ['id' => $hcpProfession->id]);
                            }
                        }
                    }
                }
            }
            //-----------------------------

            // Hcp Activity
            create_hcp_activity(dv($id), 'account-updated', __('hcp_activities.account_updated'), $authUser->id);
            //-------------

            DB::commit();
        } catch (\Exception $e) {
            $hcpUpdate = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($hcpUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Hcp']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.edit', ['id' => $id])->withInput()->with(['notification' => $notification]);
        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Hcp']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.edit', ['id' => $id])->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Update hcps documents.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 03 Dec 2020
     */
    public function uploadDocument(Request $request, $id)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $errorMessage = null;
        $currentTime = Carbon::now();
        $hcpUpdate = null;

        DB::beginTransaction();
        try {

            // Get Hcp
            $hcp = $this->hcp->find_hcp_without_details(dv($id));
            //--------

            // Upload hcp documents
            $documentsData = [];
            $documentName = null;
            if (count($request['mandatory_documents'])) {
                foreach ($request['mandatory_documents'] as $document) {

                    $name = strtolower(str_replace(' ', '-', $document['document_name']));

                    // Upload hcp file
                    if (!empty($document['file']) && file_exists($document['file'])) {
                        $path = config('constants.hcps.hcps_path') . '/' . $hcp->hcp_prefix . $hcp->id . '/documents/';
                        $file = $this->uploadFile($document['file'], $path, 75, $name);

                        if ($file['_status']) {
                            $documentName = $file['_data'];
                        }
                    } else {
                        $documentName = ($document['file'] ?? null);
                    }
                    //----------------

                    if ( isset($document['expiry_date']) && !empty($document['expiry_date'])) {
                        if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 60 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 60 days'));
                        } else if(strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 30 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 30 days'));
                        } else if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 7 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 7 days'));
                        } else if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 1 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 1 days'));
                        } else {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date']));
                        }
                    } else {
                        $sendNotificationDate = null;
                    }

                    if (!empty($document['file'])) {

                        $hcpDocument = DocumentHcp::updateOrCreate([
                            'document_id' => $document['document_id'],
                            'hcp_id' => $hcp->id,
                        ], [
                            'document_name' => $documentName,
                            'expiry_date' => $document['expiry_date'] ?? null,
                            'send_notification_date' => $sendNotificationDate,
                            'document_approval' => 'approved',
                            'show_in_document_approval' => 'no',
                            'show_in_notification' => 'no',
                            'created_by' => $authUser->id,
                            'updated_by' => $authUser->id,
                            'created_at' => now(),
                            'updated_at' => now(),
                        ]);
                    }
                }
                $hcpUpdate = true;

                // Update Hcp
                $appRegistrationScreen = '0';
                if ($hcp->status != 'active' && isset($appRegistrationScreen) && $appRegistrationScreen != '' && $appRegistrationScreen != '') {
                    if ($appRegistrationScreen == 0) {
                        $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                        $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                    } else if($request['app_registration_screen'] >= $hcp->app_registration_screen) {
                        $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                        $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                    } else if($hcp->app_registration_screen == null || $hcp->app_registration_screen == '') {
                        $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                        $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                    }
                }
                //-----------

                // Hcp Activity
                create_hcp_activity(dv($id), 'mandatory-document-updated', __('hcp_activities.mandatory_document_updated'), $authUser->id);
                //-------------

            }
            //---------------------

            DB::commit();
        } catch (\Exception $e) {
            $hcpUpdate = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($hcpUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Hcp']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.edit', ['id' => ev($hcp->id)])->with(['notification' => $notification]);
        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Hcp']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.edit', ['id' => ev($hcp->id)])->withInput()->with(['notification' => $notification]);
        }

    }

    /**
     * Update hcps documents.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 03 Dec 2020
     */
    public function updateProfession(Request $request, $id)
    {
//         p($request->all());
        // Get users
        $authUser = auth()->user();
        //----------

        $errorMessage = null;
        $currentTime = Carbon::now();
        $hcpUpdate = null;

        DB::beginTransaction();
        try {
            // Get Hcp
            $hcp = $this->hcp->find_hcp_without_details(dv($id));
            //--------

            // Create hcp professions
            $professionsData = [];
            if (isset($request['professions']) && count($request['professions'])) {
                foreach ($request['professions'] as $profession) {
                    $hcpProfession = HcpProfession::updateOrCreate([
                        'category_id' => $profession['category_id'] ?? null,
                        'profession_id' => $profession['professions_id'],
                        'hcp_id' => $hcp->id,
                    ], [
                        'profession_id' => $profession['professions_id'],
                        'category_id' => $profession['category_id'],
                        'level_id' => $profession['level_id'] ?? null,
                        'created_by' => $authUser->id,
                        'updated_by' => $authUser->id,
                        'updated_at' => now(),
                    ]);

                    if($hcpProfession->wasRecentlyCreated){
                       // updateOrCreate performed create
                        send_other_push_notification($hcpProfession->hcp_id, 'hcp-profession-document-approved', 'hcp', null, null, $hcpProfession['profession']->name, null);
                    }
                }
            }
            //-----------------------

            // Upload hcp documents
            $documentsData = [];
            $documentName = null;
            if (isset($request['documents']) &&  count($request['documents'])) {
                foreach ($request['documents'] as $document) {

                    $name = strtolower(str_replace(' ', '-', $document['document_name']));

                    // Upload hcp file
                    if (!empty($document['file']) && file_exists($document['file'])) {
                        $path = config('constants.hcps.hcps_path') . '/' . $hcp->hcp_prefix . $hcp->id . '/documents/';
                        $file = $this->uploadFile($document['file'], $path, 75, $name);

                        if ($file['_status']) {
                            $documentName = $file['_data'];
                        }
                    } else {
                        $documentName = ($document['file'] ?? null);
                    }
                    //----------------

                    if ( isset($document['expiry_date']) && !empty($document['expiry_date'])) {
                        if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 60 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 60 days'));
                        } else if(strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 30 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 30 days'));
                        } else if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 7 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 7 days'));
                        } else if (strtotime($document['expiry_date']) > strtotime(date('Y-m-d', strtotime(now() . ' + 1 days')))) {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date'] . ' - 1 days'));
                        } else {
                            $sendNotificationDate = date('Y-m-d', strtotime($document['expiry_date']));
                        }
                    } else {
                        $sendNotificationDate = null;
                    }

                    if (!empty($document['file'])) {

                        $hcpDocument = DocumentHcp::updateOrCreate([
                            'document_id' => $document['document_id'] ?? null,
                            'profession_id' => $document['profession_id'] ?? null,
                            'hcp_id' => $hcp->id,
                        ], [
                            'document_name' => $documentName,
                            'profession_id' => $document['profession_id'],
                            'level_id' => $document['level_id'] ?? null,
                            'expiry_date' => $document['expiry_date'] ?? null,
                            'send_notification_date' => $sendNotificationDate,
                            'document_approval' => 'approved',
                            'show_in_document_approval' => 'no',
                            'show_in_notification' => 'no',
                            'created_by' => $authUser->id,
                            'updated_by' => $authUser->id,
                            'created_at' => now(),
                            'updated_at' => now(),
                        ]);

                    }
                }
                $hcpUpdate = true;
            }
            //---------------------

            if (!isset($request['professions']) && !isset($request['documents']) ) {
                $hcpUpdate = true;
            }

            //Update Hcp Professions
            $hcp_professions = HcpProfession::where('hcp_id',$hcp->id)->get();
            foreach($hcp_professions as $hcp_profession){
                $expired_doc_count = DocumentHcp::where('hcp_id',$hcp->id)->where('profession_id',$hcp_profession->profession_id)->where('level_id',$hcp_profession->level_id)->whereIn('document_approval',['pending','pending-reapproval','expired'])->count();
                if($expired_doc_count==0){
                    $hcp_profession->status = 'active';
                    $hcp_profession->save();
                }
            }
            //Update Hcp Professions

            // Update Hcp
            $appRegistrationScreen = '4';
            if ($hcp->status != 'active' && isset($appRegistrationScreen) && $appRegistrationScreen != '' && $hcp->app_registration_screen != 0) {
                if ($appRegistrationScreen == 0) {
                    $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                } else if($appRegistrationScreen >= $hcp->app_registration_screen) {
                    $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                } else if($hcp->app_registration_screen == null || $hcp->app_registration_screen == '') {
                    $hcpData = ['app_registration_screen' => $appRegistrationScreen];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $hcp->id]);
                }
            }
            //-----------
            // Hcp Activity
            create_hcp_activity(dv($id), 'professions-updated', __('hcp_activities.professions_updated'), $authUser->id);
            //-------------

            DB::commit();
        } catch (\Exception $e) {
            $hcpUpdate = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($hcpUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Hcp']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.edit', ['id' => ev($hcp->id)])->with(['notification' => $notification]);
        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Hcp']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.edit', ['id' => ev($hcp->id)])->withInput()->with(['notification' => $notification]);
        }

    }

    /**
     * Add more professions.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 20 Aug 2020
     */
    public function addMoreProfessions(Request $request)
    {
        // Get Category
        $categories = Category::active()->get();
        //-------------

        $response = [
            '_status' => true,
            '_data' => [],
            '_message' => __('messages.record_created', ['record' => 'Professions']),
            '_type' => 'success',
            '_content' => view('admin-panel.includes.hcps.add-more-professions')->with([
                'categories' => $categories,
                'counter' => $request['counter'],
                'current_counter' => $request['counter'],
            ])->render(),
        ];

        return response()->json($response, 200);
    }

    /**
     * Destroy profession data.
     *
     * @return void
     *
     * @author Sumit
     * @created 20 Aug 2020
     */
    public function removeProfession(Request $request)
    {
        $id = $request['id'];
        $professionId = $request['profession_id'];
        $hcpId = $request['hcp_id'];
        $profession = null;

        if (!empty($id)) {
            $professionRequest= HcpProfessionRequest::where('hcp_profession_id', $id)->delete();
            $profession = HcpProfession::where('id', $id)->delete();
            if(!empty($professionId))
            DocumentHcp::where('profession_id', $professionId)->where('hcp_id',$hcpId)->delete();
        } else {
            $profession = null;
        }

        // Set response
        if (!is_null($profession)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.record_deleted', ['record' => 'Profession']),
                '_type' => 'success',
            ];
        } else {
            $response = [
                '_status' => false,
                '_message' => __('messages.record_failed', ['record' => 'Profession']),
                '_type' => 'error',
            ];
        }
        //-------------

        return response()->json($response, 200);
    }

    /**
     * View hcp details.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 26 Aug 2020
     */
    public function details(Request $request, $id)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get hcp
        $hcp = $this->hcp->find_hcp(dv($id));
        //--------

        // Get hcp favourites
        $hcpFavourites = $this->favouritesAndBlocklist->get_hpc_favourites(dv($id), $request['filter_type'] == 'favourites' ? $request : null);

        if (!empty($authUser->facility)) {
            $facilityId = $authUser->facility->id;
            $hcpFavorite = $this->favouritesAndBlocklist->get_hcp_mark_favorite($facilityId,dv($id));
            $request['facility'] = $facilityId;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $facilityId = $authUser->sub_admin->facility_id;
            $hcpFavorite = $this->favouritesAndBlocklist->get_hcp_mark_favorite($facilityId,dv($id));
            $request['facility'] = $facilityId;
        } else {
            $hcpFavorite = null;
        }
        //-------------------

        // Get hcp blocklist
        $hcpBlocklist = $this->favouritesAndBlocklist->get_hcp_blocklist(dv($id), $request['filter_type'] == 'blocklist' ? $request : null);

        if (!empty($authUser->facility)) {
            $facilityId = $authUser->facility->id;
            $hcpBlock = $this->favouritesAndBlocklist->get_hcp_mark_blocklist($facilityId,dv($id));
            $request['facility'] = $facilityId;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $facilityId = $authUser->sub_admin->facility_id;
            $hcpBlock = $this->favouritesAndBlocklist->get_hcp_mark_blocklist($facilityId,dv($id));
            $request['facility'] = $facilityId;
        } else {
            $hcpBlock = null;
        }
        //------------------

        // Get Hcp Documents
        $documents = $this->document_hcp->find_hcp_document_paginate(dv($id), $request);
        //------------------

        // Get Shifts
        $shiftWhere = [];
        if (!empty($authUser->facility)) {
            $facilityId = $authUser->facility->id;
            $shiftWhere = ['hcp_id' => $hcp->id, 'facility_id' => $facilityId];
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $facilityId = $authUser->sub_admin->facility_id;
            $shiftWhere = ['hcp_id' => $hcp->id, 'facility_id' => $facilityId];
        } else {
            $shiftWhere = ['hcp_id' => $hcp->id];
        }
        $shifts = $this->shift->getAll($shiftWhere, true, $request['filter_type'] == 'shifts' ? $request : null);
        //-----------

        // Get Refer And Earn
        $where = ['referrer_hcp_id' => $hcp->id];
        $referrals = $this->referral->getAll($where, true);
        $totalReferrerAmount = $referrals->where('status', 'completed')->sum('referrer_amount');
        $totalReferrerCount = $referrals->where('status', 'completed')->count();
        //-------------------

        // Get States
        $whereState = ['status' => 'active', 'country_id' => 1];
        $states = $this->state->getAll($whereState);
        //-----------

        // Get hcp activities
        $hcpActivityWhere = ['hcp_id' => $hcp->id];
        $hcpActivities = $this->hcp_activity->getAll($hcpActivityWhere, true);
        //-------------------

        $this->viewData['hcp'] = $hcp;
        $this->viewData['hcpFavourites'] = $hcpFavourites;
        $this->viewData['hcpBlocklist'] = $hcpBlocklist;
        $this->viewData['documents'] = $documents;
        $this->viewData['shifts'] = $shifts;
        $this->viewData['referrals'] = $referrals;
        $this->viewData['totalReferrerAmount'] = $totalReferrerAmount;
        $this->viewData['totalReferrerCount'] = $totalReferrerCount;
        $this->viewData['request'] = $request->all();
        $this->viewData['authUser'] = $authUser;
        $this->viewData['hcpFavorite'] = $hcpFavorite;
        $this->viewData['hcpBlock'] = $hcpBlock;
        $this->viewData['states'] = $states;
        $this->viewData['hcpActivities'] = $hcpActivities;
//        p($hcp->hcp_professions);
        return view('admin-panel.hcps.details')->with($this->viewData);
    }

    /**
     * Get hcps documents.
     *
     * @return datatable
     *
     * @author Sumit
     * @created 27 Aug 2020
     */
    public function getHcpDocuments(Request $request, $id = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get Documents
        $documents = DocumentHcp::with('document')->with(['hcp' => function ($query) {
            $query->select('id', 'hcp_prefix', 'user_id');
        }])->where('hcp_id', dv($id))->orderBy('id', 'DESC')->get();
        //--------------

        return DataTables::of($documents)
            ->addColumn('name', function ($document) {
                $name = ucwords($document->document->name);
                return $name;
            })
            ->addColumn('expiry', function ($document) {
                if (!empty($document->expiry_date)) {
                    return date("d F Y", strtotime($document->expiry_date));
                } else {
                    return 'N/A';
                }
            })
            ->addColumn('status', function ($document) {
                $status = '';
                if ($document->document_approval == 'approved') {
                    $status .= '<label class="badge badge-success mb0"> ' . __("language.document_approved") . ' </label> &nbsp;';
                } else if ($document->document_approval == 'pending') {
                    $status .= '<label class="badge badge-warning mb0"> ' . __("language.document_pending") . ' </label> &nbsp;';
                } else if ($document->document_approval == 'pending-reapproval') {
                    $status .= '<label class="badge badge-warning mb0"> ' . __("language.document_pending_approved") . ' </label> &nbsp;';
                } else if ($document->document_approval == 'reapproved') {
                    $status .= '<label class="badge badge-success mb0"> ' . __("language.document_reapproved") . ' </label> &nbsp;';
                }
                return $status;
            })
            ->addColumn('action', function ($document) use ($authUser) {
                $documentUrl = get_file_url(config('constants.hcps.hcps_path') . $document->hcp->hcp_prefix . $document->hcp->id . '/documents/', $document->document_name);
                $action = '
                    <ul class="datatable-action">
                        <li>
                            <div class="dropdown custom-dropdown-icon">
                                <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                    <i class="fa fa-ellipsis-v" aria-hidden="true"></i>
                                </a>
                                <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                    <a class="dropdown-item" href="' . $documentUrl . '" target="_blank" download>
                                    ' . __("language.download") . '
                                    </a>
                    ';

                if ($document->document_approval == 'pending') {
                    $action .= '<a class="dropdown-item" href="' . route('adminPanel.hcps.documentApproved', ['id' => ev($document->id), 'hcpId' => ev($document->hcp_id)]) . '">
                                    ' . __("language.document_approved") . '
                                </a>';
                } else if ($document->document_approval == 'pending-reapproval') {
                    $action .= '<a class="dropdown-item" href="' . route('adminPanel.hcps.documentReapproved', ['id' => ev($document->id), 'hcpId' => ev($document->hcp_id)]) . '">
                                    ' . __("language.document_reapproved") . '
                                </a>';
                }

                $action .= '</div>
                            </div>
                        </li>
                    </ul>
                ';

                return $action;
            })
            ->rawColumns([
                'name' => 'name',
                'action' => 'action',
                'status' => 'status',
            ])
            ->addIndexColumn()->make(true);
    }

    /**
     * Get document Approved.
     *
     * @return datatable
     *
     * @author Sumit
     * @created 27 Aug 2020
     */
    public function documentApproved(Request $request, $id = null, $hcpId = null)
    {
        $documentHcp = DocumentHcp::where('id', dv($id))->update(['document_approval' => 'approved']);

        // Set response
        if (!is_null($documentHcp)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
                '_redirect_url' => route('adminPanel.hcps.details', ['id' => $hcpId, '#documents']),
            ];
        } else {
            #documents
            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
                '_redirect_url' => route('adminPanel.hcps.details', ['id' => $hcpId, '#documents']),
            ];
        }
        //-------------

        return response()->json($response, 200);
    }

    /**
     * Get document reapproved.
     *
     * @return datatable
     *
     * @author Sumit
     * @created 27 Aug 2020
     */
    public function documentReapproved(Request $request, $id = null, $hcpId = null)
    {
        $documentHcp = DocumentHcp::where('id', dv($id))->update(['document_approval' => 'reapproved']);

        // Set response
        if (!is_null($documentHcp)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
                '_redirect_url' => route('adminPanel.hcps.details', ['id' => $hcpId, '#documents']),
            ];
        } else {
            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
                '_redirect_url' => route('adminPanel.hcps.details', ['id' => $hcpId, '#documents']),
            ];
        }
        //-------------

        return response()->json($response, 200);
    }

    /**
     * Details Change Status.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 24 Sep 2020
     */
    public function detailsChangeStatus(Request $request, $id, $status)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $hcp = null;
        $hcpBlockTime = null;
        $data = [];
        $dataBlock = [];
        $where = [];

        DB::beginTransaction();
        try {

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Get hcp
            $hcp = $this->hcp->find_hcp(dv($id));
            //--------

            if ($hcp->status == 'blocked' && $request['status'] == 'active') {
                $data['points'] = $generalConfiguration['hcp_signup_awarded_points'];

                // Hcp Activity
                create_hcp_activity(dv($id), 'point-reset', __('hcp_activities.point_added', ['awarded' => $data['points']]), $authUser->id);
                //-------------

                // Send Notification
                send_other_push_notification(dv($id), 'hcp-unblock', 'hcp');
                //------------------
            }

            if ($request['status'] == 'blocked'){
                $dataBlock = [
                    'hcp_id' => dv($id),
                    'created_by' => $authUser->id,
                    'updated_by' => $authUser->id,
                ];
                $hcpBlockTime = $this->hcp_block_time->store($dataBlock);
            }

            if(($hcp->status == 'pending-approval' && $request['status'] == 'active') || ($hcp->status == 'rejected' && $request['status'] == 'active')){
                $data['show_approved_screen'] = 1;
                $totalMandatoryDocuement = 0;

                $uploadedMandatoryDoucment = get_hcp_uploaded_mandatory_documents($hcp->id);
                $mandatoryDoucment = get_hcp_mandatory_documents($hcp->id);
                $hcpUploadedDocuments = get_hcp_uploaded_documents($hcp->id);
                $hcpApprovedUploadedDocuments = get_hcp_approved_uploaded_documents($hcp->id);

                if(!empty($mandatoryDoucment['general_documents_count'])) {
                    $totalMandatoryDocuement += $mandatoryDoucment['general_documents_count'];
                }

                if(!empty($mandatoryDoucment['profession_documents_count'])) {
                    $totalMandatoryDocuement += $mandatoryDoucment['profession_documents_count'];
                }

                if($uploadedMandatoryDoucment < $totalMandatoryDocuement) {
                    $response = [
                        '_status' => false,
                        '_message' => __('messages.hcp_mandatory_documents_not_uploaded'),
                        '_type' => 'error',
                    ];
                    return response()->json($response, 200);
                } else if($hcpUploadedDocuments != $hcpApprovedUploadedDocuments) {
                    $response = [
                        '_status' => false,
                        '_message' => __('messages.hcp_documents_not_approved'),
                        '_type' => 'error',
                    ];
                    return response()->json($response, 200);
                }

                // Send Account Approved Notification
                if($request['status'] == 'active'){
                    if($hcp->approval_notification_sent != 1){
                        send_other_push_notification(dv($id), 'hcp-account-approved', 'hcp');
                    } else {
                        send_other_push_notification(dv($id), 'hcp-account-approved-second-time', 'hcp');
                    }
                }
                //-----------------------------------

                // Send SMS
                if($hcp->approval_notification_sent != 1 && $request['status'] == 'active'){
                    try {
                        $smsMessage = __('messages.hcp_account_approve', ['hcp' => $hcp->first_name.' '.$hcp->last_name]);
                        $accountSid = env("TWILIO_SID");
                        $authToken = env("TWILIO_AUTH_TOKEN");
                        $twilioNumber = env("TWILIO_NAME");
                        $client = new Client($accountSid, $authToken);

                        if(!empty($hcp['contact_number'])) {
                            $message = $client->messages->create($hcp['contact_number'], [
                                'from' => $twilioNumber,
                                'body' => $smsMessage
                            ]);
                        }

                        $data['approval_notification_sent'] = 1;
                    } catch (\Exception $e) {
                        $response = [
                            'status' => false,
                            'message' => $e->getMessage(),
                            'data' => null,
                        ];
                    }
                }
                //---------
            }

            $data['status'] = $request['status'];
            $data['updated_by'] = $authUser->id;

            $where = ['id' => dv($id)];
            $hcp = $this->hcp->update($data, $where);

            // Hcp Activity
            create_hcp_activity(dv($id), 'status-change', __('hcp_activities.status_change', ['status' => $request['status']]), $authUser->id);
            //-------------

            DB::commit();
        } catch (\Exception $exception) {
            $hcp = null;
            DB::rollback();
        }

        if (!is_null($hcp)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
                '_redirect_url' => route('adminPanel.hcps.details', ['id' => $id]),
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
                '_redirect_url' => route('adminPanel.hcps.details', ['id' => $id]),
            ];
        }
        return response()->json($response, 200);
    }

    /**
     * Remove facility to favourite.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Sep 2020
     */
    public function removeFavouriteFacility(Request $request, $id, $hcpId)
    {
        // Remove facility favourites
        $favourites = $this->favouritesAndBlocklist->delete($id);
        //---------------------------

        if ($favourites == true) {

            $response = [
                '_status' => true,
                '_message' => __('messages.favourite_removed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.favourite_removed_failed'),
                '_type' => 'error',
            ];

            return response()->json($response, 200);
        }

    }


    /**
     * Remove facility to blocklist.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 22 Sep 2020
     */
    public function removeBlocklistFacility(Request $request, $id, $hcpId)
    {
        // Remove facility blocklist
        $blocklist = $this->favouritesAndBlocklist->delete($id);
        //---------------------------

        if ($blocklist == true) {

            $response = [
                '_status' => true,
                '_message' => __('messages.blocklist_removed'),
                '_type' => 'success',
            ];

            return response()->json($response, 200);

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.blocklist_removed_failed'),
                '_type' => 'error',
            ];

            return response()->json($response, 200);
        }

    }

    /**
     * View hcp lms.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 14 Oct 2020
     */
    public function hcpLms(Request $request)
    {
        try {

            // Get LMS
            $where = [];
            $lms = $this->lms_url->getAll($where);
            //--------

            return view('admin-panel.lms.index', compact('lms'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Add/Update lms.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 14 Oct 2020
     */
    public function addUpdateLms(ValidateLmsUrl $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $lmsUrl = null;
        $data = [];

        DB::beginTransaction();
        try {

            if(empty($request['id'])) {
                $data = [
                    'lms_url' => $request['lms_url'],
                    'created_by' => $authUser->id,
                    'updated_by' => $authUser->id,
                ];

                $lmsUrl = $this->lms_url->store($data);
            } else {

                $data = [
                    'lms_url' => $request['lms_url'],
                    'updated_by' => $authUser->id,
                ];

                $lmsUrl = $this->lms_url->update($data, ['id' => $request['id']]);
            }
            DB::commit();
        } catch (\Exception $exception) {
            $lmsUrl = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($lmsUrl)) {
            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'LMS Url']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.lms')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'LMS Url']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.lms')->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Check Registration Number.
     *
     * @author Sumit
     * @created 02 Dec 2020
     */
    public function checkRegistrationNumber(Request $request)
    {
        $status = false;

        if (!is_null($request->registration_number)) {
            $hcp = Hcp::where('registration_number', $request['registration_number'])->first();

            if (!is_null($hcp)) {
                if ($request->filled('id') && $hcp->id == $request['id']) {
                    $status = true;
                } else {
                    $status = false;
                }
            } else {
                $status = true;
            }
        }

        return response()->json($status, 200);
    }

    /**
     * Add hcp to favorites.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 07 Dec 2020
     */
    public function addHcpFavorites(Request $request, $hcpId, $facilityId)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $favourite = null;
        $data = [];

        // Add to blocklist
        DB::beginTransaction();
        try {

            $data = [
                'facility_id' => $facilityId,
                'hcp_id' => $hcpId,
                'marked_by' => 'facility',
                'type' => 'favourite',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            $favourite = $this->favouritesAndBlocklist->store($data);

            // Send Notification
            send_other_push_notification($hcpId, 'facility-marked-as-favourite', 'hcp', null, null, null, null, null, $facilityId);
            //------------------

            DB::commit();
        } catch (\Exception $exception) {
            $favourite = null;
            DB::rollback();
        }
        //-----------------

        if (!is_null($favourite)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.favourite_added'),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.details', ['id' => ev($hcpId)])->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.favourite_added_failed'),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.details', ['id' => ev($hcpId)])->with(['notification' => $notification]);
        }

    }

    /**
     * Remove hcp to favourite.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 07 Dec 2020
     */
    public function removeFavouriteHcp(Request $request, $hcpId, $facilityId, $page = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Remove facility favourites
        $favourites = $this->favouritesAndBlocklist->remove_hcp_from_favorite($facilityId, $hcpId);
        //---------------------------

        // Send Notification
        send_other_push_notification($hcpId, 'facility-remove-favourite', 'hcp', null, null, null, null, null, $facilityId);
        //------------------

        if ($favourites == true) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.favourite_removed'),
                '_type' => 'success',
            ];
            //-----------------

            // Facility Activity
            create_facility_activity($facilityId, 'remove-as-favourites', __('facility_activities.hcp_remove_as_favourites', ['hcp' => get_hcp_name($hcpId)]), $authUser->id);
            //------------------

            if(!empty($page)){
                return response()->json($notification, 200);
            } else {
                return redirect()->route('adminPanel.hcps.details', ['id' => ev($hcpId)])->with(['notification' => $notification]);
            }


        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.favourite_removed_failed'),
                '_type' => 'error',
            ];
            //-----------------

            if(!empty($page)){
                return response()->json($notification, 200);
            } else {
                return redirect()->route('adminPanel.hcps.details', ['id' => ev($hcpId)])->with(['notification' => $notification]);
            }
        }

    }

    /**
     * Add hcp to blocklist.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 07 Dec 2020
     */
    public function addHcpBlocklist(Request $request, $hcpId, $facilityId)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $blocklist = null;
        $data = [];

        // Add to blocklist
        DB::beginTransaction();
        try {

            $data = [
                'facility_id' => $facilityId,
                'hcp_id' => $hcpId,
                'marked_by' => 'facility',
                'type' => 'blocked',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            $blocklist = $this->favouritesAndBlocklist->store($data);

            // Send Notification
            send_other_push_notification($hcpId, 'facility-added-on-blocklist', 'hcp', null, null, null, null, null, $facilityId);
            //------------------

            DB::commit();
        } catch (\Exception $exception) {
            $blocklist = null;
            DB::rollback();
        }
        //-----------------

        if (!is_null($blocklist)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.blocklist_added'),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.details', ['id' => ev($hcpId)])->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.blocklist_added_failed'),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.details', ['id' => ev($hcpId)])->with(['notification' => $notification]);
        }

    }

    /**
     * Remove hcp to blocklist.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 07 Dec 2020
     */
    public function removeBlocklistHcp(Request $request, $hcpId, $facilityId, $page = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Remove facility blocklist
        $blocklist = $this->favouritesAndBlocklist->remove_hcp_from_blocklist($facilityId, $hcpId);
        //---------------------------

        if ($blocklist == true) {

            // Send Notification
            send_other_push_notification($hcpId, 'facility-remove-from-blocklist', 'hcp', null, null, null, null, null, $facilityId);
            //------------------

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.blocklist_removed'),
                '_type' => 'success',
            ];
            //-----------------

            // Facility Activity
            create_facility_activity($facilityId, 'remove-as-block', __('facility_activities.hcp_remove_as_block', ['hcp' => get_hcp_name($hcpId)]), $authUser->id);
            //------------------

            if(!empty($page)){
                return response()->json($notification, 200);
            } else {
                return redirect()->route('adminPanel.hcps.details', ['id' => ev($hcpId)])->with(['notification' => $notification]);
            }

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.blocklist_removed_failed'),
                '_type' => 'error',
            ];
            //-----------------

            if(!empty($page)){
                return response()->json($notification, 200);
            } else {
                return redirect()->route('adminPanel.hcps.details', ['id' => ev($hcpId)])->with(['notification' => $notification]);
            }
        }

    }

    /**
     * Get facility blocklist hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 07 Dec 2020
     */
    public function getFacilityBlocklistHcps(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get Categories
        $categories = $this->category->get(['status' => 'active']);
        //---------------

        // Get Professions
        $professions = $this->profession->get(['status' => 'active']);
        //----------------

        // Hcps
        $where = [];
        if (!empty($authUser->facility)) {
            $request['facility'] = $authUser->facility->id;
            $request['state_id'] = $authUser->facility->state_id;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $request['facility'] = $authUser->sub_admin->facility_id;
            $request['state_id'] = $authUser->sub_admin->facility->state_id;
        }
        $hcps = $this->hcp->get_hcp_marked_by_facility($where, $request, $request['facility'], 'blocked');
        //-----

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['request'] = $request->all();
        $this->viewData['authUser'] = $authUser;

        return view('admin-panel.hcps.facility-blocklist')->with($this->viewData);
    }

    /**
     * Get facility blocklist hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 07 Dec 2020
     */
    public function getFacilityFavoritesHcps(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get Categories
        $categories = $this->category->get(['status' => 'active']);
        //---------------

        // Get Professions
        $professions = $this->profession->get(['status' => 'active']);
        //----------------

        // Hcps
        $where = [];
        if (!empty($authUser->facility)) {
            $request['facility'] = $authUser->facility->id;
            $request['state_id'] = $authUser->facility->state_id;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $request['facility'] = $authUser->sub_admin->facility_id;
            $request['state_id'] = $authUser->sub_admin->facility->state_id;
        }
        $hcps = $this->hcp->get_hcp_marked_by_facility($where, $request, $request['facility'], 'favourite');
        //-----

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['hcps'] = $hcps;
        $this->viewData['request'] = $request->all();
        $this->viewData['authUser'] = $authUser;

        return view('admin-panel.hcps.facility-favorites')->with($this->viewData);
    }

    /**
     * Reject hcp modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 15 Dec 2020
     */
    public function rejectHcpModal(Request $request, $id = null)
    {
        try {

            return view('admin-panel.includes.hcps.reject-hcp-modal', compact('id'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Reject hcp.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 15 Dec 2020
     */
    public function rejectHcp(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $hcp = null;

        DB::beginTransaction();
        try {

            $where = ['id' => dv($id)];

            $data = [
                'status' => 'rejected',
                'updated_by' => $authUser->id,
            ];

            $hcp = $this->hcp->update($data, $where);

            // Send Account Rejected Notification
            send_other_push_notification(dv($id), 'hcp-account-rejected', 'hcp', $request['reject_reason']);
            //-----------------------------------

            // Hcp Activity
            create_hcp_activity(dv($id), 'status-change', __('hcp_activities.status_change', ['status' => 'rejected']), $authUser->id);
            //-------------

            DB::commit();
        } catch (\Exception $exception) {
            $hcp = null;
            DB::rollback();
        }

        if (!is_null($hcp)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Hcp']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.pendingApproval')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Hcp']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.pendingApproval')->with(['notification' => $notification]);
        }
    }

    /**
     * Export Hcp.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 12 Jan 2021
     */
    public function hcpExport(Request $request, $status = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['export'] = true;
            $request['request']['export'] = true;
            $request['hcp_list'] = true;
            unset($request['request']['per_page']);

            if ($request['status'] == 'pending-approval') {
                $where = [['status', '!=', 'active'], ['status', '!=', 'archived'], ['status', '!=', 'blocked'], ['status', '!=', 'rejected'], ['app_registration_screen', '=', '0']];
            } else {
                $where['status'] = $request['status'];
            }

            return Excel::download(new HcpsExport($this->hcp,$where,$request), 'hcps.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * View profession pending approval hcps.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 13 Aug 2020
     */
    public function professionPendingApprovalHcps(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        // Get Categories
        $categories = $this->category->get();
        //---------------

        // Get Professions
        $professions = $this->profession->get();
        //----------------

        // Profession Requests
        $where = ['status' => 'pending'];
        $professionRequests = $this->hcp_profession_request->get_hcp_profession_requests_with_pagination($where, $request);
        //--------------------

        $this->viewData['categories'] = $categories;
        $this->viewData['professions'] = $professions;
        $this->viewData['professionRequests'] = $professionRequests;
        $this->viewData['request'] = $request->all();
        $this->viewData['authUser'] = $authUser;

        return view('admin-panel.hcps.profession-pending-approval')->with($this->viewData);
    }

    /**
     * Approve Pending Profession.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 24 Sep 2020
     */
    public function approvePendingProfession(Request $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $professionRequest = null;

        DB::beginTransaction();
        try {

            // Get Profession Request
            $getProfessionRequest = $this->hcp_profession_request->find_hcp_profession_request(dv($id));
            //------------------------

            // Get Find Pending Profession Request
            $getAllPendingProfessionRequest = $this->hcp_profession_request->getAll(['profession_id' => $getProfessionRequest['profession_id'], 'hcp_id' => $getProfessionRequest['hcp_id'], 'status' => 'pending'], true);
            //------------------------------------

            if($getProfessionRequest['type'] == 'document-expired') {

                $pendingDocuments = get_pending_hcp_doucments_by_ids($getProfessionRequest['hcp_document_ids']);
                ;

                if(count($pendingDocuments) == 0) {

                    // Update Profession Request
                    $professionRequest = $this->hcp_profession_request->update([
                        'status' => 'approved',
                    ], [
                        'id' => $getProfessionRequest['id']
                    ]);
                    //--------------------------

                    // Update Hcp Profession
                    if(count($getAllPendingProfessionRequest) == 1) {
                        $this->hcp_profession->update([
                            'status' => 'active'
                        ], [
                            'hcp_id' => $getProfessionRequest['hcp_id'],
                            'category_id' => $getProfessionRequest['category_id'],
                            'profession_id' => $getProfessionRequest['profession_id'],
                        ]);
                    }
                    //----------------------

                    // Send Approved Notification
                    send_other_push_notification($getProfessionRequest['hcp_id'], 'hcp-profession-document-approved', 'hcp', null, null, $getProfessionRequest['profession']['name'], null);
                    //---------------------------

                    // Hcp Activity
                    create_hcp_activity($getProfessionRequest['hcp_id'], 'profession-approved', __('hcp_activities.profession_approved', ['professionName' => $getProfessionRequest['profession']['name']]), $authUser->id);
                    //-------------

                } else {
                    $response = [
                        '_status' => false,
                        '_message' => __('messages.hcp_profession_document_not_approve'),
                        '_type' => 'error',
                    ];
                    return response()->json($response, 200);
                }

            } else if($getProfessionRequest['type'] == 'level-update') {

                // Update Profession Request
                $professionRequest = $this->hcp_profession_request->update([
                    'status' => 'approved',
                ], [
                    'id' => $getProfessionRequest['id']
                ]);
                //--------------------------

                // Update Hcp Profession
                if(count($getAllPendingProfessionRequest) == 1) {
                    $this->hcp_profession->update([
                        'status' => 'active'
                    ], [
                        'hcp_id' => $getProfessionRequest['hcp_id'],
                        'category_id' => $getProfessionRequest['category_id'],
                        'profession_id' => $getProfessionRequest['profession_id'],
                    ]);
                }
                //----------------------

                // Send Approved Notification
                send_other_push_notification($getProfessionRequest->hcp_id, 'hcp-profession-level-approved', 'hcp', null, null, $getProfessionRequest['profession']['name'], null);
                //---------------------------

                // Hcp Activity
                create_hcp_activity($getProfessionRequest['hcp_id'], 'profession-approved', __('hcp_activities.profession_approved', ['professionName' => $getProfessionRequest['profession']['name']]), $authUser->id);
                //-------------

            } else if($getProfessionRequest['type'] == 'profession-added') {

                // Hcp Documents
                $hcpDoucments = DocumentHcp::where('hcp_id', $getProfessionRequest['hcp_id'])
                ->where('profession_id', $getProfessionRequest['profession_id'])
                ->where('document_approval', 'approved')
                ->whereHas('document', function ($query) {
                    $query->where('mandatory_status', 'yes');
                })
                ->with(['document' => function ($query)  {
                    $query->where('mandatory_status', 'yes');
                }])->count();
                //--------------

                // Profession Mandatory Documents
                $professionDocuments = DocumentConfiguration::where('profession_id', $getProfessionRequest['profession_id'])
                ->whereHas('document', function ($query) use ($getProfessionRequest) {
                    $query->where('required_for', 'hcp');
                    $query->where('mandatory_status', 'yes');
                    $query->where('doc_type', 'profession');
                })->with(['document' => function ($query) use($getProfessionRequest) {
                    $query->where('required_for', 'hcp');
                    $query->where('mandatory_status', 'yes');
                    $query->where('doc_type', 'profession');
                }])
                ->count();
                //-------------------------------

                if($hcpDoucments >= $professionDocuments) {

                    // Update Profession Request
                    $professionRequest = $this->hcp_profession_request->update([
                        'status' => 'approved',
                    ], [
                        'id' => $getProfessionRequest['id']
                    ]);
                    //--------------------------

                    // Update Hcp Profession
                    if(count($getAllPendingProfessionRequest) == 1) {
                        $this->hcp_profession->update([
                            'status' => 'active'
                        ], [
                            'hcp_id' => $getProfessionRequest['hcp_id'],
                            'category_id' => $getProfessionRequest['category_id'],
                            'profession_id' => $getProfessionRequest['profession_id'],
                        ]);
                    }
                    //----------------------

                    // Send Approved Notification
                    send_other_push_notification($getProfessionRequest['hcp_id'], 'hcp-profession-approved', 'hcp', null, null, $getProfessionRequest['profession']['name'], null);
                    //---------------------------

                    // Hcp Activity
                    create_hcp_activity($getProfessionRequest['hcp_id'], 'profession-approved', __('hcp_activities.profession_approved', ['professionName' => $getProfessionRequest['profession']['name']]), $authUser->id);
                    //-------------

                } else {
                    $response = [
                        '_status' => false,
                        '_message' => __('messages.hcp_profession_document_not_approve'),
                        '_type' => 'error',
                    ];
                    return response()->json($response, 200);
                }
            }


            DB::commit();
        } catch (\Exception $exception) {
            $professionRequest = null;
            $errorMessage = $exception->getMessage();
            DB::rollback();
        }

        if (!is_null($professionRequest)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
                '_redirect_url' => route('adminPanel.hcps.details', ['id' => $id]),
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
                '_redirect_url' => route('adminPanel.hcps.details', ['id' => $id]),
            ];
        }
        return response()->json($response, 200);
    }

    /**
     * Reject Pending Profession Modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 15 Dec 2020
     */
    public function rejectPendingProfessionModal(Request $request, $id = null)
    {
        try {

            return view('admin-panel.includes.hcps.reject-pending-profession-modal', compact('id'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Reject Pending Profession.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 15 Dec 2020
     */
    public function rejectPendingProfession(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $professionRequest = null;

        DB::beginTransaction();
        try {
            // Get Profession Request
            $getProfessionRequest = $this->hcp_profession_request->find_hcp_profession_request(dv($id));
            //------------------------

            if($getProfessionRequest['type'] == 'document-expired') {

                // Update Profession Request
                $professionRequest = $this->hcp_profession_request->update([
                    'status' => 'rejected',
                ], [
                    'id' => $getProfessionRequest['id']
                ]);
                //--------------------------

                // Send Reject Notification
                send_other_push_notification($getProfessionRequest->hcp_id, 'hcp-profession-rejected', 'hcp', $request['reject_reason'], null, $getProfessionRequest['profession']['name'], null);
                //---------------------------

                // Hcp Activity
                create_hcp_activity($getProfessionRequest->hcp_id, 'profession-rejected', __('hcp_activities.profession_rejected', ['professionName' => $getProfessionRequest['profession']['name'], 'Reason' => $request['reject_reason']]), $authUser->id);
                //-------------

            } else if($getProfessionRequest['type'] == 'level-update') {

                // Reupdate profession level
                    // Update Hcp Profession
                    $this->hcp_profession->update(['status' => 'active', 'level_id' => $getProfessionRequest['previous_level_id']], ['hcp_id' => $getProfessionRequest->hcp->id, 'id' => $getProfessionRequest['hcp_profession_id']]);
                    //----------------------

                    // Check Accept Lower Level Job
                    if ($getProfessionRequest->hcp['accept_lower_level_job'] == 1) {
                        $hcpProfessions = $this->hcp_profession->getAll(['hcp_id' => $getProfessionRequest->hcp->id], true);
                        if (count($hcpProfessions)) {
                            foreach($hcpProfessions as $hcpProfession){
                                if (!is_null($hcpProfession->level_id)) {
                                    $levelWhere = [
                                        'category_id' => $hcpProfession->category_id,
                                        'profession_id' => $hcpProfession->profession_id,
                                        ['id', '<=', $hcpProfession->level_id]
                                    ];
                                    $hcplevels = $this->level->getAll($levelWhere, true)->pluck('id');
                                    if (count($hcplevels)) {
                                        $this->hcp_profession->update(['accept_level_ids' => implode(',', $hcplevels->toArray())], ['id' => $hcpProfession->id]);
                                    }
                                }
                            }
                        }
                    } else {
                        $hcpProfessions = $this->hcp_profession->getAll(['hcp_id' => $getProfessionRequest->hcp->id], true);
                        if(count($hcpProfessions)) {
                            foreach($hcpProfessions as $hcpProfession){
                                if (!is_null($hcpProfession->level_id)) {
                                    $this->hcp_profession->update(['accept_level_ids' => $hcpProfession->level_id], ['id' => $hcpProfession->id]);
                                }
                            }
                        }
                    }
                    //-----------------------------
                //--------------------------

                // Update Profession Request
                $professionRequest = $this->hcp_profession_request->update([
                    'status' => 'rejected',
                ], [
                    'id' => $getProfessionRequest['id']
                ]);
                //--------------------------

                // Send Reject Notification
                send_other_push_notification($getProfessionRequest->hcp_id, 'hcp-profession-rejected', 'hcp', $request['reject_reason'], null, $getProfessionRequest['profession']['name'], null);
                //---------------------------

                // Hcp Activity
                create_hcp_activity($getProfessionRequest->hcp_id, 'profession-rejected', __('hcp_activities.profession_rejected', ['professionName' => $getProfessionRequest['profession']['name'], 'Reason' => $request['reject_reason']]), $authUser->id);
                //-------------
            } else if($getProfessionRequest['type'] == 'profession-added') {

                // Update Hcp Profession
                $this->hcp_profession->update(['status' => 'pending-approval'], ['hcp_id' => $getProfessionRequest->hcp->id, 'id' => $getProfessionRequest['hcp_profession_id']]);
                //----------------------

                // Update Profession Request
                $professionRequest = $this->hcp_profession_request->update([
                    'status' => 'rejected',
                ], [
                    'id' => $getProfessionRequest['id']
                ]);
                //--------------------------

                // Send Reject Notification
                send_other_push_notification($getProfessionRequest->hcp_id, 'hcp-profession-rejected', 'hcp', $request['reject_reason'], null, $getProfessionRequest['profession']['name'], null);
                //---------------------------

                // Hcp Activity
                create_hcp_activity($getProfessionRequest->hcp_id, 'profession-rejected', __('hcp_activities.profession_rejected', ['professionName' => $getProfessionRequest['profession']['name'], 'Reason' => $request['reject_reason']]), $authUser->id);
                //-------------
            }

            create_hcp_activity($getProfessionRequest->hcp_id, 'profession-rejected', __('hcp_activities.profession_rejected', ['professionName' => $getProfessionRequest['profession']['name'], 'Reason' => $request['reject_reason']]), $authUser->id);

            DB::commit();
        } catch (\Exception $exception) {
            $professionRequest = null;
            $errorMessage = $exception->getMessage();
            DB::rollback();
        }

        if (!is_null($professionRequest)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Hcp']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.professionPendingApprovalHcps')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Hcp']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.hcps.professionPendingApprovalHcps')->with(['notification' => $notification]);
        }
    }

    /**
     * Export Hcp.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 12 Jan 2021
     */
    public function professionPendingApprovalHcpExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['per_page']);
            $where = ['status' => 'pending'];

            return Excel::download(new ProfessionPendingApprovalHcpExport($this->hcp_profession_request,$where,$request), 'hcps.xls');

        } catch (\Exception $exception) {

            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Block Hcp Modal.
     *
     * @return mixed
     *
     * @author Yamini
     * @created 07 Apr 2023
     */
    public function blockHcpModal(Request $request, $id)
    {
        try {
            // Get hcp
            $hcp = $this->hcp->find_hcp(dv($id));
            //--------

            // Get Facility
            $where = ['status' => 'active'];
            $facilities = $this->facility->getAll($where, true, $request);

            return view('admin-panel.hcps.block-modal', compact('facilities','hcp'));
        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Block Hcp for any facility.
     *
     * @return mixed
     *
     * @author Yamini
     * @created 07 Apr 2023
     */
    public function blockHcp(Request $request, $id)
    {
        $authUser = auth()->user();
        $facilityId = $request->facility;
        $hcpId = dv($id);
        $blocklist = null;
        $data = [];

        $alreadyBlocked = $this->favouritesAndBlocklist->get_hcp_mark_blocklist($facilityId,$hcpId);
        if($alreadyBlocked>0){
            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.blocklist_added'),
                '_type' => 'success',
            ];
            //-----------------
            return redirect()->route('adminPanel.hcps.activeHcps')->with(['notification' => $notification]);
        }

        // Add to blocklist
        DB::beginTransaction();
        try {

            $data = [
                'facility_id' => $facilityId,
                'hcp_id' => $hcpId,
                'marked_by' => 'facility',
                'type' => 'blocked',
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            $blocklist = $this->favouritesAndBlocklist->store($data);

            // Send Notification
            send_other_push_notification($hcpId, 'facility-added-on-blocklist', 'hcp', null, null, null, null, null, $facilityId);
            //------------------

            // Facility Activity
            create_facility_activity($facilityId, 'mark-as-block', __('facility_activities.hcp_mark_as_block', ['hcp' => get_hcp_name($hcpId)]), $authUser->id);
            //------------------

            DB::commit();
        } catch (\Exception $exception) {
            $blocklist = null;
            DB::rollback();
//            p($exception);
            return dashboard_redirect($exception);
        }
        //-----------------

        if (!is_null($blocklist)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.blocklist_added'),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.blocklist_added_failed'),
                '_type' => 'error',
            ];
            //-----------------
        }
        return redirect()->route('adminPanel.hcps.activeHcps')->with(['notification' => $notification]);
    }

   public function showDetails(Request $request)
    {
        p('heyy');
        $user = Auth::user('user');
        if ($user->id) {
            p($user);
            return view('admin-panel.user-details', compact('user'));
        } else {
            return redirect()->back()->withErrors('Something went wrong, please try again');
        }
    }
}
