<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Interfaces\CategoryInterface;
use App\Interfaces\ProfessionInterface;
use App\Interfaces\LevelInterface;
use Excel;
use App\Exports\CategoryExport;
use App\Exports\ProfessionExport;
use App\Exports\LevelExport;

class HcpConfiguration extends Controller
{
    private $category,$profession,$level;

    public function __construct(CategoryInterface $category,ProfessionInterface $profession, LevelInterface $level)
    {
        $this->middleware('auth.admin');
        $this->category = $category;
        $this->profession = $profession;
        $this->level = $level;
    }

    /**
     * View Hcp Configuration.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 19 Dec 2020
    */
    public function index(Request $request)
    {
        try {

            // General Configuration
            $generalConfiguration = get_general_configuration();
            $adminFees = $generalConfiguration['admin_fee'];
	$hcp_sleepover_rate = $generalConfiguration['hcp_sleepover_rate'];
            $facility_sleepover_rate = $generalConfiguration['facility_sleepover_rate'];
	$hcp_extra_night_rate = $generalConfiguration['hcp_extra_night_rate'];
            $facility_extra_night_rate = $generalConfiguration['facility_extra_night_rate'];
            //----------------------

            // Get Categories
            $categoryWhere = [];
            $categories = $this->category->get_category_with_pagination($categoryWhere, $request);
            //---------------

            // Get Professions
            $professionWhere = [];
            $professions = $this->profession->get_profession_with_pagination($professionWhere, $request);
            //----------------

            // Get Levels
            $levelWhere = [];
            $levels = $this->level->get_level_with_pagination($levelWhere, $request);
            //-----------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.hcp-configuration.index', compact('hcp_sleepover_rate','facility_sleepover_rate','categories', 'professions', 'levels', 'request', 'adminFees','hcp_extra_night_rate','facility_extra_night_rate'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Category Change Status.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 19 Dec 2020
     */
    public function categoryChangeStatus(Request $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $category = null;
        $data = [];
        $where = [];

        DB::beginTransaction();
        try {

            $where = [
                'id' => dv($id)
            ];

            $data = [
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $category = $this->category->update($data, $where);

            DB::commit();
        } catch (\Exception $exception) {
            $category = null;
            DB::rollback();
        }

        if (!is_null($category)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
                '_tab' => 'category',
            ];
            //-----------------

            return response()->json($notification, 200);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
                '_tab' => 'category',
            ];
            //-----------------

            return response()->json($notification, 200);
        }

    }


    /**
     * Profession Change Status.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 19 Dec 2020
     */
    public function professionChangeStatus(Request $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $profession = null;
        $data = [];
        $where = [];

        DB::beginTransaction();
        try {

            $where = [
                'id' => dv($id)
            ];

            $data = [
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $profession = $this->profession->update($data, $where);

            DB::commit();
        } catch (\Exception $exception) {
            $profession = null;
            DB::rollback();
        }

        if (!is_null($profession)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
                '_tab' => 'profession',
            ];
            //-----------------

            return response()->json($notification, 200);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
                '_tab' => 'profession',
            ];
            //-----------------

            return response()->json($notification, 200);
        }

    }


    /**
     * Level Change Status.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 19 Dec 2020
     */
    public function levelChangeStatus(Request $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $level = null;
        $data = [];
        $where = [];

        DB::beginTransaction();
        try {

            $where = [
                'id' => dv($id)
            ];

            $data = [
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $level = $this->level->update($data, $where);

            DB::commit();
        } catch (\Exception $exception) {
            $level = null;
            DB::rollback();
        }

        if (!is_null($level)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
                '_tab' => 'level',
            ];
            //-----------------

            return response()->json($notification, 200);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
                '_tab' => 'level',
            ];
            //-----------------

            return response()->json($notification, 200);
        }

    }

    /**
     * Category Export.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 06 Jan 2021
     */
    public function categoryExport(Request $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['category_per_page']);

            return Excel::download(new CategoryExport($this->category,$where,$request), 'category.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }


    /**
     * Profession Export.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 06 Jan 2021
     */
    public function professionExport(Request $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['profession_per_page']);

            return Excel::download(new ProfessionExport($this->profession,$where,$request), 'professions.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Profession Export.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 06 Jan 2021
     */
    public function levelExport(Request $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['level_per_page']);

            return Excel::download(new LevelExport($this->level,$where,$request), 'levels.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }
}
