<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Http\Requests\AdminPanel\DocumentRequest;
use App\Interfaces\DocumentInterface;
use App\Interfaces\ProfessionInterface;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\DocumentsExport;
use App\Exports\FacilityDocumentsExport;

class ManageDocumentController extends Controller
{
    private $document,$profession;
    public function __construct(DocumentInterface $document,ProfessionInterface $profession){
        $this->document = $document;
        $this->profession = $profession;
    }

    public function index(Request $request){

        try {

            // Request
            $request = $request->all();
            //--------

            // Get Documents
            $documents = $this->document->get([], true, $request);
            //--------------

            return view('admin-panel.documents.index', compact('documents', 'request'));
        } catch (\Exception $exception){
            return dashboard_redirect($exception->getMessage());
        }
    }

    public function create(){
        try {

            // Get Profession
            $professions = $this->profession->getAll(['status' => 'active'], true, null);
            //---------------

            return view('admin-panel.documents.create', compact('professions'));
        } catch (\Exception $exception){
            return dashboard_redirect($exception->getMessage());
        }
    }

    public function store(DocumentRequest $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $document = null;
        $data = [];

        DB::beginTransaction();
        try {

            $data = [
                'name' => $request['name'],
                'required_for' => $request['required_for'],
                'mandatory_status' => $request['mandatory_status'] ?? 'no',
                'expiry_date_mandatory' => $request['expiry_date_mandatory'] ?? 'no',
                'profession_id' => isset($request['facility_profession']) ? $request['facility_profession'] : null,
                'doc_type' => $request['doc_type'],
                'status' => $request['status'],
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            $document = $this->document->store($data);

            DB::commit();
        } catch (\Exception $exception) {
            $document = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($document)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Document']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.documents.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_creation_failed', ['record' => 'Document']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.documents.create')->withInput()->with(['notification' => $notification]);
        }
    }


    public function edit(Request $request, $id){
        try {

            // Get Document
            $document = $this->document->find_document(dv($id));
            //-------------

            // Get Profession
            $professions = $this->profession->getAll(['status' => 'active'], true, null);
            //---------------

            return view('admin-panel.documents.edit', compact('document', 'professions'));
        }catch (\Exception $exception){
            return dashboard_redirect($exception->getMessage());
        }
    }

    public function update(DocumentRequest $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $document = null;
        $data = [];

        DB::beginTransaction();
        try {

            $data = [
                'name' => $request['name'],
                'required_for' => $request['required_for'],
                'mandatory_status' => $request['mandatory_status'] ?? 'no',
                'expiry_date_mandatory' => $request['expiry_date_mandatory'] ?? 'no',
                'profession_id' => isset($request['facility_profession']) ? $request['facility_profession'] : null,
                'doc_type' => $request['doc_type'],
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $document = $this->document->update($data, ['id' => dv($id)]);

            DB::commit();
        } catch (\Exception $exception) {
            $document = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($document)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Document']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.documents.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Document']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.documents.edit', ['id' => $id])->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Change Status.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 30 Oct 2020
     */
    public function changeStatus(Request $request, $id, $status)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $document = null;
        $data = [];
        $where = [];

        DB::beginTransaction();
        try {
            $where = ['id' => dv($id)];

            $data = [
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $document = $this->document->update($data, $where);

            DB::commit();
        } catch (\Exception $exception) {
            $document = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($document)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }
        return response()->json($response, 200);
    }

    /**
     * Get document type.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 24 Nov 2020
     */
    public function getDocumentType(Request $request)
    {

        // Get document type
        if($request['required_by'] == 'hcp') {
            $documentTypes = config('constants.documents.doc_type_hcp');
        } else {
            $documentTypes = config('constants.documents.doc_type_facility');
        }
        //------------------

        // Set response
        if (count($documentTypes)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.record_found', ['record' => 'Document Type']),
                '_data' => $documentTypes,
            ];
        } else {
            $response = [
                '_status' => false,
                '_message' => __('messages.record_not_found', ['record' => 'Document Type']),
                '_data' => [],
            ];
        }
        //-------------

        return response()->json($response, 200);
    }

    /**
     * Export Document
     *
     * @return Excel
     *
     * @author Sumit
     * @created 26 Jan 2021
     */
    public function documentExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new DocumentsExport($this->document,$where,$request), 'documents.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

}
