<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Http\Requests\AdminPanel\ValidateNotification;
use App\Interfaces\NotificationInterface;
use App\Interfaces\StateInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\HcpInterface;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use \OneSignal as OneSignal;
use Twilio\Rest\Client;

class NotificationController extends Controller
{
    private $notification;
    public function __construct(NotificationInterface $notification, StateInterface $state, HcpInterface $hcp, FacilityInterface $facility){
        $this->notification = $notification;
        $this->state = $state;
        $this->hcp = $hcp;
        $this->facility = $facility;
    }

    /**
     * View notifications.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 28 Nov 2020
     */
    public function index()
    {

        // Get admin notifications
        $where = ['notification_type' => 'custom'];
        $notifications = $this->notification->get($where, true);
        //------------------------

        return view('admin-panel.notification.index', compact('notifications'));
    }

    /**
     * Create notifications.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 28 Nov 2020
     */
    public function create()
    {
        try {

            // Get States
            $stateWhere = ['status' => 'active'];
            $states = $this->state->get_states($stateWhere);
            //-----------

            return view('admin-panel.notification.create', compact('states'));
        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    /**
     * Store notifications.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 28 Nov 2020
     */
    public function store(ValidateNotification $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $notification = null;
        $data = [];
        $userDeviceIds = [];

        DB::beginTransaction();
        try {

            if (empty($request['state_id']) && $request['send_to'] == 'all-hcp') {

                // Get Hcp
                $hcps = $this->hcp->get_hcp_for_notification($request);
                //--------
                $player_ids = $hcps->pluck("user.device_id")->toArray();
                $params = [];
                $params['include_player_ids'] = $player_ids;
                $headings = [
                    "en" => !empty($request['title'])? $request['title'] : "",
                ];
                $contents = [
                    "en" => $request['message'],
                ];
                $params['contents'] = $contents;
                $params['headings'] = $headings;
                $params['data'] =  [
                                     'notification_type' => 'other',
                                     'document_type' => '',
                                     'shift_id' => '',
                                     'hcp_id' => '',
                                    ];

                OneSignal::sendNotificationCustom($params);



                if (count($hcps)) {
//                    dd("ASDSAD");
                    foreach($hcps as $hcp){
//                        if(!empty($hcp->contact_number)) {
//                            $notification = true;
//
//                            // Send SMS
//                            try {
//                                $smsMessage = $request['message'];
//                                $accountSid = env("TWILIO_SID");
//                                $authToken = env("TWILIO_AUTH_TOKEN");
//                                $twilioNumber = env("TWILIO_NAME");
//                                $client = new Client($accountSid, $authToken);
//
//                                $message = $client->messages->create($hcp->contact_number, [
//                                    'from' => $twilioNumber,
//                                    'body' => $smsMessage
//                                ]);
//
//                            } catch (\Exception $e) {
//                                // will return user to with twilio error
//                                $response = [
//                                    'status' => false,
//                                    'message' => $e->getMessage(),
//                                    'data' => null,
//                                ];
//
//                            }
//                        }

                        $data = [
                             'title' => $request['title'],
                             'message' => $request['message'],
                             'hcp_id' => $hcp->id,
                             'send_to' => 'hcp',
                             'sent_by' => 'admin',
                             'notification_type' => 'other',
                             'read_status' => 'unread',
                             'created_by' => $authUser->id,
                             'updated_by' => $authUser->id,
                         ];

                         $notification = $this->notification->store($data);

//                         if(!empty($hcp->user->device_id) && env('ONE_SIGNAL_APP_ID') !=''){
//                             $notiArray = [
//                                 'notification_type' => 'other',
//                                 'document_type' => '',
//                                 'shift_id' => '',
//                                 'hcp_id' => '',
//                             ];
//
//                             $response = OneSignal::sendNotificationToUser(
//                                 $request['message'],
//                                 $hcp->user->device_id,
//                                 null,
//                                 $notiArray,
//                                 null,
//                                 null,
//                                 $request['title'],
//                                 null
//                             );
//                         }
//                         dd($response, "onesignal resp");
                    }

                }

            } else if(!empty($request['state_id']) && $request['send_to'] == 'all-hcp') {

                // Get Hcp
                $hcps = $this->hcp->get_hcp_for_notification($request);
                //--------
                $player_ids = $hcps->pluck("user.device_id")->toArray();
                $params = [];
                $params['include_player_ids'] = $player_ids;
                $headings = [
                    "en" => !empty($request['title'])? $request['title'] : "",
                ];
                $contents = [
                    "en" => $request['message'],
                ];
                $params['contents'] = $contents;
                $params['headings'] = $headings;
                $params['data'] =  [
                    'notification_type' => 'other',
                    'document_type' => '',
                    'shift_id' => '',
                    'hcp_id' => '',
                ];

                OneSignal::sendNotificationCustom($params);

                if (count($hcps)) {
                    foreach($hcps as $hcp){

//                        if(!empty($hcp->contact_number)) {
//                            $notification = true;
//
//                            // Send SMS
//                            try {
//                                $smsMessage = $request['message'];
//                                $accountSid = env("TWILIO_SID");
//                                $authToken = env("TWILIO_AUTH_TOKEN");
//                                $twilioNumber = env("TWILIO_NAME");
//                                $client = new Client($accountSid, $authToken);
//
//                                $message = $client->messages->create($hcp->contact_number, [
//                                    'from' => $twilioNumber,
//                                    'body' => $smsMessage
//                                ]);
//
//                            } catch (\Exception $e) {
//                                $response = [
//                                    'status' => false,
//                                    'message' => $e->getMessage(),
//                                    'data' => null,
//                                ];
//
//                            }
//                        }

                         $data = [
                             'title' => $request['title'],
                             'message' => $request['message'],
                             'hcp_id' => $hcp->id,
                             'send_to' => 'hcp',
                             'sent_by' => 'admin',
                             'notification_type' => 'other',
                             'read_status' => 'unread',
                             'created_by' => $authUser->id,
                             'updated_by' => $authUser->id,
                         ];

                         $notification = $this->notification->store($data);

                        // if(!empty($hcp->user->device_id) && env('ONE_SIGNAL_APP_ID') !=''){
                        //     $notiArray = [
                        //         'notification_type' => 'other',
                        //         'document_type' => '',
                        //         'shift_id' => '',
                        //         'hcp_id' => '',
                        //     ];

                        //     $response = OneSignal::sendNotificationToUser(
                        //         $request['message'],
                        //         $hcp->user->device_id,
                        //         null,
                        //         $notiArray,
                        //         null,
                        //         null,
                        //         $request['title'],
                        //         null
                        //     );
                        // }
                    }

                }

            } else if(empty($request['state_id']) && $request['send_to'] == 'all-facility') {

                $data = [
                    'title' => $request['title'],
                    'message' => $request['message'],
                    'send_to' => $request['send_to'],
                    'sent_by' => 'admin',
                    'notification_type' => 'custom',
                    'read_status' => 'unread',
                    'created_by' => $authUser->id,
                    'updated_by' => $authUser->id,
                ];

                $notification = $this->notification->store($data);
            } else if(!empty($request['state_id']) && $request['send_to'] == 'all-facility') {

                // Get Facilities
                $facilities = $this->facility->getAll([], true, $request);
                //---------------

                if (count($facilities)) {
                    foreach($facilities as $facility){
                        $data = [
                            'title' => $request['title'],
                            'message' => $request['message'],
                            'facility_id' => $facility->id,
                            'send_to' => 'facility',
                            'sent_by' => 'admin',
                            'notification_type' => 'custom',
                            'read_status' => 'unread',
                            'created_by' => $authUser->id,
                            'updated_by' => $authUser->id,
                        ];

                        $notification = $this->notification->store($data);
                    }
                }
            }

            DB::commit();
        } catch (\Exception $exception) {
            $notification = null;
            DB::rollback();

            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($notification)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Notification']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.notification.getAdminNotifications')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_creation_failed', ['record' => 'Notification']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.notification.create')->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Get Notification For Top Bar.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 12 Dec 2020
     */
    public function getNotificationForTopBar(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Get facility
        $facility = $authUser->facility;
        //-------------

        // Get notifications
        if(!empty($facility)) {
            $request['type'] = 'facility';
            $request['facility_id'] = $facility->id;
        }

        $request = $request->all();
        $notifications = $this->notification->get_notifications($request, $limit = 8);
        $unreadNotificationCount = get_unread_notifications_count($request);
        //------------------

        return view('admin-panel.notification.top-bar-list', compact('notifications', 'unreadNotificationCount', 'request'));
    }


    /**
     * Get Unread Notification Count.
     *
     * @author Sumit
     * @created 12 Dec 2020
     */
    public function getUnreadNotificationCount(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Get facility
        $facility = $authUser->facility;
        //-------------

        // Get notifications
        if(!empty($facility)) {
            $request['type'] = 'facility';
            $request['facility_id'] = $facility->id;
        }

        $request = $request->all();

        $response = [
            'status' => true,
            'unread_notification_count' => get_unread_notifications_count($request),
        ];
        return response()->json($response, 200);
    }

    /**
     * Mark As Read.
     *
     * @author Sumit
     * @created 12 Dec 2020
     */
    public function markAsRead(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Get facility
        if (!empty($authUser->facility)) {
            $facility = $authUser->facility;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $facility = $authUser->sub_admin->facility;
        }
        //-------------

        $messageUpdate = null;
        $errorMessage = null;
        $notificationArray = [];

        DB::beginTransaction();
        try {

            if(!empty($facility)) {
                $request['type'] = 'facility';
                $request['facility_id'] = $facility->id;
            }

            $notifications = $this->notification->get_notifications($request);
            if(!empty($notifications)) {
                foreach($notifications as $notification){
                    $readFacilities = $notification['read_facilities'];
                    if (empty($readFacilities)) {
                        $messageUpdate = $this->notification->update(['read_status' => 'read','read_facilities' => $request['facility_id']], ['id' => $notification->id]);
                    } else {
                        $facilityIds = explode(',', $readFacilities);
                        $facilityIds[] = $request['facility_id'];
                        $messageUpdate = $this->notification->update(['read_status' => 'read', 'read_facilities' => implode(',', $facilityIds)], ['id' => $notification->id]);
                    }
                }
            }

            $messageUpdate = $this->notification->update(['read_status' => 'read'], ['facility_id' => $request['facility_id'], 'notification_type' => 'documents']);

            DB::commit();
        } catch (\Exception $e) {
            $messageUpdate = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }



        if (!is_null($messageUpdate)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }

        return response()->json($response, 200);
    }

    /**
     * Get Facility Notification.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 12 Dec 2020
     */
    public function getFacilityNotifications(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Get notifications
        if (!empty($authUser->facility)) {
            $request['type'] = 'facility';
            $request['facility_id'] = $authUser->facility->id;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $request['type'] = 'facility';
            $request['facility_id'] = $authUser->sub_admin->facility_id;
        }

        $request = $request->all();
        $notifications = $this->notification->get_notifications($request, $limit = 20);
        $unreadNotificationCount = get_unread_notifications_count($request);
        //------------------


        return view('admin-panel.notification.facility-notification', compact('notifications', 'unreadNotificationCount', 'authUser'));
    }

    /**
     * Get Admin Notification.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 12 Jan 2021
     */
    public function getAdminNotifications(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Get notifications
        if($authUser->role_name == 'super-admin') {
            $request['type'] = 'admin';
        }

        $request = $request->all();
        $notifications = $this->notification->get_notifications($request, $limit = 20);
        $unreadNotificationCount = get_unread_notifications_count($request);
        //------------------


        return view('admin-panel.notification.admin-notification', compact('notifications', 'unreadNotificationCount', 'authUser'));
    }

    /**
     * Get Admin Notification For Top Bar.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 12 Jan 2021
     */
    public function getAdminNotificationForTopBar(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Get notifications
        if($authUser->role_name == 'super-admin') {
            $request['type'] = 'admin';
        }

        $request = $request->all();
        $notifications = $this->notification->get_notifications($request, $limit = 8);
        //$unreadNotificationCount = get_unread_notifications_count($request);
        //------------------

        //return view('admin-panel.notification.top-bar-list', compact('notifications', 'unreadNotificationCount', 'request'));
	return view('admin-panel.notification.top-bar-list', compact('notifications',  'request'));
    }


    /**
     * Get Admin Unread Notification Count.
     *
     * @author Sumit
     * @created 12 Jan 2021
     */
    public function getAdminUnreadNotificationCount(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Get facility
        $facility = $authUser->facility;
        //-------------

        // Get notifications
        if($authUser->role_name == 'super-admin') {
            $request['type'] = 'admin';
        }

        $request = $request->all();

        $response = [
            'status' => true,
            'unread_notification_count' => get_unread_notifications_count($request),
        ];

        return response()->json($response, 200);
    }

    /**
     * Admin Mark As Read.
     *
     * @author Sumit
     * @created 12 Jan 2021
     */
    public function adminMarkAsRead(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $messageUpdate = null;
        $errorMessage = null;
        $notificationArray = [];

        DB::beginTransaction();
        try {

            $messageUpdate = $this->notification->update(['read_status' => 'read'], ['send_to' => 'admin']);

            DB::commit();
        } catch (\Exception $e) {
            $messageUpdate = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($messageUpdate)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }

        return response()->json($response, 200);
    }
}
