<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Interfaces\PlanInterface;
use App\Interfaces\ProfessionInterface;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use App\Interfaces\FacilityInterface;
use Stripe;

class PlanController extends Controller
{
    private $plan, $profession;
    public function __construct(PlanInterface $plan, ProfessionInterface $profession,FacilityInterface $facility){
        $this->plan = $plan;
        $this->profession = $profession;
        $this->facility=$facility;
    }

    public function index(){
        try {

            // Get Plans
            $planWhere = [];
            $plans = $this->plan->getAll($planWhere);
            //----------

            // Get Professions
            $professionWhere = [
                'status' => 'active'
            ];
            $professions = $this->profession->getAll($professionWhere, true);
            //----------------

            return view('admin-panel.plans.index', compact('plans', 'professions'));

        }catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    public function edit(){
        try {

            // Get Plans
            $planWhere = [];
            $plans = $this->plan->getAll($planWhere);
            //----------

            // Get Professions
            $professionWhere = [
                'status' => 'active'
            ];
            $professions = $this->profession->getAll($professionWhere, true);
            //----------------

            return view('admin-panel.plans.edit', compact('plans', 'professions'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    public function update(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $planUpdate = false;
        $errorMessage = null;

        // Update plan
        DB::beginTransaction();
        try {

            if(!empty($request->plan)) {
                foreach($request->plan as $plan){

                    // Plan
                    $planWhere = ['id' => $plan['plan_id']];
                    $planData = [
                        'monthly_price' => $plan['monthly_price'],
                        'stripe_monthly_price_key' => $plan['monthly_price_key'],
                        'yearly_discount' => $plan['yearly_discount'],
                        'yearly_price' => $plan['yearly_price'],
                        'stripe_yearly_price_key' => $plan['yearly_price_key'],
                    ];
                    $planUpdate = $this->plan->update($planData, $planWhere);
                    //-----

                    // Create assignment code grade & band
                    $planProfessions = [];
                    $planRecord = $this->plan->find_plan($plan['plan_id']);
                    if(!is_null($planRecord)){
                        foreach($plan['profession'] as $profession){
                            $planProfessions[$profession] = [
                                'plan_id' => $plan['plan_id'],
                                'created_by' => $authUser->id,
                                'updated_by' => $authUser->id,
                            ];
                        }
                        $planRecord->professions()->sync($planProfessions);
                    }
                    //------------------------------------
                }

            }

            DB::commit();
        } catch (\Exception $exception) {
            $planUpdate = null;
            DB::rollback();
            return dashboard_redirect($exception);
        }
        //------------

        if (!is_null($planUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Plan']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.plans.index')->with(['notification' => $notification]);
        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_creation_failed', ['record' => 'Plan']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.plans.edit')->withInput()->with(['notification' => $notification]);
        }
    }

    public function getPlanPrice(Request $request){
        $plan=$this->plan->find_plan($request->plan_id);
        if($request->plan_type=='monthly'){
            return $plan->monthly_price;
        }
        elseif($request->plan_type=='6_month'){
            return $plan['6_month_price'];
        }
        elseif($request->plan_type=='yearly'){
            return $plan->yearly_price;
        }
    }
}
