<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Interfaces\AdminProfileInterface;
use App\Interfaces\UserInterface;
use App\Interfaces\SubAdminInterface;
use App\Http\Requests\AdminPanel\ValidateChangePassword;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use App\Interfaces\FacilityInterface;

class ProfileController extends Controller
{

    private $adminProfile, $user, $subAdmin;
    public function __construct(AdminProfileInterface $adminProfile, UserInterface $user, SubAdminInterface $subAdmin,FacilityInterface $facility){
        $this->admin_profile = $adminProfile;
        $this->sub_admin = $subAdmin;
        $this->user = $user;
        $this->facility=$facility;
    }

    /**
     * View Admin.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 05 Oct 2020
    */
    public function index()
    {
        try {

            // Get users
            $authUser = auth()->user();
            //----------

            if($authUser->role_name == 'super-admin') {

                // Get admin
                $where = ['user_id' => $authUser->id];
                $profile = $this->admin_profile->find_admin_profile($where);
                //----------

            } elseif($authUser->role_name == 'sub-admin') {

                // Get sub admin
                $where = ['user_id' => $authUser->id];
                $profile = $this->sub_admin->get_sub_admin($where);
                //--------------

            }elseif($authUser->role_name == 'facility') {

                // Get facility admin
                $profile = $this->facility->find_facility($authUser->facility->id);
                //---------------------

                // Get Current Plan
                $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
                //-----------------

                // Get Current Plan
                if (!empty($facilityActivePlan) && $facilityActivePlan['plan_id'] != 4 && !empty($facilityActivePlan['stripe_subscriptions_id'])) {
                    $stripe = new \Stripe\StripeClient(env('STRIPE_SECRET'));
                    $subscription = $stripe->subscriptions->retrieve(
                        $facilityActivePlan['stripe_subscriptions_id'],
                        []
                    );
                } else {
                    $subscription = null;
                }
                //-----------------

                return view('admin-panel.profile.facility-profile', compact('profile', 'authUser', 'subscription', 'facilityActivePlan'));

            } else {
                return dashboard_redirect('no role find');
            }

            return view('admin-panel.profile.index', compact('profile', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }


    /**
     * View edit admin.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 05 Oct 2020
    */
    public function edit(Request $request)
    {
        try {

            // Get users
            $authUser = auth()->user();
            //----------

            if($authUser->role_name == 'super-admin') {

                // Get admin
                $where = ['user_id' => $authUser->id];
                $profile = $this->admin_profile->find_admin_profile($where);
                //----------

            } elseif($authUser->role_name == 'sub-admin') {

                // Get sub admin
                $where = ['user_id' => $authUser->id];
                $profile = $this->sub_admin->get_sub_admin($where);
                //--------------

            } else {
                return dashboard_redirect('no role find');
            }

            return view('admin-panel.profile.edit', compact('profile', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Update admin.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 05 Oct 2020
    */
    public function update(Request $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $profile = null;
        $profileUpdate = null;
        $userUpdate = null;
        $profileData = [];
        $userData = [];

        DB::beginTransaction();
        try {

            if($authUser->role_name == 'super-admin') {

                $profileData = [
                    'first_name' => $request['first_name'],
                    'last_name' => $request['last_name'],
                    'contact_number' => $request['contact_number'],
                    'updated_by' => $authUser->id,
                ];

                $userData = [
                    'name' => $request['first_name'].' '.$request['last_name'],
                    'updated_by' => $authUser->id,
                ];

                $profileUpdate = $this->admin_profile->update($profileData, ['id' => dv($id)]);
                $userUpdate = $this->user->update($userData, ['id' => $authUser->id]);

            } elseif($authUser->role_name == 'sub-admin') {

                $profileData = [
                    'name' => $request['name'],
                    'surname' => $request['surname'],
                    'contact_number' => $request['contact_number'],
                    'updated_by' => $authUser->id,
                ];

                $userData = [
                    'name' => $request['name'],
                    'updated_by' => $authUser->id,
                ];

                $profileUpdate = $this->sub_admin->update($profileData, ['id' => dv($id)]);
                $userUpdate = $this->user->update($userData, ['id' => $authUser->id]);

            }

            DB::commit();
        } catch (\Exception $exception) {
            $profileUpdate = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }


        if (!is_null($profileUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Profile']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.profile.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Sub Profile']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.profile.index')->withInput()->with(['notification' => $notification]);
        }

    }

    /**
     * View Change Password.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 05 Oct 2020
    */
    public function changePassword()
    {
        try {

            // Get users
            $authUser = auth()->user();
            //----------

            return view('admin-panel.profile.change-password', compact('authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Update password.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 05 Oct 2020
    */
    public function updatePassword(ValidateChangePassword $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $passwordUpdate = null;
        $userData = [];

        if (Hash::check($request->get('current_password'), $authUser->password)) {

            DB::beginTransaction();
            try {

                $userData = [
                    'password' => bcrypt($request['new_password']),
                    'updated_by' => $authUser->id,
                ];
                $passwordUpdate = $this->user->update($userData, ['id' => $authUser->id]);

                DB::commit();
            } catch (\Exception $exception) {
                $passwordUpdate = null;
                DB::rollback();
                return dashboard_redirect($exception->getMessage());
            }


            if (!is_null($passwordUpdate)) {

                // Set notification
                $notification = [
                    '_status' => true,
                    '_message' => __('messages.password_updated'),
                    '_type' => 'success',
                ];
                //-----------------

                return redirect()->route('adminPanel.profile.changePassword')->with(['notification' => $notification]);

            } else {

                // Set notification
                $notification = [
                    '_status' => false,
                    '_message' => __('messages.password_updation_failed'),
                    '_type' => 'error',
                ];
                //-----------------

                return redirect()->route('adminPanel.profile.changePassword')->withInput()->with(['notification' => $notification]);
            }
        } else {
            return redirect()->back()->withInput()->withErrors(__('messages.password_not_matched'));
        }

    }
}
