<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Interfaces\RatingReviewInterface;
use App\Interfaces\FacilityInterface;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\FacilityRatingsExport;
use App\Exports\HcpRatingsExport;
use App\Interfaces\FacilityGroupInterface;

class RatingController extends Controller
{
    private $ratingReview, $facility;
    public function __construct(RatingReviewInterface $ratingReview, FacilityInterface $facility,FacilityGroupInterface $facilityGroupInterface){
        $this->ratingReview = $ratingReview;
        $this->facility = $facility;
        $this->facility_group = $facilityGroupInterface;
    }

    /**
     * View Ratings & Reviews.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 23 Oct 2020
     */
    public function index(Request $request) {

        try {

            // Facility Ratings
            $facilityRatings = $this->ratingReview->get_facility_ratings($request);
            //-----------------

            // Hcp Ratings
            $hcpRatings = $this->ratingReview->get_hcp_ratings($request);
            //------------

            // Facilities
            $facilities = $this->facility->getAll([]);
            //-----------

            $this->viewData['facilityRatings'] = $facilityRatings;
            $this->viewData['hcpRatings'] = $hcpRatings;
            $this->viewData['facilities'] = $facilities;
            $this->viewData['request'] = $request->all();

            return view('admin-panel.rating.index')->with($this->viewData);

        } catch (\Exception $exception){
            return dashboard_redirect($exception->getMessage());
        }

    }


    /**
     * Change Status.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 23 Oct 2020
     */
    public function changeStatus(Request $request, $id, $status, $fragment = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $ratings = null;
        $data = [];
        $where = [];

        DB::beginTransaction();
        try {
            $where = ['id' => dv($id)];

            $data = [
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $ratings = $this->ratingReview->update($data, $where);

            DB::commit();
        } catch (\Exception $exception) {
            $ratings = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($ratings)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
                '_redirect_url' => route('adminPanel.rating-review.index', ['#'.$fragment]),
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
                '_redirect_url' => route('adminPanel.rating-review.index', ['#'.$fragment]),
            ];
        }
        return response()->json($response, 200);
    }


    /**
     * Facility Ratings & Reviews.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 11 Dec 2020
     */
    public function facilityRatings(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        // Get facility
        $where = [];
        if (!empty($authUser->facility)) {
            $facility = $authUser->facility;
        } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
            $facility = $authUser->sub_admin->facility;
        }
        elseif($authUser->hasRole('Facility Group') == true){
            $where['facility_group_id'] = $authUser->facility_group->id;
            $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();
            $request['facilities'] = $facilities;
        }
        elseif($authUser->hasRole('Facility Group Sub Admin') == true){
            $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);
            $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();
            $request['facilities'] = $facilities;

        }
        elseif($authUser->hasRole('Facility Group Admin') == true){
            $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
            // Get States
            $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
            $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
            $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            $facilities = $this->facility->getAll($where, true, $request)->pluck('id')->toArray();
            $request['facilities'] = $facilities;
        }
        //-------------

        try {

            // Ratings
            $request['facility'] = isset($facility)?$facility->id:'';
            $request['status'] = 'publish';
            $ratings = $this->ratingReview->get_facility_ratings($request);
            //--------

            $this->viewData['ratings'] = $ratings;
            $this->viewData['request'] = $request->all();

            return view('admin-panel.rating.facility-ratings')->with($this->viewData);

        } catch (\Exception $exception){
            p($exception->getMessage());
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Export Facility Ratings Export.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 13 Feb 2021
     */
    public function facilityRatingsExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new FacilityRatingsExport($this->ratingReview, $request), 'facility-ratings.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Export Hcp Ratings Export.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 13 Feb 2021
     */
    public function hcpRatingsExport(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['hcp_per_page']);

            return Excel::download(new HcpRatingsExport($this->ratingReview, $request), 'hcp-ratings.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }
}
