<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Http\Requests\AdminPanel\ValidateShift;
use App\Interfaces\ShiftInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\HcpInterface;
use App\Interfaces\ShiftActivityInterface;
use Carbon\Carbon;
use Illuminate\Support\Facades\Log;
use Illuminate\Http\Request;

class ShiftBroadcastController extends Controller
{
    private $shift, $facility, $hcp, $shiftActivity;

    public function __construct(ShiftInterface $shift, FacilityInterface $facility, HcpInterface $hcp, ShiftActivityInterface $shiftActivity)
    {
        $this->shift = $shift;
        $this->facility = $facility;
        $this->hcp = $hcp;
        $this->shiftActivity = $shiftActivity;
    }

    /**
     * Broadcast shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 20 Nov 2020
     */
    public function broadcast(Request $request)
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/jobs-logs/shift-broadcast.log')]);

        $hcpFilter = [];
        $favouritesHcpIds = [];
        $ratedHcpIds = [];
        $otherHcpIds = [];
        $allHcpsIds = [];
        $cancelledHcpIds = [];
        $userDeviceIds = [];

        // General Configuration
        $generalConfiguration = get_general_configuration();
        //----------------------

        // Get Shift
        $shiftWhere = ['shift_status' => '0', 'id' => '300'];
        $shifts = $this->shift->shift_where($shiftWhere);
        //----------

        if (count($shifts)) {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->info("shift broadcast job start");

            foreach($shifts as $shift) {
                // Set time zone
                date_default_timezone_set($shift->state->time_zone_name);
                //--------------

                $currentTime = Carbon::now($shift->state->time_zone_name);

                $getfacility = $this->facility->find_facility($shift['facility_id']);
                $hcpFilter['shift_id'] = $shift['id'];
                $hcpFilter['facility_id'] = $shift['facility_id'];
                $hcpFilter['state_id'] = $shift['state_id'];
                $hcpFilter['country_id'] = $shift['country_id'];
                $hcpFilter['facility_latitude'] = $getfacility['latitude'];
                $hcpFilter['facility_longitude'] = $getfacility['longitude'];
                $hcpFilter['category_id'] = $shift['category_id'];
                $hcpFilter['profession_id'] = $shift['profession_id'];
                $hcpFilter['level_id'] = $shift['hcp_level_id'];
                $hcpFilter['shift_start_time'] = $shift['start_time'];
                $hcpFilter['shift_end_time'] = $shift['end_time'];
                $hcpFilter['time_zone_name'] = $shift->state->time_zone_name;

                // Get Cancelled Hcps
                if (count($shift['cancelled_shifts'])) {
                    foreach($shift['cancelled_shifts'] as $cancelledShifts){
                        $cancelledHcpIds[] = $cancelledShifts->hcp_id;
                    }
                    $hcpFilter['cancelled_hcps'] = $cancelledHcpIds;
                }
                //-------------------

                // Send Notification To Favourites Hcp
                if($shift['shift_broadcast'] == 'favourite') {
                    $hcpFilter['only_favourites'] = true;
                    $favouritesHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                    if (count($favouritesHcps)) {
                        foreach($favouritesHcps as $favouritesHcp){
                            $favouritesHcpIds[] = $favouritesHcp->id;
                        }

                        // send_shift_push_notification($shift->id, 'new-shift', array_unique($favouritesHcpIds));

                        Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                        Log::channel('cronlog')->info("notification sent to favorite hcp");
                    }

                    $shiftActivityData = [
                        'shift_id'      => $shift->id,
                        'activity'      => 'broadcast-to-favourites-hcp',
                        'created_by'    => $shift->created_by,
                        'updated_by'    => $shift->created_by,
                    ];
                    // $this->shiftActivity->store($shiftActivityData);

                    Log::channel('cronlog')->info("shift broadcast to favourites hcp");

                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift['id']];

                    if(count($favouritesHcps)) {
                        $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_mint']);
                    } else {
                        $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes(2);
                    }

                    print_r('Fav');
                    print_r($hcpFilter);
                    print_r($favouritesHcpIds);

                    // $this->shift->update(['shift_broadcast' => 'rated', 'shift_rebroadcast_time' => $shiftRebroadcastTime], $shiftBroadcastWhere);
                    //-----------------------
                }
                //------------------------------------

                // Send Notification To Rated Hcp
                else if($shift['shift_broadcast'] == 'rated' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                    $hcpFilter['only_ratings'] = true;
                    $ratedHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                    if (count($ratedHcps)) {
                        foreach($ratedHcps as $ratedHcp){
                            $ratedHcpIds[] = $ratedHcp->id;
                        }

                        // send_shift_push_notification($shift->id, 'new-shift', array_unique($ratedHcpIds));

                        Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                        Log::channel('cronlog')->info("notification sent to rated Hcp");
                    }

                    $shiftActivityData = [
                        'shift_id'      => $shift->id,
                        'activity'      => 'broadcast-to-rated-hcp',
                        'created_by'    => $shift->created_by,
                        'updated_by'    => $shift->created_by,
                    ];
                    // $this->shiftActivity->store($shiftActivityData);

                    Log::channel('cronlog')->info("shift broadcast to rated hcp");

                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift['id']];

                    if(count($ratedHcps)) {
                        $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_mint']);
                    } else {
                        $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes(2);
                    }


                    print_r('Rated');
                    print_r($hcpFilter);
                    print_r($ratedHcpIds);
                    // $this->shift->update(['shift_broadcast' => 'other', 'shift_rebroadcast_time' => $shiftRebroadcastTime] ,$shiftBroadcastWhere);
                    //-----------------------
                }
                //--------------------------------

                // Send Notification To Other Hcp
                else if($shift['shift_broadcast'] == 'other' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                    $otherHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);

                    if (count($otherHcps)) {
                        foreach($otherHcps as $otherHcp){
                            $otherHcpIds[] = $otherHcp->id;
                        }

                        // send_shift_push_notification($shift->id, 'new-shift', array_unique($otherHcpIds));

                        Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                        Log::channel('cronlog')->info("notification sent to other hcp");
                    }

                    $shiftActivityData = [
                        'shift_id'      => $shift->id,
                        'activity'      => 'broadcast-to-other-hcp',
                        'created_by'    => $shift->created_by,
                        'updated_by'    => $shift->created_by,
                    ];
                    // $this->shiftActivity->store($shiftActivityData);

                    Log::channel('cronlog')->info("shift broadcast to other hcp");

                    // Check Time Diff
                    $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);

                    $to = Carbon::parse($shift['start_time'])->setTimezone($shift->state->time_zone_name);
                    $from = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);
                    $timeDiff = $to->diffInHours($from);
                    //----------------

                    if($timeDiff <= $generalConfiguration['rebroadcast_to_all_before_shift_start']) {
                        $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours(1);
                    } else {
                        $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);
                    }

                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift['id']];
                    // $this->shift->update(['shift_broadcast' => 'all', 'shift_rebroadcast_time' => $nextReabroadcast] ,$shiftBroadcastWhere);
                    //-----------------------

                    print_r('Other');
                    print_r($hcpFilter);
                    print_r($otherHcpIds);
                }
                //-------------------------------

                // Send Notification To All Hcp
                else if($shift['shift_broadcast'] == 'all' ) {
                    $allHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);
                    $allHcpsIds = [];
                    if (count($allHcps)) {
                        foreach($allHcps as $allHcp){
                            $allHcpsIds[] = $allHcp->id;
                        }

                        // p($hcpFilter);
                        // p($allHcpsIds);
                        // send_shift_push_notification($shift->id, 'new-shift', array_unique($allHcpsIds));

                        Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                        Log::channel('cronlog')->info("notification sent to all hcp");
                    }

                    $shiftActivityData = [
                        'shift_id'      => $shift->id,
                        'activity'      => 'broadcast-to-all-hcp',
                        'created_by'    => $shift->created_by,
                        'updated_by'    => $shift->created_by,
                    ];
                    // $this->shiftActivity->store($shiftActivityData);

                    Log::channel('cronlog')->info("shift broadcast to all hcp");

                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift['id']];
                    // $this->shift->update(['shift_broadcast' => 'all', 'shift_rebroadcast_time' => Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_to_all_mint'])] ,$shiftBroadcastWhere);
                    //-----------------------

                    echo '<pre>';
                    print_r('All');
                    print_r($hcpFilter);
                    print_r($allHcpsIds);
                    echo '</pre>';
                }
                //-------------------------------
            }

            Log::channel('cronlog')->info("shift broadcast job end");
            Log::channel('cronlog')->info("-----------------------");
        }

        p('done');
    }

}
