<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Interfaces\SubAdminInterface;
use App\Interfaces\PermissionInterface;
use App\Interfaces\UserInterface;
use App\Http\Requests\AdminPanel\ValidateSubAdmin;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use App\Http\Traits\UploadImage;
use Illuminate\Http\Request;
use App\User;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\SubAdminExport;
use App\Interfaces\FacilityInterface;
use Spatie\Permission\Models\Permission;

class SubAdminController extends Controller
{
    use UploadImage;

    private $sub_admin, $permission, $facilities;
    public function __construct(SubAdminInterface $sub_admin, PermissionInterface $permission, UserInterface $user, FacilityInterface $facilities){
        $this->sub_admin = $sub_admin;
        $this->permission = $permission;
        $this->facilities = $facilities;
        $this->user = $user;
    }

    /**
     * View Sub Admin.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 25 Sep 2020
    */
    public function index(Request $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        try {

            if (!empty($authUser->facility)) {
                $request['facility_id'] = $authUser->facility->id;
                $request['state_id'] = $authUser->facility->state_id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $request['facility_id'] = $authUser->sub_admin->facility_id;
                $request['state_id'] = $authUser->sub_admin->facility->state_id;
            }
            // elseif(!empty($authUser->facility_group)){
            //     $request['facility_group_id'] = $authUser->facility_group->id;
            // }

            // Get Sub Admin
            $where = ['facility_group_id'=>NULL];
            $subAdmins = $this->sub_admin->getAll($where, true, $request);
            //--------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.sub-admin.index', compact('authUser','subAdmins', 'request'));

        } catch (\Exception $exception) {
            p($exception->getMessage());
            return dashboard_redirect($exception->getMessage());
        }
    }


    /**
     * View create sub admin.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector|\Illuminate\View\View
     *
     * @author Sumit
     * @created 24 Sep 2020
    */
    public function create()
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $where = [];
        $permissions =[];
        $facilities =[];

        try {
            if($authUser->hasRole('Facility Group')){
                $where = ['status' => 'active', 'facility_group_id' =>  $authUser->facility_group->id];
                // Get Facilities
                $facilities = $this->facilities->getAll($where, true);
            }
            else{
                if (!empty($authUser->facility)) {
                    $request['facility_id'] = $authUser->facility->id;
                    $where = ['status' => 'active', 'panel_permissions' => 'facility', 'is_default' => 'yes'];
                } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                    $request['facility_id'] = $authUser->sub_admin->facility_id;
                    $where = ['status' => 'active', 'panel_permissions' => 'facility', 'is_default' => 'yes'];
                } else {
                    $where = ['status' => 'active', 'panel_permissions' => 'super-admin', 'is_default' => 'yes'];
                }

                // Get Permissions
                $permissions = $this->permission->get_with_group($where, true);
                //----------------
            }


            return view('admin-panel.sub-admin.create', compact('permissions','authUser','facilities'));
        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Store sub admin.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 28 Sep 2020
    */
    public function store(ValidateSubAdmin $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $subAdmin = null;
        $randomPassword = str_random(8);
        $imageName = null;
        $subAdminData = [];
        $userData = [];

        DB::beginTransaction();
        try {

            $userData = [
                'name' => $request['name'],
                'email' => $request['email'],
                'password' => bcrypt($randomPassword),
                'status' => $request['status'],
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            if (!empty($authUser->facility)) {
                $userData['role_name'] = 'facility-sub-admin';
            }
            else {
                $userData['role_name'] = 'sub-admin';
            }

            $user = $this->user->store($userData);

            // Assign Permissions
            $user->givePermissionTo($request['permission']);


            //-------------------

            // Assign role
            if (!empty($authUser->facility)) {
                $user->assignRole('Facility Sub Admin');
            } else {
                $user->assignRole('Sub Admin');
            }
            //------------

            $subAdminData = [
                'name' => $request['name'],
                'surname' => $request['surname'],
                'username' => $request['username'],
                'contact_number' => $request['contact_number'],
                'status' => $request['status'],
                'user_id' => $user->id,
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];

            if (!empty($authUser->facility)) {
                $subAdminData['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $subAdminData['facility_id'] = $authUser->sub_admin->facility_id;
            }elseif(!empty($authUser->facility_group)){
                $subAdminData['facility_group_id'] = $authUser->facility_group->id;
                $subAdminData['assigned_facilities'] = json_encode($request['facility']);
            }

            $subAdmin = $this->sub_admin->store($subAdminData);

            // Upload image
            if ($request->hasFile('image')) {
                $path  = config('constants.sub_admins.sub_admins_path') . '/' . $subAdmin->sub_admin_prefix . $subAdmin->id . '/image/';
                $image = $this->uploadImage($request->file('image'), $path, 75, strtolower($subAdmin->name));
                if ($image['_status']) {
                    $imageName = $image['_data'];
                }

                $subAdmin = $this->sub_admin->update(['image' => $imageName], ['id' => $subAdmin->id]);
            }
            //-------------

            // Send nurse email with password
            if(!empty($subAdmin)){
                $emailTemplate = config('constants.admin_email_path') . 'user-welcome-email';
                $emailData = [
                    'template' => $emailTemplate,
                    'data' => [
                        'name' => ucwords($request['name']),
                        'email' => $request['email'],
                        'subject' => __('subjects.user_welcome', ['app_name' => config('app.name')]),
                        'password' => $randomPassword,
                    ],
                ];


                // if(config('app.server') == 'AWS' ) {
                //     SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                // } else {
                //     $data = $emailData['data'];
                //     Mail::send($emailTemplate, $data, function ($message) use ($data) {
                //         $message->to($data['email']);
                //         $message->subject($data['subject']);
                //     });
                // }
            }
            //-------------------------------

            DB::commit();
        } catch (\Exception $exception) {
            p($exception->getMessage());
            $subAdmin = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if(!is_null($subAdmin)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Sub Admin']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.sub-admins.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_creation_failed', ['record' => 'Sub Admin']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.sub-admins.create')->withInput()->with(['notification' => $notification]);
        }

    }

    /**
     * View edit sub admin.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 28 Sep 2020
    */
    public function edit(Request $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $where = [];
        $facilities =[];
        $permissions =[];
        try {

            // Get sub admin
            $subAdmin = $this->sub_admin->find_sub_admin(dv($id));
            //--------------

            // Get user
            $user = $this->user->find_user($subAdmin->user_id);
            //---------

            // User Permissions
            $userPermissions = $user->getDirectPermissions();
            //-----------------
            if($authUser->hasRole('Facility Group')){
                $where = ['status' => 'active', 'facility_group_id' =>  $authUser->facility_group->id];
                // Get Facilities
                $facilities = $this->facilities->getAll($where, true);
            }
            else{
                if (!empty($authUser->facility)) {
                    $request['facility_id'] = $authUser->facility->id;
                    $where = ['status' => 'active', 'panel_permissions' => 'facility', 'is_default' => 'yes'];
                } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                    $request['facility_id'] = $authUser->sub_admin->facility_id;
                    $where = ['status' => 'active', 'panel_permissions' => 'facility', 'is_default' => 'yes'];
                } else {
                    $where = ['status' => 'active', 'panel_permissions' => 'super-admin', 'is_default' => 'yes'];
                }
                // Get Permissions
                $permissions = $this->permission->get_with_group($where , true);
            }



            //----------------

            return view('admin-panel.sub-admin.edit', compact('permissions', 'subAdmin', 'userPermissions','facilities'));
        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Update sub admin.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 28 Sep 2020
    */
    public function update(ValidateSubAdmin $request, $id)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $subAdmin = null;
        $subAdminUpdate = null;
        $userUpdate =  null;
        $randomPassword = str_random(8);
        $imageName = null;
        $subAdminData = [];
        $userData = [];

        DB::beginTransaction();
        try {

            // Get sub admin
            $subAdmin = $this->sub_admin->find_sub_admin(dv($id));
            //--------------

            // Get user
            $user = $this->user->find_user($subAdmin->user_id);
            //---------

            $subAdminData = [
                'name' => $request['name'],
                'surname' => $request['surname'],
                'contact_number' => $request['contact_number'],
                'username' => $request['username'],
                'status' => $request['status'],
                'user_id' => $user->id,
                'updated_by' => $authUser->id,
            ];


            $subAdminUpdate = $this->sub_admin->update($subAdminData, ['id' => $subAdmin->id]);

            // Upload image
            if ($request->hasFile('image')) {
                $path  = config('constants.sub_admins.sub_admins_path') . '/' . $subAdmin->sub_admin_prefix . $subAdmin->id . '/image/';
                $image = $this->uploadImage($request->file('image'), $path, 75, strtolower($subAdmin->name));
                if ($image['_status']) {
                    $imageName = $image['_data'];
                }

                $subAdminUpdate = $this->sub_admin->update(['image' => $imageName], ['id' => $subAdmin->id]);
            }
            //-------------

            // Send nurse email with password
            if($user->email != $request['email']) {
                $emailTemplate = config('constants.admin_email_path') . 'user-welcome-email';
                $emailData = [
                    'template' => $emailTemplate,
                    'data' => [
                        'name' => ucwords($request['name']),
                        'email' => $request['email'],
                        'subject' => __('subjects.user_welcome', ['app_name' => config('app.name')]),
                        'password' => $randomPassword,
                    ],
                ];


                if(config('app.server') == 'AWS' ) {
                    SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                } else {
                    $data = $emailData['data'];
                    Mail::send($emailTemplate, $data, function ($message) use ($data) {
                        $message->to($data['email']);
                        $message->subject($data['subject']);
                    });
                }

                $userData = [
                    'password' => bcrypt($randomPassword),
                ];
            }
            //-------------------------------

            $userData = [
                'name' => $request['name'] . ' ' . $request['surname'],
                'status' => $request['status'],
                'email' => $request['email'],
                'updated_by' => $authUser->id,
            ];

            $userUpdate = $this->user->update($userData, ['id' => $subAdmin->user_id]);

            // Assign Permissions
             $user->syncPermissions($request['permission']);
            //-------------------

            DB::commit();
        } catch (\Exception $exception) {
            p($exception->getMessage());
            $subAdmin = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }


        if (!is_null($subAdminUpdate)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Sub Admin']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.sub-admins.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Sub Admin']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.sub-admins.edit', ['id' => ev($subAdmin->id)])->withInput()->with(['notification' => $notification]);
        }


    }

    /**
     * Change status.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 28 Sep 2020
    */
    public function changeStatus(Request $request, $id, $status, $page = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $subAdmin = null;
        $data = [];
        $where = [];

        DB::beginTransaction();
        try {

            $where = [
                'id' => dv($id)
            ];

            $data = [
                'status' => $request['status'],
                'updated_by' => $authUser->id,
            ];

            $subAdmin = $this->sub_admin->update($data, $where);

            DB::commit();
        } catch (\Exception $exception) {
            $subAdmin = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($subAdmin)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];
            //-----------------

            if (!empty($page)) {
                return response()->json($notification, 200);
            } else {
                return redirect()->route('adminPanel.sub-admins.details', ['id' => $id])->with(['notification' => $notification]);
            }


        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
            //-----------------


            if (!empty($page)) {
                return response()->json($notification, 200);
            } else {
                return redirect()->route('adminPanel.sub-admins.details', ['id' => $id])->with(['notification' => $notification]);
            }
        }
    }

    /**
     * View details.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 28 Sep 2020
    */
    public function details(Request $request, $id)
    {
        try {

            // Get sub admin
            $subAdmin = $this->sub_admin->find_sub_admin(dv($id));
            //--------------

            // Get user
            $user = $this->user->find_user($subAdmin->user_id);
            //---------

            // User Permissions
            $userPermissions = $user->getDirectPermissions();
            //-----------------

            return view('admin-panel.sub-admin.details', compact('subAdmin', 'userPermissions'));
        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }


    /**
     * Check user email.
     *
     * @return boolean
     *
     * @author Sumit
     * @created 10 Aug 2020
     */
    public function checkUserEmail(Request $request)
    {
        $status = false;

        if (!is_null($request->email)) {
            $user = User::where('email', $request['email'])->first();

            if (!is_null($user)) {
                if ($request->filled('id') && $user->id == $request['id']) {
                    $status = true;
                } else {
                    $status = false;
                }
            } else {
                $status = true;
            }
        }

        return response()->json($status, 200);
    }

    /**
     * Export.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 16 Feb 2021
     */
    public function export(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------
        try {

            $request = $request->all();
            $request['export'] = true;
            unset($request['request']['per_page']);

            return Excel::download(new SubAdminExport($this->sub_admin, $request), 'sub-admins.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }
}
