<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Interfaces\SupportingPageInterface;
use App\Http\Requests\AdminPanel\ValidateSupportingPage;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use App\Http\Traits\UploadFile;
use Illuminate\Http\Request;
use App\Interfaces\FacilityInterface;

class SupportingPageController extends Controller
{
    use UploadFile;

    private $supportingPage, $facility;
    public function __construct(SupportingPageInterface $supportingPage, FacilityInterface $facility){
        $this->supporting_page = $supportingPage;
        $this->facility = $facility;
    }

    /**
     * View Supporting Page.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 08 Oct 2020
    */
    public function index()
    {
        try {

            // Get Supporting Page
            $where = [];
            $supportingPage = $this->supporting_page->getAll($where);
            //--------------------

            return view('admin-panel.supporting-pages.index', compact('supportingPage'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Store Supporting Page.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 08 Oct 2020
    */
    public function store(ValidateSupportingPage $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $supportingPage = null;
        $termConditionFile = null;
        $faqFile = null;
        $policyFile = null;
        $aboutFile = null;;
        $contactFile = null;
        $data = [];

        DB::beginTransaction();
        try {

            if(empty($request['id'])) {

                // Upload term condition file
                if ($request->hasFile('term_condition_hcp_file')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('term_condition_hcp_file'), $path, 75, 'term-and-condition');
                    if ($file['_status']) {
                        $termConditionFile = $file['_data'];
                    }
                }
                //---------------------------

                // Upload faq file
                if ($request->hasFile('supporting_pages_faq_hcp')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('supporting_pages_faq_hcp'), $path, 75, 'faq');
                    if ($file['_status']) {
                        $faqFile = $file['_data'];
                    }
                }
                //----------------

                // Upload about file
                if ($request->hasFile('about_us_hcp_file')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('about_us_hcp_file'), $path, 75, 'about-us');
                    if ($file['_status']) {
                        $aboutFile = $file['_data'];
                    }
                }
                //------------------

                // Upload contact file
                if ($request->hasFile('contact_us_hcp_file')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('contact_us_hcp_file'), $path, 75, 'contact-us');
                    if ($file['_status']) {
                        $contactFile = $file['_data'];
                    }
                }
                //--------------------

                $data = [
                    'term_condition_hcp_file' => $termConditionFile,
                    'faq_hcp_file' => $faqFile,
                    'policy_hcp_file' => $policyFile,
                    'about_us_hcp_file' => $request['about_us_hcp_file'],
                    'contact_us_hcp_file' => $request['contact_us_hcp_file'],
                    'term_condition_facility_link' => $request['term_condition_facility_link'],
                    'faq_facility_link' => $request['faq_facility_link'],
                    'policy_facility_link' => $request['policy_facility_link'],
                    'term_condition_facility_plan' => $request['term_condition_facility_plan'],
                    'created_by' => $authUser->id,
                    'updated_by' => $authUser->id,
                ];

                if($request['notify_term_condition_facility'] = 1) {
                    $this->facility->update(['term_condition_accept' => 0], []);
                }

                $supportingPage = $this->supporting_page->store($data);
            } else {

                // Get Supporting Page
                $getSupportingPage = $this->supporting_page->find_supporting_page($request['id']);
                //--------------------

                // Upload term condition file
                if ($request->hasFile('term_condition_hcp_file')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('term_condition_hcp_file'), $path, 75, 'term-and-condition');
                    if ($file['_status']) {
                        $termConditionFile = $file['_data'];
                    }
                } else {
                    $termConditionFile = $getSupportingPage['term_condition_hcp_file'];
                }
                //---------------------------

                // Upload faq file
                if ($request->hasFile('supporting_pages_faq_hcp')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('supporting_pages_faq_hcp'), $path, 75, 'faq');
                    if ($file['_status']) {
                        $faqFile = $file['_data'];
                    }
                } else {
                    $faqFile = $getSupportingPage['faq_hcp_file'];
                }
                //----------------

                // Upload faq file
                if ($request->hasFile('supporting_pages_policy_hcp')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('supporting_pages_policy_hcp'), $path, 75, 'privacy-policy');
                    if ($file['_status']) {
                        $policyFile = $file['_data'];
                    }
                } else {
                    $policyFile = $getSupportingPage['policy_hcp_file'];
                }
                //----------------

                // Upload about file
                if ($request->hasFile('about_us_hcp_file')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('about_us_hcp_file'), $path, 75, 'about-us');
                    if ($file['_status']) {
                        $aboutFile = $file['_data'];
                    }
                } else {
                    $aboutFile = $getSupportingPage['about_us_hcp_file'];
                }
                //------------------

                // Upload contact file
                if ($request->hasFile('contact_us_hcp_file')) {
                    $path  = config('constants.supporting_pages.supporting_pages_file_path');
                    $file = $this->uploadFile($request->file('contact_us_hcp_file'), $path, 75, 'contact-us');
                    if ($file['_status']) {
                        $contactFile = $file['_data'];
                    }
                } else {
                    $contactFile = $getSupportingPage['contact_us_hcp_file'];
                }
                //--------------------

                if($request['notify_term_condition_facility'] == 1) {
                    $this->facility->update(['term_condition_accept' => 0], []);
                }

                $data = [
                    'term_condition_hcp_file' => $termConditionFile,
                    'faq_hcp_file' => $faqFile,
                    'policy_hcp_file' => $policyFile,
                    'about_us_hcp_file' => $request['about_us_hcp_file'],
                    'contact_us_hcp_file' => $request['contact_us_hcp_file'],
                    'term_condition_facility_link' => $request['term_condition_facility_link'],
                    'faq_facility_link' => $request['faq_facility_link'],
                    'policy_facility_link' => $request['policy_facility_link'],
                    'term_condition_facility_plan' => $request['term_condition_facility_plan'],
                    'updated_by' => $authUser->id,
                ];

                $supportingPage = $this->supporting_page->update($data, ['id' => $request['id']]);
            }

            DB::commit();
        } catch (\Exception $exception) {
            $supportingPage = null;
            DB::rollback();
            return dashboard_redirect($exception->getMessage());
        }

        if (!is_null($supportingPage)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Supporting Pages']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.supporting-pages.index')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Supporting Pages']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.supporting-pages.index')->withInput()->with(['notification' => $notification]);
        }
    }

}
