<?php

namespace App\Http\Controllers\AdminPanel;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\ShiftInterface;
use App\Interfaces\ShiftTrackingInterface;
use App\Models\ShiftTracking;
use App\User;
use DB;

class TrackHCPController extends Controller
{
    /**
     * @var array
     */
    public $viewData = [];

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct(ShiftInterface $shiftInterface,ShiftTrackingInterface $shiftTrackingInterface)
    {
        $this->middleware('auth.admin');
        $this->shiftInterface=$shiftInterface;
        $this->shiftTrackingInterface=$shiftTrackingInterface;
    }

    /**
     * Track HCP for schedule Shift.
     *
     * @summary track HCP.
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     * @author Yamini
     * @created 09 Dec 2020
     */
    public function TrackHCP($id = null)
    {
        try {

            $authUser = auth()->user();
            $this->viewData['shift_id']=dv($id);
            $this->viewData['shift_type']=1;

            $data = [];

            return view('admin-panel.shifts.track-hcp',compact('data'))->with($this->viewData);

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }

    }

    public function TrackRunningHCP(Request $request)
    {
        try {
            $authUser = auth()->user();
            $shifts=(explode(',',$request->input('shift_ids')));

            $nurses=array();
            foreach($shifts as $shift){

                $HCPs=$this->shiftTrackingInterface->find_shift_track_by_id($shift);

                foreach($HCPs as $hcp){
                   $nurses[$hcp->hcp_id]=$hcp['hcp']->first_name.' '.$hcp['hcp']->last_name;
                }
            }
            $this->viewData['shift_id']=$request->input('shift_ids');
            $this->viewData['shift_type']=2;
            $this->viewData['hcps']=$nurses;

            $data = [];

            return view('admin-panel.shifts.track-hcp',compact('data'))->with($this->viewData);

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }

    }

    /**
     * Get HCP LatLon for schedule Shift.
     *
     * @summary HCP Latlon.
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     * @author Yamini
     * @created 09 Dec 2020
     */
    public function getScheduleHCPLatlong($id = null){
        $response=array();
        $HCPs=$this->shiftTrackingInterface->find_shift_track_by_id($id);
        $nurses=array();
        foreach($HCPs as $hcp){
           $nurses[]=$hcp->hcp_id;
        }

        $latest_HCPs = ShiftTracking::select(DB::raw('MAX(id) as id'))
                        ->whereIn('hcp_id', $nurses)
                      ->groupBy('hcp_id');

        $HCPs = ShiftTracking::joinSub($latest_HCPs, 'latest_hcps', function ($join) {
            $join->on('shift_tracking.id', '=', 'latest_hcps.id');
        })
        ->get();

        foreach($HCPs as $hcp){
            $response[]=array(
                'shift'=>$hcp['shift']->shift_prefix.' '.$hcp['shift']->id,
                'facility'=>$hcp['facility']->name,
                'hcp'=>$hcp['hcp']->first_name.' '.$hcp['hcp']->last_name,
                'hcp_image'=>(!empty($hcp['hcp']->image)?(get_file_url(config('constants.hcps.hcps_path') . $hcp['hcp']->hcp_prefix .
                                        $hcp['hcp']->id . '/image/', $hcp['hcp']->image)):(($hcp['hcp']->gender=='female')?asset('admin-assets/images/dummy-nurse.png'):asset('admin-assets/images/dummy-doctor.png'))),
                'latitude'=>$hcp->latitude,
                'longitude'=>$hcp->longitude
            );

        }

        echo json_encode($response);

    }

    public function getRunningHCPLatlong($ids=null){
        $ids=explode(',',$ids);


        $latest_HCPs = ShiftTracking::select(DB::raw('MAX(id) as id'))
                   ->whereIn('hcp_id', $ids)
                   ->groupBy('hcp_id');

        $HCPs = ShiftTracking::joinSub($latest_HCPs, 'latest_hcps', function ($join) {
            $join->on('shift_tracking.id', '=', 'latest_hcps.id');
        })->get();




        $response=array();
        foreach($HCPs as $hcp){
            $response[]=array(
                'shift'=>$hcp['shift']->shift_prefix.' '.$hcp['shift']->id,
                'facility'=>$hcp['facility']->name,
                'hcp'=>$hcp['hcp']->first_name.' '.$hcp['hcp']->last_name,
                'hcp_image'=>(!empty($hcp['hcp']->image)?(get_file_url(config('constants.hcps.hcps_path') . $hcp['hcp']->hcp_prefix .
                                        $hcp['hcp']->id . '/image/', $hcp['hcp']->image)):(($hcp['hcp']->gender=='female')?asset('admin-assets/images/dummy-nurse.png'):asset('admin-assets/images/dummy-doctor.png'))),
                'latitude'=>$hcp->latitude,
                'longitude'=>$hcp->longitude
            );
        }
        echo json_encode($response);
    }

    public function hcpTracker($shift_id){
        $HCPs=$this->shiftTrackingInterface->find_shift_track_by_id($shift_id);
        $hcp_coordinates=[];
        $facility_cordinates=[];
        foreach($HCPs as $hcp){
            $hcp_coordinates=json_decode($hcp->hcp_coordinates);   
            $facility_cordinates['latitude']=$hcp->facility->latitude;
            $facility_cordinates['longitude']=$hcp->facility->longitude;
        }

            // p($hcp_coordinates);
        return view('admin-panel.shifts.hcp-tracker',compact('hcp_coordinates','facility_cordinates'));
    }

}
