<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;
use \OneSignal as OneSignal;
use App\Models\Profession;
use App\Models\Level;
use App\Models\Document;
use App\Models\DocumentHcp;
use App\Models\BuddyShiftRequest;
use App\Models\PlanProfession;
use App\Models\GeneralConfiguration;
use App\Models\DocumentConfiguration;
use App\Models\loading_time_config;
use App\Models\DevConfiguration;
use App\Models\BreakTimeConfig;
use App\Models\Hcp;
use App\Models\Shift;
use App\Models\NotificationMessage;
use App\Models\Notification;
use App\Models\FacilityDocument;
use App\Models\ShiftTransfer;
use App\Models\TrialAccountConfig;
use App\Models\FacilityActivity;
use App\Models\HcpActivity;
use App\Models\Facility;
use App\Models\FacilityPlan;
use App\Models\SupportingPage;
use App\Models\Transaction;
use App\Models\RatingReview;
use App\Models\HcpProfessionRequest;
use App\User;

if (!function_exists('ev')) {
    /**
     * Encrypt the given value.
     *
     * @param  string  $value
     * @return string
     */
    function ev($value)
    {
        return encrypt($value);
    }
}

if (!function_exists('dv')) {
    /**
     * Decrypt the given value.
     *
     * @param  string  $value
     * @return string
     */
    function dv($value)
    {
        $decryptedValue = null;

        try {
            $decryptedValue = decrypt($value);
        } catch (\Exception $e) {
            abort(404);
        }

        return $decryptedValue;
    }
}

if (!function_exists('p')) {

    /**
     * Short function for print data
     *
     * @param Array or Object or string
     * @return formatted array or object
     *
     * @author Sumit
     * @created_at 06 May 2020
     */
    function p($p, $exit = 1)
    {
        echo '<pre>';
        print_r($p);
        echo '</pre>';
        if ($exit == 1) {
            exit;
        }
    }
}

if (!function_exists('create_select_options')) {
    /**
     * Create select option.
     *
     * @param  mixed  $data, $value, $key, $default
     * @return array
     *
     * @author Sumit
     * @created_at 09 May 2020
     */
    function create_select_options($data, $value, $key = null, $default = null)
    {
        $options = [];

        // Create options
        if ($data instanceof Illuminate\Database\Eloquent\Collection) {
            $options = array_column($data->toArray(), $value, $key);
        } else {
            $options = array_column($data, $value, $key);
        }
        //---------------

        // Set default option
        if (!is_null($default)) {
            $options = array_prepend($options, $default, '');
        }
        return $options;
    }
}

if (!function_exists('create_select_groups_options')) {
    /**
     * Create select groups option.
     *
     * @param  mixed  $data, $value, $key, $default
     * @return array
     *
     * @author Sumit
     * @created_at 09 May 2020
     */
    function create_select_groups_options($data, $childColumn, $value, $key = null, $default = null)
    {
        $options = [];

        // Create options
        if ($data instanceof Illuminate\Database\Eloquent\Collection) {
            foreach ($data as $_value) {
                $options[$_value[$value]] = array_column($_value[$childColumn]->toArray(), $value, $key);
            }
        } else {
            foreach ($data as $_value) {
                $options[$_value[$value]] = array_column($_value[$childColumn], $value, $key);
            }
        }
        //---------------

        // Set default option
        if (!is_null($default)) {
            $options = array_prepend($options, $default, '');
        }
        //-------------------

        return $options;
    }
}

if (!function_exists('get_file_url')) {
    /**
     * Get file url.
     *
     * @param  string  $value
     * @return string  $url
     *
     * @author Sumit
     * @created_at 18 May 2020
     */
    function get_file_url($path, $name)
    {
        // // File system
        // $fileSystem = config('filesystems.default');
        // //------------

        // if (!is_null($name) && Storage::disk($fileSystem)->exists($path . $name)) {
        //     return Storage::disk($fileSystem)->url($path . $name);
        // } else {
        //     return null;
        // }

        // File system
        $file_system = env('AWS_CloudFront_URL');
        //------------

        $url = $file_system.'/'.$path . str_replace(' ', '%20', $name);
        $finalUrl = str_replace('#', '%23', $url);

        if(file_get_contents($finalUrl)) {
            return $finalUrl;
        } else {
            return null;
        }
    }
}

if (!function_exists('delete_file')) {
    /**
     * Delete file.
     *
     * @param  string  $value
     * @return boolean
     *
     * @author Sumit
     * @created_at 18 May 2020
     */
    function delete_file($path, $name)
    {
        // File system
        $fileSystem = config('filesystems.default');
        //------------

        if (Storage::disk($fileSystem)->exists($path . $name)) {
            return Storage::disk($fileSystem)->delete($path . $name);
        } else {
            return false;
        }
    }
}

if (!function_exists('get_dev_configurations')) {
    /**
     * Get dev configurations.
     *
     * @param  string  $value
     * @return boolean
     *
     * @author Sumit
     * @created 12 Aug 2020
     */
    function get_dev_configurations()
    {
        // Get dev configurations
        $devConfiguration = DevConfiguration::select('id', 'config_key', 'config_value')->get()->toArray();
        //-----------------------

        return json_encode(dev_config_array($devConfiguration), true);
    }
}

if (!function_exists('generate_initials')) {
    /**
     * Generate initials.
     *
     * @param  string  $value
     * @return initials
     *
     * @author Sumit
     * @created_at 03 Jun 2020
     */
    function generate_initials(string $name): string
    {
        $words = explode(' ', $name);
        return strtoupper(substr($words[0], 0, 1) . substr(end($words), 0, 1));
    }
}

if (!function_exists('get_hours')) {
    /**
     * Get Hours.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 23 Jun 2020
     */
    function get_hours($startDate, $endDate)
    {
        $start = Carbon::parse($startDate);
        $end = Carbon::parse($endDate);
        $minutes = $end->diffInMinutes($start);
        // $hours = floor($minutes / 60);
        // $min = $minutes - ($hours * 60);

        return date('H:i', mktime(0,$minutes));
    }
}

if (!function_exists('get_hours_in_number')) {
    /**
     * Get hours in number.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 20 Sep 2020
     */
    function get_hours_in_number($startDate, $endDate)
    {
        $start = Carbon::parse($startDate);
        $end = Carbon::parse($endDate);
        $minutes = $end->diffInMinutes($start);
        $hours = floor($minutes / 60);
        $min = $minutes - ($hours * 60);

        return date('H', mktime(0,$minutes));
    }
}

if (!function_exists('get_hours_in_decimal')) {
    /**
     * Get hours in decimal.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 20 Sep 2020
     */
    function get_hours_in_decimal($hours)
    {
        list($h, $m) = explode(':',$hours);  //Split up string into hours/minutes
        $decimal = $m/60;  //get minutes as decimal
        $hoursAsDecimal = $h+$decimal;
        return number_format($hoursAsDecimal, 2);
    }
}

if (!function_exists('decimal_to_hours')) {
    /**
     * Get decimal to hours.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 20 Sep 2020
     */
    function decimal_to_hours($decimal)
    {
        $hours = floor($decimal / 60);
        $minutes = floor($decimal % 60);
        $seconds = $decimal - (int)$decimal;
        $seconds = round($seconds * 60);

        // str_pad($hours, 2, "0", STR_PAD_LEFT) . ":" .
        return str_pad($minutes, 2, "0", STR_PAD_LEFT) . ":" . str_pad($seconds, 2, "0", STR_PAD_LEFT);
    }
}

if (!function_exists('get_break_time')) {
    /**
     * Get Break time.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 24 Jun 2020
     */
    function get_break_time($hours)
    {
        // Get configurations
        $breakTimeConfig = BreakTimeConfig::where('id', 1)->first();
        //-------------------

        if ( ($hours <= 6)) {
            return $breakTimeConfig['up_to_four_hours_shift'];
        } else if ( $hours > 6 ) {
            return $breakTimeConfig['four_eight_hours_to_shift'];
        } else {
            return 0;
        }
    }
}

if (!function_exists('dev_config_array')) {
    /**
     * Get nurse document list.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 15 Jun 2020
     */
    function dev_config_array($array, $devConfigKey = 'config_key')
    {
        $result = [];
        array_walk(
            $array,
            function (&$value, $key) use (&$result, $devConfigKey) {
                $result[$value[$devConfigKey]] = $value;
            }
        );
        return $result;
    }
}

if (!function_exists('get_professions')) {
    /**
     * Get professions.
     *
     * @param  string  $value
     * @return initials
     *
     * @author Sumit
     * @created_at 22 Aug 2020
     */
    function get_professions($categoryId = null)
    {
        // Get professions
        if (!empty($categoryId)) {
            $professions = Profession::where('category_id', $categoryId)->active()->get();
        } else {
            $professions = Profession::active()->get();
        }
        //----------------

        return $professions;
    }
}

if (!function_exists('get_levels')) {
    /**
     * Get levels.
     *
     * @param  string  $value
     * @return initials
     *
     * @author Sumit
     * @created_at 22 Aug 2020
     */
    function get_levels($professionId = null)
    {
        // Get levels
        if (!empty($professionId)) {
            $levels = Level::where('profession_id', $professionId)->active()->get();
        } else {
            $levels = Level::active()->get();
        }
        //-----------

        return $levels;
    }
}

if (!function_exists('get_hcp_doucment')) {
    /**
     * Get Hcp Doucment.
     *
     * @param  string  $value
     * @return initials
     *
     * @author Sumit
     * @created_at 22 Aug 2020
     */
    function get_hcp_doucment($hcp = null, $documentId = null)
    {
        // Get document
        $documentArr = [];
        if (!empty($hcp) && !empty($documentId)) {
            $document = DocumentHcp::where([['hcp_id', $hcp->id], ['document_id', $documentId]])->first();
            if (!empty($document)) {
                $documentFile = get_file_url(config('constants.hcps.hcps_path') . $hcp->hcp_prefix . $hcp->id . '/documents/', $document->document_name);
                $documentArr = [
                    'document_id' => $document->document_id,
                    'document_name' => $document->document_name,
                    'start_date' => $document->start_date,
                    'expiry_date' => $document->expiry_date,
                    'document_url' => $documentFile,
                ];
            } else {
                $documentArr = [];
            }
        }
        //-------------

        return $documentArr;
    }
}

if (!function_exists('check_buddy_shift_request')) {
    /**
    * Check Buddy Shift Request.
    *
    * @param  string  $value
    * @return initials
    *
    * @author Sumit
    * @created_at 22 Aug 2020
    */
    function check_buddy_shift_request($hcpProfessionId){
        $buddyShift = BuddyShiftRequest::where('hcp_profession_id', $hcpProfessionId)->orderBy('id', 'DESC')->first();

        if(!empty($buddyShift)){
            return $buddyShift->status;
        } else {
            return 'Pending';
        }

    }
}

if (!function_exists('get_plan_profession')) {
    /**
    * Get plan profession.
    *
    * @param  string  $value
    * @return initials
    *
    * @author Sumit
    * @created_at 22 Aug 2020
    */
    function get_plan_profession($planId, $professionId){
        $planProfession = PlanProfession::where('plan_id', $planId)->where('profession_id', $professionId)->first();

        if(!empty($planProfession)) {
            return true;
        } else {
            return false;
        }
    }
}

if (!function_exists('get_general_configuration')) {
    /**
    * Get General Configuration.
    *
    * @param  string  $value
    * @return initials
    *
    * @author Sumit
    * @created_at 22 Aug 2020
    */
    function get_general_configuration(){
        $generalConfiguration = GeneralConfiguration::where('id', 1)->first();

        if(!empty($generalConfiguration)) {
            return $generalConfiguration;
        } else {
            return null;
        }
    }
}

if (!function_exists('get_document_profession')) {
    /**
    * Get Document Profession.
    *
    * @param  string  $value
    * @return initials
    *
    * @author Sumit
    * @created_at 22 Aug 2020
    */
    function get_document_profession($documentId, $professionId){
        $documentProfession = DocumentConfiguration::where('document_id', $documentId)->where('profession_id', $professionId)->first();

        if(!empty($documentProfession)) {
            return true;
        } else {
            return false;
        }
    }
}

if (!function_exists('get_loading_time_configuration')) {
    /**
    * Get Loading Time Configuration.
    *
    * @param  string  $value
    * @return initials
    *
    * @author Sumit
    * @created_at 22 Aug 2020
    */
    function get_loading_time_configuration(){
        $loadingTimeConfiguration = loading_time_config::where('id', 1)->first();

        if(!empty($loadingTimeConfiguration)) {
            return $loadingTimeConfiguration;
        } else {
            return null;
        }
    }
}

if (!function_exists('send_shift_push_notification')) {
    /**
     * Send job push notifications.
     *
     * @param  $shiftId, $type, $hcpIds
     * @return boolean
     *
     * @author Sumit
     * @created_at 11 Nov 2020
     */
    function send_shift_push_notification($shiftId = null, $type = null, $hcpIds =  null, $swapRequestId = null, $broadcastType = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $userDeviceIds = [];
        $nurseName = null;
        $shiftDate = null;
        $facilityName = null;
        $facilityGroupName = null;
        $shiftAmount = null;
        $shiftStartTime = null;
        $shiftEndTime = null;
        $facilityContactName = null;
        $facilityContactNumber = null;
        $superAdminName = null;
        $superAdminContactNumber = null;
        $documentName = null;
        $message = null;
        $reason = null;
        $notificationShiftId = null;

        // Get Super Admin
        $superAdmin = User::where('role_name', 'super-admin')->first();
        //----------------

        // Get shift
        if (!empty($shiftId)) {

            $shift = Shift::where('id', $shiftId)
                ->with(['facility' => function ($query) {
                    $query->select('id', 'name', 'address', 'contact_person', 'contact_number');
                }])
                ->with(['facility_group' => function ($query) {
                    $query->select('id', 'name');
                }])
                ->with(['hcp' => function ($query) {
                    $query->select('id', 'first_name', 'last_name', 'user_id');
                    $query->with(['user' => function ($query) {
                        $query->select('id', 'name', 'device_id');
                    }]);
                }])->with(['user' => function ($query) {
                    $query->select('id', 'name');
                }])
                ->first();

            $hcpName = $shift->hcp ? ucwords($shift->hcp->first_name . ' ' . $shift->hcp->last_name) : null;
            $shiftDate = $shift ? date("d-m-Y", strtotime($shift->created_at)) : null;
            $facilityName = $shift->facility ? ucwords($shift->facility->name) : null;
            $facilityGroupName = $shift->facility_group ? ucwords($shift->facility_group->name) : null;
            $shiftAmount = $shift ? '$'. $shift->hcp_amount : null;
            $shiftStartTime = $shift ? date("d M Y h:i A", strtotime($shift->start_time)) : null;
            $shiftEndTime =  $shift ? date("d M Y h:i A", strtotime($shift->end_time)) : null;
            $facilityContactName = $shift->facility ? ucwords($shift->facility->contact_person) : null;
            $facilityContactNumber = $shift->facility ? $shift->facility->contact_number : null;
            $superAdminName = $superAdmin ? ucwords($superAdmin->name) : null;
            $superAdminContactNumber = $superAdmin ? $superAdmin->contact_number : null;
            $notificationShiftId = $shift->shift_prefix.$shift->id;
        }
        //----------

        // Send New Shift Notification
        if (!empty($hcpIds) && $type == 'new-shift') {
            $hcps = Hcp::whereIn('id', $hcpIds)
                ->with(['user' => function ($query) {
                    $query->select('id', 'name', 'device_id');
                }])
                ->select('id', 'user_id', 'first_name', 'last_name')->get();
            if (!empty($hcps)) {


                $deviceIds = $hcps->whereNotNull('user.device_id')->pluck('user.device_id')->toArray();


                $notificationMessage = NotificationMessage::where('type', 'new-shift')->first();
                $messageTags = config('constants.notification_tags');

                $replaceTags = [
                    $hcpName, $shiftDate, $facilityName,
                    $facilityContactName, $facilityContactNumber,
                    $shiftAmount, $shiftStartTime, $shiftEndTime, $superAdminName,
                    $superAdminContactNumber, $documentName, $facilityGroupName, $reason, $notificationShiftId
                ];
                $message = str_replace($messageTags, $replaceTags, $notificationMessage->message);
                $title = $notificationMessage->title;

                $params = [];
                $params['include_player_ids'] = $deviceIds;

                $headings = [
                    "en" => $title
                ];
                $contents = [
                    "en" => $message,
                ];
                $params['contents'] = $contents;
                $params['headings'] = $headings;


                OneSignal::sendNotificationCustom($params);
//                dd($params, "done");
                foreach ($hcps as $hcp) {
//                    $hcpName = $hcp ? ucwords($hcp->first_name . ' ' . $hcp->last_name) : null;

                    // Get message
//                    $notificationMessage = NotificationMessage::where('type', 'new-shift')->first();
//
//                    $messageTags = config('constants.notification_tags');
//                    $replaceTags = [
//                        $hcpName, $shiftDate, $facilityName,
//                        $facilityContactName, $facilityContactNumber,
//                        $shiftAmount, $shiftStartTime, $shiftEndTime, $superAdminName,
//                        $superAdminContactNumber, $documentName, $facilityGroupName, $reason, $notificationShiftId
//                    ];
//
//                    $message = str_replace($messageTags, $replaceTags, $notificationMessage->message);
//                    $title = $notificationMessage->title;
//                    //------------
//
//                    // Check Hcp Notification
//                    if($broadcastType != 'all') {
//                        $checkHcpNotification = Notification::where('shift_id', $shift->id)->where('hcp_id', $hcp->id)->where('shift_broadcast_type', $broadcastType)->first();
//                    } else {
//                        $checkHcpNotification = null;
//                    }
                    //-----------------------

                    if(empty($checkHcpNotification)) {
                        // Create notification
                        $notification = new Notification();
                        $notification->shift_id = $shift->id;
                        $notification->hcp_id = $hcp->id;
                        $notification->title = $title;
                        $notification->message = $message;
                        $notification->notification_type = 'shifts';
                        $notification->shift_broadcast_type = $broadcastType;
                        $notification->read_status = 'read';
                        $notification->send_to = 'hcp';
                        $notification->created_by = $shift->created_by;
                        $notification->updated_by = $shift->updated_by;
                        $notification->save();
                        //--------------------

                        // Send Notification
                        if(!empty($hcp->user->device_id) && env('ONE_SIGNAL_APP_ID') !=''){
                            $notiArray = [
                                'notification_type' => 'shifts',
                                'document_type' => '',
                                'swap_request_id' => '',
                                'shift_id' => $shift->id,
                                'hcp_id' => '',
                                'shift' => [
                                    'id' => $shift->id,
                                    'shift_prefix' => $shift->shift_prefix,
                                    'shift_type' => $shift->shift_type,
                                    'shift_status' => $shift->shift_status,
                                    'swap_request_id' => '',
                                    'swap_request' => '',
                                ],
                            ];

//                            $response = OneSignal::sendNotificationToUser(
//                                $message,
//                                $hcp->user->device_id,
//                                null,
//                                $notiArray,
//                                null,
//                                null,
//                                $title,
//                                null
//                            );
                            $userDeviceIds[] = $hcp->user->device_id;
                        } else {
                            $response = '';
                        }
                        //------------------
                    }
                }
            }

            if (!empty($userDeviceIds) && empty($response)) {
                return true;
            } else {
                return false;
            }
        }
        //----------------------------

        // Send New Swap Shift Notification
        if (!empty($hcpIds) && !empty($swapRequestId) && $type == 'shift-swap-request') {

            $hcps = Hcp::whereIn('id', $hcpIds)
                ->with(['user' => function ($query) {
                    $query->select('id', 'name', 'device_id');
                }])
                ->select('id', 'user_id', 'first_name', 'last_name')->get();

            if (!empty($hcps)) {
                foreach ($hcps as $hcp) {
                    $hcpName = $hcp ? ucwords($hcp->first_name . ' ' . $hcp->last_name) : null;

                    // Get message
                    $notificationMessage = NotificationMessage::where('type', $type)->first();

                    $messageTags = config('constants.notification_tags');
                    $replaceTags = [
                        $hcpName, $shiftDate, $facilityName,
                        $facilityContactName, $facilityContactNumber,
                        $shiftAmount, $shiftStartTime, $shiftEndTime, $superAdminName,
                        $superAdminContactNumber, $documentName, $facilityGroupName
                    ];

                    $message = str_replace($messageTags, $replaceTags, $notificationMessage->message);
                    $title = $notificationMessage->title;
                    //------------

                    // Create notification
                    $notification = new Notification();
                    $notification->shift_id = $shift->id;
                    $notification->hcp_id = $hcp->id;
                    $notification->title = $title;
                    $notification->message = $message;
                    $notification->notification_type = 'shifts';
                    $notification->read_status = 'read';
                    $notification->swap_request_id = $swapRequestId;
                    $notification->send_to = 'hcp';
                    $notification->created_by = $shift->created_by;
                    $notification->updated_by = $shift->updated_by;
                    $notification->save();
                    //--------------------

                    // Send Notification
                    if(!empty($hcp->user->device_id) && env('ONE_SIGNAL_APP_ID') !=''){
                        $notiArray = [
                            'notification_type' => 'shifts',
                            'document_type' => '',
                            'swap_request_id' => $swapRequestId,
                            'shift_id' => $shift->id,
                            'hcp_id' => '',
                            'shift' => [
                                'id' => $shift->id,
                                'shift_prefix' => $shift->shift_prefix,
                                'shift_type' => $shift->shift_type,
                                'shift_status' => $shift->shift_status,
                                'swap_request_id' => $swapRequestId,
                                'swap_request' => 'true',
                            ],
                        ];

                        $response = OneSignal::sendNotificationToUser(
                            $message,
                            $hcp->user->device_id,
                            null,
                            $notiArray,
                            null,
                            null,
                            $title,
                            null
                        );
                        $userDeviceIds[] = $hcp->user->device_id;
                    } else {
                        $response = '';
                    }
                    //------------------
                }
            }

            if (empty($response)) {
                return true;
            } else {
                return false;
            }
        }
        //---------------------------------

        // Send Shift Other Notification
        if (!empty($hcpIds) && !empty($type) && $type != 'new-shift' && $type != 'shift-swap-request') {

            $hcp = Hcp::where('id', $hcpIds)
                ->with(['user' => function ($query) {
                    $query->select('id', 'name', 'device_id');
                }])
                ->select('id', 'user_id', 'first_name', 'last_name')->first();

            if (!empty($hcp)) {
                $hcpName = $hcp ? ucwords($hcp->first_name . ' ' . $hcp->last_name) : null;

                if (!empty($hcp->user->device_id)) {
                    $userDeviceIds[] = $hcp->user->device_id;
                }

                // Get message
                $notificationMessage = NotificationMessage::where('type', $type)->first();

                $messageTags = config('constants.notification_tags');
                $replaceTags = [
                    $hcpName, $shiftDate, $facilityName,
                    $facilityContactName, $facilityContactNumber,
                    $shiftAmount, $shiftStartTime, $shiftEndTime, $superAdminName,
                    $superAdminContactNumber, $documentName, $facilityGroupName
                ];

                $message = str_replace($messageTags, $replaceTags, $notificationMessage->message);
                $title = $notificationMessage->title;
                //------------

                // Create notification
                $notification = new Notification();
                $notification->shift_id = $shift->id;
                $notification->hcp_id = $hcp->id;
                $notification->title = $title;
                $notification->message = $message;
                $notification->notification_type = 'shifts';
                $notification->read_status = 'read';
                $notification->send_to = 'hcp';
                $notification->created_by = $shift->created_by;
                $notification->updated_by = $shift->updated_by;
                $notification->save();
                //--------------------

                // Send Notification
                if(!empty($userDeviceIds) && env('ONE_SIGNAL_APP_ID') !=''){

                    $notiArray = [
                        'notification_type' => 'shifts',
                        'document_type' => '',
                        'swap_request_id' => '',
                        'shift_id' => $shift->id,
                        'hcp_id' => '',
                        'shift' => [
                            'id' => $shift->id,
                            'shift_prefix' => $shift->shift_prefix,
                            'shift_type' => $shift->shift_type,
                            'shift_status' => $shift->shift_status,
                            'swap_request_id' => '',
                            'swap_request' => '',
                        ],
                    ];

                    $response = OneSignal::sendNotificationToUser(
                        $message,
                        $userDeviceIds,
                        null,
                        $notiArray,
                        null,
                        null,
                        $title,
                        null
                    );
                } else {
                    $response = '';
                }

                if (empty($response)) {
                    return true;
                } else {
                    return false;
                }
                //------------------
            }
        }
        //------------------------------
    }
}

if (!function_exists('send_document_expiry_push_notification')) {
    /**
     * Send document expiry push notifications.
     *
     * @param  $hcpIds, $documentName, $documentType, $type
     * @return boolean
     *
     * @author Sumit
     * @created_at 01 Dec 2020
     */

    function send_document_expiry_push_notification($hcpIds = null, $documentName = null, $documentType = null, $type = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $userDeviceIds = [];
        $hcpName = null;
        $shiftDate = null;
        $facilityName = null;
        $facilityGroupName = null;
        $shiftAmount = null;
        $shiftStartTime = null;
        $shiftEndTime = null;
        $facilityContactName = null;
        $facilityContactNumber = null;
        $superAdminName = null;
        $superAdminContactNumber = null;
        $message = null;

        // Get Super Admin
        $superAdmin = User::where('role_name', 'super-admin')->first();
        //----------------

        // Get nurse
        if (!empty($hcpIds) && !empty($documentName) && !empty($type) && !empty($documentType)) {

            $hcp = Hcp::where('id', $hcpIds)
            ->with(['user' => function ($query) {
                $query->select('id', 'name', 'device_id');
            }])
            ->select('id', 'user_id', 'first_name', 'last_name')->first();

            $hcpName = $hcp ? ucwords($hcp->first_name . ' ' . $hcp->last_name) : null;
            $userDeviceIds = $hcp->user->device_id;

            // Get message
            $notificationMessage = NotificationMessage::where('type', $type)->first();

            $messageTags = config('constants.notification_tags');
            $replaceTags = [
                $hcpName, $shiftDate, $facilityName,
                $facilityContactName, $facilityContactNumber,
                $shiftAmount, $shiftStartTime, $shiftEndTime, $superAdminName,
                $superAdminContactNumber, $documentName, $facilityGroupName
            ];

            $message = str_replace($messageTags, $replaceTags, $notificationMessage->message);
            $title = $notificationMessage->title;
            //------------

            // Create notification
            $notification = new Notification();
            $notification->hcp_id = $hcp->id;
            $notification->title = $title;
            $notification->message = $message;
            $notification->notification_type = 'documents';
            $notification->read_status = 'read';
            $notification->send_to = 'hcp';
            $notification->created_by = $superAdmin->id;
            $notification->updated_by = $superAdmin->id;
            $notification->save();
            //--------------------

            // Send Notification
            if(!empty($userDeviceIds) && env('ONE_SIGNAL_APP_ID') !=''){

                $notiArray = [
                    'notification_type' => 'documents',
                    'document_type' => $documentType,
                    'shift_id' => '',
                    'hcp_id' => $hcp->id,
                ];

                $response = OneSignal::sendNotificationToUser(
                    $message,
                    $userDeviceIds,
                    null,
                    $notiArray,
                    null,
                    null,
                    $title,
                    null
                );
            } else {
                $response = '';
            }
            //------------------

        }
        //----------

    }
}

if (!function_exists('get_hcp_profession_document')) {
    /**
    * Get Hcp Profession Document.
    *
    * @param  string  $value
    * @return initials
    *
    * @author Sumit
    * @created_at 04 Dec 2020
    */
    function get_hcp_profession_document($hcpId, $professionId, $levelId = null){

        // Get document
        $document = [];
        if (!empty($hcpId) && !empty($professionId)) {
            $document = DocumentHcp::where([['hcp_id', $hcpId], ['profession_id', $professionId], ['level_id', $levelId]])->with('document')->get();
        }
        //-------------

        return $document;
    }
}

if (!function_exists('get_facility_doucment')) {
    /**
     * Get Facility Doucment.
     *
     * @param  string  $value
     * @return initials
     *
     * @author Sumit
     * @created_at 07 Dec 2020
     */
    function get_facility_doucment($facility = null, $documentId = null)
    {
        // Get document
        $documentArr = [];
        if (!empty($facility) && !empty($documentId)) {
            $document = FacilityDocument::where([['facility_id', $facility->id], ['document_id', $documentId]])->first();
            if (!empty($document)) {
                $documentFile = get_file_url(config('constants.facility.facility_path') . $facility->facility_prefix . $facility->id . '/documents/', $document->document_name);
                $documentArr = [
                    'document_id' => $document->document_id,
                    'document_name' => $document->document_name,
                    'start_date' => $document->start_date,
                    'expiry_date' => $document->expiry_date,
                    'document_url' => $documentFile,
                ];
            } else {
                $documentArr = [];
            }
        }
        //-------------

        return $documentArr;
    }
}

if (!function_exists('get_unread_notifications_count')) {
    /**
     * Get Unread Notifications Count.
     *
     * @param  string  $value
     * @return initials
     *
     * @author Sumit
     * @created_at 12 Dec 2020
     */
    function get_unread_notifications_count($request)
    {
        // Get notification
        $notifications = Notification::where(function ($query) use ($request) {
            if(isset($request['type']) && $request['type'] == 'admin') {
                $query->where('send_to', 'admin');
            }
        })
        ->where(function ($query) use ($request) {
            if(isset($request['type']) && $request['type'] == 'facility') {
                $query->orWhere('send_to', 'all-facility');
                if(isset($request['facility_id']) && !empty($request['facility_id'])){
                    $query->orWhereRaw('NOT FIND_IN_SET('.$request['facility_id'].', read_facilities)');
                    $query->orWhere('facility_id', $request['facility_id']);
                }
            }
        })
        ->where(function ($query) use ($request) {
            $query->where('read_status', 'unread');
        })
        ->whereDate('created_at', '>', Carbon::now()->subDays(30))->count();
        //-----------------
        return $notifications;
    }
}

if (!function_exists('get_notifications_for_top_bar')) {
    /**
     * Get Unread Notifications Count.
     *
     * @param  string  $value
     * @return initials
     *
     * @author Sumit
     * @created_at 12 Dec 2020
     */
    function get_notifications_for_top_bar($request)
    {
        // Get notification
        $notifications = Notification::where(function ($query) use ($request) {
            if(isset($request['type']) && $request['type'] == 'admin') {
                $query->where('send_to', 'admin');
            }
        })
        ->where(function ($query) use ($request) {
            if(isset($request['type']) && $request['type'] == 'facility') {
                $query->orWhere('send_to', 'all-facility');
                if(isset($request['facility_id']) && !empty($request['facility_id'])){
                    $query->orWhereRaw('NOT FIND_IN_SET('.$request['facility_id'].', read_facilities)');
                    $query->orWhere('facility_id', $request['facility_id']);
                }
            }
        })->orderBy('id', 'DESC')->get()->take(8);
        //-----------------

        return $notifications;
    }
}

if (!function_exists('send_other_push_notification')) {
    /**
     * Send other push notifications.
     *
     * @param  $hcpIds, $type, $sendTo
     * @return boolean
     *
     * @author Sumit
     * @created_at 15 Dec 2020
     */

    function send_other_push_notification($hcpIds = null, $type = null, $sendTo = null, $reason = null, $shiftId = null, $profession = null, $referAmount = null, $statmentIds = null, $facilityId = null, $statmentIdWithoutPrefix = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $userDeviceIds = [];
        $hcpName = null;
        $shiftDate = null;
        $facilityName = null;
        $facilityGroupName = null;
        $shiftAmount = null;
        $shiftStartTime = null;
        $shiftEndTime = null;
        $facilityContactName = null;
        $facilityContactNumber = null;
        $superAdminName = null;
        $superAdminContactNumber = null;
        $documentName = null;
        $message = null;
        $shiftFullId = null;
        $hcpFullId = null;
        $facilityFullId = null;
        $planName = null;
        $planStart = null;
        $planEnd = null;
        $planCycle = null;

        // Get Super Admin
        $superAdmin = User::where('role_name', 'super-admin')->first();
        //----------------

        // Get nurse
        if (!empty($hcpIds) && !empty($type)) {

            $hcp = Hcp::where('id', $hcpIds)
            ->with(['user' => function ($query) {
                $query->select('id', 'name', 'device_id');
            }])
            ->select('id', 'user_id', 'first_name', 'last_name')->first();

            $hcpName = $hcp ? ucwords($hcp->first_name . ' ' . $hcp->last_name) : null;
            $userDeviceIds = $hcp->user->device_id;

            // Get shift
            if (!empty($shiftId)) {

                $shift = Shift::where('id', $shiftId)
                    ->with(['facility' => function ($query) {
                        $query->select('id', 'name', 'address', 'contact_person', 'contact_number');
                    }])
                    ->with(['facility_group' => function ($query) {
                        $query->select('id', 'name');
                    }])
                    ->with(['hcp' => function ($query) {
                        $query->select('id', 'first_name', 'last_name', 'user_id');
                        $query->with(['user' => function ($query) {
                            $query->select('id', 'name', 'device_id');
                        }]);
                    }])->with(['user' => function ($query) {
                        $query->select('id', 'name');
                    }])
                    ->first();

                $hcpName = $shift->hcp ? ucwords($shift->hcp->first_name . ' ' . $shift->hcp->last_name) : null;
                $shiftDate = $shift ? date("d-m-Y", strtotime($shift->created_at)) : null;
                $facilityName = $shift->facility ? ucwords($shift->facility->name) : null;
                $facilityGroupName = $shift->facility_group ? ucwords($shift->facility_group->name) : null;
                $shiftAmount = $shift ? '$'. $shift->hcp_amount : null;
                $shiftStartTime = $shift ? date("d M Y h:i A", strtotime($shift->start_time)) : null;
                $shiftEndTime =  $shift ? date("d M Y h:i A", strtotime($shift->end_time)) : null;
                $facilityContactName = $shift->facility ? ucwords($shift->facility->contact_person) : null;
                $facilityContactNumber = $shift->facility ? $shift->facility->contact_number : null;
                $superAdminName = $superAdmin ? ucwords($superAdmin->name) : null;
                $superAdminContactNumber = $superAdmin ? $superAdmin->contact_number : null;
            }
            //----------

            // Get facility
            if (!empty($facilityId)) {
                $facility = Facility::where('id', $facilityId)
                ->with(['user' => function ($query) {
                    $query->select('id', 'name', 'device_id');
                }])
                ->select('id', 'user_id', 'name', 'facility_prefix')->first();

                $superAdminName = $superAdmin ? ucwords($superAdmin->name) : null;
                $superAdminContactNumber = $superAdmin ? $superAdmin->contact_number : null;
                $facilityName = $facility ? ucwords($facility->name) : null;
                $facilityGroupName = $facility->facility_group ? ucwords($facility->facility_group->name) : null;
                $facilityFullId = $facility->facility_prefix.$facility->id;
            }
            //-------------

            // Get message
            $notificationMessage = NotificationMessage::where('type', $type)->first();

            $messageTags = config('constants.notification_tags');
            $replaceTags = [
                $hcpName, $shiftDate, $facilityName,
                $facilityContactName, $facilityContactNumber,
                $shiftAmount, $shiftStartTime, $shiftEndTime, $superAdminName,
                $superAdminContactNumber, $documentName, $facilityGroupName, $reason, $shiftFullId, $hcpFullId, $facilityFullId, $planName, $planStart, $planEnd, $planCycle, $profession, $referAmount, $statmentIds
            ];

            $message = str_replace($messageTags, $replaceTags, $notificationMessage->message);
            $title = $notificationMessage->title;
            //------------

            if(!empty($statmentIds) && !empty($statmentIdWithoutPrefix)) {
                $notificationType = 'statement-details';
                $notiArrayType = 'statement-details';
                $statmentId = $statmentIdWithoutPrefix;
                $statmentStatus = 'completed';
            } else {
                $notificationType = 'other';
                $notiArrayType = 'hcps';
                $statmentId = '';
                $statmentStatus = '';
            }

            // Create notification
            $notification = new Notification();
            $notification->hcp_id = $hcp->id;
            $notification->title = $title;
            $notification->message = $message;
            $notification->notification_type = $notificationType;
            $notification->statement_id = $statmentId;
            $notification->statement_status = $statmentStatus;
            $notification->read_status = 'unread';
            $notification->send_to = $sendTo;
            $notification->created_by = $superAdmin->id;
            $notification->updated_by = $superAdmin->id;
            $notification->save();
            //--------------------

            // Send Notification
            if(!empty($userDeviceIds) && env('ONE_SIGNAL_APP_ID') !=''){

                $notiArray = [
                    'notification_type' => $notiArrayType,
                    'document_type' => '',
                    'shift_id' => '',
                    'hcp_id' => $hcp->id,
                    'statement_id' => $statmentId,
                    'statement_status' => $statmentStatus,
                ];

                $response = OneSignal::sendNotificationToUser(
                    $message,
                    $userDeviceIds,
                    null,
                    $notiArray,
                    null,
                    null,
                    $title,
                    null
                );
            } else {
                $response = '';
            }
            //------------------

        }
        //----------

    }
}

if (!function_exists('get_facility_and_hcp_distance')) {
    /**
     * Get Facility And Hcp Distance.
     *
     * @param  string  $lat1, $lon1, $lat2, $lon2, $unit
     * @return initials
     *
     * @author Sumit
     * @created_at 21 Dec 2020
     */
    function get_facility_and_hcp_distance($lat1, $lon1, $lat2, $lon2, $unit)
    {
        if (($lat1 == $lat2) && ($lon1 == $lon2)) {
            return 0;
        } else {
            $theta = $lon1 - $lon2;
            $dist = sin(deg2rad($lat1)) * sin(deg2rad($lat2)) +  cos(deg2rad($lat1)) * cos(deg2rad($lat2)) * cos(deg2rad($theta));
            $dist = acos($dist);
            $dist = rad2deg($dist);
            $miles = $dist * 60 * 1.1515;
            $unit = strtoupper($unit);

            if ($unit == "K") {
                return ($miles * 1.609344);
            } else if ($unit == "N") {
                return ($miles * 0.8684);
            } else if ($unit == "M") {
                return ($miles * 1609.344);
            } else {
                return $miles;
            }

        }
    }
}

if (!function_exists('get_shift_hcp_transfer_status')) {
    /**
    * Get Shift Hcp Transfer Status.
    *
    * @param  string  $hcpId, $shiftId
    * @return initials
    *
    * @author Sumit
    * @created_at 28 Dec 2020
    */
    function get_shift_hcp_transfer_status($hcpId, $shiftId){

        // Get shift transfer
        $shiftTransfer = null;
        if (!empty($hcpId) && !empty($shiftId)) {
            $shiftTransfer = ShiftTransfer::where([['transfer_hcp_id', $hcpId], ['shift_id', $shiftId]])->first();
        }
        //-------------

        return $shiftTransfer;
    }
}

if (!function_exists('get_shift_status')) {
    /**
    * Get Shift Status.
    *
    * @param  string $shiftId
    * @return initials
    *
    * @author Sumit
    * @created_at 28 Dec 2020
    */
    function get_shift_status($shiftId){

        // Get shift
        $shift = null;
        if (!empty($shiftId)) {
            $shift = Shift::where('id', $shiftId)->select('id', 'shift_status', 'shift_transfered', 'shift_swapped')->first();
        }
        //----------

        return $shift;
    }
}

if (!function_exists('get_trial_plan_configurations')) {
    /**
     * Get trial plan configurations.
     *
     * @param  string  $value
     * @return boolean
     *
     * @author Sumit
     * @created 04 Jna 2021
     */
    function get_trial_plan_configurations()
    {
        // Get trial plan configurations.
        $trialPlanConfigurations = TrialAccountConfig::find(1);
        //------------------------------

        return $trialPlanConfigurations;
    }
}

if (!function_exists('create_facility_activity')) {
    /**
     * Create facility activity.
     *
     * @param  string  $value
     * @return void
     *
     * @author Sumit
     * @created 08 Jan 2021
     */
    function create_facility_activity($facilityId, $activity, $message = null, $userId = null, $hcpId = null, $shiftId = null)
    {
        if(!empty($facilityId) && !empty($activity)) {

            // Create activity
            $facilityActivity = new FacilityActivity();
            $facilityActivity->facility_id = $facilityId;
            $facilityActivity->activity = $activity;
            $facilityActivity->message = $message;
            $facilityActivity->hcp_id = $hcpId;
            $facilityActivity->shift_id = $shiftId;
            $facilityActivity->created_by = $userId;
            $facilityActivity->updated_by = $userId;
            $facilityActivity->save();
            //----------------

        }
    }
}

if (!function_exists('get_hcp_name')) {
    /**
     * Get hcp name.
     *
     * @param  string  $value
     * @return name
     *
     * @author Sumit
     * @created_at 08 Jan 2021
     */
    function get_hcp_name($hcpId)
    {
        // Get hcp name
        $hcpName = '';
        if (!empty($hcpId)) {
            $hcp = Hcp::where('id', $hcpId)->select('id', 'first_name', 'last_name')->first();
            $hcpName = ucwords($hcp['first_name'].' '.$hcp['last_name']);
        }
        //-------------

        return $hcpName;
    }
}

if (!function_exists('create_hcp_activity')) {
    /**
     * Create hcp activity.
     *
     * @param  string  $value
     * @return void
     *
     * @author Sumit
     * @created 11 Jan 2021
     */
    function create_hcp_activity($hcpId, $activity, $message = null, $userId = null, $facilityId = null, $shiftId = null)
    {
        if(!empty($hcpId) && !empty($activity)) {

            // Create activity
            $facilityActivity = new HcpActivity();
            $facilityActivity->facility_id = $facilityId;
            $facilityActivity->activity = $activity;
            $facilityActivity->message = $message;
            $facilityActivity->hcp_id = $hcpId;
            $facilityActivity->shift_id = $shiftId;
            $facilityActivity->created_by = $userId;
            $facilityActivity->updated_by = $userId;
            $facilityActivity->save();
            //----------------

        }
    }
}

if (!function_exists('get_facility_name')) {
    /**
     * Get facility name.
     *
     * @param  string  $value
     * @return name
     *
     * @author Sumit
     * @created_at 11 Jan 2021
     */
    function get_facility_name($facilityNameId)
    {
        // Get facility name
        $facilityName = '';
        if (!empty($facilityNameId)) {
            $facility = Facility::where('id', $facilityNameId)->select('id', 'name')->first();
            $facilityName = ucwords($facility['name']);
        }
        //------------------

        return $facilityName;
    }
}

if (!function_exists('send_admin_notification')) {
    /**
     * Send admin notifications.
     *
     * @param  $type, $sendTo, $shiftId, $hcpId, $facilityId, $reason,
     * @return boolean
     *
     * @author Sumit
     * @created_at 13 Jan 2021
     */

    function send_admin_notification($type = null, $sendTo = null, $shiftId = null, $hcpId = null, $facilityId = null, $reason = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $userDeviceIds = [];
        $hcpName = null;
        $shiftDate = null;
        $facilityName = null;
        $facilityGroupName = null;
        $shiftAmount = null;
        $shiftStartTime = null;
        $shiftEndTime = null;
        $facilityContactName = null;
        $facilityContactNumber = null;
        $superAdminName = null;
        $superAdminContactNumber = null;
        $documentName = null;
        $message = null;
        $shiftFullId = null;
        $hcpFullId = null;
        $facilityFullId = null;


        // Get Super Admin
        $superAdmin = User::where('role_name', 'super-admin')->first();
        //----------------

        // Get nurse
        if (!empty($sendTo) && !empty($type)) {

            // Get shift
            if (!empty($shiftId)) {
                $shift = Shift::where('id', $shiftId)
                    ->with(['facility' => function ($query) {
                        $query->select('id', 'name', 'address', 'contact_person', 'contact_number');
                    }])
                    ->with(['facility_group' => function ($query) {
                        $query->select('id', 'name');
                    }])
                    ->with(['hcp' => function ($query) {
                        $query->select('id', 'first_name', 'last_name', 'user_id');
                        $query->with(['user' => function ($query) {
                            $query->select('id', 'name', 'device_id');
                        }]);
                    }])->with(['user' => function ($query) {
                        $query->select('id', 'name');
                    }])
                    ->first();

                $hcpName = $shift->hcp ? ucwords($shift->hcp->first_name . ' ' . $shift->hcp->last_name) : null;
                $shiftDate = $shift ? date("d-m-Y", strtotime($shift->created_at)) : null;
                $facilityName = $shift->facility ? ucwords($shift->facility->name) : null;
                $facilityGroupName = $shift->facility_group ? ucwords($shift->facility_group->name) : null;
                $shiftAmount = $shift ? '$'. $shift->hcp_amount : null;
                $shiftStartTime = $shift ? date("d M Y h:i A", strtotime($shift->start_time)) : null;
                $shiftEndTime =  $shift ? date("d M Y h:i A", strtotime($shift->end_time)) : null;
                $facilityContactName = $shift->facility ? ucwords($shift->facility->contact_person) : null;
                $facilityContactNumber = $shift->facility ? $shift->facility->contact_number : null;
                $superAdminName = $superAdmin ? ucwords($superAdmin->name) : null;
                $superAdminContactNumber = $superAdmin ? $superAdmin->contact_number : null;
                $shiftFullId = $shift->shift_prefix.$shift->id;
            }
            //----------

            // Get Hcp
            if (!empty($hcpId)) {
                $hcp = Hcp::where('id', $hcpId)
                ->with(['user' => function ($query) {
                    $query->select('id', 'name', 'device_id');
                }])
                ->select('id', 'user_id', 'first_name', 'last_name', 'hcp_prefix')->first();

                $superAdminName = $superAdmin ? ucwords($superAdmin->name) : null;
                $superAdminContactNumber = $superAdmin ? $superAdmin->contact_number : null;
                $hcpName = $hcp ? ucwords($hcp->first_name . ' ' . $hcp->last_name) : null;
                $hcpFullId = $hcp->hcp_prefix.$hcp->id;
            }
            //--------

            // Get facility
            if (!empty($facilityId)) {
                $facility = Facility::where('id', $facilityId)
                ->with(['user' => function ($query) {
                    $query->select('id', 'name', 'device_id');
                }])
                ->select('id', 'user_id', 'name', 'facility_prefix')->first();

                $superAdminName = $superAdmin ? ucwords($superAdmin->name) : null;
                $superAdminContactNumber = $superAdmin ? $superAdmin->contact_number : null;
                $facilityName = $facility ? ucwords($facility->name) : null;
                $facilityGroupName = $facility->facility_group ? ucwords($facility->facility_group->name) : null;
                $facilityFullId = $facility->facility_prefix.$facility->id;
            }
            //-------------

            // Get message
            $notificationMessage = NotificationMessage::where('type', $type)->first();

            $messageTags = config('constants.notification_tags');
            $replaceTags = [
                $hcpName, $shiftDate, $facilityName,
                $facilityContactName, $facilityContactNumber,
                $shiftAmount, $shiftStartTime, $shiftEndTime, $superAdminName,
                $superAdminContactNumber, $documentName, $facilityGroupName, $reason,
                $shiftFullId, $hcpFullId, $facilityFullId
            ];

            $message = str_replace($messageTags, $replaceTags, $notificationMessage->message);
            $title = $notificationMessage->title;
            //------------

            // Create notification
            $notification = new Notification();
            $notification->hcp_id = $hcpId;
            $notification->facility_id = $facilityId;
            $notification->shift_id = $shiftId;
            $notification->title = $title;
            $notification->message = $message;
            $notification->notification_type = 'custom';
            $notification->read_status = 'unread';
            $notification->send_to = $sendTo;
            $notification->save();
            //--------------------

        }
        //----------

    }
}

if (!function_exists('get_facility_active_plan')) {
    /**
     * Get facility active plan.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 13 Jan 2021
     */
    function get_facility_active_plan($facilityId)
    {
        // Get facility
        $facilityPlan = [];
        if (!empty($facilityId)) {
            $facilityPlan = FacilityPlan::where('facility_id', $facilityId)->where('status', '!=', 'expired')->where('status', '!=', 'disable')->where('status', '!=', 'pending')->with('plan')->first();
        }
        //-------------

        return $facilityPlan;
    }
}

if (!function_exists('get_supporting_page_data')) {
    /**
     * Get Supporting Page Data.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 13 Jan 2021
     */
    function get_supporting_page_data()
    {
        // Get supporting page
        $supportingPage = SupportingPage::first();
        //-------------

        return $supportingPage;
    }
}

if (!function_exists('get_facility_shift_pending_transactions')) {
    /**
     * Get facility shift pending transactions.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 27 Jan 2021
     */
    function get_facility_shift_pending_transactions($facilityId)
    {
        // Get facility shift pending transactions
        $transactions = Transaction::where(['facility_id' => $facilityId, 'amount_type' => 'shift', 'status' => 'pending'])->count();
        //----------------------------------------

        return $transactions;
    }
}

if (!function_exists('send_facility_plan_notification')) {
    /**
     * Send facility plan notifications.
     *
     * @param  $type, $facilityId, $planName, $planStart, $planEnd, $planCycle
     * @return boolean
     *
     * @author Sumit
     * @created_at 28 Jan 2021
     */

    function send_facility_plan_notification($type = null, $facilityId = null, $planName = null, $planStart = null, $planEnd = null, $planCycle = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $userDeviceIds = [];
        $hcpName = null;
        $shiftDate = null;
        $facilityName = null;
        $facilityGroupName = null;
        $shiftAmount = null;
        $shiftStartTime = null;
        $shiftEndTime = null;
        $facilityContactName = null;
        $facilityContactNumber = null;
        $superAdminName = null;
        $superAdminContactNumber = null;
        $documentName = null;
        $message = null;
        $shiftFullId = null;
        $hcpFullId = null;
        $facilityFullId = null;
        $reason = null;

        // Get Super Admin
        $superAdmin = User::where('role_name', 'super-admin')->first();
        //----------------

        // Get nurse
        if (!empty($facilityId) && !empty($type)) {

            // Get facility
            if (!empty($facilityId)) {
                $facility = Facility::where('id', $facilityId)
                ->with(['user' => function ($query) {
                    $query->select('id', 'name', 'device_id');
                }])
                ->select('id', 'user_id', 'name', 'facility_prefix')->first();

                $superAdminName = $superAdmin ? ucwords($superAdmin->name) : null;
                $superAdminContactNumber = $superAdmin ? $superAdmin->contact_number : null;
                $facilityName = $facility ? ucwords($facility->name) : null;
                $facilityGroupName = $facility->facility_group ? ucwords($facility->facility_group->name) : null;
                $facilityFullId = $facility->facility_prefix.$facility->id;
            }
            //-------------

            // Get message
            $notificationMessage = NotificationMessage::where('type', $type)->first();

            $messageTags = config('constants.notification_tags');
            $replaceTags = [
                $hcpName, $shiftDate, $facilityName,
                $facilityContactName, $facilityContactNumber,
                $shiftAmount, $shiftStartTime, $shiftEndTime, $superAdminName,
                $superAdminContactNumber, $documentName, $facilityGroupName, $reason,
                $shiftFullId, $hcpFullId, $facilityFullId, $planName, $planStart, $planEnd, $planCycle
            ];

            $message = str_replace($messageTags, $replaceTags, $notificationMessage->message);
            $title = $notificationMessage->title;
            //------------

            // Create notification
            $notification = new Notification();
            $notification->hcp_id = null;
            $notification->facility_id = $facilityId;
            $notification->shift_id = null;
            $notification->title = $title;
            $notification->message = $message;
            $notification->notification_type = 'custom';
            $notification->read_status = 'unread';
            $notification->send_to = 'facility';
            $notification->save();
            //--------------------

        }
        //----------

    }
}

if (!function_exists('get_facility_trial_plan')) {
    /**
     * Get facility trial plan.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 13 Jan 2021
     */
    function get_facility_trial_plan($facilityId)
    {
        // Get facility
        $facilityPlan = [];
        if (!empty($facilityId)) {
            $facilityPlan = FacilityPlan::where('facility_id', $facilityId)->first();
        }
        //-------------

        return $facilityPlan;
    }
}

if (!function_exists('get_rating_by_facility')) {
    /**
     * Get rating by facility.
     *
     * @param  string  $value
     * @return array
     *
     * @author Sumit
     * @created_at 13 Jan 2021
     */
    function get_rating_by_facility($facilityId, $shiftId)
    {
        // Get facility
        if (!empty($facilityId)) {
            $rating = RatingReview::where('facility_id', $facilityId)->where('shift_id', $shiftId)->where('hcp_rating', '!=', null)->first();
        }
        //-------------

        return $rating;
    }
}

if (!function_exists('get_hcp_mandatory_document')) {
    /**
     * Get hcp mandatory document.
     *
     * @param  string  $hcpId
     * @return array
     *
     * @author Sumit
     * @created_at 31 Jan 2021
     */
    function get_hcp_mandatory_documents($hcpId)
    {
        $generalDocuments = null;
        $professionDocuments = null;

        // Get hcp
        if (!empty($hcpId)) {
            $hcp = Hcp::where('id', $hcpId)->with('hcp_professions')->select('id')->first();

            $generalDocuments = Document::where('required_for', 'hcp')
            ->where('mandatory_status', 'yes')
            ->where('doc_type', 'general-statement')
            ->count();

            if(count($hcp->hcp_professions)) {
                $professionIds = $hcp->hcp_professions->pluck('profession_id');

                $professionDocuments = DocumentConfiguration::whereIn('profession_id', $professionIds)
                ->whereHas('document', function ($query) use ($professionIds) {
                    $query->where('required_for', 'hcp');
                    $query->where('mandatory_status', 'yes');
                    $query->where('doc_type', 'profession');
                })->with(['document' => function ($query) use($professionIds) {
                    $query->where('required_for', 'hcp');
                    $query->where('mandatory_status', 'yes');
                    $query->where('doc_type', 'profession');
                }])
                ->count();
            }

        }
        //-------------

        return ['general_documents_count' => $generalDocuments, 'profession_documents_count' => $professionDocuments];
    }
}

if (!function_exists('get_hcp_uploaded_mandatory_documents')) {
    /**
     * Get hcp uploaded mandatory document.
     *
     * @param  string  $hcpId
     * @return array
     *
     * @author Sumit
     * @created_at 31 Jan 2021
     */
    function get_hcp_uploaded_mandatory_documents($hcpId)
    {
        $hcpDoucments = null;

        // Get hcp
        if (!empty($hcpId)) {
            $hcpDoucments = DocumentHcp::where('hcp_id', $hcpId)
            ->whereHas('document', function ($query) {
                $query->where('mandatory_status', 'yes');
            })
            ->with(['document' => function ($query)  {
                $query->where('mandatory_status', 'yes');
            }])->count();
        }
        //-------------

        return $hcpDoucments;
    }
}

if (!function_exists('get_hcp_uploaded_documents')) {
    /**
     * Get hcp uploaded document.
     *
     * @param  string  $hcpId
     * @return array
     *
     * @author Sumit
     * @created_at 31 Jan 2021
     */
    function get_hcp_uploaded_documents($hcpId)
    {
        $hcpDoucments = null;

        // Get hcp
        if (!empty($hcpId)) {
            $hcpDoucments = DocumentHcp::where('hcp_id', $hcpId)->count();
        }
        //-------------

        return $hcpDoucments;
    }
}

if (!function_exists('get_hcp_approved_uploaded_documents')) {
    /**
     * Get hcp approved uploaded document.
     *
     * @param  string  $hcpId
     * @return array
     *
     * @author Sumit
     * @created_at 31 Jan 2021
     */
    function get_hcp_approved_uploaded_documents($hcpId)
    {
        $hcpDoucments = null;

        // Get hcp
        if (!empty($hcpId)) {
            $hcpDoucments = DocumentHcp::where('hcp_id', $hcpId)
            ->where(function ($query) {
                $query->orwhere(function ($query) {
                    $query->where('document_approval', 'approved');
                });
                $query->orwhere(function ($query) {
                    $query->where('document_approval', 'reapproved');
                });
            })->count();
        }
        //-------------

        return $hcpDoucments;
    }
}

if (!function_exists('get_hcp_pending_approval_count')) {
    /**
     * Get hcp pending approval count.
     *
     * @param  string  $hcpId
     * @return array
     *
     * @author Sumit
     * @created_at 31 Jan 2021
     */
    function get_hcp_pending_approval_count()
    {
        // Get hcp

        $where = [['status', '!=', 'active'], ['status', '!=', 'archived'], ['status', '!=', 'blocked'], ['app_registration_screen', '=', '0']];
        $hcp = Hcp::where($where)->count();
        //-------------

        return $hcp;
    }
}

if (!function_exists('get_hcp_pending_profession_request_count')) {
    /**
     * Get hcp pending profession request count.
     *
     * @param  string  $hcpId
     * @return array
     *
     * @author Sumit
     * @created_at 31 Jan 2021
     */
    function get_hcp_pending_profession_request_count()
    {
        // Get hcp

        $where = ['status' => 'pending'];
        $hcpProfessionrequests = HcpProfessionRequest::where($where)->count();
        //-------------

        return $hcpProfessionrequests;
    }
}

if (!function_exists('get_hcp_doucments_by_ids')) {
    /**
     * Get hcp doucments by ids.
     *
     * @param  string  $hcpId
     * @return array
     *
     * @author Sumit
     * @created_at 31 Jan 2021
     */
    function get_hcp_doucments_by_ids($hcpDocumentIds)
    {
        $hcpDoucments = null;

        // Get hcp
        if (!empty($hcpDocumentIds)) {
            $hcpDoucments = DocumentHcp::whereIn('id', explode(',', $hcpDocumentIds))->with('document')->get();
        }
        //-------------

        return $hcpDoucments;
    }
}

if (!function_exists('get_pending_hcp_doucments_by_ids')) {
    /**
     * Get hcp doucments by ids.
     *
     * @param  string  $hcpId
     * @return array
     *
     * @author Sumit
     * @created_at 31 Jan 2021
     */
    function get_pending_hcp_doucments_by_ids($hcpDocumentIds)
    {
        $hcpDoucments = null;

        // Get hcp
        if (!empty($hcpDocumentIds)) {
            $where = [['document_approval', '!=', 'approved'], ['document_approval', '!=', 'reapproved']];
            $hcpDoucments = DocumentHcp::whereIn('id', explode(',', $hcpDocumentIds))->where($where)->with('document')->get();
        }
        //-------------

        return $hcpDoucments;
    }
}

if (!function_exists('generate_random_string')) {
    function generate_random_string($length = 8) {
        $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }
}

if (!function_exists('remove_new_shift_notification')) {

    /**
     * Remove new shift notification.
     *
     * @param  string  $shiftId
     * @return array
     *
     * @author Sumit
     * @created_at 14 Jun 2021
     */
    function remove_new_shift_notification($shiftId)
    {
        if(!empty($shiftId)) {
            $deleteNotification = Notification::where('shift_id', $shiftId)->where('shift_broadcast_type', '!=', null)->where('shift_broadcast_type', '!=', 'all')->delete();
            return $deleteNotification;
        }
    }
}

if (!function_exists('get_accept_lower_job_checkbox_status')) {
    /**
    * Get Accept lower job checkbox status.
    *
    * @param  string  $value
    * @return initials
    *
    * @author Sumit
    * @created_at 22 Aug 2020
    */
    function get_accept_lower_job_checkbox_status(){
        $generalConfiguration = GeneralConfiguration::where('id', 1)->select('show_accept_lower_level_job_checkbox')->first();

        if(!empty($generalConfiguration)) {
            return $generalConfiguration;
        } else {
            return null;
        }
    }
}


if (!function_exists('get_profession_documens')) {
    /**
    * Get Profession Document.
    *
    * @param  string  $value
    * @return initials
    *
    * @author Sumit
    * @created_at 04 Dec 2020
    */
    function get_profession_documens($professionId, $levelId = null){

        // Get document
        $document = [];
        if (!empty($professionId)) {
            $document = DocumentConfiguration::where([['profession_id', $professionId]])->with('document')->get();
        }
        //-------------

        return $document;
    }
}
