<?php

namespace App\Http\Requests\API\Auth;

use Illuminate\Foundation\Http\FormRequest;

class Login extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        $email_or_mobile_number = '|email|exists:users,email';

        if (request()->filled('email')) {
            if (is_numeric(request('email'))) {
                $email_or_mobile_number = '|digits:10|exists:users,mobile_number';
            }
        }

        return [
            'email' => 'required' . $email_or_mobile_number,
            'password' => 'required',
        ];
    }

    /**
     * Messages.
     */
    public function messages()
    {
        $email_or_mobile_number_exists = __('messages.email_address_not_exists');

        if (request()->filled('email')) {
            if (is_numeric(request('email'))) {
                $email_or_mobile_number_exists = __('messages.mobile_number_not_exists');
            }
        }

        return [
            'email.required' => __('messages.email_or_mobile_number_required'),
            'email.digits' => __('messages.email_or_mobile_number_required'),
            'email.email' => __('messages.email_or_mobile_number_required'),
            'email.exists' => $email_or_mobile_number_exists,
        ];
    }
}
