<?php

namespace App\Http\Requests\API\Auth;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class VerifyOTP extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        $exists = null;

        if (
            request()->filled('one_time_password') &&
            request()->filled('request_token') &&
            is_numeric(request('one_time_password'))
        ) {
            $exists = Rule::exists('one_time_passwords')
                ->where('request_token', request('request_token'))
                ->where('one_time_password', request('one_time_password'));
        }

        return [
            'type'              => 'required',
            'request_token'     => 'required',
            'one_time_password' => [
                'required',
                'digits:6',
                $exists
            ]
        ];
    }

    /**
     * Messages.
     */
    public function messages()
    {
        return [
            'one_time_password.exists' => __('messages.invalid_one_time_password')
        ];
    }
}
