<?php

namespace App\Http\Requests\API\Hcp;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\JsonResponse;
use Auth;

class ValidateChangePassword extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'current_password'          => 'required',
            'new_password'              => 'required|different:current_password',
            'new_password_again'        => 'required|same:new_password'
        ];
    }

    /**
     * Get the error messages for the defined validation rules.
     *
     * @return array
     */
    public function messages()
    {
        return [
            'new_password_again.same'   => 'The new password and new confirm password are not the same.',
            'new_password.different'    => "New password can't be same as current password",
        ];
    }

    /**
        * Get the failed validation response for the request.
        *
        * @param array $errors
        * @return JsonResponse
    */
    protected function failedValidation(\Illuminate\Contracts\Validation\Validator $validator)
    {
        $response = new JsonResponse([
                    'message' => 'The given data is invalid',
                    'errors' => $validator->errors()->all()
                ], 422);

        throw new \Illuminate\Validation\ValidationException($validator, $response);
    }
}
