<?php

namespace App\Http\Traits;

use Illuminate\Support\Facades\Storage;
use Intervention\Image\Facades\Image;
use Illuminate\Support\Str;

trait UploadImage
{
    /**
     * Upload image.
     */
    private function uploadImage($file, $path = null, $compression = null, $name = null)
    {
        $image_uploaded = false;

        // File system
        $file_system = config('filesystems.default');
        //------------

        // Generate image name and get extension
        $extension        = $file->getClientOriginalExtension();
        $file_name        = $this->generateImageName($extension, $name);
        $destination_path = $path . $file_name;
        //--------------------------------------

        // Upload image
        try {
            if (!is_null($compression)) {

                if ($extension != 'svg') {
                    // Compress image
                    $image = Image::make($file)->encode($extension, $compression);
                    //---------------

                    // Upload image
                    $image_uploaded = Storage::disk($file_system)->put($destination_path, (string) $image);
                    //-------------
                } else {

                    // Upload image
                    $image = Storage::disk($file_system)->putFileAs(rtrim($path, '/'), $file, $file_name);
                    //-------------
                }
            } else {

                // Upload image
                $image = Storage::disk($file_system)->putFileAs(rtrim($path, '/'), $file, $file_name);
                //-------------

                if (!is_null($image)) {
                    $image_uploaded = true;
                }
            }
        } catch (\Exception $e) {
            //
        }
        //-------------

        // Set data
        if ($image_uploaded) {
            $data = [
                '_status'  => true,
                '_message' => __('messages.image_uploaded'),
                '_data'    => $file_name
            ];
        } else {
            $data = [
                '_status'  => false,
                '_message' => __('messages.image_uploading_failed'),
                '_data'    => null
            ];
        }
        //---------

        return $data;
    }

    /**
     * Generate image name.
     *
     * @param  string  $extension
     * @return string
     */
    private function generateImageName($extension, $name)
    {
        return  $name . '-' . date('Y-m-d') . '-' . time() . '.' . $extension;
    }
}
