<?php

namespace App\Imports;

use App\Models\FacilityName;
use App\Models\FacilityGroup;
use App\Models\State;
use Maatwebsite\Excel\Concerns\ToModel;
use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\ToCollection;
use Maatwebsite\Excel\Concerns\WithHeadingRow;
use Illuminate\Support\Facades\DB;

class FacilityNamesImport implements ToCollection, WithHeadingRow
{

    private $rows = 0;

    /**
    * @param array $row
    *
    * @return \Illuminate\Database\Eloquent\Model|null
    */
    public function collection(Collection $rows)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $facilityName = null;
        $address = null;
        $lat = null;
        $long = null;
        $facilityGroupId = null;
        $googleKey = env('GOOGLE_API_KEY'); // env('GOOGLE_API_KEY')

        foreach ($rows as $row)
        {
            // Get Address
            if(!empty($row['address'])) {
                $address = $row['address'].' '.$row['city'].' '.$row['suburb'].' '.$row['state'].' '.$row['post_code'];
                $address = str_replace(" ", "+", $address);
                $json = file_get_contents("https://maps.google.com/maps/api/geocode/json?address=$address&sensor=false&key=".$googleKey);
                $json = json_decode($json);

                if(!empty($json->results)){
                    $lat = $json->results[0]->geometry->location->lat;
                    $long = $json->results[0]->geometry->location->lng;
                }

            }
            //------------

            // Get facility Group
            $facilityGroup = FacilityGroup::whereRaw('LOWER(`name`) LIKE ? ',[trim(strtolower($row['facility_group_name'])).'%'])->first();
            if(!empty($facilityGroup)){
                $facilityGroupId = $facilityGroup->id;
            }
            //-------------------

            // Get facility Group
            $state = State::whereRaw('LOWER(`short_form`) LIKE ? ',[trim(strtolower($row['state'])).'%'])->first();
            if(!empty($state)){
                $stateId = $state->id;
            }
            //-------------------

            if(!empty($facilityGroupId) && !empty($stateId)) {
                DB::beginTransaction();
                try {

                    // Set data
                    $data = [
                        'facility_group_id' => $facilityGroupId,
                        'name' => $row['facility_name'],
                        'address' => ucwords(strtolower($row['address'])),
                        'suburb_name' => ucwords(strtolower($row['suburb'])),
                        'city_name' => ucwords(strtolower($row['city'])) ?? null,
                        'state_id' => $stateId,
                        'country_id' => 1,
                        'post_code' => $row['post_code'],
                        'latitude' => $lat,
                        'longitude' => $long,
                        'created_by' => $authUser->id,
                        'updated_by' => $authUser->id,
                    ];
                    //---------

                    $facilityName = FacilityName::create($data);
                    ++$this->rows;

                    DB::commit();
                } catch (\Exception $e) {
                    $facilityName = null;
                    $errorMessage = $e->getMessage();
                    DB::rollback();
                }
            }

        }
    }

    public function getRowCount(): int
    {
        return $this->rows;
    }

    public function headingRow(): int
    {
        return 1;
    }
}
