<?php

namespace App\Jobs\AdminPanel;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use App\Interfaces\ShiftInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\HcpInterface;
use App\Interfaces\ShiftActivityInterface;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use App\Models\CronJob;
use Carbon\Carbon;

class ShiftBroadcastJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct()
    {
        //
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle(ShiftInterface $shift, FacilityInterface $facility, HcpInterface $hcp, ShiftActivityInterface $shiftActivity)
    {
        config(['logging.channels.cronlog.path' => storage_path('logs/jobs-logs/shift-broadcast.log')]);

        $hcpFilter = [];
        $favouritesHcpIds = [];
        $ratedHcpIds = [];
        $otherHcpIds = [];
        $allHcpsIds = [];
        $cancelledHcpIds = [];
        $userDeviceIds = [];

        // General Configuration
        $generalConfiguration = get_general_configuration();
        //----------------------

        // Get Shift
        $shiftWhere = ['shift_status' => '0'];
        $shifts = $shift->shift_where($shiftWhere);
        //----------

        if (count($shifts)) {
            Log::channel('cronlog')->info("-----------------------");
            Log::channel('cronlog')->info("shift broadcast job start");

            foreach($shifts as $shift) {
                // Set time zone
                date_default_timezone_set($shift->state->time_zone_name);
                //--------------

                $currentTime = Carbon::now($shift->state->time_zone_name);

                $getfacility = $facility->find_facility($shift['facility_id']);
                $hcpFilter['shift_id'] = $shift['id'];
                $hcpFilter['facility_id'] = $shift['facility_id'];
                $hcpFilter['state_id'] = $shift['state_id'];
                $hcpFilter['country_id'] = $shift['country_id'];
                $hcpFilter['facility_latitude'] = $getfacility['latitude'];
                $hcpFilter['facility_longitude'] = $getfacility['longitude'];
                $hcpFilter['category_id'] = $shift['category_id'];
                $hcpFilter['profession_id'] = $shift['profession_id'];
                $hcpFilter['level_id'] = $shift['hcp_level_id'];
                $hcpFilter['shift_start_time'] = $shift['start_time'];
                $hcpFilter['shift_end_time'] = $shift['end_time'];
                $hcpFilter['time_zone_name'] = $shift->state->time_zone_name;
                $hcpFilter['check_transfer_case'] = 'true';
                $hcpFilter['check_swap_case'] = 'true';

                // Get Cancelled Hcps
                $cancelledHcpIds = [];
                if (count($shift['cancelled_shifts'])) {
                    foreach($shift['cancelled_shifts'] as $cancelledShifts){
                        $cancelledHcpIds[] = $cancelledShifts->hcp_id;
                    }
                    $hcpFilter['cancelled_hcps'] = $cancelledHcpIds;
                }
                //-------------------

                // Send Notification To Favourites Hcp
                if($shift['shift_broadcast'] == 'favourite') {
                    $hcpFilter['only_favourites'] = true;
                    $favouritesHcps = $hcp->get_hcp_listing_for_shift($hcpFilter);

                    $favouritesHcpIds = [];
                    if (count($favouritesHcps)) {
                        foreach($favouritesHcps as $favouritesHcp){
                            $favouritesHcpIds[] = $favouritesHcp->id;
                        }

                        send_shift_push_notification($shift->id, 'new-shift', array_unique($favouritesHcpIds), null, 'favourite');

                        Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                        Log::channel('cronlog')->info("notification sent to favorite hcp");
                    }

                    $shiftActivityData = [
                        'shift_id'      => $shift->id,
                        'activity'      => 'broadcast-to-favourites-hcp',
                        'created_by'    => $shift->created_by,
                        'updated_by'    => $shift->created_by,
                    ];
                    $shiftActivity->store($shiftActivityData);

                    Log::channel('cronlog')->info("shift broadcast to favourites hcp");

                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift['id']];

                    if(count($favouritesHcps)) {
                        $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_mint']);
                    } else {
                        $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes(1);
                    }

                    $shift->update(['shift_broadcast' => 'rated', 'shift_rebroadcast_time' => $shiftRebroadcastTime], $shiftBroadcastWhere);
                    //-----------------------
                }
                //------------------------------------

                // Send Notification To Rated Hcp
                else if($shift['shift_broadcast'] == 'rated' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                    $hcpFilter['only_ratings'] = true;
                    $ratedHcps = $hcp->get_hcp_listing_for_shift($hcpFilter);

                    $ratedHcpIds = [];
                    if (count($ratedHcps)) {
                        foreach($ratedHcps as $ratedHcp){
                            $ratedHcpIds[] = $ratedHcp->id;
                        }

                        send_shift_push_notification($shift->id, 'new-shift', array_unique($ratedHcpIds), null, 'rated');

                        Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                        Log::channel('cronlog')->info("notification sent to rated Hcp");
                    }

                    $shiftActivityData = [
                        'shift_id'      => $shift->id,
                        'activity'      => 'broadcast-to-rated-hcp',
                        'created_by'    => $shift->created_by,
                        'updated_by'    => $shift->created_by,
                    ];
                    $shiftActivity->store($shiftActivityData);

                    Log::channel('cronlog')->info("shift broadcast to rated hcp");

                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift['id']];

                    if(count($ratedHcps)) {
                        $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_mint']);
                    } else {
                        $shiftRebroadcastTime = Carbon::now($shift->state->time_zone_name)->addMinutes(1);
                    }

                    $shift->update(['shift_broadcast' => 'other', 'shift_rebroadcast_time' => $shiftRebroadcastTime] ,$shiftBroadcastWhere);
                    //-----------------------
                }
                //--------------------------------

                // Send Notification To Other Hcp
                else if($shift['shift_broadcast'] == 'other' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                    $otherHcps = $hcp->get_hcp_listing_for_shift($hcpFilter);

                    $otherHcpIds = [];
                    if (count($otherHcps)) {
                        foreach($otherHcps as $otherHcp){
                            $otherHcpIds[] = $otherHcp->id;
                        }

                        send_shift_push_notification($shift->id, 'new-shift', array_unique($otherHcpIds), null, 'other');

                        Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                        Log::channel('cronlog')->info("notification sent to other hcp");
                    }

                    $shiftActivityData = [
                        'shift_id'      => $shift->id,
                        'activity'      => 'broadcast-to-other-hcp',
                        'created_by'    => $shift->created_by,
                        'updated_by'    => $shift->created_by,
                    ];
                    $shiftActivity->store($shiftActivityData);

                    Log::channel('cronlog')->info("shift broadcast to other hcp");

                    // Check Time Diff
                    $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);

                    $to = Carbon::parse($shift['start_time'])->setTimezone($shift->state->time_zone_name);
                    $from = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);
                    $timeDiff = $to->diffInHours($from);
                    //----------------

                    if($timeDiff <= $generalConfiguration['rebroadcast_to_all_before_shift_start']) {
                        $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours(1);
                    } else {
                        $nextReabroadcast = Carbon::parse($shift->start_time)->setTimezone($shift->state->time_zone_name)->subHours($generalConfiguration['rebroadcast_to_all_before_shift_start']);
                    }

                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift['id']];
                    $shift->update(['shift_broadcast' => 'all', 'shift_rebroadcast_time' => $nextReabroadcast] ,$shiftBroadcastWhere);
                    //-----------------------
                }
                //-------------------------------

                // Send Notification To All Hcp
                else if($shift['shift_broadcast'] == 'all' && strtotime($currentTime) >= strtotime($shift->shift_rebroadcast_time)) {
                    $allHcps = $hcp->get_hcp_listing_for_shift($hcpFilter);

                    $allHcpsIds = [];
                    if (count($allHcps)) {
                        foreach($allHcps as $allHcp){
                            $allHcpsIds[] = $allHcp->id;
                        }

                        send_shift_push_notification($shift->id, 'new-shift', array_unique($allHcpsIds), null, 'all');

                        Log::channel('cronlog')->info("shift ".$shift->shift_prefix.$shift->id);
                        Log::channel('cronlog')->info("notification sent to all hcp");
                    }

                    $shiftActivityData = [
                        'shift_id'      => $shift->id,
                        'activity'      => 'broadcast-to-all-hcp',
                        'created_by'    => $shift->created_by,
                        'updated_by'    => $shift->created_by,
                    ];
                    $shiftActivity->store($shiftActivityData);

                    Log::channel('cronlog')->info("shift broadcast to all hcp");

                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift['id']];
                    $shift->update(['shift_broadcast' => 'all', 'shift_rebroadcast_time' => Carbon::now($shift->state->time_zone_name)->addMinutes($generalConfiguration['shift_rebroadcast_to_all_mint'])] ,$shiftBroadcastWhere);
                    //-----------------------
                }
                //-------------------------------
            }

            Log::channel('cronlog')->info("shift broadcast job end");
            Log::channel('cronlog')->info("-----------------------");
        }

    }
}
