<?php

namespace App\Jobs\StripeWebhooks;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Spatie\WebhookClient\Models\WebhookCall;
use App\Models\LogEntry;
use App\Models\Facility;
use App\Models\FacilityPlan;
use App\Models\Transaction;

class InvoicePaymentSucceededJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /** @var \Spatie\WebhookClient\Models\WebhookCall */
    public WebhookCall $webhookCall;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct(WebhookCall $webhookCall)
    {
        $this->webhookCall = $webhookCall;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $charge = $this->webhookCall->payload['data']['object'];

        $logEntry = new LogEntry();
        $logEntry->url = 'stripe-webhooks-invoice-succeeded';
        $logEntry->method = null;
        $logEntry->request_header = null;
        $logEntry->request_body = null;
        $logEntry->response_body = json_encode($charge, true);
        $logEntry->status_code = null;
        $logEntry->request_ip = null;
        $logEntry->save();

        $facility = Facility::where('stripe_customer_id', $charge['customer'])->first();
        if(!empty($facility)){

            // Get Facility Plan
            $facilityPlan = FacilityPlan::where('facility_id', $facility->id)
            ->where('status', 'active')->orderBy('id', 'DESC')->first();
            //------------------

            $checkTransaction = Transaction::where('facility_id', $facility->id)->where('transaction_id', $charge['id'])->first();

            if(empty($checkTransaction)) {

                // Store transaction
                $maxInvoiceId = Transaction::where(function ($query) {
                })->orderBy('id', 'DESC')->select('id','invoice_prefix','invoice_id')->first();

                if (!empty($maxInvoiceId)) {
                    $invoiceId = sprintf("%'03d", ($maxInvoiceId['id']+1));
                } else {
                    $invoiceId = sprintf("%'03d", 1);
                }
                $invoiceId = $facility->id.$invoiceId;

                if (!empty($facilityPlan)) {
                    $stripe = new \Stripe\StripeClient(env('STRIPE_SECRET'));
                    $subscription = $stripe->subscriptions->retrieve(
                        $facilityPlan['stripe_subscriptions_id'],
                        []
                    );
                } else {
                    $subscription = null;
                }

                $payAmount = number_format($charge['amount_paid']/100, 2);
                $transactionData = [
                    'facility_id' => $facility->id,
                    'facility_plan_id' => $facilityPlan['id'],
                    'invoice_id' => $invoiceId,
                    'facility_plan_json' => $facilityPlan['plan_details'],
                    'facility_amount' => $payAmount,
                    'amount_for' => 'facility',
                    'amount_type' => 'subscription',
                    'status' => 'completed',
                    'stripe_plan_expire_date' => $subscription ? date("Y-m-d H:i:s", $subscription['current_period_end']) : null,
                    'transaction_id' => $charge['id'],
                ];
                Transaction::create($transactionData);
                //------------------
            }
        }

    }
}
