<?php

namespace App\Models;
use Illuminate\Database\Eloquent\Model;

class HcpProfession extends Model
{
    protected $table  = 'hcp_profession';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'hcp_id',
        'category_id',
        'profession_id',
        'level_id',
        'created_by',
        'updated_by'
    ];


    /**
     * The professions that belong to the hcp
     */
    public function profession()
    {
        return $this->belongsTo('App\Models\Profession');
    }

    /**
     * The category that belong to the hcp
     */
    public function category()
    {
        return $this->belongsTo('App\Models\Category');
    }

    /**
     * The level that belong to the hcp
     */
    public function level()
    {
        return $this->belongsTo('App\Models\Level');
    }

    /**
     * The buddy shift request that belong to the hcp
     */
    public function buddy_shift_request()
    {
        return $this->hasOne('App\Models\BuddyShiftRequest', 'hcp_profession_id');
    }

    /**
     * The document that belong to the professions
     */
    public function profession_documents()
    {
        return $this->hasMany('App\Models\DocumentConfiguration', 'profession_id');
    }

    /**
     * The Document Hcp
     */
    public function hcp_documents()
    {
        return $this->hasMany('App\Models\DocumentHcp', 'profession_id');
    }

    /**
     * The level that belong to the hcp
     */
    public function hcp()
    {
        return $this->belongsTo('App\Models\Hcp');
    }
}
