<?php

namespace App\Models;
use Illuminate\Database\Eloquent\Model;
use App\Http\Traits\Statusable;
use App\Http\Traits\StatusToggleable;

class Level extends Model
{
    use Statusable, StatusToggleable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'category_id',
        'profession_id',
        'hcp_per_rate',
        'facility_per_rate',
        'admin_fees',
        'created_by',
        'updated_by'
    ];

    /**
     * Insert prefix.
     */
    public static function boot()
    {
        parent::boot();
        self::creating(function ($model) {
            $model->level_prefix = '#LEV';
        });
    }


    /**
     * The category that belong to the levels
     */
    public function category(){
        return $this->belongsTo('App\Models\Category');
    }

    /**
     * The profession that belong to the levels
     */
    public function profession(){
        return $this->belongsTo('App\Models\Profession');
    }
}
