<?php

namespace App\Models;
use Illuminate\Database\Eloquent\Model;
use App\Http\Traits\Statusable;
use App\Http\Traits\StatusToggleable;

class Profession extends Model
{
    use Statusable, StatusToggleable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'category_id',
        'has_levels',
        'hcp_per_rate',
        'facility_per_rate',
        'admin_fees',
        'created_by',
        'updated_by'
    ];

    /**
     * Insert prefix.
     */
    public static function boot()
    {
        parent::boot();
        self::creating(function ($model) {
            $model->profession_prefix = '#PRO';
        });
    }


    /**
     * The category that belong to the professions
     */
    public function category()
    {
        return $this->belongsTo('App\Models\Category');
    }

    /**
     * Get plans.
     */
    public function plans()
    {
        return $this->belongsToMany('App\Models\Plan');
    }

    /**
     * The document that belong to the professions
     */
    public function document()
    {
        return $this->belongsTo('App\Models\Document');
    }

    /**
     * The document that belong to the professions
     */
    public function document_configuration()
    {
        return $this->hasMany('App\Models\DocumentConfiguration');
    }

    /**
     * Get levels.
     */
    public function levels()
    {
        return $this->hasMany('App\Models\Level');
    }

    /**
     * The document that belong to the professions
     */
    public function profession_documents()
    {
        return $this->hasMany('App\Models\DocumentConfiguration');
    }

    /**
     * The Document Hcp
     */
    public function hcp_documents()
    {
        return $this->hasMany('App\Models\DocumentHcp', 'profession_id');
    }

    /**
     * Get Buddy Shift Request.
     */
    public function buddy_shift_requests()
    {
        return $this->hasMany('App\Models\BuddyShiftRequest', 'profession_id');
    }
}
