<?php

namespace App\Models;
use Illuminate\Database\Eloquent\Model;

class Shift extends Model
{
    protected $guarded = [];

    /**
     * Insert prefix.
     */
    public static function boot()
    {
        parent::boot();
        self::creating(function ($model) {
            $model->shift_prefix = '#SFI';
        });
    }

    /**
     * The facility that belong to the shift.
     */
    public function facility()
    {
        return $this->belongsTo('App\Models\Facility', 'facility_id');
    }

    /**
     * The hcp that belong to the shift.
     */
    public function hcp()
    {
        return $this->belongsTo('App\Models\Hcp', 'hcp_id');
    }

    /**
     * The category that belong to the shift.
     */
    public function category()
    {
        return $this->belongsTo('App\Models\Category', 'category_id');
    }

    /**
     * The profession that belong to the shift.
     */
    public function profession()
    {
        return $this->belongsTo('App\Models\Profession', 'profession_id');
    }

    /**
     * The level that belong to the shift.
     */
    public function level()
    {
        return $this->belongsTo('App\Models\Level', 'hcp_level_id');
    }

    /**
     * The cancelled shifts that belong to the shift.
     */
    public function cancelled_shift()
    {
        return $this->hasOne('App\Models\CancelledShift', 'shift_id');
    }

    /**
     * The shift transfers that belong to the shift.
     */
    public function shift_transfers()
    {
        return $this->hasOne('App\Models\ShiftTransfer', 'shift_id');
    }

    /**
     * Get User.
     */
    public function user()
    {
        return $this->belongsTo('App\User');
    }

    /**
     * The facility group that belong to the shift.
     */
    public function facility_group()
    {
        return $this->belongsTo('App\Models\FacilityGroup', 'facility_group_id');
    }

    /**
     * The activities that belong to the shift.
     */
    public function activities()
    {
        return $this->hasMany('App\Models\ShiftActivity')->orderBy('id', 'DESC');
    }

    /**
     * The buddy hcp that belong to the shift.
     */
    public function buddy_hcp()
    {
        return $this->belongsTo('App\Models\Hcp', 'buddy_hcp_id');
    }

    /**
     * The shift transfers that belong to the shift.
     */
    public function shift_transferred()
    {
        return $this->hasMany('App\Models\ShiftTransfer', 'shift_id');
    }

    /**
     * The Ratings that belong to the shift.
     */
    public function rating_reviews()
    {
        return $this->hasOne('App\Models\RatingReview', 'shift_id');
    }

    /**
     * The shift swap that belong to the shift.
     */
    public function shift_swap()
    {
        return $this->hasOne('App\Models\ShiftSwapRequest', 'shift_id');
    }


    /**
     * The shift transfers that belong to the shift.
     */
    public function shift_transfer_from()
    {
        return $this->hasOne('App\Models\ShiftTransfer', 'shift_id')->orderBy('id', 'DESC');
    }


    /**
     * The shift transfers that belong to the shift.
     */
    public function shift_transfer_to()
    {
        return $this->hasOne('App\Models\ShiftTransfer', 'shift_id')->orderBy('id', 'DESC');
    }

    /**
     * The shift swap reject request that belong to the shift.
     */
    public function swap_reject_request()
    {
        return $this->hasOne('App\Models\ShiftSwapRejectedRequest', 'shift_id');
    }

    /**
     * The hcp location that belong to the shift.
     */
    public function shift_hcp_loaction()
    {
        return $this->hasOne('App\Models\ShiftTracking', 'shift_id')->orderBy('id', 'DESC');
    }

    /**
     * The cancelled shifts that belong to the shift.
     */
    public function cancelled_shifts()
    {
        return $this->hasMany('App\Models\CancelledShift', 'shift_id');
    }

    /**
     * The buddy hcp that belong to the shift.
     */
    public function buddy_shift_request()
    {
        return $this->hasOne('App\Models\BuddyShiftRequest', 'shift_id');
    }

    /**
     * The transactions that belong to the shift.
     */
    public function transactions()
    {
        return $this->hasOne('App\Models\Transaction', 'shift_id');
    }

    /**
     * The state that belong to the shift.
     */
    public function state()
    {
        return $this->belongsTo('App\Models\State', 'state_id');
    }

    /**
     * The Ratings that belong to the shift.
     */
    public function hcp_rating()
    {
        return $this->hasOne('App\Models\RatingReview', 'shift_id')->where('hcp_rating', '!=', null);
    }

    /**
     * The Ratings that belong to the shift.
     */
    public function facility_rating()
    {
        return $this->hasOne('App\Models\RatingReview', 'shift_id')->where('facility_rating', '!=', null);
    }

    /**
     * The rejected shifts that belong to the shift.
     */
    public function rejected_shifts()
    {
        return $this->hasMany('App\Models\RejectedShift', 'shift_id');
    }

    /**
     * The cancelled shifts that belong to the shift.
     */
    public function facility_cancelled_shift()
    {
        return $this->hasOne('App\Models\CancelledShift', 'shift_id')->where('cancel_by', 'facility');
    }

    /**
     * The transactions that belong to the shift.
     */
    public function hcp_transaction()
    {
        return $this->hasOne('App\Models\Transaction', 'shift_id')->where('amount_for', 'hcp');
    }
}
