<?php

namespace App\Models;
use Illuminate\Database\Eloquent\Model;

class Transaction extends Model {

    protected $fillable = [
        'shift_id',
        'hcp_id',
        'facility_id',
        'hcp_amount',
        'facility_amount',
        'admin_fees',
        'amount_for',
        'amount_type',
        'status',
        'created_by',
        'updated_by',
        'facility_plan_id',
        'referral_id',
        'invoice_id',
        'invoice_created_at',
        'facility_plan_json',
        'stripe_payment_session_id',
        'transaction_id',
        'stripe_plan_expire_date',
        'total_admin_fees_with_loading',
        'paid_on',
        'paid_by',
    ];

    /**
     * Insert prefix.
     */
    public static function boot()
    {
        parent::boot();
        self::creating(function ($model) {
            $model->invoice_prefix = '#INV';
            $model->statement_prefix = '#STA';
        });
    }

    public function facility(){
        return $this->belongsTo('App\Models\Facility', 'facility_id');
    }

    public function shift(){
        return $this->belongsTo('App\Models\Shift', 'shift_id')->with('facility','hcp');
    }

    public function hcp(){
        return $this->belongsTo('App\Models\Hcp', 'hcp_id');
    }

    public function referral(){
        return $this->belongsTo('App\Models\Referral', 'referral_id');
    }

    public function facility_plan(){
        return $this->belongsTo('App\Models\FacilityPlan', 'facility_plan_id');
    }
}
