<?php

namespace App\Repositories;
use App\Interfaces\BuddyShiftRequestInterface;
use App\Models\BuddyShiftRequest;

class BuddyShiftRequestRepository implements BuddyShiftRequestInterface
{
    private $buddyShiftRequest;
    public function __construct(BuddyShiftRequest $buddyShiftRequest){
        $this->buddy_shift_request = $buddyShiftRequest;
    }

    public function get(){
        return $this->buddy_shift_request->all();
    }

    public function find_buddy_shift_request($where){
        return $this->buddy_shift_request->where($where)->with('category', 'profession', 'level')->first();
    }

    public function getAll($where, $options = false, $request = null){
        $paginationLimit = null;

        if(isset($request['shift_per_page']) && !empty($request['shift_per_page'])) {
            $paginationLimit = $request['shift_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        if ($options){
            $shiftQuery =  $this->buddy_shift_request->where(function ($query) use ($where, $request) {

                if(isset($request['status']) && $request['status'] !='') {
                    $query->where('status', $request['status']);
                }

                if(isset($request['facility_id']) && $request['facility_id'] !='') {
                    $query->where('facility_id', $request['facility_id']);
                }

                if(!empty($request['date_range'])) {
                    $date = explode('to', $request['date_range']);
                    $query->whereBetween('created_at', [trim($date[0]), trim($date[1])]);
                }

                if(!empty($request['date_from'])) {
                    $query->whereDate('created_at', '>=', $request['date_from']);
                }

                if(!empty($request['date_to'])) {
                    $query->whereDate('created_at', '<=', $request['date_to']);
                }

                if(!empty($request['shift_hcp_search'])) {
                    $query->whereHas('buddy_hcp', function ($query) use ($request) {
                        $query->where('first_name', 'LIKE', "%{$request['shift_hcp_search']}%");
                    });
                }

                if ((isset($request['states']) && $request['states'] !='') || (isset($request['state_id']) && $request['state_id'] !='') || (isset($request['profession']) && $request['profession'] !='') || (isset($request['category']) && $request['category'] !='') || (isset($request['category']) && $request['date_range'] !='')) {

                    $query->whereHas('buddy_hcp', function($query) use($request){

                        if(!empty($request['states']) ) {
                            $query->whereIn('state_id', $request['states']);
                        }

                        if(!empty($request['state_id']) ) {
                            $query->where('state_id', $request['state_id']);
                        }

                        if(isset($request['profession']) &&  $request['profession'] !='') {
                            $query->where('profession_id', $request['profession']);
                        }

                        if(isset($request['category']) && $request['category'] !='') {
                            $query->where('category_id', $request['category']);
                        }

                    });

                }

                $query->where($where);

            })->with('category', 'profession', 'level', 'buddy_hcp', 'shift.facility', 'shift.hcp')->orderBy('id', 'DESC');

            if(isset($request['shift_export']) && $request['shift_export'] == true) {
                return $shiftQuery->get();
            } else {
                return $shiftQuery->paginate($paginationLimit)->fragment('shift')->onEachSide(2);
            }

        } else {
            return $this->buddy_shift_request->get();
        }
    }

    public function store($array){
        return $this->buddy_shift_request->create($array);
    }

    public function update($array, $where){
        return $this->buddy_shift_request->where($where)->update($array);
    }

    public function delete($id){
        return $this->buddy_shift_request->destroy($id);
    }

    public function api_buddy_shift_requests($request, $user){
        $paginationLimit = config('constants.pagination_limit');

        return $this->buddy_shift_request->where(function ($query) use ($request, $user) {

        })->with(['hcp' => function ($query) {
            $query->select('id', 'first_name', 'last_name');
        }])->orderBy('id', 'DESC')->paginate($paginationLimit);
    }
}

