<?php

namespace App\Repositories;
use App\Interfaces\CategoryInterface;
use App\Models\Category;

class CategoryRepository implements CategoryInterface
{
    private $category;
    public function __construct(Category $category){
        $this->category = $category;
    }

    public function get($where = null){
        return $this->category->where($where)->get();
    }

    public function find_category($id){
        return $this->category->find($id);
    }

    public function getAll($where, $options = false){
        if ($options){
            return $this->category->where($where)->get();
        } else {
            return $this->category->get();
        }
    }

    public function store($array){
        return $this->category->create($array);
    }

    public function update($array, $where){
        return $this->category->where($where)->update($array);
    }

    public function delete($id){
        return $this->category->destroy($id);
    }

    public function get_category_with_pagination($where, $request = null){
        $paginationLimit = null;

        if(isset($request['category_per_page']) && !empty($request['category_per_page'])) {
            $paginationLimit = $request['category_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $categoryQuery = $this->category->where(function ($query) use ($where, $request) {

            if(!empty($request['status'])) {
                $query->where('status', $request['status']);
            }

            if(!empty($request['category_search'])) {
                if(is_numeric($request['category_search'])) {
                    $query->orWhere('id', 'LIKE', "%{$request['category_search']}%");
                } else {
                    $query->orWhere('name', 'LIKE', "%{$request['category_search']}%");
                }
            }

            $query->where($where);
        });

        if(isset($request['export']) && $request['export'] == true) {
            return $categoryQuery->orderBy('id', 'DESC')->get()->fragment('category');
        } else {
            return $categoryQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->fragment('category')->onEachSide(2);
        }
    }
}

