<?php

namespace App\Repositories;
use App\Interfaces\DocumentHcpInterface;
use App\Models\DocumentHcp;

class DocumentHcpRepository implements DocumentHcpInterface
{
    private $document_hcp;
    public function __construct(DocumentHcp $document_hcp){
        $this->document_hcp = $document_hcp;
    }

    public function find_hcp_document($documentId, $hcpId){
        return $this->document_hcp->where('document_id', $documentId)->where('hcp_id', $hcpId)->first();
    }

    public function find_hcp_document_paginate($hcpId, $request = null){
        $paginationLimit = null;

        if(isset($request['document_per_page']) && !empty($request['document_per_page'])) {
            $paginationLimit = $request['document_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        return $this->document_hcp
        ->where(function ($query) use ($request, $hcpId) {
            $query->where('hcp_id', $hcpId);

            if(!empty($request['document_search'])) {
                $query->whereHas('document', function ($query) use ($request) {
                    $query->where('name', 'LIKE', "%{$request['document_search']}%");
                });
            }
        })
        ->with(['document' => function ($query) use ($request) {
            if(!empty($request['document_search'])) {
                $query->where('name', 'LIKE', "%{$request['document_search']}%");
            }
        }])->paginate($paginationLimit)->fragment('documents')->onEachSide(2);
    }

    public function get_doc_as_date($from,$to){
        return $this->document_hcp->with('document','hcp')->whereBetween('expiry_date',[$from,$to])->get();
    }

    public function getAll($where, $options = false){
        if ($options){
            return $this->document_hcp->where($where)->with('document', 'hcp')->get();
        }else{
            return $this->document_hcp->with('document', 'hcp')->get();
        }
    }

    public function store($array){
        return $this->document_hcp->create($array);
    }

    public function update($array, $where){
        return $this->document_hcp->where($where)->update($array);
    }

    public function delete($id){
        return $this->document_hcp->destroy($id);
    }

    public function api_hcp_documents($hcpId,  $request){
        $paginationLimit = config('constants.pagination_limit');

        return $this->document_hcp
        ->where('hcp_id', $hcpId)
        ->with('profession', 'level')
        ->whereHas('document', function ($query) use ($request) {
            $query->where('required_for', 'hcp');

            if(!empty($request['type'])){
                $query->where('doc_type', $request['type']);
            }

        })
        ->with(['document' => function ($query) use($request) {
            $query->where('required_for', 'hcp');

            if(!empty($request['type'])){
                $query->where('doc_type', $request['type']);
            }


        }])->paginate($paginationLimit);
    }

    public function update_or_create($where, $array){
        return $this->document_hcp->updateOrCreate($where, $array);
    }

    public function get_expiring_documents($request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
            unset($request['recent_per_page']);
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $expDocQuery = $this->document_hcp->where(function ($query) use ($request) {

            if(!empty($request['hcp_expiring_search'])) {
                $query->whereHas('hcp', function ($query) use ($request) {
                    $query->where('first_name', 'LIKE', "%{$request['hcp_expiring_search']}%");
                });
            }
            $query->where('show_in_notification', 'yes');

        })->with(['hcp' => function ($query) {
            $query->select('id', 'hcp_prefix', 'first_name', 'last_name', 'user_id');
        }]);

        if(isset($request['export']) && $request['export'] == true) {
            return $expDocQuery->orderBy('id', 'DESC')->get();
        } else {
            return $expDocQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->fragment('expiring')->onEachSide(2);
        }
    }

    public function get_last_submitted_documents($from, $to, $request=null){
        $paginationLimit = null;

        if(isset($request['recent_per_page']) && !empty($request['recent_per_page'])) {
            $paginationLimit = $request['recent_per_page'];
            unset($request['per_page']);
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $recentDocQuery = $this->document_hcp->where(function ($query) use ($request) {

                if(!empty($request['hcp_recent_search'])) {
                    $query->whereHas('hcp', function ($query) use ($request) {
                        $query->where('first_name', 'LIKE', "%{$request['hcp_recent_search']}%");
                    });
                }
            })
            ->whereBetween('updated_at',[$from,$to])
            ->with(['hcp' => function ($query) {
                $query->select('id', 'hcp_prefix', 'first_name', 'last_name', 'user_id');
            }]);

            if(isset($request['export']) && $request['export'] == true) {
                return $recentDocQuery->orderBy('id', 'DESC')->get();
            } else {
                return $recentDocQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->fragment('recent')->onEachSide(2);
            };
    }

    public function api_delete_hcp_profession_document($hcpId, $professionId, $levelId = null){
        return $this->document_hcp->where(function ($query) use ($hcpId, $professionId, $levelId) {
                $query->where('hcp_id', $hcpId)->where('profession_id', $professionId)->where('level_id', $levelId);
        })->delete();
    }

    public function api_get_hcp_document($where){
        return $this->document_hcp->where($where)->first();
    }

    public function api_get_hcp_expire_general_document($request = null){
        return $this->document_hcp->where(function ($query) use ($request) {

            if (isset($request['expiry_date']) && !empty($request['expiry_date'])) {
                $query->whereDate('expiry_date', '<=', $request['expiry_date']);
            }

            if (isset($request['hcp_id']) && !empty($request['hcp_id'])) {
                $query->where('hcp_id', $request['hcp_id']);
            }

        })->whereHas('document', function ($query) use ($request) {
            $query->where('required_for', 'hcp');
            $query->where('mandatory_status', 'yes');
            $query->where('doc_type', 'general-statement');
            $query->where('status', 'active');
        })->with(['document' => function ($query) use($request) {
            $query->where('required_for', 'hcp');
            $query->where('mandatory_status', 'yes');
            $query->where('doc_type', 'general-statement');
            $query->where('status', 'active');
        }])->get();
    }

    public function api_get_hcp_expire_profession_document($request = null){
        return $this->document_hcp->where(function ($query) use ($request) {

            if (isset($request['expiry_date']) && !empty($request['expiry_date'])) {
                $query->whereDate('expiry_date', '<=', $request['expiry_date']);
            }

            if (isset($request['profession_id']) && !empty($request['profession_id'])) {
                $query->where('profession_id', $request['profession_id']);
            }

            if (isset($request['hcp_id']) && !empty($request['hcp_id'])) {
                $query->where('hcp_id', $request['hcp_id']);
            }

        })->whereHas('document', function ($query) use ($request) {
            $query->where('required_for', 'hcp');
            $query->where('mandatory_status', 'yes');
            $query->where('doc_type', 'profession');
            $query->where('status', 'active');
        })->with(['document' => function ($query) use($request) {
            $query->where('required_for', 'hcp');
            $query->where('mandatory_status', 'yes');
            $query->where('doc_type', 'profession');
            $query->where('status', 'active');
        }])->get();
    }

    public function api_get_hcp_pending_approval_general_document($request = null){
        return $this->document_hcp->where(function ($query) use ($request) {

            if (isset($request['hcp_id']) && !empty($request['hcp_id'])) {
                $query->where('hcp_id', $request['hcp_id']);
            }

        })
        ->where(function ($query) use ($request) {
            $query->where('document_approval', '=', 'pending')->orWhere('document_approval', '=', 'pending-reapproval');
        })
        ->whereHas('document', function ($query) use ($request) {
            $query->where('required_for', 'hcp');
            $query->where('mandatory_status', 'yes');
            $query->where('doc_type', 'general-statement');
            $query->where('status', 'active');
        })->with(['document' => function ($query) use($request) {
            $query->where('required_for', 'hcp');
            $query->where('mandatory_status', 'yes');
            $query->where('doc_type', 'general-statement');
            $query->where('status', 'active');
        }])->get();
    }

    public function api_get_hcp_pending_approval_profession_document($request = null){
        return $this->document_hcp->where(function ($query) use ($request) {


            if (isset($request['profession_id']) && !empty($request['profession_id'])) {
                $query->where('profession_id', $request['profession_id']);
            }

            if (isset($request['hcp_id']) && !empty($request['hcp_id'])) {
                $query->where('hcp_id', $request['hcp_id']);
            }

        })
        ->where(function ($query) use ($request) {
            $query->where('document_approval', '=', 'pending')->orWhere('document_approval', '=', 'pending-reapproval');
        })->whereHas('document', function ($query) use ($request) {
            $query->where('required_for', 'hcp');
            $query->where('mandatory_status', 'yes');
            $query->where('doc_type', 'profession');
            $query->where('status', 'active');
        })->with(['document' => function ($query) use($request) {
            $query->where('required_for', 'hcp');
            $query->where('mandatory_status', 'yes');
            $query->where('doc_type', 'profession');
            $query->where('status', 'active');
        }])->get();
    }
}

