<?php

namespace App\Repositories;
use App\Interfaces\DocumentInterface;
use App\Models\Document;

class DocumentRepository implements DocumentInterface
{
    private $document;
    public function __construct(Document $document){
        $this->document = $document;
    }

    public function find_document($id){
        return $this->document->find($id);
    }

    public function get($where, $option=false, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        if ($option){
            $documentQuery = $this->document->where(function ($query) use ($where, $request) {

                if(!empty($request['search'])) {
                    $query->where('name', 'LIKE', "%{$request['search']}%");
                }

                $query->where($where);

            });

        } else {
            $documentQuery = $this->document;
        }

        if (isset($request['export']) && $request['export'] == true) {
                return $documentQuery->orderBy('id', 'DESC')->get();
        } else {
                return $documentQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function store($data){
        return $this->document->create($data);
    }

    public function update($array, $where){
        return $this->document->where($where)->update($array);
    }

    public function get_sort_data(){
        return $this->document->orderBy('id', 'desc')->first();
    }

    public function update_or_insert($check_ar,$update_ar){
        return $this->document->updateOrCreate($check_ar,$update_ar);
    }

    public function get_documents_facility_with_pagination($where, $facilityId = null, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $documentQuery = $this->document
        ->where('required_for', 'facility')
        ->where(function ($query) use ($where, $request) {

            if(!empty($request['search'])) {
                $query->where('name', 'LIKE', "%{$request['search']}%");
            }
            $query->where($where);
        })->where(function ($query) use ($where, $request) {

            if(!empty($request['professions'])) {
                $query->orWhereIn('profession_id', $request['professions']);
                $query->orWhere('profession_id', NULL);
            }

        })->with(['facility_document' => function ($query) use($facilityId, $request) {
            if (!is_null($facilityId)) {
                $query->where('facility_id', $facilityId);
            }
        }]);

        if(isset($request['export']) && $request['export'] == true) {
            return $documentQuery->orderBy('id', 'DESC')->get();
        } else {
            return $documentQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

}

