<?php

namespace App\Repositories;
use App\Interfaces\FacilityDocumentInterface;
use App\Models\FacilityDocument;

class FacilityDocumentRepository implements FacilityDocumentInterface
{
    private $facilityDocument;
    public function __construct(FacilityDocument $facilityDocument){
        $this->facility_document = $facilityDocument;
    }

    public function find_facility_document($documentId, $facilityId){
        return $this->facility_document->where('document_id', $documentId)->where('facility_id', $facilityId)->first();
    }

    public function find_facility_document_paginate($facilityId, $request = null){
        $paginationLimit = null;

        if(isset($request['document_per_page']) && !empty($request['document_per_page'])) {
            $paginationLimit = $request['document_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        return $this->facility_document->where(function ($query) use ($request, $facilityId) {
            $query->where('facility_id', $facilityId);

            if(!empty($request['document_search'])) {
                $query->whereHas('document', function ($query) use ($request) {
                    $query->where('name', 'LIKE', "%{$request['document_search']}%");
                });
            }
        })
        ->with(['document' => function ($query) use ($request) {
            if(!empty($request['document_search'])) {
                $query->where('name', 'LIKE', "%{$request['document_search']}%");
            }
        }])
        ->paginate($paginationLimit)->fragment('document')->onEachSide(2);
    }

    public function get_doc_as_date($from,$to){
        return $this->facility_document->with('document', 'facility')->whereBetween('expiry_date',[$from,$to])->get();
    }

    public function getAll($where, $options = false){
        if ($options){
            return $this->facility_document->where($where)->with('document', 'facility')->get();
        }else{
            return $this->facility_document->with('document', 'facility')->get();
        }
    }

    public function store($array){
        return $this->facility_document->create($array);
    }

    public function update($array, $where){
        return $this->facility_document->where($where)->update($array);
    }

    public function delete($id){
        return $this->facility_document->destroy($id);
    }

    public function api_facility_documents($facilityId,  $request){
        $paginationLimit = config('constants.pagination_limit');

        return $this->facility_document->where('facility_id', $facilityId)
        ->whereHas('document', function ($query) use ($request) {
            $query->where('required_for', 'facility');

            if(!empty($request['type'])){
                $query->where('doc_type', $request['type']);
            }

        })
        ->with(['document' => function ($query) use($request) {
            $query->where('required_for', 'facility');

            if(!empty($request['type'])){
                $query->where('doc_type', $request['type']);
            }

        }])->paginate($paginationLimit);
    }

    public function update_or_create($where, $array){
        return $this->facility_document->updateOrCreate($where, $array);
    }

    public function get_expiring_documents($request=null){
        $paginationLimit = config('constants.pagination_limit');

        return $this->facility_document->where(function ($query) use ($request) {
            if($request['facility'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            $query->where('show_in_notification', 'yes');
        })
        ->orderBy('id', 'DESC')->paginate($paginationLimit);
    }

    public function get_last_submitted_documents($from, $to, $request=null){
        $paginationLimit = config('constants.pagination_limit');

        return $this->facility_document->where(function ($query) use ($request) {
                if($request['facility'] !='') {
                    $query->where('facility_id', $request['facility']);
                }
            })
        ->whereBetween('updated_at',[$from,$to])
        ->orderBy('id', 'DESC')->paginate($paginationLimit);
    }
}

