<?php

namespace App\Repositories;
use App\Interfaces\FacilityGroupInterface;
use App\Models\FacilityGroup;
use DB;

class FacilityGroupRepository implements FacilityGroupInterface
{
    private $facilityGroup;
    public function __construct(FacilityGroup $facilityGroup){
        $this->facility_group = $facilityGroup;
    }

    public function get(){
        return $this->facility_group->all();
    }

    public function find_facility_group($id){
        return $this->facility_group->find($id);
    }

    public function getAll($where, $options = false, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        if ($options){
            $facilityQuery = $this->facility_group->where(function ($query) use ($where, $request) {

                if(!empty($request['status'])) {
                    $query->where('status', $request['status']);
                }

                if(!empty($request['search'])) {
                    if(is_numeric($request['search'])) {
                        $query->orWhere('id', 'LIKE', "%{$request['search']}%");
                    } else {
                        $query->orWhere('name', 'LIKE', "%{$request['search']}%");
                    }
                }

                if(!empty($request['facility_group_admin_id'])) {
                    $query->where('facility_group_admin_id', 'LIKE', '%"' . $request['facility_group_admin_id'] . '"%');
                    // $query->whereJsonContains('facility_group_admin_id', $request['facility_group_admin_id']);
                }

                $query->where($where);

            })->withCount('facilities');

            if(isset($request['export']) && $request['export'] == true) {
                return $facilityQuery->orderBy('id', 'DESC')->get();
            } else {
                return $facilityQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
            }

        }else{
            return $this->facility_group->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function store($array){
        return $this->facility_group->create($array);
    }

    public function update($array, $where){
        return $this->facility_group->where($where)->update($array);
    }

    public function delete($id){
        return $this->facility_group->destroy($id);
    }

    public function get_list($where,  $request = null){
        return $this->facility_group->where(function ($query) use ($where, $request) {
            $query->where($where);
            if(!empty($request['facility_group_admin_id'])) {
                $query->where('facility_group_admin_id', 'LIKE', '%"' . $request['facility_group_admin_id'] . '"%');
            }
            if(!empty($request['facility_group_ids'])) {
                $query->whereIn('id', $request['facility_group_ids']);
            }
        })->orderBy('name', 'ASC')->get();
    }

    public function get_facility_group_without_pagination($where, $options = false, $request = null){

        if ($options){
            $facilityQuery = $this->facility_group->where(function ($query) use ($where, $request) {

                if(!empty($request['status'])) {
                    $query->where('status', $request['status']);
                }

                if(!empty($request['search'])) {
                    if(is_numeric($request['search'])) {
                        $query->orWhere('id', 'LIKE', "%{$request['search']}%");
                    } else {
                        $query->orWhere('name', 'LIKE', "%{$request['search']}%");
                    }
                }
                if(!empty($request['facility_group_admin_id'])) {
                    // p('heyy');
                    $query->where('facility_group_admin_id', 'LIKE', '%"' . $request['facility_group_admin_id'] . '"%');
                    // $query->whereJsonContains('facility_group_admin_id', $request['facility_group_admin_id']);
                }

                if(!empty($request['facility_group_ids'])) {
                    $query->whereIn('id', $request['facility_group_ids']);
                }
                $query->where($where);

            })->withCount('facilities');

            if(isset($request['export']) && $request['export'] == true) {
                return $facilityQuery->orderBy('id', 'DESC')->get();
            } else {
                return $facilityQuery->orderBy('id', 'DESC')->get();
            }

        }else{
            return $this->facility_group->orderBy('id', 'DESC')->get();
        }
    }
}

