<?php

namespace App\Repositories;
use App\Interfaces\FacilityNameInterface;
use App\Models\FacilityName;

class FacilityNameRepository implements FacilityNameInterface
{
    private $facilityName;
    public function __construct(FacilityName $facilityName){
        $this->facility_name = $facilityName;
    }

    public function get(){
        return $this->facility_name->all();
    }

    public function find_facility_name($id){
        return $this->facility_name->find($id);
    }

    public function getAll($where, $options = false, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        if ($options){
            $facilityQuery = $this->facility_name->where(function ($query) use ($where, $request) {

                if(!empty($request['status'])) {
                    $query->where('status', $request['status']);
                }

                if(!empty($request['facility_group'])) {
                    $query->where('facility_group_id', $request['facility_group']);
                }

                if(!empty($request['state'])) {
                    $query->where('state_id', $request['state']);
                }

                if(!empty($request['search'])) {
                    if(is_numeric($request['search'])) {
                        $query->orWhere('id', 'LIKE', "%{$request['search']}%");
                    } else {
                        $query->orWhere('name', 'LIKE', "%{$request['search']}%");
                        $query->orWhere('address', 'LIKE', "%{$request['search']}%");
                        $query->orWhere('suburb_name', 'LIKE', "%{$request['search']}%");
                    }
                }

                $query->where($where);
            });

            if(isset($request['export']) && $request['export'] == true) {
                return $facilityQuery->orderBy('id', 'DESC')->get();
            } else {
                return $facilityQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
            }

        } else {
            return $this->facility_name->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function store($array){
        return $this->facility_name->create($array);
    }

    public function update($array, $where){
        return $this->facility_name->where($where)->update($array);
    }

    public function delete($id){
        return $this->facility_name->destroy($id);
    }

    public function get_list($where){
        return $this->facility_name->where(function ($query) use ($where) {
            $query->where($where);
        })->orderBy('id', 'DESC')->get();
    }
}

