<?php

namespace App\Repositories;
use App\Interfaces\FacilityInterface;
use App\Models\Facility;
use DB;

class FacilityRepository implements FacilityInterface
{
    private $facility;
    public function __construct(Facility $facility){
        $this->facility = $facility;
    }

    public function get(){
        return $this->facility->all();
    }

    public function find_facility($id){
        return $this->facility->with('country', 'state', 'city', 'suburb','facility_group')
            ->with(['plans' => function ($query)  {
                $query->orderBy('id', 'DESC');
            }])->find($id);
    }

    public function getAll($where, $options = false, $request = null){
        if($options){
            return $this->facility->where(function ($query) use ($where, $request) {

                if(!empty($request['state_id'])) {
                    $query->where('state_id', $request['state_id']);
                }

                if(!empty($request['name'])) {
                    $query->where('name', 'LIKE', "%{$request['name']}%");
                }

                if(!empty($request['assigned_facilities'])) {
                    $query->whereIn('id', $request['assigned_facilities']);
                }

                if(!empty($request['facility_group_ids'])) {
                    $query->whereIn('facility_group_id', $request['facility_group_ids']);
                }

                $query->where($where);

            })->with('country', 'state', 'city', 'suburb', 'facility_name')->orderBy('id', 'DESC')->get();
        } else {
            return $this->facility->with('country', 'state', 'city', 'suburb')->orderBy('id', 'DESC')->get();
        }
    }

    public function store($array){
        return $this->facility->create($array);
    }

    public function update($array, $where){
        return $this->facility->where($where)->update($array);
    }

    public function delete($id){
        return $this->facility->destroy($id);
    }

    public function get_facility_with_pagination($where, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $facilityQuery = $this->facility->where(function ($query) use ($where, $request) {
            if(!empty($request['states'])) {
                $query->whereIn('state_id', $request['states']);
            }
            if(!empty($request['status'])) {
                $query->where('status', $request['status']);
            }
            if(!empty($request['state_id'])) {
                $query->where('state_id', $request['state_id']);
            }

            if(!empty($request['plan_type']) || !empty($request['plan_cycle']) || !empty($request['plan_end_date'])) {
                $query->whereHas('plans', function ($query) use ($where, $request) {
                    $query->where('plans.status', 'active');

                    if(!empty($request['plan_type'])) {
                        $query->where('facility_plan.plan_id', $request['plan_type']);
                    }

                    if(!empty($request['plan_cycle'])) {
                        $query->where('facility_plan.plan_cycle', $request['plan_cycle']);
                    }

                    if(!empty($request['plan_end_date'])) {
                        $query->where('facility_plan.expiry_date', $request['plan_end_date']);
                    }
                });
            }

            $query->where($where);
        })
        ->where(function ($query) use ($where, $request) {
            if(isset($request['search']) && !empty($request['search'])) {
                if(is_numeric($request['search'])) {
                    $query->orWhere('id', 'LIKE', "%{$request['search']}%");
                } else {
                    $query->orWhere('name', 'LIKE', "%{$request['search']}%");
                    $query->orWhere('address', 'LIKE', "%{$request['search']}%");
                    $query->orWhere('suburb_name', 'LIKE', "%{$request['search']}%");
                }
            }
        })
        ->with(['user' => function ($query) use ($where, $request) {
            if(isset($request['search']) && !empty($request['search'])) {
                $query->orWhere(function ($query) use ($where, $request) {
                    $query->orWhere('email', 'LIKE', "%{$request['search']}%");
                });
            }
        }])
        ->with('country', 'state', 'city', 'suburb')
        ->with(['plans' => function ($query) {
            $query->where('plans.status', 'active');

            if(!empty($request['plan_type'])) {
                $query->where('facility_plan.plan_id', $request['plan_type']);
            }

            if(!empty($request['plan_cycle'])) {
                $query->where('facility_plan.plan_cycle', $request['plan_cycle']);
            }

            if(!empty($request['plan_end_date'])) {
                $query->where('facility_plan.expiry_date', $request['plan_end_date']);
            }

        }]);

        if(isset($request['shortby_filter']) && !empty($request['shortby_filter'])) {
            if ($request['shortby_filter'] == '1') {
                $facilityQuery->orderBy('id', 'ASC');
            } else if($request['shortby_filter'] == '2') {
                $facilityQuery->orderBy('id', 'DESC');
            } else {
                $facilityQuery->orderBy('id', 'DESC');
            }
        } else {
            $facilityQuery->orderBy('id', 'DESC');
        }

        if(isset($request['export']) && $request['export'] == true) {
            return $facilityQuery->get();
        } else {
            return $facilityQuery->paginate($paginationLimit)->onEachSide(2);
        }

    }

    public function get_facility_shift_with_state(){

        return $this->facility->with(['state' => function ($query)  {
            $query->where('shift_status', '0');
        }])
        ->whereHas('shifts', function ($query)  {
            $query->where('shift_status', '0');
        })
        ->with(['shifts' => function ($query)  {
            $query->where('shift_status', '0');
        }])->get();
    }

    public function get_facility_for_shift($request = null){
        $facilityQuery = $this->facility->where(function ($query) use ($request) {

            if(!empty($request['states'])) {
                $query->whereIn('state_id', $request['states']);
            }

            if(!empty($request['status'])) {
                $query->where('status', $request['status']);
            }

            if(!empty($request['facility_id'])) {
                $query->where('id', $request['facility_id']);
            }

            if(!empty($request['state_id'])) {
                $query->where('state_id', $request['state_id']);
            }

            if(!empty($request['facility_group_id'])) {
                $query->where('facility_group_id', $request['facility_group_id']);
            }

            if(!empty($request['search'])) {
                $query->where('name', 'LIKE', "%{$request['search']}%");
            }

            if (!empty($request['profession_id'])) {
                $query->whereHas('plans', function ($query) use ($request) {
                    $query->where('facility_plan.status', 'active');
                    $query->whereHas('professions', function ($query) use ($request) {
                        $query->where('profession_id', $request['profession_id']);
                    });
                });
            }
            $query->where(['status' => 'active']);
        })
        ->with(['plans' => function ($query) use ($request) {
            $query->where('facility_plan.status', 'active');
            if (!empty($request['profession_id'])) {
                $query->with(['professions' => function ($query) use ($request) {
                    $query->where('profession_id', $request['profession_id']);
                }]);
            }
        }]);

        if(!empty($request['latitude']) && !empty($request['longitude']) && !empty($request['radius'])) {
            $facilityQuery->select('id','name', 'facility_group_id', 'address', 'latitude', 'longitude', DB::raw('( 111.111 * ( DEGREES( ACOS( COS(RADIANS('.$request['latitude'].')) * COS(RADIANS(latitude)) * COS( RADIANS('.$request['longitude'].' - longitude)) + SIN(RADIANS('.$request['latitude'].')) * SIN(RADIANS(latitude)))))) AS distance'))->having("distance", "<", $request['radius']);
        } else {
            $facilityQuery->select('id', 'name', 'facility_group_id', 'address', 'latitude', 'longitude');
        }

        return $facilityQuery->get();
    }

    public function get_facility_for_shift_invoice_generate($request = null){
        return $this->facility->where(function ($query) use ($request) {

            $query->whereHas('shifts', function ($query) use ($request) {
                $query->where('shift_status', '!=', '0');
                $query->where('shift_status', '!=', '1');
                $query->where('shift_status', '!=', '2');
                $query->where('shift_status', '!=', '4');
                $query->where('shift_status', '!=', '5');
                $query->where('hcp_id', '!=', null);

                if (isset($request['shift_approved_time']) && !empty($request['shift_approved_time'])) {
                    $query->whereDate('shift_approved_time', '<=', $request['shift_approved_time']);
                }

                $query->whereHas('transactions', function ($query) use ($request) {
                    $query->where('amount_for', 'facility');
                    $query->where('invoice_id', null);
                    $query->where('status', '!=', 'cancelled');
                    $query->where('status', '!=', 'completed');
                    $query->where('status', '!=', 'overdue');

                    $query->where(function ($query) use ($request) {
                        $query->orWhere('amount_type', 'shift');
                        $query->orWhere('amount_type', 'shift-cancel-penalty');
                    });
                });
            });
        })
        ->with(['shifts' => function ($query) use ($request) {
            $query->where('shift_status', '!=', '0');
            $query->where('shift_status', '!=', '1');
            $query->where('shift_status', '!=', '2');
            $query->where('shift_status', '!=', '4');
            $query->where('shift_status', '!=', '5');
            $query->where('hcp_id', '!=', null);

            if (isset($request['shift_approved_time']) && !empty($request['shift_approved_time'])) {
                $query->whereDate('shift_approved_time', '<=', $request['shift_approved_time']);
            }

            $query->select('id','shift_prefix', 'shift_status', 'hcp_id', 'facility_id', 'shift_approved_time');

            $query->whereHas('transactions', function ($query) use ($request) {
                $query->where('amount_for', 'facility');
                $query->where('invoice_id', null);
                $query->where('status', '!=', 'cancelled');
                $query->where('status', '!=', 'completed');
                $query->where('status', '!=', 'overdue');

                $query->where(function ($query) use ($request) {
                    $query->orWhere('amount_type', 'shift');
                    $query->orWhere('amount_type', 'shift-cancel-penalty');
                });
            });

            $query->with(['transactions' => function ($query) use ($request) {
                $query->where('amount_for', 'facility');
                $query->where('invoice_id', null);
                $query->where('status', '!=', 'cancelled');
                $query->where('status', '!=', 'completed');
                $query->where('status', '!=', 'overdue');

                $query->where(function ($query) use ($request) {
                    $query->orWhere('amount_type', 'shift');
                    $query->orWhere('amount_type', 'shift-cancel-penalty');
                });
            }]);

        }])->whereIn('id',[1])->select('id','name', 'address', 'state_id', 'user_id', 'contact_number', 'status','additional_email')->get();
    }

    public function api_find_facility($id){
        return $this->facility->with('country', 'state', 'city', 'suburb','facility_group')->find($id);
    }
}

