<?php

namespace App\Repositories;
use App\Interfaces\FavouritesAndBlocklistInterface;
use App\Models\FavouritesAndBlocklist;

class FavouritesAndBlocklistRepository implements FavouritesAndBlocklistInterface
{
    private $favouritesAndBlocklist;
    public function __construct(FavouritesAndBlocklist $favouritesAndBlocklist){
        $this->favouritesAndBlocklist = $favouritesAndBlocklist;
    }

    public function get_facilities_favourites($facilityId){
        return $this->favouritesAndBlocklist->where('facility_id', $facilityId)->where('marked_by', 'facility')
        ->where('type', 'favourite')->with('hcp')->get();
    }

    public function get_facilities_blocklist($facilityId){
        return $this->favouritesAndBlocklist->where('facility_id', $facilityId)
                ->where('marked_by', 'facility')->where('type', 'blocked')->with('hcp')->get();
    }

    public function get_hpc_favourites($hcpId, $request = null){
        return $this->favouritesAndBlocklist->where('hcp_id', $hcpId)
        ->where('marked_by', 'facility')->where('type', 'favourite')
        ->whereHas('facility', function ($query) use ($request) {

            $query->select('id', 'facility_prefix', 'user_id', 'name', 'address', 'suburb_name', 'state_id');

            if(!empty($request['state_id']) && $request['filter_type'] == 'favourites') {
                $query->where('state_id', $request['state_id']);
            }

        })->with(['facility' => function ($query) {

            $query->select('id', 'facility_prefix', 'user_id', 'name', 'address', 'suburb_name', 'state_id');

            if(!empty($request['state_id']) && $request['filter_type'] == 'favourites') {
                $query->where('state_id', $request['state_id']);
            }

        }])->get();
    }

    public function get_hcp_blocklist($hcpId, $request = null){
        return $this->favouritesAndBlocklist->where('hcp_id', $hcpId)
        ->where('marked_by', 'facility')->where('type', 'blocked')->whereHas('facility', function ($query) use ($request) {

            $query->select('id', 'facility_prefix', 'user_id', 'name', 'address', 'suburb_name', 'state_id');

            if(!empty($request['state_id']) && $request['filter_type'] == 'blocklist') {
                $query->where('state_id', $request['state_id']);
            }

        })->with(['facility' => function ($query) {

            $query->select('id', 'facility_prefix', 'user_id', 'name', 'address', 'suburb_name', 'state_id');

            if(!empty($request['state_id']) && $request['filter_type'] == 'blocklist') {
                $query->where('state_id', $request['state_id']);
            }

        }])->get();
    }

    public function delete($id){
        return $this->favouritesAndBlocklist->destroy($id);
    }

    public function store($array){
        return $this->favouritesAndBlocklist->create($array);
    }

    public function get_hcp_mark_favorite($facilityId, $hcpId){
        return $this->favouritesAndBlocklist->where('facility_id', $facilityId)->where('hcp_id', $hcpId)->where('marked_by', 'facility')->where('type', 'favourite')->count();
    }

    public function get_hcp_mark_blocklist($facilityId, $hcpId){
        return $this->favouritesAndBlocklist->where('facility_id', $facilityId)->where('hcp_id', $hcpId)->where('marked_by', 'facility')->where('type', 'blocked')->count();
    }

    public function remove_hcp_from_favorite($facilityId, $hcpId){
        return $this->favouritesAndBlocklist->where('facility_id', $facilityId)->where('hcp_id', $hcpId)->where('type', 'favourite')->delete();
    }

    public function remove_hcp_from_blocklist($facilityId, $hcpId){
        return $this->favouritesAndBlocklist->where('facility_id', $facilityId)->where('hcp_id', $hcpId)->where('type', 'blocked')->delete();
    }


    public function find($id){
        return $this->favouritesAndBlocklist->find($id);
    }

}

