<?php

namespace App\Repositories;
use App\Interfaces\HcpProfessionInterface;
use App\Models\HcpProfession;

class HcpProfessionRepository implements HcpProfessionInterface
{
    private $hcpProfession;
    public function __construct(HcpProfession $hcpProfession){
        $this->hcp_profession = $hcpProfession;
    }

    public function getAll($where,$options = false){
        if ($options){
            return $this->hcp_profession->where($where)->get();
        }else{
            return $this->hcp_profession->get();
        }
    }

    public function store($array){
        return $this->hcp_profession->create($array);
    }

    public function update($array, $where){
        return $this->hcp_profession->where($where)->update($array);
    }

    public function delete($id){
        return $this->hcp_profession->destroy($id);
    }

    public function update_or_create($where, $array){
        return $this->hcp_profession->updateOrCreate($where, $array);
    }

    public function api_get_hcp_professions($user){
        return $this->hcp_profession
        ->where(function ($query) use ($user) {
            $query->where('hcp_id', $user->hcp->id);
        })
        ->with('profession', 'category', 'level')
        ->with([
            'buddy_shift_request' => function ($query) use ($user) {
                $query->where('hcp_id', $user->hcp->id);
                $query->orderBy('id', 'DESC');

            },
        ])
        ->get();
    }

    public function api_get_hcp_professions_with_document($user, $request = null){
        return $this->hcp_profession
        ->where(function ($query) use ($user) {
            $query->where('hcp_id', $user->hcp->id);
        })
        ->with([
            'category' => function ($query) use ($user) {
                $query->orderBy('id', 'DESC');
            },
            'profession' => function ($query) use ($user) {
                $query->withCount([
                    'profession_documents' => function ($query) use ($user) {
                        $query->whereHas('document', function($query) use($user){
                            $query->where('status', 'active');
                        });
                    }
                ]);
                $query->withCount([
                    'profession_documents as mandatory_documents_count' => function ($query) use ($user) {
                        $query->whereHas('document', function($query) use($user){
                            $query->where('status', 'active');
                            $query->where('mandatory_status', 'yes');
                        });
                    }
                ]);
                $query->withCount([
                    'hcp_documents as uploaded_mandatory_documents_count' => function ($query) use ($user) {
                        $query->where('hcp_id', $user->hcp->id);
                        $query->whereHas('document', function($query) use($user){
                            $query->where('mandatory_status', 'yes');
                        });
                    }
                ]);
                $query->orderBy('id', 'DESC');
            },
            'level' => function ($query) use ($user) {
                $query->orderBy('id', 'DESC');
            },
        ])
        ->get();
    }

    public function api_find_hcp_professions($id){
        return $this->hcp_profession->with('category', 'profession', 'level')->find($id);
    }

    public function find_last_hcp_profession($where){
        return $this->hcp_profession->where($where)->orderBy('id', 'DESC')->first();
    }

    public function api_get_pending_mandatory_profession_documents($user, $request = null){
        return $this->hcp_profession
        ->where(function ($query) use ($user) {
            $query->where('hcp_id', $user->hcp->id);
        })
        ->with([
            'category' => function ($query) use ($user) {
                $query->orderBy('id', 'DESC');
            },
            'profession' => function ($query) use ($user) {
                $query->whereHas('profession_documents', function ($query) use ($user) {
                    $query->whereHas('document', function($query) use($user){
                        $query->where('status', 'active');
                        $query->where('mandatory_status', 'yes');
                    });
                });

                $query->withCount([
                    'profession_documents' => function ($query) use ($user) {
                        $query->whereHas('document', function($query) use($user){
                            $query->where('status', 'active');
                            $query->where('mandatory_status', 'yes');
                        });
                    }
                ]);

                $query->withCount([
                    'hcp_documents' => function ($query) use ($user) {
                        $query->where('hcp_id', $user->hcp->id);
                        $query->whereHas('document', function($query) use($user){
                            $query->where('mandatory_status', 'yes');
                        });
                    }
                ]);
                $query->orderBy('id', 'DESC');
            },
            'level' => function ($query) use ($user) {
                $query->orderBy('id', 'DESC');
            },
        ])
        ->get();
    }
}

