<?php

namespace App\Repositories;
use App\Interfaces\HcpProfessionRequestInterface;
use App\Models\HcpProfessionRequest;
use Illuminate\Support\Facades\DB;

class HcpProfessionRequestRepository implements HcpProfessionRequestInterface
{
    private $hcpProfessionRequest;
    public function __construct(HcpProfessionRequest $hcpProfessionRequest){
        $this->hcp_profession_request = $hcpProfessionRequest;
    }

    public function getAll($where,$options = false){
        if ($options){
            return $this->hcp_profession_request->where($where)->get();
        } else {
            return $this->hcp_profession_request->get();
        }
    }

    public function store($array){
        return $this->hcp_profession_request->create($array);
    }

    public function update($array, $where){
        return $this->hcp_profession_request->where($where)->update($array);
    }

    public function delete($id){
        return $this->hcp_profession_request->destroy($id);
    }

    public function update_or_create($where, $array){
        return $this->hcp_profession_request->updateOrCreate($where, $array);
    }

    public function get_hcp_profession_requests_with_pagination($where, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $requestQuery = $this->hcp_profession_request->where(function ($query) use ($where, $request) {

            if(!empty($request['search'])) {
                if(is_numeric($request['search'])) {
                    $query->where('id', 'LIKE', "%{$request['search']}%");
                } else {
                    $query->whereHas('hcp', function ($query) use ($request) {
                        $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['search']).'%');
                    });
                }
            }

            $query->where($where);
        })->with(['hcp' => function ($query) use ($request) {
            if(!empty($request['search']) && !is_numeric($request['search'])) {
                $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['search']).'%');
            }
        }]);

        if(isset($request['export']) && $request['export'] == true) {
            return $requestQuery->orderBy('id', 'DESC')->get();
        } else {
            return $requestQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }

    }

    public function find_hcp_profession_request($id){
        return $this->hcp_profession_request->find($id);
    }

    public function get_hcp_profession_request($where){
        return $this->hcp_profession_request->where($where)->first();
    }
}

