<?php

namespace App\Repositories;
use App\Interfaces\LevelInterface;
use App\Models\Level;

class LevelRepository implements LevelInterface
{
    private $level;
    public function __construct(Level $level){
        $this->level = $level;
    }

    public function get($where = null){
        return $this->level->where($where)->get();
    }

    public function find_level($id){
        return $this->level->find($id);
    }

    public function getAll($where, $options = false){
        if($options){
            return $this->level->where($where)->get();
        }else{
            return $this->level->all();
        }
    }

    public function store($array){
        return $this->level->create($array);
    }

    public function update($array, $where){
        return $this->level->where($where)->update($array);
    }

    public function delete($id){
        return $this->level->destroy($id);
    }

    public function get_level_with_pagination($where, $request = null){
        $paginationLimit = null;

        if(isset($request['level_per_page']) && !empty($request['level_per_page'])) {
            $paginationLimit = $request['level_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $levelQuery = $this->level->where(function ($query) use ($where, $request) {

            if(!empty($request['status'])) {
                $query->where('status', $request['status']);
            }

            if(!empty($request['level_search'])) {
                if(is_numeric($request['level_search'])) {
                    $query->orWhere('id', 'LIKE', "%{$request['level_search']}%");
                } else {
                    $query->orWhere('name', 'LIKE', "%{$request['level_search']}%");
                }
            }

            $query->where($where);
        });

        if(isset($request['export']) && $request['export'] == true) {
            return $levelQuery->orderBy('id', 'DESC')->get()->fragment('level');
        } else {
            return $levelQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->fragment('level')->onEachSide(2);
        }
    }
}

