<?php

namespace App\Repositories;
use App\Interfaces\NotificationInterface;
use App\Models\Notification;
use Carbon\Carbon;

class NotificationRepository implements NotificationInterface
{
    private $notification;
    public function __construct(Notification $notification){
        $this->notification = $notification;
    }

    public function get($where, $option=false){
        $paginationLimit = config('constants.pagination_limit');
        if($option){
            return $this->notification->where($where)->with('facility')->with('hcp')->orderBy('date_time', 'DESC')
            ->paginate($paginationLimit)->onEachSide(2);
        }else{
            return $this->notification->get();
        }
    }

    public function store($array){
        return $this->notification->create($array);
    }

    public function get_sort_data(){
        return $this->notification->orderBy('id', 'desc')->first();
    }

    public function api_get_notifications($user, $request){
        $paginationLimit = config('constants.pagination_limit');

        return $this->notification->where(function ($query) use ($user, $request) {
            $query->where('send_to', 'hcp');
        })
        ->where(function ($query) use ($user, $request) {
            $query->where('hcp_id', $user->hcp->id);
        })
        ->orWhere(function ($query) use ($user, $request) {
            $query->where('send_to', 'all-hcp');
        })
        ->with(['shift' => function ($query) use ($request) {
            $query->select('id', 'shift_prefix', 'shift_type');
        }])->whereDate('created_at', '>', Carbon::now()->subDays(30))->orderBy('id', 'DESC')->paginate($paginationLimit);

    }

    public function get_notifications($request, $limit = null){

        if (!empty($limit)) {
            return $this->notification->where(function ($query) use ($request) {
                if(isset($request['type']) && $request['type'] == 'admin') {
                    $query->where('send_to', 'admin')->orWhere('sent_by', 'admin');
                }
            })
            ->where(function ($query) use ($request) {
                if(isset($request['type']) && $request['type'] == 'facility') {
                    $query->orWhere('send_to', 'all-facility');
                    if(isset($request['facility_id']) && !empty($request['facility_id'])){
                        $query->orWhereRaw('NOT FIND_IN_SET('.$request['facility_id'].', read_facilities)');
                        $query->orWhere('facility_id', $request['facility_id']);
                    }
                }
            })
            ->whereDate('created_at', '>', Carbon::now()->subDays(30))
            ->with(['facility' => function ($query) use ($request) {
                $query->select('id', 'facility_prefix', 'name', 'state_id');
            }])->with(['shift' => function ($query) use ($request) {
                $query->select('id', 'shift_prefix', 'state_id');
            }])->with(['hcp' => function ($query) use ($request) {
                $query->select('id', 'hcp_prefix', 'state_id', 'first_name', 'last_name');
            }])->orderBy('id', 'DESC')->paginate($limit);

        } else {
            return $this->notification->where(function ($query) use ($request) {
                if(isset($request['type']) && $request['type'] == 'admin') {
                    $query->where('send_to', 'admin')->orWhere('sent_by', 'admin');
                }
            })
            ->where(function ($query) use ($request) {
                if(isset($request['type']) && $request['type'] == 'facility') {
                    $query->orWhere('send_to', 'all-facility');
                    if(isset($request['facility_id']) && !empty($request['facility_id'])){
                        $query->orWhereRaw('NOT FIND_IN_SET('.$request['facility_id'].', read_facilities)');
                        $query->orWhere('facility_id', $request['facility_id']);
                    }
                }
            })
            ->whereDate('created_at', '>', Carbon::now()->subDays(30))
            ->with(['facility' => function ($query) use ($request) {
                $query->select('id', 'facility_prefix', 'name', 'state_id');
            }])->with(['facility' => function ($query) use ($request) {
                $query->select('id', 'facility_prefix', 'name', 'state_id');
            }])->with(['shift' => function ($query) use ($request) {
                $query->select('id', 'shift_prefix', 'state_id');
            }])->with(['hcp' => function ($query) use ($request) {
                $query->select('id', 'hcp_prefix', 'state_id', 'first_name', 'last_name');
            }])->orderBy('id', 'DESC')->get();
        }

    }

    public function update($array, $where){
        return $this->notification->where($where)->update($array);
    }


}

