<?php

namespace App\Repositories;
use App\Interfaces\ProfessionInterface;
use App\Models\Profession;

class ProfessionRepository implements ProfessionInterface
{
    private $profession;
    public function __construct(Profession $profession){
        $this->profession = $profession;
    }

    public function get($where = null){
        return $this->profession->where($where)->orderBy('name', 'ASC')->get();
    }

    public function find_profession($id){
        return $this->profession->find($id);
    }

    public function getAll($where, $options = false, $request = null){
        if($options){
            return $this->profession
            ->where(function ($query) use ($where, $request) {

                if(isset($request['hcp_profession_ids']) && count($request['hcp_profession_ids'])) {
                    $query->whereNotIn('id', $request['hcp_profession_ids']);
                }

                $query->where($where);
            })
            ->with('document')->with('document_configuration.document')
            ->orderByRaw('ISNULL(plan_list_order), plan_list_order ASC')->get();
        }else{
            return $this->profession->with('document')->with('document_configuration.document')->all();
        }
    }

    public function store($array){
        return $this->profession->create($array);
    }

    public function update($array, $where){
        return $this->profession->where($where)->update($array);
    }

    public function delete($id){
        return $this->profession->destroy($id);
    }

    public function get_profession_with_pagination($where, $request = null){
        $paginationLimit = null;

        if(isset($request['profession_per_page']) && !empty($request['profession_per_page'])) {
            $paginationLimit = $request['profession_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $professionQuery =  $this->profession->where(function ($query) use ($where, $request) {

            if(!empty($request['status'])) {
                $query->where('status', $request['status']);
            }

            if(!empty($request['profession_search'])) {
                if(is_numeric($request['profession_search'])) {
                    $query->orWhere('id', 'LIKE', "%{$request['profession_search']}%");
                } else {
                    $query->orWhere('name', 'LIKE', "%{$request['profession_search']}%");
                }
            }

            $query->where($where);
        });

        if(isset($request['export']) && $request['export'] == true) {
            return $professionQuery->orderBy('id', 'DESC')->get();
        } else {
            return $professionQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->fragment('profession')->onEachSide(2);
        }
    }

    public function api_get_profession_with_documents($request = null){
        return $this->profession->where(function ($query) use ($request) {
            if(!empty($request['profession_id'])) {
                $query->where('id', $request['profession_id']);
            }

            $query->whereHas('profession_documents', function($query) use($request){
                $query->whereHas('document', function($query) use($request){
                    $query->where('status', 'active');
                });
                $query->with(['document' => function ($query) use ($request) {
                    $query->where('status', 'active');
                }]);
            });

        })
        ->with([
            'profession_documents' => function ($query) use ($request) {
                $query->whereHas('document', function($query) use($request){
                    $query->where('status', 'active');
                });
                $query->with(['document' => function ($query) use ($request) {
                    $query->where('status', 'active');

                    $query->with(['hcp_document' => function ($query) use ($request) {
                        $query->where('profession_id', $request['profession_id']);
                        $query->where('hcp_id', $request['hcp_id']);
                    }]);
                }]);

            }
        ])->get();
    }

}

