<?php

namespace App\Repositories;
use App\Interfaces\PublicHolidayInterface;
use App\Models\PublicHoliday;

class PublicHolidayRepository implements PublicHolidayInterface
{
    private $publicHoliday;
    public function __construct(PublicHoliday $publicHoliday){
        $this->public_holiday = $publicHoliday;
    }

    public function find_public_holiday($id){
        return $this->public_holiday->with('states')->find($id);
    }

    public function getAll($where, $options = false, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        if($options){
            $holidayQuery = $this->public_holiday->where(function ($query) use ($where, $request) {

                if(isset($request['status']) && $request['status'] !='') {
                    $query->where('status', $request['status']);
                }

                if(isset($request['state']) && $request['state'] !='') {
                    $query->whereHas('states', function($query) use($request){
                        $query->where('state_id', $request['state']);
                    });
                }

                if(!empty($request['date_range'])) {
                    $date = explode('to', $request['date_range']);
                    $query->whereBetween('holiday_date', [trim($date[0]), trim($date[1])]);
                }

                if(!empty($request['search'])) {
                    $query->where('name', 'LIKE', "%{$request['search']}%");
                }

                $query->where($where);

            })->with('states');

            if(isset($request['export']) && $request['export'] == true) {
                return $holidayQuery->orderBy('holiday_date', 'DESC')->get();
            } else {
                return $holidayQuery->orderBy('holiday_date', 'DESC')->paginate($paginationLimit)->fragment('facility-rating')->onEachSide(2);
            }

        }else{
            return $this->public_holiday->orderBy('holiday_date', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function store($array){
        return $this->public_holiday->create($array);
    }

    public function update($array, $where){
        return $this->public_holiday->where($where)->update($array);
    }

    public function delete($id){
        return $this->public_holiday->destroy($id);
    }

    public function get_public_holiday_by_state($where, $stateId = null){
        return $this->public_holiday->where($where)
        ->where('status', 'active')
        ->whereHas('states', function ($query) use ($stateId) {

            if(!empty($stateId)) {
                $query->where('state_id', $stateId);
            }

        })
        ->with(['states' => function ($query) use ($stateId) {

            if(!empty($stateId)) {
                $query->where('state_id', $stateId);
            }

        }])->first();
    }

    public function get_public_holiday_by_state_with_pagination($where, $stateId = null, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $holidayQuery = $this->public_holiday->where(function ($query) use ($where, $request, $stateId) {

            $query->whereHas('states', function ($query) use ($stateId) {
                if(!empty($stateId)) {
                    $query->where('state_id', $stateId);
                }
            });

            if(isset($request['status']) && $request['status'] !='') {
                $query->where('status', $request['status']);
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereBetween('holiday_date', [trim($date[0]), trim($date[1])]);
            }

            $query->where($where);

        })
        ->with(['states' => function ($query) use ($stateId) {

            if(!empty($stateId)) {
                $query->where('state_id', $stateId);
            }

        }]);

        if(isset($request['export']) && $request['export'] == true) {
            return $holidayQuery->orderBy('holiday_date', 'DESC')->get();
        } else {
            return $holidayQuery->orderBy('holiday_date', 'DESC')->paginate($paginationLimit)->fragment('facility-rating')->onEachSide(2);
        }
    }
}

