<?php

namespace App\Repositories;
use App\Interfaces\RatingReviewInterface;
use App\Models\RatingReview;
use DB;
use Carbon\Carbon;

class RatingReviewRepository implements RatingReviewInterface
{
    private $ratingReview;
    public function __construct(RatingReview $ratingReview){
        $this->ratingReview = $ratingReview;
    }

    public function get($where, $option=false, $request = null){
        $paginationLimit = config('constants.pagination_limit');

        if($option){

            return $this->ratingReview->where(function ($query) use ($where, $request) {

                if($request['status'] !='') {
                    $query->where('status', $request['status']);
                }

                if($request['facility'] !='') {
                    $query->where('facility_id', $request['facility']);
                }

                if($request['hcp'] !='') {
                    $query->where('hcp_id', $request['hcp']);
                }

                if(!empty($request['date_range'])) {
                    $date = explode('to', $request['date_range']);
                    $query->whereDate('created_at', '>=', trim($date[0]))->whereDate('created_at', '<=', trim($date[1]));
                }

                $query->where($where);
            })
            ->with(['shift' => function ($query) {
                $query->select('id', 'shift_prefix', 'state_id');
            }])->with(['category' => function ($query) {
                $query->select('id', 'name');
            }])->with(['profession' => function ($query) {
                $query->select('id', 'name');
            }])->with(['facility' => function ($query) {
                $query->select('id', 'facility_prefix', 'name');
            }])->with(['hcp' => function ($query) {
                $query->select('id', 'hcp_prefix', 'first_name', 'last_name');
            }])
            ->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);

        } else {
            return $this->ratingReview
            ->with(['shift' => function ($query) {
                $query->select('id', 'shift_prefix');
            }])->with(['category' => function ($query) {
                $query->select('id', 'name');
            }])->with(['profession' => function ($query) {
                $query->select('id', 'name');
            }])->with(['facility' => function ($query) {
                $query->select('id', 'facility_prefix', 'name');
            }])->with(['hcp' => function ($query) {
                $query->select('id', 'hcp_prefix', 'first_name', 'last_name');
            }])
            ->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function store($array){
        return $this->ratingReview->create($array);
    }

    public function update($array, $where){
        return $this->ratingReview->where($where)->update($array);
    }

    public function get_facility_ratings($request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $ratingQuery = $this->ratingReview->where(function ($query) use ($request) {

            if(isset($request['status']) && $request['status'] !='') {
                $query->where('status', $request['status']);
            }

            if(isset($request['facility']) && $request['facility'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(isset($request['facilities']) && $request['facilities'] !='') {
                $query->whereIn('facility_id', $request['facilities']);
            }

            if(isset($request['hcp']) && $request['hcp'] !='') {
                $query->where('hcp_id', $request['hcp']);
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereDate('created_at', '>=', trim($date[0]))->whereDate('created_at', '<=', trim($date[1]));
            }

            if(!empty($request['hcp_search'])) {
                if(is_numeric($request['hcp_search'])) {
                    $query->where('id', 'LIKE', "%{$request['hcp_search']}%");
                } else {
                    $query->whereHas('hcp', function ($query) use ($request) {
                        $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['hcp_search']).'%');
                    });
                }
            }

            if(!empty($request['facility_search'])) {
                if(is_numeric($request['facility_search'])) {
                    $query->where('id', 'LIKE', "%{$request['facility_search']}%");
                } else {
                    $query->whereHas('facility', function ($query) use ($request) {
                        $query->where('name', 'LIKE', "%{$request['facility_search']}%");
                    });
                }
            }

            $query->where('facility_rating', '!=', null);
        })
        ->with(['shift' => function ($query) {
            $query->select('id', 'shift_prefix', 'state_id');
        }])->with(['category' => function ($query) {
            $query->select('id', 'name');
        }])->with(['profession' => function ($query) {
            $query->select('id', 'name');
        }])->with(['facility' => function ($query) {
            $query->select('id', 'facility_prefix', 'name');
        }])->with(['hcp' => function ($query) {
            $query->select('id', 'hcp_prefix', 'first_name', 'last_name');
        }]);

        if(isset($request['facility_export']) && $request['facility_export'] == true) {
            return $ratingQuery->orderBy('id', 'DESC')->get();
        } else {
            return $ratingQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->fragment('facility-rating')->onEachSide(2);
        }
    }

    public function get_hcp_ratings($request = null){
        $paginationLimit = null;

        if(isset($request['hcp_per_page']) && !empty($request['hcp_per_page'])) {
            $paginationLimit = $request['hcp_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $ratingQuery = $this->ratingReview->where(function ($query) use ($request) {

            if(isset($request['status']) && $request['status'] !='') {
                $query->where('status', $request['status']);
            }

            if(isset($request['facility']) && $request['facility'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(isset($request['hcp']) && $request['hcp'] !='') {
                $query->where('hcp_id', $request['hcp']);
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereDate('created_at', '>=', trim($date[0]))->whereDate('created_at', '<=', trim($date[1]));
            }

            if(!empty($request['hcp_rating_search'])) {
                $query->whereHas('hcp', function ($query) use ($request) {
                    $query->where('first_name', 'LIKE', "%{$request['hcp_rating_search']}%");
                });
            }

            if(!empty($request['facility_search'])) {
                $query->whereHas('facility', function ($query) use ($request) {
                    $query->where('name', 'LIKE', "%{$request['facility_search']}%");
                });
            }

            $query->where('hcp_rating', '!=', null);
        })
        ->with(['shift' => function ($query) {
            $query->select('id', 'shift_prefix', 'state_id');
        }])->with(['category' => function ($query) {
            $query->select('id', 'name');
        }])->with(['profession' => function ($query) {
            $query->select('id', 'name');
        }])->with(['facility' => function ($query) {
            $query->select('id', 'facility_prefix', 'name');
        }])->with(['hcp' => function ($query) {
            $query->select('id', 'hcp_prefix', 'first_name', 'last_name');
        }]);

        if(isset($request['facility_export']) && $request['facility_export'] == true) {
            return $ratingQuery->orderBy('id', 'DESC')->get();
        } else {
            return $ratingQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->fragment('hcp-rating')->onEachSide(2);
        }
    }

    public function update_or_create($where, $array){
        return $this->ratingReview->updateOrCreate($where, $array);
    }

    public function api_get_hcp_ratings($request = null){

        $paginationLimit = config('constants.pagination_limit');

        return $this->ratingReview->where(function ($query) use ($request) {

            if(isset($request['status']) && $request['status'] !='') {
                $query->where('status', $request['status']);
            }

            if(isset($request['facility']) && $request['facility'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(isset($request['hcp']) && $request['hcp'] !='') {
                $query->where('hcp_id', $request['hcp']);
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereDate('created_at', '>=', trim($date[0]))->whereDate('created_at', '<=', trim($date[1]));
            }

            if(!empty($request['hcp_rating_search'])) {
                $query->whereHas('hcp', function ($query) use ($request) {
                    $query->where('first_name', 'LIKE', "%{$request['hcp_rating_search']}%");
                });
            }

            if(!empty($request['facility_search'])) {
                $query->whereHas('facility', function ($query) use ($request) {
                    $query->where('name', 'LIKE', "%{$request['facility_search']}%");
                });
            }

            $query->where('status', '=', 'publish');
            $query->where('hcp_rating', '!=', null);
        })
        ->with(['shift' => function ($query) {
            $query->select('id', 'shift_prefix', 'state_id', 'approved_shift_start_time', 'approved_shift_end_time');
        }])->with(['category' => function ($query) {
            $query->select('id', 'name');
        }])->with(['profession' => function ($query) {
            $query->select('id', 'name');
        }])->with(['facility' => function ($query) {
            $query->select('id', 'facility_prefix', 'name');
        }])->with(['hcp' => function ($query) {
            $query->select('id', 'hcp_prefix', 'first_name', 'last_name');
        }])->orderBy('id', 'DESC')->paginate($paginationLimit);
    }
}

