<?php

namespace App\Repositories;
use App\Interfaces\ShiftSwapRequestInterface;
use App\Models\ShiftSwapRequest;

class ShiftSwapRequestRepository implements ShiftSwapRequestInterface
{
    private $shiftSwapRequest;
    public function __construct(ShiftSwapRequest $shiftSwapRequest){
        $this->shift_swap_request = $shiftSwapRequest;
    }

    public function get(){
        return $this->shift_swap_request->all();
    }

    public function find_shift_swap_request($where){
        return $this->shift_swap_request->where($where)->first();
    }

    public function getAll($where, $options = false, $request = null){
        $paginationLimit = null;

        if(isset($request['shift_per_page']) && !empty($request['shift_per_page'])) {
            $paginationLimit = $request['shift_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        if ($options){
            $shiftQuery = $this->shift_swap_request->where(function ($query) use ($where, $request) {

                $query->whereHas('shift', function($query) use($request){

                    if(!empty($request['states'])) {
                        $query->whereIn('state_id', $request['states']);
                    }

                    if(isset($request['status']) && $request['status'] !='') {
                        $query->where('shift_status', $request['status']);
                    }

                    if(isset($request['facility']) &&$request['facility'] !='') {
                        $query->where('facility_id', $request['facility']);
                    }

                    if(isset($request['profession']) &&$request['profession'] !='') {
                        $query->where('profession_id', $request['profession']);
                    }

                    if(isset($request['category']) && $request['category'] !='') {
                        $query->where('category_id', $request['category']);
                    }

                    if(isset($request['shift_type']) && $request['shift_type'] !='') {
                        $query->where('shift_type', $request['shift_type']);
                    }

                    if(!empty($request['date_range'])) {
                        $date = explode('to', $request['date_range']);
                        $query->whereBetween('start_time', [trim($date[0]), trim($date[1])]);
                    }

                    if(isset($request['filter_mints']) && $request['filter_mints'] !='') {
                        $startTime = Carbon::now()->addMinutes($request['filter_mints'])->format('Y-m-d H:i');
                        $currentTime = Carbon::now()->format('Y-m-d H:i');
                        $query->where('start_time', '<', $startTime)->where('start_time', '>', $currentTime);
                    }

                    if(!empty($request['shift_hcp_search'])) {
                        $query->whereHas('hcp', function ($query) use ($request) {
                            $query->where('first_name', 'LIKE', "%{$request['shift_hcp_search']}%");
                        });
                    }

                    if(!empty($request['shift_facility_search'])) {
                        $query->whereHas('facility', function ($query) use ($request) {
                                $query->where('name', 'LIKE', "%{$request['shift_facility_search']}%");
                        });
                    }
                    if(!empty($request['assigned_facilities'])) {
                        $query->whereIn('facility_id', $request['assigned_facilities']);
                    }

                    if(!empty($request['facility_group_ids'])) {
                        $query->whereIn('facility_group_id', $request['facility_group_ids']);
                    }
                });

                $query->where($where);

            })->with('shift', 'shift.facility', 'shift.category', 'shift.profession', 'shift.level', 'hcp', 'swap_hcp');

            if(isset($request['shift_export']) && $request['shift_export'] == true) {
                return $shiftQuery->orderBy('id', 'DESC')->get();
            } else {
                return $shiftQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
            }

        } else {
            return $this->shift_swap_request->get();
        }
    }

    public function store($array){
        return $this->shift_swap_request->create($array);
    }

    public function update($array, $where){
        return $this->shift_swap_request->where($where)->update($array);
    }

    public function delete($id){
        return $this->shift_swap_request->destroy($id);
    }

    public function api_get_swap_requests($request, $user){
        $paginationLimit = config('constants.pagination_limit');

        return $this->shift_swap_request->where(function ($query) use ($request, $user) {
            $query->where('status', 'pending');

        })->with(['hcp' => function ($query) {
            $query->select('id', 'first_name', 'last_name');
        }])->with(['shift' => function ($query) {

            $query->with(['facility' => function ($query) {
                $query->select('id', 'name', 'facility_group_id', 'address');
            }]);

        }])->orderBy('id', 'DESC')->paginate($paginationLimit);
    }

    public function api_find_shift_swap_request($request, $user){

        return $this->shift_swap_request->where(function ($query) use ($request, $user) {
            $query->where('id', $request['swap_request_id']);
            $query->where('status', 'pending');

        })->with(['hcp' => function ($query) {
            $query->select('id', 'first_name', 'last_name');
        }])->with(['shift' => function ($query) {

            $query->with('state')
            ->with(['category' => function ($query) {
                $query->select('id', 'name');
            }])->with(['profession' => function ($query) {
                $query->select('id', 'name');
            }])->with(['level' => function ($query) {
                $query->select('id', 'name');
            }])->with(['facility' => function ($query) {
                $query->select('id', 'name', 'facility_group_id', 'address');
            }]);

        }])->orderBy('id', 'DESC')->first();
    }
}

