<?php

namespace App\Repositories;
use App\Interfaces\ShiftTrackingInterface;
use App\Models\ShiftTracking;

class ShiftTrackingRepository implements ShiftTrackingInterface
{
    private $shiftTracking;
    public function __construct(ShiftTracking $shiftTracking){
        $this->shift_tracking = $shiftTracking;
    }

    public function get(){
        return $this->shift_tracking->all();
    }

    public function find_shift_tracking($where){
        return $this->shift_tracking->where($where)->with('shift')->orderBy('id', 'DESC')->first();
    }

    public function getAll($where, $options = false, $request = null){
        $paginationLimit = config('constants.pagination_limit');
        if ($options){
            return $this->shift_tracking->where(function ($query) use ($where, $request) {

                $query->whereHas('shift', function($query) use($request){

                    if(!empty($request['states'])) {
                        $query->whereIn('state_id', $request['states']);
                    }

                    if($request['status'] !='') {
                        $query->where('shift_status', $request['status']);
                    }

                    if($request['facility'] !='') {
                        $query->where('facility_id', $request['facility']);
                    }

                    if($request['profession'] !='') {
                        $query->where('profession_id', $request['profession']);
                    }

                    if($request['category'] !='') {
                        $query->where('category_id', $request['category']);
                    }

                    if($request['shift_type'] !='') {
                        $query->where('shift_type', $request['shift_type']);
                    }

                    if(!empty($request['date_range'])) {
                        $date = explode('to', $request['date_range']);
                        $query->whereBetween('start_time', [trim($date[0]), trim($date[1])]);
                    }

                    if($request['filter_mints'] !='') {
                        $startTime = Carbon::now()->addMinutes($request['filter_mints'])->format('Y-m-d H:i');
                        $currentTime = Carbon::now()->format('Y-m-d H:i');
                        $query->where('start_time', '<', $startTime)->where('start_time', '>', $currentTime);
                    }
                });

                $query->where($where);

            })->with('shift', 'shift.facility', 'shift.category', 'shift.profession', 'shift.level', 'hcp')->orderBy('id', 'DESC')->paginate($paginationLimit);
        } else {
            return $this->shift_tracking->get();
        }
    }

    public function store($array){
        return $this->shift_tracking->create($array);
    }

    public function update($array, $where){
        return $this->shift_tracking->where($where)->update($array);
    }

    public function delete($id){
        return $this->shift_tracking->destroy($id);
    }

    public function find_shift_track_by_id($id){
        return $this->shift_tracking->where('shift_id',$id)
                ->with('hcp','facility','shift')
                ->groupBy('hcp_id')
                ->latest()
                ->orderBy('id', 'DESC')->get();

    }
}

