<?php

namespace App\Repositories;
use App\Interfaces\ShiftTransferInterface;
use App\Models\ShiftTransfer;

class ShiftTransferRepository implements ShiftTransferInterface
{
    private $shiftTransfer;
    public function __construct(ShiftTransfer $shiftTransfer){
        $this->shift_transfer = $shiftTransfer;
    }

    public function get(){
        return $this->shift_transfer->all();
    }

    public function find_shift_transfer($where){
        return $this->shift_transfer->where($where)->orderBy('id', 'DESC')->first();
    }

    public function getAll($where, $options = false, $request = null){
        $paginationLimit = null;

        if(isset($request['shift_per_page']) && !empty($request['shift_per_page'])) {
            $paginationLimit = $request['shift_per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        if ($options){
            $shiftQuery = $this->shift_transfer->where(function ($query) use ($where, $request) {

                $query->whereHas('shift', function($query) use($request){

                    if(!empty($request['states'])) {
                        $query->whereIn('state_id', $request['states']);
                    }

                    if(isset($request['status']) && $request['status'] !='') {
                        $query->where('shift_status', $request['status']);
                    }

                    if(isset($request['facility']) && $request['facility'] !='') {
                        $query->where('facility_id', $request['facility']);
                    }

                    if(isset($request['profession']) && $request['profession'] !='') {
                        $query->where('profession_id', $request['profession']);
                    }

                    if(isset($request['category']) && $request['category'] !='') {
                        $query->where('category_id', $request['category']);
                    }

                    if(isset($request['shift_type']) && $request['shift_type'] !='') {
                        $query->where('shift_type', $request['shift_type']);
                    }

                    if(!empty($request['date_range'])) {
                        $date = explode('to', $request['date_range']);
                        $query->whereBetween('start_time', [trim($date[0]), trim($date[1])]);
                    }

                    if(isset($request['filter_mints']) && $request['filter_mints'] !='') {
                        $startTime = Carbon::now()->addMinutes($request['filter_mints'])->format('Y-m-d H:i');
                        $currentTime = Carbon::now()->format('Y-m-d H:i');
                        $query->where('start_time', '<', $startTime)->where('start_time', '>', $currentTime);
                    }

                    if(!empty($request['shift_hcp_search'])) {
                        $query->whereHas('hcp', function ($query) use ($request) {
                            $query->where('first_name', 'LIKE', "%{$request['shift_hcp_search']}%");
                        });
                    }

                    if(!empty($request['shift_facility_search'])) {
                        $query->whereHas('facility', function ($query) use ($request) {
                                $query->where('name', 'LIKE', "%{$request['shift_facility_search']}%");
                        });
                    }
                    if(!empty($request['assigned_facilities'])) {
                        $query->whereIn('facility_id', $request['assigned_facilities']);
                    }

                    if(!empty($request['facility_group_ids'])) {
                        $query->whereIn('facility_group_id', $request['facility_group_ids']);
                    }
                });

                $query->where($where);

            })->with('shift', 'shift.facility', 'shift.category', 'shift.profession', 'shift.level', 'hcp', 'transfer_hcp');

            if(isset($request['shift_export']) && $request['shift_export'] == true) {
                return $shiftQuery->orderBy('id', 'DESC')->get();
            } else {
                return $shiftQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
            }

        } else {
            return $this->shift_transfer->get();
        }
    }

    public function store($array){
        return $this->shift_transfer->create($array);
    }

    public function update($array, $where){
        return $this->shift_transfer->where($where)->update($array);
    }

    public function delete($id){
        return $this->shift_transfer->destroy($id);
    }
}

