<?php

namespace App\Repositories;
use App\Interfaces\StateInterface;
use App\Models\State;

class StateRepository implements StateInterface
{
    private $state;
    public function __construct(State $state){
        $this->state = $state;
    }

    public function find_state($id){
        return $this->state->find($id);
    }

    public function getAll($where, $options = false, $shiftStatus = null, $shiftType = null, $shiftTransfered = null, $shiftSwapped = null,$facilityStatus = null, $hcpStatus = null){
        if ($options){
            return $this->state->where($where)->with('cities.suburbs')
            ->withCount(['hcps' => function ($query) use($hcpStatus) {

                if(!is_null($hcpStatus)){
                    if ($hcpStatus == 'active') {
                        $query->where('status', '=', 'active');
                    } else if($hcpStatus == 'pending-approval') {
                        $query->where('status', '=', 'pending-approval')->orWhere('status', '=', 'rejected');
                    } else {
                        $query->where('status', $hcpStatus);
                    }
                }

            }])
            ->withCount(['facilities' => function ($query) use($facilityStatus) {

                if(!is_null($facilityStatus)){
                    if ($facilityStatus == 'active') {
                        $query->where('status', '!=', 'archived');
                    } else {
                        $query->where('status', $facilityStatus);
                    }
                }

            }])
            ->withCount(['shifts' => function ($query) use($shiftStatus, $shiftType, $shiftTransfered, $shiftSwapped) {

                if(!is_null($shiftStatus)){
                    $query->where('shift_status', $shiftStatus);
                }

                if(!is_null($shiftType)){
                    $query->where('shift_type', $shiftType);
                }

                if(!is_null($shiftTransfered)){
                    $query->where('shift_transfered', $shiftTransfered);
                }

                if(!is_null($shiftSwapped)){
                    $query->where('shift_swapped', $shiftSwapped);
                }

            }])->orderBy('name', 'ASC')->get();
        }else{
            return $this->state
                ->withCount(['hcps' => function ($query) use($hcpStatus) {

                    if(!is_null($hcpStatus)){
                        $query->where('status', $hcpStatus);
                    }

                }])
                ->withCount(['facilities' => function ($query) use($facilityStatus) {

                    if(!is_null($facilityStatus)){
                        $query->where('status', $facilityStatus);
                    }

                }])
                ->withCount(['shifts' => function ($query) use($shiftStatus, $shiftType, $shiftTransfered, $shiftSwapped) {
                    if(!is_null($shiftStatus)){
                        $query->where('shift_status', $shiftStatus);
                    }

                    if(!is_null($shiftType)){
                        $query->where('shift_type', $shiftType);
                    }

                    if(!is_null($shiftTransfered)){
                        $query->where('shift_transfered', $shiftTransfered);
                    }

                    if(!is_null($shiftSwapped)){
                        $query->where('shift_swapped', $shiftSwapped);
                    }
                }])->orderBy('name', 'ASC')->get();
        }
    }

    public function store($array){
        return $this->state->create($array);
    }

    public function update($array, $where){
        return $this->state->where($where)->update($array);
    }

    public function delete($id){
        return $this->state->destroy($id);
    }

    public function api_get_states($where){
        return $this->state->where($where)->with('cities.suburbs')->orderBy('name', 'ASC')->get();
    }

    public function get_states($where){
        return $this->state->where($where)->with('cities.suburbs')->orderBy('name', 'ASC')->get();
    }
}

