<?php

namespace App\Repositories;
use App\Interfaces\SubAdminInterface;
use App\Models\SubAdmin;

class SubAdminRepository implements SubAdminInterface
{
    private $subAdmin;
    public function __construct(SubAdmin $subAdmin){
        $this->sub_admin = $subAdmin;
    }

    public function find_sub_admin($id){
        return $this->sub_admin->find($id);
    }

    public function getAll($where, $options = false, $request = null){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        if($options){
            $subAdminQuery = $this->sub_admin->where(function ($query) use ($where, $request) {

                if(isset($request['status']) && $request['status'] !='') {
                    $query->where('status', $request['status']);
                }

                if(isset($request['panel_permissions']) && $request['panel_permissions'] !='') {
                    $query->where('panel_permissions', $request['panel_permissions']);
                }


                if(!empty($request['search'])) {
                    $query->where('name', 'LIKE', "%{$request['search']}%");
                }

                if(!empty($request['facility_id'])) {
                    $query->where('facility_id', $request['facility_id']);
                }

                if(!empty($request['facility_group_id']) && $request['facility_group_id']!=NULL) {
                    $query->where('facility_group_id', $request['facility_group_id']);
                }

                $query->where($where);
            });

            if(isset($request['export']) && $request['export'] == true) {
                return $subAdminQuery->orderBy('id', 'DESC')->get();
            } else {
                return $subAdminQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->fragment('facility-rating')->onEachSide(2);
            }

        } else {
            return $this->sub_admin->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function store($array){
        return $this->sub_admin->create($array);
    }

    public function update($array, $where){
        return $this->sub_admin->where($where)->update($array);
    }

    public function delete($id){
        return $this->sub_admin->destroy($id);
    }

    public function get_sub_admin($where){
        return $this->sub_admin->where($where)->with('user')->first();
    }
}

