<?php

namespace App\Repositories;
use App\Interfaces\TransactionInterface;
use App\Models\Transaction;
use App\Models\Shift;
use Carbon\Carbon;
use DB;

class TransactionRepository implements TransactionInterface
{
    private $transaction;
    public function __construct(Transaction $transaction){
        $this->transaction = $transaction;
    }

    public function find_transaction($id){
        return $this->transaction->find($id);
    }

    public function getAll($where,$options = false){
        if ($options){
            return $this->transaction->where($where)->get();
        }else{
            return $this->transaction->get();
        }
    }

    public function store($array){
        return $this->transaction->create($array);
    }

    public function update($array, $where){
        return $this->transaction->where($where)->update($array);
    }

    public function delete($id){
        return $this->transaction->destroy($id);
    }

    public function get_transaction_last_days($where, $request){

        return $this->transaction->where(function ($query) use ($where, $request) {

            if(isset($request['hcp_id']) && $request['hcp_id'] !='') {
                $query->where('hcp_id', $request['hcp_id']);
            }

            if(isset($request['facility_id']) && $request['facility_id'] !='') {
                $query->where('facility_id', $request['facility_id']);
            }

            if(isset($request['status']) && $request['status'] !='') {
                $query->where('status', $request['status']);
            }

            if(isset($request['hcp_payment_status']) && $request['hcp_payment_status'] !='') {
                $query->where('hcp_payment_status', $request['hcp_payment_status']);
            }

            if(isset($request['amount_type']) && $request['amount_type'] !='') {
                // $query->where('amount_type', $request['amount_type']);
            }

            if(isset($request['last_days']) && $request['last_days'] !='') {
                $query->whereDate('created_at', '>', Carbon::now()->subDays($request['last_days']));
            }

            if(isset($request['start_date']) && !empty($request['start_date'])) {
                $query->whereDate('hcp_paid_on', '>=', $request['start_date']);
            }

            if(isset($request['end_date']) && !empty($request['end_date'])) {
                $query->whereDate('hcp_paid_on', '<=', $request['end_date']);
            }

            if(isset($request['current_year']) && $request['current_year'] == 'yes') {
                $query->whereYear('created_at', date('Y'));
            }

            $query->where($where);
        })->get();
    }

    public function get_facility_transactions_with_pagination($where,$request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery =  $this->transaction->where(function ($query) use ($where, $request) {
            if(isset($request['facility']) && $request['facility'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(isset($request['facilities']) && $request['facilities'] !='') {
                $query->whereIn('facility_id', $request['facilities']);
            }

            if(isset($request['status']) && $request['status'] == 'pending') {
                $query->where('status', 'pending')->where('invoice_id', null);
            }

            if(isset($request['status']) && $request['status'] == 'invoiced') {
                $query->where('status', 'pending')->where('invoice_id', '!=', null);

                if(!empty($request['date_from'])) {
                    $query->whereDate('invoice_created_at', '>=', $request['date_from']);
                }

                if(!empty($request['date_to'])) {
                    $query->whereDate('invoice_created_at', '<=', $request['date_to']);
                }
            }

            if(isset($request['status']) && $request['status'] == 'completed') {
                $query->where('status', 'completed')->where('invoice_id', '!=', null);

                if(!empty($request['date_from'])) {
                    $query->whereDate('paid_on', '>=', $request['date_from']);
                }

                if(!empty($request['date_to'])) {
                    $query->whereDate('paid_on', '<=', $request['date_to']);
                }
            }

            if(isset($request['status']) && $request['status'] == 'overdue') {
                $query->where('status', 'overdue')->where('invoice_id', '!=', null);

                if(!empty($request['date_from'])) {
                    $query->whereDate('invoice_overdue_date', '>=', $request['date_from']);
                }

                if(!empty($request['date_to'])) {
                    $query->whereDate('invoice_overdue_date', '<=', $request['date_to']);
                }
            }

            if(isset($request['status']) && $request['status'] == 'facility-all') {
                $query->where('invoice_id', '!=', null);

                if(!empty($request['date_from'])) {
                    $query->whereDate('invoice_created_at', '>=', $request['date_from']);
                }

                if(!empty($request['date_to'])) {
                    $query->whereDate('invoice_created_at', '<=', $request['date_to']);
                }
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereBetween('invoice_created_at', [trim($date[0]), trim($date[1])]);
            }

            if(!empty($request['search'])) {
                if(is_numeric($request['search'])) {
                    $query->where('invoice_id', 'LIKE', "%{$request['search']}%");
                } else {
                    $query->whereHas('facility', function ($query) use ($request) {
                        $query->where('name', 'LIKE', "%{$request['search']}%");
                    });
                }
            }

            $query->whereHas('shift', function ($query) use ($request) {
                $query->select('id', 'shift_prefix', 'shift_type', 'shift_approved_time', 'admin_fees', 'working_hours', 'facility_per_rate', 'hcp_per_rate', 'shift_loading');
                $query->where('shift_status', '6');

                if(!empty($request['date_from']) && !isset($request['status']) && $request['status'] == 'facility-all') {
                    $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                }

                if(!empty($request['date_to']) && !isset($request['status']) && $request['status'] == 'facility-all') {
                    $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                }
            });

            $query->whereHas('facility', function ($query) use ($request) {
                if(!empty($request['states'])) {
                    $query->whereIn('state_id', $request['states']);
                }
            });

            $query->where('amount_type', 'shift');
            $query->where('amount_for', '=', 'facility');
            $query->where('status', '!=', 'cancelled');

            $query->orWhere(function ($query) use ($where, $request) {
                // $query->where('amount_type', 'shift-cancel-penalty');
            });
            $query->where($where);
        })

        ->select('*', DB::raw('sum(CASE WHEN facility_amount >=0 THEN facility_amount ELSE 0 END) as total_facility_amount, sum((CASE WHEN admin_fees >=0 THEN admin_fees ELSE 0 END)) as total_admin_fees, sum((CASE WHEN total_admin_fees_with_loading >=0 THEN total_admin_fees_with_loading ELSE 0 END)) as final_total_admin_fees_with_loading'))
        ->with('facility')
        ->with(['shift' => function ($query) use ($request) {
            $query->select('id', 'shift_prefix', 'shift_type', 'shift_approved_time', 'admin_fees', 'working_hours', 'facility_per_rate', 'hcp_per_rate', 'shift_loading', 'total_admin_fees_with_loading');
        }])
        ->groupBy('facility_id', 'invoice_id');

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->orderBy('invoice_id', 'ASC')->orderBy('invoice_created_at', 'DESC')->get();
        } else {
//            return $transactionQuery->orderBy('invoice_id', 'ASC')->orderBy('invoice_created_at', 'DESC')->paginate($paginationLimit)->onEachSide(2);
            return $transactionQuery->orderBy('invoice_id', 'ASC')->orderBy('invoice_created_at', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_facility_transactions($where,$request){
        return $this->transaction->where(function ($query) use ($where, $request) {
                if(isset($request['facility']) && $request['facility'] !='') {
                    $query->where('facility_id', $request['facility']);
                }

                if(isset($request['status']) && $request['status'] !='') {
                    $query->where('status', $request['status']);
                }

                if(!empty($request['date_range'])) {
                    $date = explode('to', $request['date_range']);
                    $query->whereBetween('invoice_created_at', [trim($date[0]), trim($date[1])]);
                }

                $query->where('invoice_id','!=',null);
                $query->where('amount_for','=','facility');
                $query->where($where);
            })
            ->select('*', DB::raw('sum(facility_amount) as total_facility_amount, sum(admin_fees) as total_admin_fees'))
            ->with('facility')
            ->groupBy('invoice_id')
            ->get();
    }

    public function get_transaction_details($request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery = $this->transaction
            ->where(function ($query) use ($request) {
                if(!empty($request['invoice_id']) && !empty($request['facility_id']) && !isset($request['statement_id'])) {
                    $query->where('invoice_id', $request['invoice_id']);
                }

                if(!empty($request['facility_id']) && empty($request['invoice_id']) && !isset($request['statement_id'])) {
                    $query->where('facility_id', $request['facility_id']);
                    $query->where('invoice_id', null);
                }

                if(!empty($request['statement_id']) && !empty($request['hcp_id']) && !isset($request['invoice_id'])) {
                    $query->where('statement_id', $request['statement_id']);
                }

                if(!empty($request['statement_id']) && empty($request['statement_id']) && !isset($request['invoice_id'])) {
                    $query->where('hcp_id', $request['hcp_id']);
                    $query->where('statement_id', null);
                }

                if(!empty($request['search'])) {
                    $query->whereHas('hcp', function ($query) use($request) {
                        $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['search']).'%');
                    });
                }

                if (isset($request['status']) && $request['status'] == 'invoiced') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('invoice_created_at', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('invoice_created_at', '<=', $request['date_to']);
                    }
                }

                if(!empty($request['facility_id']) && !isset($request['statement_id'])) {
                    $query->where('amount_for', 'facility');

                    if (isset($request['status']) && $request['status'] == 'completed') {
                        if(!empty($request['date_from'])) {
                            $query->whereDate('paid_on', '>=', $request['date_from']);
                        }

                        if(!empty($request['date_to'])) {
                            $query->whereDate('paid_on', '<=', $request['date_to']);
                        }
                    }
                }

                if(!empty($request['hcp_id']) && !isset($request['invoice_id'])) {
                    $query->where('amount_for', 'hcp');

                    if (isset($request['status']) && $request['status'] == 'completed') {
                        if(!empty($request['date_from'])) {
                            $query->whereDate('hcp_paid_on', '>=', $request['date_from']);
                        }

                        if(!empty($request['date_to'])) {
                            $query->whereDate('hcp_paid_on', '<=', $request['date_to']);
                        }
                    }
                }

                $query->where('amount_for', '=', 'facility');
                $query->where('status', '!=', 'cancelled');
            })
            ->where(function ($query) use ($request) {
                $query->orWhere('amount_type', 'shift');
                $query->orWhere('amount_type', 'shift-cancel-penalty');
            })
            ->whereHas('shift', function ($query) use($request) {
                $query->where('shift_status', '!=', '0');
                $query->where('shift_status', '!=', '1');
                $query->where('shift_status', '!=', '2');
                $query->where('shift_status', '!=', '4');
                $query->where('shift_status', '!=', '5');

                if (isset($request['status']) && $request['status'] == 'pending') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                    }

                } else {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                    }
                }

            });

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->orderBy('id', 'DESC')->get();
        } else {
            return $transactionQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_hcp_transaction_details($request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery = $this->transaction
            ->where(function ($query) use ($request) {

                if(!empty($request['invoice_id']) && !empty($request['facility_id']) && !isset($request['statement_id'])) {
                    $query->where('invoice_id', $request['invoice_id']);
                }

                if(!empty($request['facility_id']) && empty($request['invoice_id']) && !isset($request['statement_id'])) {
                    $query->where('facility_id', $request['facility_id']);
                    $query->where('invoice_id', null);
                }

                if(!empty($request['statement_id']) && !empty($request['hcp_id']) && !isset($request['invoice_id'])) {
                    $query->where('statement_id', $request['statement_id']);
                }

                if(empty($request['statement_id']) && !isset($request['invoice_id'])) {
                    $query->where('hcp_id', $request['hcp_id']);
                    $query->where('statement_id', null);
                }

                if(!empty($request['search'])) {
                    $query->whereHas('hcp', function ($query) use($request) {
                        $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['search']).'%');
                    });
                }

                if (isset($request['status']) && $request['status'] == 'invoiced') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('invoice_created_at', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('invoice_created_at', '<=', $request['date_to']);
                    }
                }

                if(!empty($request['facility_id']) && !isset($request['statement_id'])) {
                    $query->where('amount_for', 'facility');

                    if (isset($request['status']) && $request['status'] == 'completed') {
                        if(!empty($request['date_from'])) {
                            $query->whereDate('paid_on', '>=', $request['date_from']);
                        }

                        if(!empty($request['date_to'])) {
                            $query->whereDate('paid_on', '<=', $request['date_to']);
                        }
                    }
                }

                if(!empty($request['hcp_id']) && !isset($request['invoice_id'])) {
                    $query->where('amount_for', 'hcp');

                    if (isset($request['status']) && $request['status'] == 'completed') {
                        if(!empty($request['date_from'])) {
                            $query->whereDate('hcp_paid_on', '>=', $request['date_from']);
                        }

                        if(!empty($request['date_to'])) {
                            $query->whereDate('hcp_paid_on', '<=', $request['date_to']);
                        }
                    }
                }

                $query->where('amount_type', 'shift');
                $query->where('amount_for', '=', 'hcp');
                $query->where('status', '!=', 'cancelled');
            })
            ->whereHas('shift', function ($query) use($request) {
                $query->where('shift_status', '=', '6');

                if (isset($request['status']) && $request['status'] == 'pending') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                    }

                } else {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                    }
                }

            });

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->orderBy('id', 'DESC')->get();
        } else {
            return $transactionQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_hcp_referrals_transaction_details($request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery = $this->transaction
            ->where(function ($query) use ($request) {

                if(!empty($request['invoice_id']) && !empty($request['facility_id']) && !isset($request['statement_id'])) {
                    $query->where('invoice_id', $request['invoice_id']);
                }

                if(!empty($request['facility_id']) && empty($request['invoice_id']) && !isset($request['statement_id'])) {
                    $query->where('facility_id', $request['facility_id']);
                    $query->where('invoice_id', null);
                }

                if(!empty($request['statement_id']) && !empty($request['hcp_id']) && !isset($request['invoice_id'])) {
                    $query->where('statement_id', $request['statement_id']);
                }

                if(empty($request['statement_id']) && !isset($request['invoice_id'])) {
                    $query->where('hcp_id', $request['hcp_id']);
                    $query->where('statement_id', null);
                }

                if(!empty($request['search'])) {
                    $query->whereHas('hcp', function ($query) use($request) {
                        $query->where('first_name', 'LIKE', "%{$request['search']}%");
                    });
                }

                if (empty($request['status']) || $request['status'] == 'invoiced') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('invoice_created_at', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('invoice_created_at', '<=', $request['date_to']);
                    }
                }

                if(!empty($request['facility_id']) && !isset($request['statement_id'])) {
                    $query->where('amount_for', 'facility');

                    if (empty($request['status']) || $request['status'] == 'completed') {
                        if(!empty($request['date_from'])) {
                            $query->whereDate('paid_on', '>=', $request['date_from']);
                        }

                        if(!empty($request['date_to'])) {
                            $query->whereDate('paid_on', '<=', $request['date_to']);
                        }
                    }
                }

                if(!empty($request['hcp_id']) && !isset($request['invoice_id'])) {
                    $query->where('amount_for', 'hcp');

                    if (empty($request['status']) || $request['status'] == 'completed') {
                        if(!empty($request['date_from'])) {
                            $query->whereDate('hcp_paid_on', '>=', $request['date_from']);
                        }

                        if(!empty($request['date_to'])) {
                            $query->whereDate('hcp_paid_on', '<=', $request['date_to']);
                        }
                    }
                }

                $query->where('amount_type', 'refer-and-earn');
                $query->where('amount_for', '=', 'hcp');
                $query->where('status', '!=', 'cancelled');
            });

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->orderBy('id', 'DESC')->get();
        } else {
            return $transactionQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_hcp_tranactions_with_pagination($where, $request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery = $this->transaction->where(function ($query) use ($where, $request) {

            if(isset($request['hcp']) && $request['hcp'] !='') {
                $query->where('hcp_id', $request['hcp']);
            }

            if(isset($request['status']) && $request['status'] == 'pending') {
                $query->where('hcp_payment_status', 'pending');
            }

            if(isset($request['status']) && $request['status'] == 'invoiced') {
                $query->where('hcp_payment_status', 'pending')->where('statement_id', '!=', null);
            }

            if(isset($request['status']) && $request['status'] == 'completed') {
                $query->where('hcp_payment_status', 'completed')->where('statement_id', '!=', null);
            }

            if(isset($request['status']) && $request['status'] == 'overdue') {
                $query->where('hcp_payment_status', 'overdue')->where('statement_id', '!=', null);
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereBetween('invoice_created_at', [trim($date[0]), trim($date[1])]);
            }

            if(!empty($request['statement_search'])) {
                if(is_numeric($request['statement_search'])) {
                    $query->where('statement_id', 'LIKE', "%{$request['statement_search']}%");
                } else {
                    $query->whereHas('hcp', function ($query) use ($request) {
                        $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['statement_search']).'%');
                    });
                }
            }

            $query->whereHas('shift', function ($query) use ($request) {
                $query->select('id', 'shift_prefix', 'shift_type', 'shift_approved_time', 'admin_fees', 'working_hours', 'facility_per_rate', 'hcp_per_rate', 'shift_loading');

                if(!empty($request['date_from'])) {
                    $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                }

                if(!empty($request['date_to'])) {
                    $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                }
            });

            $query->whereHas('hcp', function ($query) use ($request) {
                if(!empty($request['states'])) {
                    $query->whereIn('state_id', $request['states']);
                }
            });

            // $query->where('statement_id','!=', null);
            $query->where('amount_for','=','hcp');
            $query->where('status', '!=', 'cancelled');
            $query->where($where);
        })
        ->select('*', DB::raw('sum(hcp_amount) as total_hcp_amount,sum(admin_fees) as total_admin_fees'))
        ->with(['shift' => function ($query) use ($request) {
            $query->select('id', 'shift_prefix', 'shift_type', 'shift_approved_time', 'admin_fees', 'working_hours', 'facility_per_rate', 'hcp_per_rate', 'shift_loading');
        }])
        ->groupBy('hcp_id', 'statement_id');

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->orderBy('statement_id', 'ASC')->orderBy('invoice_created_at', 'DESC')->get();
        } else {
            return $transactionQuery->orderBy('statement_id', 'ASC')->orderBy('invoice_created_at', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }

    }

    public function get_hcp_tranactions($where, $request){
        return $this->transaction->where(function ($query) use ($where, $request) {
            if(isset($request['hcp']) && $request['hcp'] !='') {
                $query->where('hcp_id', $request['hcp']);
            }

            if(isset($request['status']) && $request['status'] !='') {
                $query->where('status', $request['status']);
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereBetween('invoice_created_at', [trim($date[0]), trim($date[1])]);
            }

            $query->where('invoice_id','!=',null);

            $query->where('amount_for','=','hcp');

            $query->where($where);
        })
        ->select('*',DB::raw('sum(hcp_amount) as total_hcp_amount,sum(admin_fees) as total_admin_fees'))
        ->with('hcp')
        ->groupBy('invoice_id')
        ->get();
    }

    public function get_hcp_first_tranaction($request, $user){
        return $this->transaction->where(function ($query) use ($user, $request) {

            if(isset($user)) {
                $query->where('hcp_id', $user->hcp->id);
            }

            $query->where('status', $request['status']);

            $query->where('amount_for','=','hcp');
        })->orderBy('created_at', 'ASC')->first();
    }

    public function api_hcp_tranactions_list($request, $user, $weekDates){

        $paginationLimit = config('constants.pagination_limit');
        return $this->transaction->where(function ($query) use ($user, $request, $weekDates) {

            if(isset($user)) {
                $query->where('hcp_id', $user->hcp->id);
            }

            if(!empty($weekDates)) {
                $query->whereDate('invoice_created_at', '>=', $weekDates['start_date'])
                ->whereDate('invoice_created_at', '<=', $weekDates['end_date']);
            }

            $query->where('hcp_payment_status', $request['status']);
            $query->where('amount_for','=','hcp');
        })->addSelect(['working_hours' => Shift::select('working_hours')
            ->whereColumn('shift_id', 'shifts.id')
        ])->addSelect(['hours' => Shift::select('hours')
            ->whereColumn('shift_id', 'shifts.id')
        ])->addSelect(['shift_earning' => Shift::select('hcp_amount')
            ->whereColumn('shift_id', 'shifts.id')
        ])->addSelect(['shift_count' => Shift::select('shift_id')
            ->whereColumn('shift_id', 'shifts.id')
        ])
        ->with(['shift' => function ($query) {
            $query->select('id', 'shift_prefix', 'start_time', 'end_time', 'hcp_shift_start_time', 'hcp_shift_end_time', 'approved_shift_start_time', 'approved_shift_end_time');
        }])
        ->with(['facility' => function ($query) {
            $query->select('id', 'facility_prefix', 'name');
        }])
        ->with(['referral' => function ($query) {
            $query->with('referee_hcp');
        }])
        ->orderBy('statement_id', 'DESC')->get()->groupBy('statement_id');

    }

    public function get_subscription_transactions_with_pagination($where,$request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery =  $this->transaction->where(function ($query) use ($where, $request) {
            if(isset($request['facility']) && $request['facility'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(isset($request['facilities']) && $request['facilities'] !='') {
                $query->whereIn('facility_id', $request['facilities']);
            }

            if(isset($request['facility_id']) && $request['facility_id'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(isset($request['status']) && $request['status'] !='') {
                $query->where('status', $request['status']);
            }

            if(!empty($request['date_from'])) {
                $query->whereDate('created_at', '>=', $request['date_from']);
            }

            if(!empty($request['date_to'])) {
                $query->whereDate('created_at', '<=', $request['date_to']);
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereBetween('created_at', [trim($date[0]), trim($date[1])]);
            }

            if(!empty($request['search'])) {
                $query->where('invoice_id', 'LIKE', "%{$request['search']}%");
            }

            $query->where('invoice_id', '!=', null);
            $query->where('amount_for', '=', 'facility');
            $query->where('amount_type', '=', 'subscription');
            $query->where($where);
        })
        ->select('*', DB::raw('sum(facility_amount) as total_facility_amount'))
        ->with('facility')
        ->groupBy('invoice_id');
        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->orderBy('invoice_id', 'DESC')->get();
        } else {
            return $transactionQuery->orderBy('invoice_id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_last_shift_generated_invoice($request = null){
        return $this->transaction->where(function ($query) use ($request) {
            $query->where('invoice_created_at', '!=', null);
            $query->where('amount_type', '=', 'shift');

            if (!empty($request) && !empty($request['amount_for'])) {
                $query->where('amount_for', $request['amount_for']);
            }

        })->orderBy('invoice_created_at', 'DESC')->first();
    }

    public function get_max_invoice_id($request = null){
        return $this->transaction->where(function ($query) use ($request) {
        })->orderBy('id', 'DESC')->select('id','invoice_prefix','invoice_id')->first();
    }

    public function update_generated_invoice($array, $where, $shiftIdArr) {
        return $this->transaction->where(function ($query) use ($where, $shiftIdArr) {
            $query->where($where);
            $query->whereIn('shift_id', $shiftIdArr);
        })->update($array);
    }

    public function get_generated_invoice($shiftId = null, $hcpId = null, $facilityId = null){
        return $this->transaction->where(function ($query) use ($shiftId, $hcpId, $facilityId) {

            if(!is_null($hcpId)) {
                $query->where('hcp_id', $hcpId);
            }

            if(!is_null($shiftId)) {
                $query->where('shift_id', $shiftId);
            }

            if(!is_null($facilityId)) {
                $query->where('facility_id', $facilityId);
            }

            $query->where('invoice_id', '!=', null);
            $query->where('amount_type', '=', 'shift');
            $query->where('amount_for', '=', 'facility');
        })->orderBy('id', 'DESC')->first();
    }

    public function get_overdue_invoice($filter = null){
        return $this->transaction->where(function ($query) use ($filter) {

            if (!empty($filter) && !empty($filter['overdue_date'])) {
                $query->where('invoice_overdue_date', $filter['overdue_date']);
            }

            if (!empty($filter) && !empty($filter['invoice_ids'])) {
                $query->whereIn('invoice_id', $filter['invoice_ids']);
            }

            if (!empty($filter) && !empty($filter['amount_for'])) {
                $query->where('amount_for', $filter['amount_for']);
            }

            $query->where('invoice_id', '!=', null);
            $query->where('amount_type', '=', 'shift');
            $query->where('status', '=', 'pending');
        })->groupBy('invoice_id')->get();
    }

    public function get_all_hcp_transaction_details($request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery = $this->transaction
            ->where(function ($query) use ($request) {
                if(isset($request['status']) && $request['status'] == 'pending') {
                    $query->where('hcp_payment_status', 'pending');
                }

                if(isset($request['status']) && $request['status'] == 'invoiced') {
                    $query->where('hcp_payment_status', 'pending')->where('statement_id', '!=', null);
                }

                if(isset($request['status']) && $request['status'] == 'completed') {
                    $query->where('hcp_payment_status', 'completed')->where('statement_id', '!=', null);
                }

                if(isset($request['status']) && $request['status'] == 'overdue') {
                    $query->where('hcp_payment_status', 'overdue')->where('statement_id', '!=', null);
                }

                if (empty($request['status']) || $request['status'] == 'invoiced') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('invoice_created_at', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('invoice_created_at', '<=', $request['date_to']);
                    }
                }

                $query->whereHas('hcp', function ($query) use ($request) {
                    if(!empty($request['states'])) {
                        $query->whereIn('state_id', $request['states']);
                    }

                    if(!empty($request['search'])) {
                        if(is_numeric($request['search'])) {
                            $query->where('statement_id', 'LIKE', "%{$request['search']}%");
                        } else {
                            $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['search']).'%');
                        }
                    }
                });

                $query->where('amount_for', 'hcp');
                $query->where('amount_type', 'shift');
                $query->where('status', '!=', 'cancelled');
            })
            ->whereHas('shift', function ($query) use($request) {

                if (empty($request['status']) || $request['status'] == 'pending') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                    }
                }

                if(!empty($request['facility'])) {
                    $query->where('facility_id', $request['facility']);
                }

                if(!empty($request['profession'])) {
                    $query->where('profession_id', $request['profession']);
                }

                if(!empty($request['category'])) {
                    $query->where('category_id', $request['category']);
                }

                if(!empty($request['level'])) {
                    $query->where('hcp_level_id', $request['level']);
                }

                if(!empty($request['shift_type'])) {
                    $query->where('shift_type', $request['shift_type']);
                }

            });

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->get();
        } else {
            return $transactionQuery->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_revenue_statement($where,$request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery =  $this->transaction->where(function ($query) use ($where, $request) {
            if(isset($request['facility']) && $request['facility'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(!empty($request['search'])) {
                if(is_numeric($request['search'])) {
                    $query->where('id', 'LIKE', "%{$request['search']}%");
                } else {
                    $query->whereHas('facility', function ($query) use ($request) {
                        $query->where('name', 'LIKE', "%{$request['search']}%");
                    });
                }
            }

            if(!empty($request['date_from'])) {
                $query->whereDate('paid_on', '>=', $request['date_from']);
            }

            if(!empty($request['date_to'])) {
                $query->whereDate('paid_on', '<=', $request['date_to']);
            }

            $query->whereHas('shift', function ($query) use ($request) {
                $query->select('id', 'shift_prefix', 'shift_type', 'shift_approved_time', 'admin_fees', 'working_hours', 'facility_per_rate', 'hcp_per_rate', 'shift_loading');
                $query->where('shift_type', '!=', 'buddy');
            });

            $query->whereHas('facility', function ($query) use ($request) {
                if(!empty($request['states'])) {
                    $query->whereIn('state_id', $request['states']);
                }
            });

            $query->where('status', 'completed');
            $query->where('amount_type', '=', 'shift');
            $query->where('amount_for', '=', 'facility');
            $query->where($where);
        })
//        ->select('*', DB::raw('sum(facility_amount) as total_facility_amount,sum(admin_fees) as total_admin_fees'))
        ->select('*', DB::raw('sum(CASE WHEN facility_amount >=0 THEN facility_amount ELSE 0 END) as total_facility_amount, sum((CASE WHEN admin_fees >=0 THEN admin_fees ELSE 0 END)) as total_admin_fees, sum((CASE WHEN total_admin_fees_with_loading >=0 THEN total_admin_fees_with_loading ELSE 0 END)) as final_total_admin_fees_with_loading'))
        ->with('facility')
        ->with(['shift' => function ($query) use ($request) {
            $query->select('id', 'shift_prefix', 'shift_type', 'shift_approved_time', 'admin_fees', 'working_hours', 'facility_per_rate', 'hcp_per_rate', 'shift_loading');
        }])->groupBy('facility_id', 'invoice_id');

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->orderBy('id', 'DESC')->get();
        } else {
            return $transactionQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_revenue_statement_details($request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery = $this->transaction
            ->where(function ($query) use ($request) {

                if(!empty($request['search'])) {
                    $query->whereHas('hcp', function ($query) use($request) {
                        $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['shift_hcp_search']).'%');
                    });
                }

                if(!empty($request['facility_id']) && !isset($request['statement_id'])) {
                    $query->where('amount_for', 'facility');
                }

                $query->where('facility_id', $request['facility_id']);
                $query->where('invoice_id', $request['invoice_id']);
            })
            ->whereHas('shift', function ($query) use($request) {
                $query->where('shift_status', '6');
                if (empty($request['status']) || $request['status'] == 'pending') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                    }
                }

            });

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->get();
        } else {
            return $transactionQuery->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function find_transaction_with_stripe_session($sessionId){
        return $this->transaction->where(['stripe_payment_session_id' => $sessionId])->first();
    }

    public function api_hcp_tranactions_details_list($request, $user, $weekDates){

        $paginationLimit = config('constants.pagination_limit');
        return $this->transaction->where(function ($query) use ($user, $request, $weekDates) {

            if(isset($user)) {
                $query->where('hcp_id', $user->hcp->id);
            }

            if(isset($request['statement_id']) && !empty($request['statement_id'])) {
                $query->where('statement_id', $request['statement_id']);
            }

            if(isset($request['status']) && !empty($request['status'])) {
                $query->where('hcp_payment_status', $request['status']);
            }

            $query->where('amount_for','=','hcp');
        })->addSelect(['working_hours' => Shift::select('working_hours')
            ->whereColumn('shift_id', 'shifts.id')
        ])->addSelect(['hours' => Shift::select('hours')
            ->whereColumn('shift_id', 'shifts.id')
        ])->addSelect(['shift_earning' => Shift::select('hcp_amount')
            ->whereColumn('shift_id', 'shifts.id')
        ])->addSelect(['shift_count' => Shift::select('shift_id')
            ->whereColumn('shift_id', 'shifts.id')
        ])
        ->with(['shift' => function ($query) {
            $query->select('id', 'shift_prefix', 'start_time', 'end_time', 'hcp_shift_start_time', 'hcp_shift_end_time', 'approved_shift_start_time', 'approved_shift_end_time');
        }])
        ->with(['facility' => function ($query) {
            $query->select('id', 'facility_prefix', 'name');
        }])
        ->with(['referral' => function ($query) {
            $query->with('referee_hcp');
        }])
        ->get();

    }

    public function get_referrals_transactions_with_pagination($where,$request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery =  $this->transaction->where(function ($query) use ($where, $request) {
            if(isset($request['facility']) && $request['facility'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(isset($request['facility_id']) && $request['facility_id'] !='') {
                $query->where('facility_id', $request['facility']);
            }

            if(isset($request['status']) && $request['status'] !='') {
                $query->where('hcp_payment_status', $request['status']);
            }

            if(!empty($request['date_from'])) {
                $query->whereDate('created_at', '>=', $request['date_from']);
            }

            if(!empty($request['date_to'])) {
                $query->whereDate('created_at', '<=', $request['date_to']);
            }

            if(!empty($request['date_range'])) {
                $date = explode('to', $request['date_range']);
                $query->whereBetween('created_at', [trim($date[0]), trim($date[1])]);
            }

            if(isset($request['hcp']) && $request['hcp'] !='') {
                $query->where('hcp_id', $request['hcp']);
            }

            if(!empty($request['statement_search'])) {
                if(is_numeric($request['statement_search'])) {
                    $query->where('statement_id', 'LIKE', "%{$request['statement_search']}%");
                } else {
                    $query->whereHas('hcp', function ($query) use ($request) {
                        $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['statement_search']).'%');
                    });
                }
            }

            $query->whereHas('hcp', function ($query) use ($request) {
                if(!empty($request['states'])) {
                    $query->whereIn('state_id', $request['states']);
                }
            });

            $query->where('amount_for', '=', 'hcp');
            $query->where('amount_type', '=', 'refer-and-earn');
            $query->where($where);
        })
        ->with('hcp');

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->orderBy('id', 'DESC')->get();
        } else {
            return $transactionQuery->orderBy('id', 'DESC')->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_all_facility_transaction_details($request){
        $paginationLimit = null;

        if(isset($request['per_page']) && !empty($request['per_page'])) {
            $paginationLimit = $request['per_page'];
        } else {
            $paginationLimit = config('constants.pagination_limit');
        }

        $transactionQuery = $this->transaction
            ->where(function ($query) use ($request) {
                if(isset($request['status']) && $request['status'] == 'pending') {
                    $query->where('status', 'pending');
                }

                if(isset($request['status']) && $request['status'] == 'invoiced') {
                    $query->where('status', 'pending')->where('invoice_id', '!=', null);
                }

                if(isset($request['status']) && $request['status'] == 'completed') {
                    $query->where('status', 'completed')->where('invoice_id', '!=', null);
                }

                if(isset($request['status']) && $request['status'] == 'overdue') {
                    $query->where('status', 'overdue')->where('invoice_id', '!=', null);
                }

                if (empty($request['status']) || $request['status'] == 'invoiced') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('invoice_created_at', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('invoice_created_at', '<=', $request['date_to']);
                    }
                }

                #$query->whereHas('facility', function ($query) use ($request) {
                    #if(!empty($request['states'])) {
                        #$query->whereIn('state_id', $request['states']);
                    #}

                    #if(!empty($request['search'])) {
                        #$query->where('name', 'LIKE', "%{$request['search']}%");
                    #}
                #});
	if(!empty($request['search'])) {
                if(is_numeric($request['search'])) {
                    $query->where('invoice_id', 'LIKE', "%{$request['search']}%");
                } else {
                    $query->whereHas('facility', function ($query) use ($request) {
                        $query->where('name', 'LIKE', "%{$request['search']}%");
                    });
                }
            }else{
		$query->whereHas('facility', function ($query) use ($request) {
                    if(!empty($request['states'])) {
                        $query->whereIn('state_id', $request['states']);
                    }

                    if(!empty($request['search'])) {
                        $query->where('name', 'LIKE', "%{$request['search']}%");
                    }
                });
	}

                $query->where('amount_type', 'shift');
                $query->where('amount_for', '=', 'facility');
                $query->where('status', '!=', 'cancelled');

                $query->orWhere(function ($query) use ($request) {
                    $query->where('amount_type', 'shift-cancel-penalty');
                });
            })
            ->whereHas('shift', function ($query) use($request) {
                $query->where('shift_status', '6');

                if (empty($request['status']) || $request['status'] == 'pending') {
                    if(!empty($request['date_from'])) {
                        $query->whereDate('shift_approved_time', '>=', $request['date_from']);
                    }

                    if(!empty($request['date_to'])) {
                        $query->whereDate('shift_approved_time', '<=', $request['date_to']);
                    }
                }

                if(!empty($request['facility'])) {
                    $query->where('facility_id', $request['facility']);
                }

                if(!empty($request['profession'])) {
                    $query->where('profession_id', $request['profession']);
                }

                if(!empty($request['category'])) {
                    $query->where('category_id', $request['category']);
                }

                if(!empty($request['level'])) {
                    $query->where('hcp_level_id', $request['level']);
                }

                if(!empty($request['shift_type'])) {
                    $query->where('shift_type', $request['shift_type']);
                }

            });

        if(isset($request['export']) && $request['export'] == true) {
            return $transactionQuery->get();
        } else {
            return $transactionQuery->paginate($paginationLimit)->onEachSide(2);
        }
    }

    public function get_transaction($where){
        return $this->transaction->where($where)->first();
    }
}

