<?php

namespace App;
use App\Http\Traits\Statusable;
use App\Http\Traits\StatusToggleable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Spatie\Permission\Traits\HasRoles;
use App\Notifications\AdminPanel\RestPasswordNotification;
use Laravel\Passport\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, Notifiable, HasRoles, SoftDeletes, Statusable, StatusToggleable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'email',
        'password',
        'contact_number',
        'email_verified_at',
        'contact_number',
        'role_name',
        'device_id',
        'device_type',
        'device_name',
        'device_version',
        'created_by',
        'updated_by',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    /**
     * Send the password reset notification.
     *
     * @param  string  $token
     * @return void
     */
    public function sendPasswordResetNotification($token)
    {
        $this->notify(new RestPasswordNotification($token));
    }

    /**
     * The one time password that belong to the user.
     */
    public function one_time_password()
    {
        return $this->hasOne('App\OneTimePassword');
    }

    /**
     * The hcp that belong to the user.
     */
    public function hcp()
    {
        return $this->hasOne('App\Models\Hcp', 'user_id');
    }

    /**
     * The facility that belong to the user.
     */
    public function facility()
    {
        return $this->hasOne('App\Models\Facility', 'user_id');
    }

    /**
     * The facility group that belong to the user.
     */
    public function facility_group()
    {
        return $this->hasOne('App\Models\FacilityGroup', 'user_id');
    }

    /**
     * The facility group admin that belong to the user.
     */
    public function facility_group_admin()
    {
        return $this->hasOne('App\Models\FacilityGroupAdmin', 'user_id');
    }


    /**
     * The facility that belong to the user.
     */
    public function sub_admin()
    {
        return $this->hasOne('App\Models\SubAdmin', 'user_id');
    }
}
