<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateHcpsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('hcps', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->string('hcp_prefix')->nullable();

            $table->unsignedBigInteger('user_id');
            $table->foreign('user_id')->references('id')->on('users');

            $table->string('image')->nullable();
            $table->string('first_name')->nullable();
            $table->string('last_name')->nullable();
            $table->string('contact_number', 20)->nullable();
            $table->date('date_of_birth')->nullable();
            $table->enum('gender', ['male', 'female', 'other'])->nullable();

            $table->string('address')->nullable();
            $table->string('city_name')->nullable();
            $table->string('suburb_name')->nullable();

            $table->text('about_me')->nullable();
            $table->string('registration_number', 20)->nullable();
            $table->string('abn_number', 20)->nullable();
            $table->string('tfn_number', 20)->nullable();
            $table->integer('points')->nullable();

            $table->text('notes')->nullable();
            $table->string('attachment')->nullable();

            $table->unsignedInteger('country_id')->nullable();
            $table->foreign('country_id')->references('id')->on('countries');

            $table->unsignedInteger('state_id')->nullable();
            $table->foreign('state_id')->references('id')->on('states');

            $table->unsignedInteger('city_id')->nullable();
            $table->foreign('city_id')->references('id')->on('cities');

            $table->unsignedInteger('suburb_id')->nullable();
            $table->foreign('suburb_id')->references('id')->on('suburbs');

            $table->string('post_code')->nullable();

            $table->string('latitude')->nullable();
            $table->string('longitude')->nullable();
            $table->integer('maximum_distance')->nullable();

            $table->boolean('available_for_job')->default('true')->nullable();
            $table->boolean('accept_lower_level_job')->default('true')->nullable();

            $table->boolean('show_approved_screen')->default('false')->nullable();
            $table->boolean('agree_terms_and_conditions')->default('false')->nullable();
            $table->string('invitation_code', 20)->nullable();
            $table->string('referral_code', 20)->nullable();

            $table->string('app_registration_screen', 20)->nullable();

            $table->string('bank_name', 255)->nullable();
            $table->string('branch_name_and_address', 255)->nullable();
            $table->string('account_name', 255)->nullable();
            $table->string('account_number', 50)->nullable();
            $table->string('bsb_number', 50)->nullable();
            $table->string('superannuation_detail_fund_name', 255)->nullable();
            $table->string('superannuation_detail_membership_no', 255)->nullable();

            $table->boolean('approval_notification_sent')->default('false')->nullable();

            $table->enum('status', ['active', 'pending-approval', 'archived', 'inactive', 'rejected'])->default('pending-approval');

            $table->unsignedBigInteger('created_by')->nullable();
            $table->foreign('created_by')->references('id')->on('users');

            $table->unsignedBigInteger('updated_by')->nullable();
            $table->foreign('updated_by')->references('id')->on('users');

            $table->timestamps();
            $table->softDeletes();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('hcps');
    }
}
