<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateFacilitiesTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('facilities', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->string('facility_prefix')->nullable();

            $table->unsignedBigInteger('user_id');
            $table->foreign('user_id')->references('id')->on('users');

            $table->string('name')->nullable();

            $table->unsignedBigInteger('facility_group_id')->nullable();
            $table->foreign('facility_group_id')->references('id')->on('facility_groups');

            $table->unsignedBigInteger('facility_name_id')->nullable();
            $table->foreign('facility_name_id')->references('id')->on('facility_names');

            $table->string('contact_person')->nullable();
            $table->string('contact_number', 20)->nullable();

            $table->string('address')->nullable();
            $table->string('city_name')->nullable();
            $table->string('suburb_name')->nullable();
            $table->string('post_code')->nullable();

            $table->string('card_number')->nullable();
            $table->string('card_expiry_date')->nullable();
            $table->string('card_cvv')->nullable();
            $table->integer('plan_auto_renewal')->comment('1 = Yes. 0 = No')->nullable();
            $table->string('stripe_customer_id')->nullable();

            $table->unsignedInteger('country_id')->nullable();
            $table->foreign('country_id')->references('id')->on('countries');
            $table->unsignedInteger('state_id')->nullable();
            $table->foreign('state_id')->references('id')->on('states');
            $table->unsignedInteger('city_id')->nullable();
            $table->foreign('city_id')->references('id')->on('cities');
            $table->unsignedInteger('suburb_id')->nullable();
            $table->foreign('suburb_id')->references('id')->on('suburbs');

            $table->string('latitude')->nullable();
            $table->string('longitude')->nullable();

            $table->enum('status', ['active', 'pending-approval', 'archived', 'inactive'])->default('pending-approval');

            $table->date('registered_date')->nullable();

            $table->integer('term_condition_accept')->default('0')->comment('1 = Yes. 0 = No')->nullable();

            $table->unsignedBigInteger('created_by')->nullable();
            $table->foreign('created_by')->references('id')->on('users');

            $table->unsignedBigInteger('updated_by')->nullable();
            $table->foreign('updated_by')->references('id')->on('users');

            $table->timestamps();
            $table->softDeletes();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('facilities');
    }
}
