<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateShiftsTable extends Migration{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('shifts', function (Blueprint $table) {
            $table->bigIncrements('id');
            $table->string('shift_prefix')->nullable();

            $table->unsignedBigInteger('facility_group_id')->nullable();
            $table->foreign('facility_group_id')->references('id')->on('facility_groups');

            $table->unsignedBigInteger('facility_id')->nullable();
            $table->foreign('facility_id')->references('id')->on('facilities');

            $table->unsignedBigInteger('hcp_id')->nullable();
            $table->foreign('hcp_id')->references('id')->on('hcps');

            $table->unsignedBigInteger('buddy_hcp_id')->nullable();
            $table->foreign('buddy_hcp_id')->references('id')->on('hcps');

            $table->unsignedBigInteger('category_id')->nullable();

            $table->foreign('category_id')->references('id')->on('categories');
            $table->unsignedBigInteger('profession_id')->nullable();

            $table->foreign('profession_id')->references('id')->on('professions');

            $table->unsignedBigInteger('hcp_level_id')->nullable();
            $table->foreign('hcp_level_id')->references('id')->on('levels');

            $table->dateTimeTz('start_time')->nullable();
            $table->dateTimeTz('end_time')->nullable();
            $table->dateTimeTz('hcp_shift_start_time')->nullable();
            $table->dateTimeTz('hcp_shift_end_time')->nullable();
            $table->dateTimeTz('approved_shift_start_time')->nullable();
            $table->dateTimeTz('approved_shift_end_time')->nullable();
            $table->integer('break')->nullable()->comment('in minutes');
            $table->string('hours')->nullable()->comment('in hours');
            $table->string('working_hours')->nullable()->comment('in hours');
            $table->string('total_hours_time')->nullable()->comment('in hours');
            $table->string('final_hours_time')->nullable()->comment('in hours');

            $table->enum('shift_status', [0,1,2,3,4,5,6])->comment('0:pending,1:scheduled,2:running,3:cancelled,4,completed,5:transfered,6:past');
            $table->enum('cancel_by', ['hcp', 'facility', 'admin'])->nullable();
            $table->dateTimeTz('cancel_time')->nullable();
            $table->string('cancel_reason')->nullable();
            $table->decimal('hcp_amount', 10, 2)->nullable();
            $table->decimal('facility_amount', 10, 2)->nullable();
            $table->decimal('admin_amount', 10, 2)->nullable();

            $table->decimal('facility_per_rate', 10, 2)->nullable();
            $table->decimal('hcp_per_rate', 10, 2)->nullable();
            $table->decimal('admin_fees', 10, 2)->nullable();
            $table->decimal('total_admin_fees_with_loading', 10, 2)->nullable();
            $table->decimal('hcp_shift_loading', 10, 2)->nullable();
            $table->decimal('hcp_shift_total_loading', 10, 2)->nullable();
            $table->decimal('facility_shift_loading', 10, 2)->nullable();
            $table->decimal('facility_shift_total_loading', 10, 2)->nullable();

            $table->unsignedInteger('no_of_openings')->nullable();
            $table->string('notes')->nullable();
            $table->string('notes_attachments')->nullable();
            $table->enum('gender', ['male', 'female','other'])->nullable();

            $table->enum('shift_type', ['morning','afternoon', 'night', 'buddy', 'saturday', 'sunday', 'public-holiday', 'christmas'])->nullable();

            $table->enum('shift_time', ['morning','afternoon', 'night', 'saturday', 'sunday', 'public-holiday', 'christmas'])->nullable();

            $table->enum('shift_transfered', ['yes', 'no'])->default('no')->nullable();
            $table->enum('shift_swapped', ['yes', 'no'])->default('no')->nullable();

            $table->dateTimeTz('shift_approved_time')->nullable();

            $table->string('mentor_hcp_name')->nullable();
            $table->string('mentor_hcp_email')->nullable();
            $table->unsignedBigInteger('mentor_hcp_id')->nullable();
            $table->foreign('mentor_hcp_id')->references('id')->on('hcps');
            $table->unsignedBigInteger('scheduled_shift_id')->nullable();

            $table->string('trainee_hcp_name')->nullable();
            $table->string('trainee_hcp_email')->nullable();
            $table->unsignedBigInteger('trainee_hcp_id')->nullable();
            $table->foreign('trainee_hcp_id')->references('id')->on('hcps');
            $table->unsignedBigInteger('trainee_buddy_shift_id')->nullable();

            $table->string('address')->nullable();

            $table->unsignedInteger('country_id');
            $table->foreign('country_id')->references('id')->on('countries');

            $table->unsignedInteger('state_id');
            $table->foreign('state_id')->references('id')->on('states');

            $table->unsignedInteger('city_id');
            $table->foreign('city_id')->references('id')->on('cities');

            $table->unsignedInteger('suburb_id');
            $table->foreign('suburb_id')->references('id')->on('suburbs');

            $table->enum('shift_broadcast', ['favourite', 'rated', 'other', 'all', 'completed'])->default('favourite')->nullable();

            $table->dateTimeTz('shift_rebroadcast_time')->nullable();
            $table->enum('hcp_reached_at_location_notification', ['yes', 'no'])->default('no')->nullable();
            $table->enum('time_over_notification_sent', ['yes', 'no'])->default('no')->nullable();

            $table->unsignedInteger('reminder_notification_sent_count')->default('0')->nullable();

            $table->enum('multiple_shifts', ['yes', 'no'])->default('no')->nullable();

            $table->enum('status', ['active', 'inactive'])->default('active');

            $table->unsignedBigInteger('created_by')->nullable();
            $table->foreign('created_by')->references('id')->on('users');

            $table->unsignedBigInteger('updated_by')->nullable();
            $table->foreign('updated_by')->references('id')->on('users');

            $table->timestamps();
            $table->softDeletes();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down(){
        Schema::dropIfExists('shifts');
    }
}
