<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateGeneralConfigurationsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('general_configurations', function (Blueprint $table) {
            $table->bigIncrements('id');

            $table->integer('hcp_signup_awarded_points')->nullable();

            $table->integer('free_shift_cancel_period_for_hcp')->nullable();

            $table->integer('penalty_points_for_shift_cancellation')->nullable();
            $table->integer('free_shift_cancel_period_for_facillity')->nullable();

            $table->integer('default_hours_shift')->nullable();

            $table->integer('notification_to_hcp_upon_reaching_points')->nullable();

            $table->integer('job_limit_in_trial_account')->nullable();
            $table->integer('job_days_in_trial_account')->nullable();

            $table->enum('payment_hcp_after_shift_completion', ['yes', 'no'])->nullable();
            $table->integer('radius_km_for_shift_broadcast')->nullable();

            $table->integer('min_shift_booking_hours')->nullable();
            $table->integer('max_shift_booking_hours')->nullable();
            $table->integer('min_cancel_hrs_to_start_time_for_facility')->nullable();

            $table->integer('no_of_hrs_allowed_fortnight')->default(100)->nullable();

            $table->integer('reminder_job_in_minutes')->nullable();
            $table->integer('cancel_penalty_fee_for_facility')->nullable();

            $table->enum('tracking_hcp', ['yes', 'no'])->nullable();
            $table->integer('tracking_before_start_job_in_minutes')->nullable();

            $table->decimal('admin_fee', 10, 2)->nullable();
            $table->decimal('referrer_amount', 10, 2)->nullable();
            $table->decimal('referee_amount', 10, 2)->nullable();

            $table->string('hcp_cust_care_no')->nullable();
            $table->string('facillity_cust_care_no')->nullable();

            $table->decimal('radius_km_for_shift_start', 10, 2)->nullable();

            $table->integer('shift_start_before_mint')->default(5)->comment('In mint')->nullable();
            $table->integer('shift_rebroadcast_mint')->default(30)->comment('In mint')->nullable();
            $table->integer('shift_rebroadcast_to_all_mint')->default(30)->comment('In mint')->nullable();

            $table->string('hcp_cust_care_email')->nullable();
            $table->string('facillity_cust_care_email')->nullable();

            $table->integer('gst_percent')->default(0)->nullable();
            $table->string('stripe_tax_rates_key')->nullable();

            $table->integer('invoice_overdue_hcp_day')->default(30)->nullable();
            $table->integer('invoice_overdue_facillity_day')->default(30)->nullable();

            $table->integer('rebroadcast_to_all_before_shift_start')->default(6)->nullable();

            $table->integer('no_of_hrs_allowed_perday')->default(15)->nullable();

            $table->string('android_app_link')->nullable();
            $table->string('ios_app_link')->nullable();

            $table->string('android_app_version')->nullable();
            $table->float('ios_app_version')->nullable();

            $table->integer('show_accept_lower_level_job_checkbox')->default(0)->comment('1 = Yes, 0 = No')->nullable();

            $table->unsignedBigInteger('created_by')->nullable();
            $table->foreign('created_by')->references('id')->on('users');

            $table->unsignedBigInteger('updated_by')->nullable();
            $table->foreign('updated_by')->references('id')->on('users');

            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('general_configurations');
    }
}
