<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateFacilityPlanTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('facility_plan', function (Blueprint $table) {
            $table->bigIncrements('id');

            $table->unsignedBigInteger('plan_id');
            $table->foreign('plan_id')->references('id')->on('plans');

            $table->unsignedBigInteger('facility_id');
            $table->foreign('facility_id')->references('id')->on('facilities');

            $table->date('start_date')->nullable();
            $table->date('expiry_date')->nullable();
            $table->text('plan_details')->nullable();

            $table->string('shift_posting_limit_in_trial_account')->nullable();
            $table->string('days_of_shift_posting_limit_in_trial_account')->nullable();

            $table->decimal('payment_amount', 10, 2)->nullable();
            $table->dateTimeTz('last_payment_date')->nullable();

            $table->string('stripe_subscriptions_id')->nullable();

            $table->dateTimeTz('disable_date')->nullable();
            $table->date('notification_date')->nullable();

            $table->enum('status', ['active', 'expired', 'disable', 'pending', 'cancel'])->nullable();

            $table->unsignedBigInteger('created_by')->nullable();
            $table->foreign('created_by')->references('id')->on('users');

            $table->unsignedBigInteger('updated_by')->nullable();
            $table->foreign('updated_by')->references('id')->on('users');

            $table->timestamps();
            $table->softDeletes();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('facility_plan');
    }
}
