<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateTransactionsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('transactions', function (Blueprint $table) {
            $table->bigIncrements('id');

            $table->string('invoice_prefix')->nullable();
            $table->string('statement_prefix')->nullable();

            $table->unsignedBigInteger('shift_id')->nullable();
            $table->foreign('shift_id')->references('id')->on('shifts');

            $table->unsignedBigInteger('hcp_id')->nullable();
            $table->foreign('hcp_id')->references('id')->on('hcps');

            $table->unsignedBigInteger('facility_id')->nullable();
            $table->foreign('facility_id')->references('id')->on('facilities');

            $table->unsignedBigInteger('referral_id')->nullable();
            $table->foreign('referral_id')->references('id')->on('referrals');

            $table->unsignedBigInteger('facility_plan_id')->nullable();
            $table->foreign('facility_plan_id')->references('id')->on('facility_plan');

            $table->text('facility_plan_json')->nullable();

            $table->decimal('hcp_amount', 10, 2)->nullable();
            $table->decimal('facility_amount', 10, 2)->nullable();
            $table->decimal('admin_fees', 10, 2)->nullable();
            $table->decimal('total_admin_fees_with_loading', 10, 2)->nullable();

            $table->integer('invoice_gst_percent')->nullable();
            $table->decimal('invoice_gst_amount', 10, 2)->nullable();
            $table->decimal('invoice_facility_amount_with_gst', 10, 2)->nullable();

            $table->string('invoice_id')->nullable();
            $table->string('statement_id')->nullable();

            $table->string('invoice_file_name')->nullable();
            $table->string('invoice_generated_date_range')->nullable();
            $table->date('invoice_created_at')->nullable();
            $table->date('overdue_date')->nullable();

            $table->date('hcp_paid_on')->nullable();

            $table->unsignedBigInteger('hcp_paid_by')->nullable();
            $table->foreign('hcp_paid_by')->references('id')->on('users');

            $table->date('paid_on')->nullable();

            $table->unsignedBigInteger('paid_by')->nullable();
            $table->foreign('paid_by')->references('id')->on('users');

            $table->string('stripe_payment_session_id')->nullable();
            $table->dateTime('stripe_plan_expire_date')->nullable();
            $table->string('transaction_id')->nullable();

            $table->enum('amount_for', ['hcp','facility'])->nullable();

            $table->enum('amount_type', ['shift', 'shift-cancel-penalty', 'refer-and-earn', 'subscription', 'subscription-temp'])->nullable();

            $table->enum('status', ['pending', 'completed', 'cancelled', 'overdue'])->nullable();

            $table->enum('hcp_payment_status', ['pending', 'completed', 'cancelled', 'overdue'])->nullable();

            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('transactions');
    }
}
