var Components = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            $(window).bind("pageshow", function() {
                $(".form-control-sm").val("");
            });
        },

        /**
         * Date picker.
         */
        datePicker: function($source) {
            var $date_picker = $source.find(".date-picker");

            if ($date_picker.length) {
                $date_picker.flatpickr({
                    format: "Y-m-d"
                });
            }
        },

        /**
         * Image preview.
         */
        imagePreview: function($source) {
            var $image_preview = $source.find(".image-preview");

            if ($image_preview.length) {
                $image_preview.dropify({
                    allowedFileExtensions: "jpg jpeg png gif svg",
                    showRemove: true
                });
            }
        },

        /**
         * Bootstrap select.
         */
        bootstrapSelect: function($source) {
            var $select = $source.find(".select-picker");

            if ($select.length) {
                $select.selectpicker({
                    liveSearch: true,
                    selectedTextFormat: "count > 2",
                    size: "8",
                    iconBase: "fontawesome",
                    tickIcon: "fa fa-check"
                });
            }
        },

        /**
         * Add new entity.
         */
        addNewEntity: function($source) {
            $source.on("click", ".add-new-entity", function() {
                var $this = $(this);
                var $add_new_entity_modal = $("#add-new-entity-modal");

                $add_new_entity_modal.modal("show");
                $add_new_entity_modal
                    .find(".modal-content")
                    .load($this.data("url"), function() {
                        Components.validateAddNewEntityForm(
                            $add_new_entity_modal
                        );
                        Components.addNewEntityForm(
                            $add_new_entity_modal,
                            $this
                        );
                        Components.bootstrapSelect($add_new_entity_modal);
                    });

                $add_new_entity_modal.on("hidden.bs.modal", function() {
                    App.resetModal($add_new_entity_modal);
                });
            });
        },

        /**
         * Validate add new entity form.
         */
        validateAddNewEntityForm: function($source) {
            var $form = $source.find("form");

            $form.find("select").change(function() {
                $(this).valid();
            });

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    //
                },
                //------------------

                // @validation error messages
                messages: {
                    //
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },

                submitHandler: function(form) {
                    //
                }
            });
        },

        /**
         * Add new entity form.
         */
        addNewEntityForm: function($source, $this) {
            $source.find("form").on("click", ".btn-submit", function(e) {
                e.preventDefault();

                if ($source.find("form").valid()) {
                    $form = $source.find("form");

                    $.ajax({
                        url: $form.attr("action"),
                        type: "POST",
                        data: $form.serialize(),
                        cache: false,
                        processData: false,
                        beforeSend: function() {
                            $form.find("#custom-error").html("");
                            App.formLoading($form);
                        },
                        success: function(response) {
                            var data = response._data;
                            var grouped = response.grouped;

                            if (response._status == true) {
                                if (grouped) {
                                    var $form_group = $this.closest(
                                        ".form-group"
                                    );
                                    var selectedText = $form
                                        .find("select option:selected")
                                        .text();
                                    var $optgroups = $form_group.find(
                                        "select optgroup"
                                    );
                                    var $addable_optgroup = null;

                                    $.each($optgroups, function(
                                        index,
                                        optgroup
                                    ) {
                                        var $optgroup = $(optgroup);

                                        if (
                                            $optgroup.attr("label") ==
                                            selectedText
                                        ) {
                                            $addable_optgroup = $optgroup;

                                            return false;
                                        }
                                    });

                                    if ($addable_optgroup) {
                                        var html = "";
                                        html +=
                                            '<option selected value="' +
                                            data.id +
                                            '">' +
                                            data.name +
                                            "</option>";
                                        $addable_optgroup.append(html);
                                        $form_group
                                            .find("select")
                                            .selectpicker("refresh");
                                    }
                                } else {
                                    var html = "";
                                    var $form_group = $this.closest(
                                        ".form-group"
                                    );
                                    html +=
                                        '<option selected value="' +
                                        data.id +
                                        '">' +
                                        data.name +
                                        "</option>";
                                    $form_group.find("select").append(html);
                                    $form_group
                                        .find("select")
                                        .selectpicker("refresh");
                                }
                                $source.modal("hide");
                            }

                            // Show notification
                            App.showNotification(response);
                            //------------------
                        },
                        error: function(response) {
                            if (response.responseJSON._status == false) {
                                $form
                                    .find("#custom-error")
                                    .html(
                                        '<div class="alert dark alert-danger alert-dismissible"> ' +
                                            response.responseJSON._message +
                                            " </div>"
                                    );
                            }
                        },
                        complete: function(response) {
                            App.stopFormLoading($form);
                        }
                    });
                    return false;
                }
            });
        },

        /**
         * Description editor.
         */
        descriptionEditor: function($source) {
            $source.find(".editor-textarea").summernote({
                placeholder: "Enter description here...",
                height: 150,
                toolbar: [["style", ["bold", "italic", "underline", "clear"]]],
                callbacks: {
                    onKeyup: function() {
                        $(this).valid();
                    }
                }
            });
        },

        /**
         * Remove image.
         */
        removeImage: function($source) {
            var $image = $(".image-main");

            $source.on("click", ".dropify-clear", function() {
                $.ajax({
                    type: "POST",
                    url: $image.data("remove-image-url"),
                    data: {
                        id: $image.data("remove-image-id")
                    },
                    beforeSend: function() {
                        //
                    },
                    success: function(response) {
                        App.showNotification(response);
                    },
                    error: function() {},
                    complete: function() {
                        //
                    }
                });
            });
        }
    };
})();

Components.init();
