var Config = (function () {
    return {
        /**
         * Initialization.
         */
        init: function () {
            Config.initializeComponents();
            Config.customValidationMethods();
            Config.validateGeneralForm();
            Config.validateBreakTimeForm();
            Config.validateLoadingTimeForm();
            Config.validateTrialAccForm();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function () {
            //
        },

        /**
         * Custom validation methods.
         */
        customValidationMethods: function () {
            jQuery.validator.addMethod(
                "emailChecker",
                function (value, element) {
                    return (
                        this.optional(element) ||
                        /^([a-zA-Z0-9_\.\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/i.test(
                            value
                        )
                    );
                },
                "Please enter a valid email address."
            );

            jQuery.validator.addMethod(
                "mobileNumber",
                function (value, element) {
                    return (
                        this.optional(element) ||
                        /^\+[1-9]{1}[0-9]{8,14}$/i.test(value)
                    );
                },
                "Please enter valid number e.g. +61474567894"
            );
        },

        /**
         * Validate general form.
         */
        validateGeneralForm: function () {
            var $form = $(".general-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    hcp_signup_awarded_points: {
                        required: true,
                        digits: true,
                    },
                    free_shift_cancel_period_for_hcp: {
                        required: true,
                        digits: true,
                    },
                    penalty_points_for_shift_cancellation: {
                        required: true,
                        digits: true,
                    },
                    free_shift_cancel_period_for_facillity: {
                        required: true,
                        digits: true,
                    },
                    default_hours_shift: {
                        required: true,
                        digits: true,
                    },
                    radius_km_for_shift_broadcast: {
                        required: true,
                        digits: true,
                    },
                    min_shift_booking_hours: {
                        required: true,
                        digits: true,
                    },
                    min_cancel_hrs_to_start_time_for_facility: {
                        required: true,
                        digits: true,
                    },
                    no_of_hrs_allowed_fortnight: {
                        required: true,
                        digits: true,
                    },
                    reminder_job_in_minutes: {
                        required: true,
                        digits: true,
                    },
                    tracking_before_start_job_in_minutes: {
                        required: true,
                        digits: true,
                    },
                    cancel_penalty_fee_for_facility: {
                        required: true,
                        number: true,
                        min: 0,
                    },
                    admin_fee: {
                        required: true,
                        number: true,
                        min: 0,
                    },
                    hcp_cust_care_no: {
                        required: true,
                        digits: true,
                    },
                    facillity_cust_care_no: {
                        required: true,
                        digits: true,
                    },
                    referrer_amount: {
                        required: true,
                        number: true,
                        min: 0,
                    },
                    referee_amount: {
                        required: true,
                        number: true,
                        min: 0,
                    },
                    max_shift_booking_hours: {
                        required: true,
                        number: true,
                        min: 1,
                        max: 14,
                    },
                    radius_km_for_shift_start: {
                        required: true,
                        number: true,
                        min: 0,
                    },
                    tracking_every_minutes: {
                        required: true,
                        number: true,
                        min: 0,
                    },
                    shift_start_before_mint: {
                        required: true,
                        number: true,
                        min: 1,
                    },
                    shift_rebroadcast_mint: {
                        required: true,
                        number: true,
                        min: 1,
                    },
                    shift_rebroadcast_to_all_mint: {
                        required: true,
                        number: true,
                        min: 1,
                    },
                    gst_percent: {
                        required: true,
                        number: true,
                        min: 1,
                    },
                    hcp_cust_care_email: {
                        required: true,
                        email: true,
                    },
                    facillity_cust_care_email: {
                        required: true,
                        email: true,
                    },
                    invoice_overdue_hcp_day: {
                        required: true,
                        digits: true,
                    },
                    invoice_overdue_facillity_day: {
                        required: true,
                        digits: true,
                    },
                    rebroadcast_to_all_before_shift_start: {
                        required: true,
                        digits: true,
                    },
                    hcp_cannot_cancel_transfer_swap_with_hours: {
                        required: true,
                        digits: true,
                    },
                    stripe_tax_rates_key: {
                        required: true,
                    },
                    no_of_hrs_allowed_perday: {
                        required: true,
                        digits: true,
                    },
                    android_app_link: {
                        required: true,
                        url: true,
                    },
                    ios_app_link: {
                        required: true,
                        url: true,
                    },
                    android_app_version: {
                        required: true,
                    },
                    ios_app_version: {
                        required: true,
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    hcp_signup_awarded_points: {
                        required: "This field is required."
                    },
                    free_shift_cancel_period_for_hcp: {
                        required: "This field is required."
                    },
                    penalty_points_for_shift_cancellation: {
                        required: "This field is required."
                    },
                    free_shift_cancel_period_for_facillity: {
                        required: "This field is required."
                    },
                    default_hours_shift: {
                        required: "This field is required."
                    },
                    radius_km_for_shift_broadcast: {
                        required: "This field is required."
                    },
                    min_shift_booking_hours: {
                        required: "This field is required."
                    },
                    min_cancel_hrs_to_start_time_for_facility: {
                        required: "This field is required."
                    },
                    no_of_hrs_allowed_fortnight: {
                        required: "This field is required."
                    },
                    reminder_job_in_minutes: {
                        required: "This field is required."
                    },
                    tracking_before_start_job_in_minutes: {
                        required: "This field is required."
                    },
                    cancel_penalty_fee_for_facility: {
                        required: "This field is required."
                    },
                    admin_fee: {
                        required: "This field is required."
                    },
                    hcp_cust_care_no: {
                        required: "This field is required."
                    },
                    facillity_cust_care_no: {
                        required: "This field is required."
                    },
                    referrer_amount: {
                        required: "This field is required."
                    },
                    referee_amount: {
                        required: "This field is required."
                    },
                    radius_km_for_shift_start: {
                        required: "This field is required."
                    },
                    tracking_every_minutes: {
                        required: "This field is required."
                    },
                },
                //---------------------------

                highlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function (form) {
                    App.formLoading($form);
                    form.submit();
                }
            });

        },

        /**
         * Validate break time form.
         */
        validateBreakTimeForm: function () {
            var $form = $(".break-time-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    up_to_four_hours_shift: {
                        required: true,
                        digits: true,
                    },
                    four_eight_hours_to_shift: {
                        required: true,
                        digits: true,
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    up_to_four_hours_shift: {
                        required: "This field is required."
                    },
                    four_eight_hours_to_shift: {
                        required: "This field is required."
                    },
                },
                //---------------------------

                highlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function (form) {
                    App.formLoading($form);
                    form.submit();
                }
            });

        },

        /**
         * Validate loading time form.
         */
        validateLoadingTimeForm: function () {
            var $form = $(".loading-time-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    morning_shift_time_first: {
                        required: true,
                    },
                    morning_shift_time_second: {
                        required: true,
                    },
                    afternoon_shift_time_first: {
                        required: true,
                    },
                    afternoon_shift_time_second: {
                        required: true,
                    },
                    loading_afternoon_shift: {
                        required: true,
                        digits: true,
                    },
                    loading_night_shift: {
                        required: true,
                        digits: true,
                    },
                    loading_saturday_shift: {
                        required: true,
                        digits: true,
                    },
                    loading_sunday_shift: {
                        required: true,
                        digits: true,
                    },
                    loading_public_holiday_shift: {
                        required: true,
                        digits: true,
                    },
                    loading_christmas_holiday_shift: {
                        required: true,
                        digits: true,
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    morning_shift_time_first: {
                        required: "This field is required."
                    },
                    morning_shift_time_second: {
                        required: "This field is required."
                    },
                    afternoon_shift_time_first: {
                        required: "This field is required."
                    },
                    afternoon_shift_time_second: {
                        required: "This field is required."
                    },
                    loading_afternoon_shift: {
                        required: "This field is required."
                    },
                    loading_night_shift: {
                        required: "This field is required."
                    },
                    loading_saturday_shift: {
                        required: "This field is required."
                    },
                    loading_sunday_shift: {
                        required: "This field is required."
                    },
                    loading_public_holiday_shift: {
                        required: "This field is required."
                    },
                    loading_christmas_holiday_shift: {
                        required: "This field is required."
                    },
                },
                //---------------------------

                highlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function (form) {
                    App.formLoading($form);
                    form.submit();
                }
            });

        },

        /**
         * Validate trial acc form.
         */
        validateTrialAccForm: function () {
            var $form = $(".trial-acc-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    shift_posting_limit_in_trial_acc: {
                        required: true,
                        digits: true,
                    },
                    days_of_shift_posting_limit_in_trial_acc: {
                        required: true,
                        digits: true,
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    shift_posting_limit_in_trial_acc: {
                        required: "This field is required."
                    },
                    days_of_shift_posting_limit_in_trial_acc: {
                        required: "This field is required."
                    },
                },
                //---------------------------

                highlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function (form) {
                    App.formLoading($form);
                    form.submit();
                }
            });

        },

    };
})();

Config.init();
