var Facilities = (function () {
    return {
        /**
         * Initialization.
         */
        init: function () {
            Facilities.initializeComponents();
            Facilities.validateFacilitiesForm();
            Facilities.customValidationMethods();
            Facilities.dataTableCustomFilter();
            Facilities.removeHcpFromFavourite();
            Facilities.getfacilityNames();
            Facilities.getfacilityNameDetails();
            Facilities.getStates();
            Facilities.getCities();
            Facilities.getSuburbs();
            Facilities.linkAction();
            Facilities.disablePlan();
            Facilities.cancelPlan();
            Facilities.reactivePlan();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function () {
            var $form = $(".add-facilities-form");

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------

            // Expiry Date
            var expiryDays = DEV_CONFIG["expiry_date_limit"]["config_value"];
            var expiry_date = new Date();
            expiry_date.setDate(expiry_date.getDate() + parseInt(expiryDays));
            //------------

            // Date picker
            var $start_date_picker = $form.find(".start-date-picker");
            var $end_date_picker = $form.find(".end-date-picker");

            if ($start_date_picker.length) {
                $start_date_picker.flatpickr({
                    format: "Y-m-d",
                    minDate: "today",
                    onClose: function(selectedDates, dateStr, instance) {
                        var endSelectedDates = new Date(
                            selectedDates
                        ).fp_incr(1);

                        $end_date_picker.flatpickr({
                            dateFormat: "Y-m-d",
                            minDate: endSelectedDates,
                        });
                    }
                });
            }
            if ($end_date_picker.length) {
                $end_date_picker.flatpickr({
                    format: "Y-m-d",
                    minDate: "today",
                });
            }
            //------------

            // card expiry picker
            var $card_expiry_picker = $form.find(".card-expiry-date");
            if ($card_expiry_picker.length) {
                $card_expiry_picker.flatpickr({
                    format: "Y-m-d",
                    minDate: "today",
                });
            }
            //-------------------

            // filter form
            var $filter_form = $(".custom-datatable-filter-form");
            Components.bootstrapSelect($filter_form);
            //------------

            // Date picker
            var $date_picker = $filter_form.find(".date-picker");
            if ($date_picker.length) {
                $date_picker.flatpickr({
                    format: "Y-m-d",
                    mode: "range",
                    onClose: function(selectedDates, dateStr, instance) {
                        //
                    }
                });
            }
            //------------


            // Apply filter
            $(".apply-filter").on("click", function(e) {
                var checked = []
                $("input[name='states[]']:checked").each(function () {
                    checked.push(parseInt($(this).val()));
                });
                if( checked.length || $('#plan_type').val() !='' || $('#plan_cycle').val() !='' || $('#plan_end_date').val() !='') {
                    $filter_form.submit();
                    $('.filter-error').hide();
                    $(".custom-datatable-filter").toggleClass("hide");
                    e.preventDefault();
                } else {
                    $('.filter-error').show();
                }
            });
            //-------------

            // Clear filter
            $(".clear-filter").on("click", function(e) {
                $(".custom-datatable-filter-form")[0].reset();
                $source = $(".custom-datatable-filter-form");
                $select = $source.find(".select-picker");
                $select.selectpicker("refresh");
                $source.find('.btn-custom-outline').removeClass('active');
                $(".filter-button").addClass('btn-dark');
                $(".filter-button").removeClass('btn-primary');
                $(".custom-datatable-filter").toggleClass("hide");
                window.location.replace(window.location.pathname);
                e.preventDefault();
            });
            //-------------

            // Expiry date picker
            var $formDocument = $(".add-facilities-form");
            var $expiry_date_picker = $formDocument.find(".expiry-date");

            if ($expiry_date_picker.length) {
                $expiry_date_picker.flatpickr({
                    format: "Y-m-d",
                    minDate: expiry_date
                });
            }
            //-------------------

        },


        /**
         * Datatable custom filter.
         */
        dataTableCustomFilter: function() {
            $(".filter-button").click(function() {
                var $this = $(this);
                $(".custom-datatable-filter").toggleClass("hide");
                $this.addClass('btn-primary');
                $this.removeClass('btn-dark');
            });
        },


        /**
         * Custom validation methods.
         */
        customValidationMethods: function () {
            jQuery.validator.addMethod(
                "emailChecker",
                function (value, element) {
                    return (
                        this.optional(element) ||
                        /^([a-zA-Z0-9_\.\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/i.test(
                            value
                        )
                    );
                },
                "Please enter a valid email address."
            );

            jQuery.validator.addMethod(
                "mobileNumber",
                function(value, element) {
                    return (
                        this.optional(element) ||
                        /^\+[1-9]{1}[0-9]{8,14}$/i.test(value)
                    );
                },
                "Please enter valid number e.g. +61474567894"
            );
        },

        /**
         * Validate facilities form.
         */
        validateFacilitiesForm: function () {
            var $form = $(".add-facilities-form");

            $form.find("select").change(function () {
                $(this).valid();
            });

            $form.validate({
                ignore: "input[type='text']:hidden *",

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    facility_name_id: {
                        required: true,
                    },
                    facility_group: {
                        required: true,
                    },
                    contact_person: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    email: {
                        required: true,
                        emailChecker: true,
                        remote: {
                            url: $("#email").data("url"),
                            type: "post",
                            data: {
                                email: function () {
                                    return $("#email").val();
                                }
                            }
                        },
                        maxlength: DEV_CONFIG["email_length"]["config_value"]
                    },
                    contact_number: {
                        required: true,
                        mobileNumber: true,
                    },
                    plan: {
                        required: true
                    },
                    plan_cycle: {
                        required: true
                    },
                    plan_start_date: {
                        required: true
                    },
                    plan_end_date: {
                        required: true
                    },
                    country_id: {
                        required: true
                    },
                    state_id: {
                        required: true
                    },
                    city_name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    address: {
                        required: true
                    },
                    card_number: {
                        digits: true,
                        minlength: 8,
                        maxlength: 20
                    },
                    card_expiry_date: {
                        required: {
                            depends: function() {
                                return $("#card_number").val() != "";
                            }
                        },
                    },
                    card_cvv: {
                        digits: true,
                        required: {
                            depends: function() {
                                return $("#card_number").val() != "";
                            }
                        },
                        minlength: 3,
                        maxlength: 4
                    }
                },
                //------------------

                // @validation error messages
                messages: {
                    email: {
                        required: "Please enter email.",
                        emailChecker: "Please enter valid email",
                        remote:
                            "The email address you have entered is already registered."
                    },
                    contact_number: {
                        required: "Please enter contact number.",
                    },
                    plan: {
                        required: "Please select plan."
                    },
                    country_id: {
                        required: "Please select country."
                    },
                    state_id: {
                        required: "Please select state."
                    },
                    city_name: {
                        required: "Please enter city."
                    },
                    address: {
                        required: "Please enter address."
                    },
                    facility_group: {
                        required: "Please select facility group."
                    },
                    contact_person: {
                        required: "Please enter contact person name."
                    },
                    plan_cycle: {
                        required: "Please select plan cycle."
                    },
                    plan_start_date: {
                        required: "Please select plan start cycle."
                    },
                    plan_end_date: {
                        required: "Please select plan end cycle."
                    },
                    facility_name_id: {
                        required: "Please select facility name."
                    },
                    card_number: {
                        required: "Please enter card number."
                    },
                    card_expiry_date: {
                        required: "Please select card expiry date."
                    },
                    card_cvv: {
                        required: "Please enter card cvv."
                    },
                },
                //---------------------------

                highlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function (form) {
                    App.formLoading($form);
                    form.submit();
                }
            });


            for (let index = 0; index <= $("#document_count").val(); index++) {
                $(".document-file-" + index).rules("add", {
                    required: {
                        depends: function() {
                            return $(".mandatory-status-" + index).val() == "yes";
                        }
                    },
                    extension: "pdf|png|jpg|jpeg",
                    messages: {
                        required: "Please select file.",
                        extension: "Please select file only pdf,jpg,png format."
                    }
                });

                $(".expiry-date-required-" + index).rules("add", {
                    required: {
                        depends: function() {
                            return $("#file-" + index).val() != "";
                        }
                    },
                    messages: {
                        required: "Please select expiry date."
                    }
                });
            }
        },

        /**
         * Get states according to country.
         */
        getStates: function ($source) {
            var $source = $(".add-facilities-form");

            $source.on("change", ".country-state", function () {
                var $this = $(this);
                var country = $this.val();

                if (country != "") {

                    var country_sortname = $(this)
                        .find(":selected")
                        .attr("data-sortname");

                    initAutocomplete(country_sortname);

                    $(".state-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            country_id: country
                        },
                        success: function (response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function (index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#state_id").html(options);
                            $("#state_id").selectpicker("refresh");

                            $(".state-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Get city according to states.
         */
        getCities: function ($source) {
            var $source = $(".add-facilities-form");

            $source.on("change", ".state-city", function () {
                var $this = $(this);
                var state = $this.val();

                if (state != "") {
                    $(".city-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            state_id: state
                        },
                        success: function (response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function (index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#city_id").html(options);
                            $("#city_id").selectpicker("refresh");

                            $(".city-div .input-loading").hide();
                        }
                    });
                }
            });
        },


        /**
         * Get suburbs according to city.
         */
        getSuburbs: function($source) {
            var $source = $(".add-facilities-form");

            $source.on("change", ".city-suburb", function() {
                var $this = $(this);
                var city = $this.val();

                if (city != "") {
                    $(".suburb-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            city_id: city
                        },
                        success: function(response) {
                            var data = response._data;
                            var options ='';

                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#suburb_id").html(options);
                            $("#suburb_id").selectpicker("refresh");
                            $(".suburb-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Remove hcp from favourite.
         */
        removeHcpFromFavourite: function() {
            var $source = $("#dataTable-favourite-hcp");
            $source.on("click", ".remove-favourite-button", function() {
                var $this = $(this);
                var id = $this.data("id");
                var facility = $this.data("facility");

                iziToast.question({
                    timeout: 20000,
                    close: false,
                    overlay: true,
                    displayMode: "once",
                    color: "yellow",
                    id: "question",
                    zindex: 99999,
                    title: "Hey!",
                    message: "Are you sure to want to remove?",
                    position: "center",
                    progressBar: false,
                    buttons: [
                        [
                            "<button><b>YES</b></button>",
                            function(instance, toast) {
                                $.ajax({
                                    type: "DELETE",
                                    url: $this.data("destroy-url"),
                                    data: { id: id, facility: facility },
                                    beforeSend: function() {
                                        // $(".dt-delete").prop("disabled", true);
                                    },
                                    success: function(response) {
                                        App.showNotification(response);
                                        favourite_data_table.ajax.reload();
                                    },
                                    error: function() {},
                                    complete: function() {
                                        // $(".dt-delete").prop("disabled", true);
                                    }
                                });
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            },
                            true
                        ],
                        [
                            "<button>NO</button>",
                            function(instance, toast) {
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            }
                        ]
                    ],
                    onClosing: function(instance, toast, closedBy) {
                        //
                    },
                    onClosed: function(instance, toast, closedBy) {
                        //
                    }
                });
            });
        },

        /**
         * Get facility names according to facility group.
         */
        getfacilityNames: function () {
            var $source = $(".add-facilities-form,.add-sub-admins-form");

            $source.on("change", ".facility-group", function () {
                var $this = $(this);
                var facility_group = $this.val();

                if (facility_group != "") {

                    $(".facility-name-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            facility_group_id: facility_group
                        },
                        success: function (response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function (index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#facility_name_id").html(options);
                            $("#facility_name_id").selectpicker("refresh");

                            $(".facility-name-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Get facility names details according to facility name.
         */
        getfacilityNameDetails: function () {
            var $source = $(".add-facilities-form");

            $source.on("change", ".facility-name", function () {
                var $this = $(this);
                var facility_name = $this.val();

                if (facility_name != "") {

                    $(".state-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $(".address-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $(".city-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $(".suburb-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $(".post-code-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            facility_name_id: facility_name
                        },
                        success: function (response) {
                            var data = response._data;

                            if (response._status ==  true) {
                                $('select[name=state_id]').val(data.state_id);
                                $('.state-city').selectpicker('refresh');

                                $('#name').val(data.name);
                                $('#address').val(data.address);
                                $('#postcode').val(data.post_code);
                                $('#city_name').val(data.city_name);
                                $('#suburb_name').val(data.suburb_name);
                                $('#latitude').val(data.latitude);
                                $('#longitude').val(data.longitude);

                                if(data.city_name !=''){
                                    $('#city_name').val(data.city_name);
                                } else {
                                    $('#city_name').attr('readonly', false);
                                }
                            }

                            $(".state-div .input-loading").hide();
                            $(".address-div .input-loading").hide();
                            $(".city-div .input-loading").hide();
                            $(".suburb-div .input-loading").hide();
                            $(".post-code-div .input-loading").hide();
                        }
                    });
                }
            });
        },


        /**
         * Link Action.
         */
        linkAction: function() {
            var $source = $(".page-top-action");

            // Handle form submission event
            $source.on("click", ".link-action", function() {
                $this = $(this);
                iziToast.question({
                    timeout: 20000,
                    close: false,
                    overlay: true,
                    displayMode: "once",
                    color: "yellow",
                    id: "question",
                    zindex: 99999,
                    title: "Hey!",
                    message: "Are you sure to want to change status?",
                    position: "center",
                    progressBar: false,
                    buttons: [
                        [
                            "<button><b>YES</b></button>",
                            function (instance, toast) {
                                $.ajax({
                                    type: "GET",
                                    url: $this.data("url"),
                                    beforeSend: function () {
                                        //
                                    },
                                    success: function (response) {
                                        console.log(response);
                                        App.showNotification(response);
                                        location.reload(true);
                                    },
                                    error: function () {},
                                    complete: function () {
                                        //
                                    },
                                });
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            },
                            true,
                        ],
                        [
                            "<button>NO</button>",
                            function (instance, toast) {
                                instance.hide(
                                    { transitionOut: "fadeOut" }, toast,  "button"
                                );
                            },
                        ],
                    ],
                    onClosing: function (instance, toast, closedBy) {
                        //
                    },
                    onClosed: function (instance, toast, closedBy) {
                        //
                    },
                });
            });
        },

        /**
         * Disable Plan.
         */
        disablePlan: function() {
            var $source = $(".plan-div");

            // Handle form submission event
            $source.on("click", ".disable-plan", function() {
                $this = $(this);
                iziToast.question({
                    timeout: 20000,
                    close: false,
                    overlay: true,
                    displayMode: "once",
                    color: "yellow",
                    id: "question",
                    zindex: 99999,
                    title: "Hey!",
                    message: "Are you sure to want to cancel plan?",
                    position: "center",
                    progressBar: false,
                    buttons: [
                        [
                            "<button><b>YES</b></button>",
                            function (instance, toast) {
                                $.ajax({
                                    type: "GET",
                                    url: $this.data("url"),
                                    beforeSend: function () {
                                        //
                                    },
                                    success: function (response) {
                                        App.showNotification(response);
                                        location.reload(true);
                                    },
                                    error: function () {},
                                    complete: function () {
                                        //
                                    },
                                });
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            },
                            true,
                        ],
                        [
                            "<button>NO</button>",
                            function (instance, toast) {
                                instance.hide(
                                    { transitionOut: "fadeOut" }, toast,  "button"
                                );
                            },
                        ],
                    ],
                    onClosing: function (instance, toast, closedBy) {
                        //
                    },
                    onClosed: function (instance, toast, closedBy) {
                        //
                    },
                });
            });
        },

        /**
         * Reactive Plan.
         */
        reactivePlan: function() {
            var $source = $(".plan-div");

            // Handle form submission event
            $source.on("click", ".reactive-plan", function() {
                $this = $(this);
                iziToast.question({
                    timeout: 20000,
                    close: false,
                    overlay: true,
                    displayMode: "once",
                    color: "yellow",
                    id: "question",
                    zindex: 99999,
                    title: "Hey!",
                    message: "Are you sure to want to reactive plan?",
                    position: "center",
                    progressBar: false,
                    buttons: [
                        [
                            "<button><b>YES</b></button>",
                            function (instance, toast) {
                                $.ajax({
                                    type: "GET",
                                    url: $this.data("url"),
                                    beforeSend: function () {
                                        //
                                    },
                                    success: function (response) {
                                        App.showNotification(response);
                                        location.reload(true);
                                    },
                                    error: function () {},
                                    complete: function () {
                                        //
                                    },
                                });
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            },
                            true,
                        ],
                        [
                            "<button>NO</button>",
                            function (instance, toast) {
                                instance.hide(
                                    { transitionOut: "fadeOut" }, toast,  "button"
                                );
                            },
                        ],
                    ],
                    onClosing: function (instance, toast, closedBy) {
                        //
                    },
                    onClosed: function (instance, toast, closedBy) {
                        //
                    },
                });
            });
        },

        /**
         * Cancel Plan.
         */
        cancelPlan: function() {
            var $source = $(".plan-div");

            // Handle form submission event
            $source.on("click", ".cancel-plan", function() {
                $this = $(this);
                iziToast.question({
                    timeout: 20000,
                    close: false,
                    overlay: true,
                    displayMode: "once",
                    color: "yellow",
                    id: "question",
                    zindex: 99999,
                    title: "Hey!",
                    message: "Are you sure to want to cancel plan?",
                    position: "center",
                    progressBar: false,
                    buttons: [
                        [
                            "<button><b>YES</b></button>",
                            function (instance, toast) {
                                $.ajax({
                                    type: "GET",
                                    url: $this.data("url"),
                                    beforeSend: function () {
                                        //
                                    },
                                    success: function (response) {
                                        App.showNotification(response);
                                        window.location.href($this.data("redirect-url"));
                                    },
                                    error: function () {},
                                    complete: function () {
                                        //
                                    },
                                });
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            },
                            true,
                        ],
                        [
                            "<button>NO</button>",
                            function (instance, toast) {
                                instance.hide(
                                    { transitionOut: "fadeOut" }, toast,  "button"
                                );
                            },
                        ],
                    ],
                    onClosing: function (instance, toast, closedBy) {
                        //
                    },
                    onClosed: function (instance, toast, closedBy) {
                        //
                    },
                });
            });
        },

    };
})();

Facilities.init();
