var FacilityGroups = (function() {
    // Array holding selected row IDs
    var rows_selected = [];
    var data_table;
    return {
        /**
         * Initialization.
         */
        init: function() {
            FacilityGroups.initializeComponents();
            FacilityGroups.createFacilityGroupPopup();
            FacilityGroups.editFacilityGroupPopup();
            FacilityGroups.dataTableCustomFilter();
            FacilityGroups.linkAction();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {

            // filter form
            var $filter_form = $(".custom-datatable-filter-form");
            Components.bootstrapSelect($filter_form);
            //------------

            // Apply filter
            $(".apply-filter").on("click", function(e) {
                var checked = []
                $("input[name='states[]']:checked").each(function () {
                    checked.push(parseInt($(this).val()));
                });
                if( checked.length || $("#category").val() !='' || $("#profession").val() !='' || $("#availability").val() !='') {
                    $filter_form.submit();
                    $('.filter-error').hide();
                    $(".custom-datatable-filter").toggleClass("hide");
                    e.preventDefault();
                } else {
                    $('.filter-error').show();
                }
            });
            //-------------

            // Clear filter
            $(".clear-filter").on("click", function(e) {
                $(".custom-datatable-filter-form")[0].reset();
                $source = $(".custom-datatable-filter-form");
                $select = $source.find(".select-picker");
                $select.selectpicker("refresh");
                $source.find('.btn-custom-outline').removeClass('active');
                $(".filter-button").addClass('btn-dark');
                $(".filter-button").removeClass('btn-primary');
                $(".custom-datatable-filter").toggleClass("hide");
                window.location.replace(window.location.pathname);
                e.preventDefault();
            });
            //-------------
        },


        /**
         * Datatable custom filter.
         */
        dataTableCustomFilter: function() {
            $(".filter-button").click(function() {
                var $this = $(this);
                $(".custom-datatable-filter").toggleClass("hide");
                $this.addClass('btn-primary');
                $this.removeClass('btn-dark');
            });
        },


        /**
         * Validate facility group form.
         */
        validateFacilityGroupForm: function () {
            var $form = $(".add-facility-group-form");

            $form.find("select").change(function () {
                $(this).valid();
            });

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    name: {
                        required: "Please enter name."
                    },
                },
                //---------------------------

                highlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function (form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },

        /**
         * Create Facility Group Popup
         */
        createFacilityGroupPopup: function() {
            var $source = $(".widget-content");
            $source.on(
                "click",
                ".add-facility-group",
                function() {
                    var $this = $(this);
                    var $page_modal = $("#pageModalMedium");

                    $page_modal.modal("show");
                    $page_modal
                        .find(".modal-content")
                        .load($this.data("url"), function() {
                            FacilityGroups.validateFacilityGroupForm();
                            var $filter_form = $(".add-facility-group-form");
                            Components.bootstrapSelect($filter_form);
                        });

                    $page_modal.on("hidden.bs.modal", function() {
                        App.resetModal($page_modal);
                    });
                }
            );
        },

        /**
         * Edit Facility Group Popup
         */
        editFacilityGroupPopup: function() {
            var $source = $(".datatable-action");
            $source.on(
                "click",
                ".edit-facility-group",
                function() {
                    var $this = $(this);
                    var $page_modal = $("#pageModalMedium");

                    $page_modal.modal("show");
                    $page_modal
                        .find(".modal-content")
                        .load($this.data("url"), function() {
                            FacilityGroups.validateFacilityGroupForm();
                            var $filter_form = $(".add-facility-group-form");
                            Components.bootstrapSelect($filter_form);
                        });

                    $page_modal.on("hidden.bs.modal", function() {
                        App.resetModal($page_modal);
                    });
                }
            );
        },


        /**
         * Link Action.
         */
        linkAction: function() {
            var $source = $(".datatable-action");

            // Handle form submission event
            $source.on("click", ".link-action", function() {
                $this = $(this);
                iziToast.question({
                    timeout: 20000,
                    close: false,
                    overlay: true,
                    displayMode: "once",
                    color: "yellow",
                    id: "question",
                    zindex: 99999,
                    title: "Hey!",
                    message: "Are you sure to want to change status?",
                    position: "center",
                    progressBar: false,
                    buttons: [
                        [
                            "<button><b>YES</b></button>",
                            function (instance, toast) {
                                $.ajax({
                                    type: "GET",
                                    url: $this.data("url"),
                                    beforeSend: function () {
                                        //
                                    },
                                    success: function (response) {
                                        App.showNotification(response);
                                        location.reload(true);
                                    },
                                    error: function () {},
                                    complete: function () {
                                        //
                                    },
                                });
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            },
                            true,
                        ],
                        [
                            "<button>NO</button>",
                            function (instance, toast) {
                                instance.hide(
                                    { transitionOut: "fadeOut" }, toast,  "button"
                                );
                            },
                        ],
                    ],
                    onClosing: function (instance, toast, closedBy) {
                        //
                    },
                    onClosed: function (instance, toast, closedBy) {
                        //
                    },
                });
            });
        },

    };
})();

FacilityGroups.init();
