var Facilities = (function () {
    return {
        /**
         * Initialization.
         */
        init: function () {
            Facilities.initializeComponents();
            Facilities.validateFacilitiesForm();
            Facilities.customValidationMethods();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function () {
            var $form = $(".add-facility-name-form");

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------

        },


        /**
         * Datatable custom filter.
         */
        dataTableCustomFilter: function() {
            $(".filter-button").click(function() {
                var $this = $(this);
                $(".custom-datatable-filter").toggleClass("hide");
                $this.addClass('btn-primary');
                $this.removeClass('btn-dark');
            });
        },


        /**
         * Custom validation methods.
         */
        customValidationMethods: function () {
            jQuery.validator.addMethod(
                "emailChecker",
                function (value, element) {
                    return (
                        this.optional(element) ||
                        /^([a-zA-Z0-9_\.\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/i.test(
                            value
                        )
                    );
                },
                "Please enter a valid email address."
            );

            jQuery.validator.addMethod(
                "mobileNumber",
                function(value, element) {
                    return (
                        this.optional(element) ||
                        /^\+[1-9]{1}[0-9]{8,14}$/i.test(value)
                    );
                },
                "Please enter valid number e.g. +61474567894"
            );
        },

        /**
         * Validate facilities form.
         */
        validateFacilitiesForm: function () {
            var $form = $(".add-facility-name-form");

            $form.find("select").change(function () {
                $(this).valid();
            });

            $form.validate({
                ignore: "input[type='text']:hidden *",

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    facility_group: {
                        required: true,
                    },
                    state_id: {
                        required: true
                    },
                    address: {
                        required: true
                    },
                    status: {
                        required: true
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    name: {
                        required: "Please enter name."
                    },
                    state_id: {
                        required: "Please select state."
                    },
                    address: {
                        required: "Please enter address."
                    },
                    facility_group: {
                        required: "Please select facility group."
                    },
                    status: {
                        required: "Please select status."
                    },
                },
                //---------------------------

                highlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function (element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function (form) {
                    App.formLoading($form);
                    form.submit();
                }
            });


            for (let index = 0; index <= $("#document_count").val(); index++) {
                $(".document-file-" + index).rules("add", {
                    required: {
                        depends: function() {
                            return $(".mandatory-status-" + index).val() == "yes";
                        }
                    },
                    extension: "pdf|png|jpg|jpeg",
                    messages: {
                        required: "Please select file.",
                        extension: "Please select file only pdf,jpg,png format."
                    }
                });

                $(".expiry-date-required-" + index).rules("add", {
                    required: {
                        depends: function() {
                            return $("#file-" + index).val() != "";
                        }
                    },
                    messages: {
                        required: "Please select expiry date."
                    }
                });
            }
        },

        /**
         * Get states according to country.
         */
        getStates: function ($source) {
            var $source = $(".add-facilities-form");

            $source.on("change", ".country-state", function () {
                var $this = $(this);
                var country = $this.val();

                if (country != "") {

                    var country_sortname = $(this)
                        .find(":selected")
                        .attr("data-sortname");

                    initAutocomplete(country_sortname);

                    $(".state-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            country_id: country
                        },
                        success: function (response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function (index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#state_id").html(options);
                            $("#state_id").selectpicker("refresh");

                            $(".state-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Get city according to states.
         */
        getCities: function ($source) {
            var $source = $(".add-facilities-form");

            $source.on("change", ".state-city", function () {
                var $this = $(this);
                var state = $this.val();

                if (state != "") {
                    $(".city-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            state_id: state
                        },
                        success: function (response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function (index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#city_id").html(options);
                            $("#city_id").selectpicker("refresh");

                            $(".city-div .input-loading").hide();
                        }
                    });
                }
            });
        },


        /**
         * Get suburbs according to city.
         */
        getSuburbs: function($source) {
            var $source = $(".add-facilities-form");

            $source.on("change", ".city-suburb", function() {
                var $this = $(this);
                var city = $this.val();

                if (city != "") {
                    $(".suburb-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            city_id: city
                        },
                        success: function(response) {
                            var data = response._data;
                            var options ='';

                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#suburb_id").html(options);
                            $("#suburb_id").selectpicker("refresh");
                            $(".suburb-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Remove hcp from favourite.
         */
        removeHcpFromFavourite: function() {
            var $source = $("#dataTable-favourite-hcp");
            $source.on("click", ".remove-favourite-button", function() {
                var $this = $(this);
                var id = $this.data("id");
                var facility = $this.data("facility");

                iziToast.question({
                    timeout: 20000,
                    close: false,
                    overlay: true,
                    displayMode: "once",
                    color: "yellow",
                    id: "question",
                    zindex: 99999,
                    title: "Hey!",
                    message: "Are you sure to want to remove?",
                    position: "center",
                    progressBar: false,
                    buttons: [
                        [
                            "<button><b>YES</b></button>",
                            function(instance, toast) {
                                $.ajax({
                                    type: "DELETE",
                                    url: $this.data("destroy-url"),
                                    data: { id: id, facility: facility },
                                    beforeSend: function() {
                                        // $(".dt-delete").prop("disabled", true);
                                    },
                                    success: function(response) {
                                        App.showNotification(response);
                                        favourite_data_table.ajax.reload();
                                    },
                                    error: function() {},
                                    complete: function() {
                                        // $(".dt-delete").prop("disabled", true);
                                    }
                                });
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            },
                            true
                        ],
                        [
                            "<button>NO</button>",
                            function(instance, toast) {
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            }
                        ]
                    ],
                    onClosing: function(instance, toast, closedBy) {
                        //
                    },
                    onClosed: function(instance, toast, closedBy) {
                        //
                    }
                });
            });
        },
    };
})();

Facilities.init();
