var Hcps = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            Hcps.initializeComponents();
            Hcps.validateHcpsForm();
            Hcps.customValidationMethods();
            Hcps.getStates();
            Hcps.getCities();
            Hcps.getSuburbs();
            Hcps.getProfessions();
            Hcps.getLevels();
            Hcps.addMoreProfessions();
            Hcps.removeProfessions();
            Hcps.validateHcpsDocumentsForm();
            Hcps.validateHcpsProfessionForm();
            Hcps.addLevelIdInDocument();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            var $form = $(".add-hcps-form");

            // Expiry Date
            var expiryDays = DEV_CONFIG["expiry_date_limit"]["config_value"];
            var expiry_date = new Date();
            expiry_date.setDate(expiry_date.getDate() + parseInt(expiryDays));
            //------------

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------

            // Image preview
            Components.imagePreview($form);
            //--------------

            // DOB Date picker
            var $dob_date_picker = $form.find(".dob-date-picker");

            if ($dob_date_picker.length) {
                var d = new Date("2020-12-31");
                var year = d.getFullYear();
                var month = d.getMonth();
                var day = d.getDate();
                var dateYear = new Date(
                    year - DEV_CONFIG["age_limit"]["config_value"],
                    month,
                    day
                );
                $dob_date_picker.flatpickr({
                    format: "Y-m-d",
                    maxDate: dateYear
                });
            }
            //----------------

            // Expiry date picker
            var $formDocument = $(".upload-hcp-document-form");
            var $expiry_date_picker = $formDocument.find(".expiry-date");

            if ($expiry_date_picker.length) {
                $expiry_date_picker.flatpickr({
                    format: "Y-m-d",
                    minDate: expiry_date
                });
            }
            //-------------------

            var $formProfession = $(".update-hcp-profession-form");

            // Bootstrap select
            Components.bootstrapSelect($formProfession);
            //-----------------


            // Expiry date picker
            var $formDocument = $('.document-box');
            var $expiry_date_picker = $formDocument.find(".expiry-date");

            if ($expiry_date_picker.length) {
                $expiry_date_picker.flatpickr({
                    format: "Y-m-d",
                    minDate: expiry_date
                });
            }
            //-------------------

        },

        /**
         * Custom validation methods.
         */
        customValidationMethods: function() {
            jQuery.validator.addMethod(
                "emailChecker",
                function(value, element) {
                    return (
                        this.optional(element) ||
                        /^([a-zA-Z0-9_\.\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/i.test(
                            value
                        )
                    );
                },
                "Please enter a valid email address."
            );

            jQuery.validator.addMethod(
                "mobileNumber",
                function(value, element) {
                    return (
                        this.optional(element) ||
                        /^\+[1-9]{1}[0-9]{8,14}$/i.test(value)
                    );
                },
                "Please enter valid number e.g. +61474567894"
            );
        },

        /**
         * Validate hcps form.
         */
        validateHcpsForm: function() {
            var $form = $(".add-hcps-form");

            $form.find("select").change(function() {
                $(this).valid();
            });

            $form.validate({
                ignore: "input[type='text']:hidden *",

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    first_name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    last_name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    email: {
                        required: true,
                        emailChecker: true,
                        remote: {
                            url: $("#email").data("url"),
                            type: "post",
                            data: {
                                email: function() {
                                    return $("#email").val();
                                }
                            }
                        },
                        maxlength: DEV_CONFIG["email_length"]["config_value"]
                    },
                    contact_number: {
                        required: true,
                        mobileNumber: true
                    },
                    dob: {
                        required: true
                    },
                    gender: {
                        required: true
                    },
                    state_id: {
                        required: true
                    },
                    address: {
                        required: true
                    },
                    registration_number: {
                        remote: {
                            url: $("#registration_number").data("url"),
                            type: "post",
                            data: {
                                registration_number: function() {
                                    return $("#registration_number").val();
                                }
                            }
                        }
                    },
                    abn_number: {
                        digits: true,
                        minlength: 11,
                        maxlength: 11
                    },
                    tfn_number: {
                        required: true,
                        digits: true,
                        minlength: 9,
                        maxlength: 9
                    },
                    attachment: {
                        extension: "pdf|png|jpg|jpeg|doc|docx",
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    first_name: {
                        required: "Please enter first name."
                    },
                    last_name: {
                        required: "Please enter last name."
                    },
                    email: {
                        required: "Please enter email.",
                        emailChecker: "Please enter valid email",
                        remote:
                            "The email address you have entered is already registered."
                    },
                    contact_number: {
                        required: "Please enter contact number.",
                    },
                    country_id: {
                        required: "Please select country."
                    },
                    state_id: {
                        required: "Please select state."
                    },
                    city_id: {
                        required: "Please select city."
                    },
                    address: {
                        required: "Please enter address."
                    },
                    dob: {
                        required: "Please select date of birth."
                    },
                    gender: {
                        required: "Please select gender."
                    },
                    registration_number: {
                        required: "Please enter registration number.",
                        remote:
                            "The registration number you have entered is already registered."
                    },
                    abn_number: {
                        required: "Please enter abn number."
                    },
                    tfn_number: {
                        required: "Please enter tfn number."
                    },
                    attachment: {

                    },


                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });

        },

        /**
         * Validate hcps documents form.
         */
        validateHcpsDocumentsForm: function() {
            var $form = $(".upload-hcp-document-form");

            $form.find("select").change(function() {
	console.log(this);
                $(this).valid();
            });

            $form.validate({
                ignore: "input[type='text']:hidden *",

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    //
                },
                //------------------

                // @validation error messages
                messages: {
                    //
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });

            for (let index = 0; index <= $("#mandatory_document_count").val(); index++) {
	
	console.log('validation');
	var sFileName = $(".document-file-" + index).value;
	console.log(sFileName);
	
                $(".document-file-" + index).rules("add", {
                    required: {
                        depends: function() {
                            return $(".mandatory-status-" + index).val() == "yes";
                        }
                    },
                    extension: "pdf|png|jpg|jpeg",
                    messages: {
                        required: "Please select file.",
                        extension: "Please select file only pdf,jpg,png format."+index
                    }
                });
		

                $(".expiry-date-required-" + index).rules("add", {
                    required: {
                        depends: function() {
                            return $("#file-" + index).val() != "";
                        }
                    },
                    messages: {
                        required: "Please select expiry date."
                    }
                });
            }
        },

        /**
         * Get states according to country. (not in use for now)
         */
        getStates: function($source) {
            var $source = $(".add-hcps-form");

            $source.on("change", ".country-state", function() {
                var $this = $(this);
                var country = $this.val();

                if (country != "") {

                    $(".state-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            country_id: country
                        },
                        success: function(response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#state_id").html(options);
                            $("#state_id").selectpicker("refresh");
                            $(".state-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Get city according to states. (not in use for now)
         */
        getCities: function($source) {
            var $source = $(".add-hcps-form");

            $source.on("change", ".state-city-test", function() {
                var $this = $(this);
                var state = $this.val();

                if (state != "") {
                    $(".city-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            state_id: state
                        },
                        success: function(response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#city_id").html(options);
                            $("#city_id").selectpicker("refresh");
                            $(".city-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Get suburbs according to city.  (not in use for now)
         */
        getSuburbs: function($source) {
            var $source = $(".add-hcps-form");

            $source.on("change", ".city-suburb", function() {
                var $this = $(this);
                var city = $this.val();

                if (city != "") {
                    $(".suburb-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            city_id: city
                        },
                        success: function(response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#suburb_id").html(options);
                            $("#suburb_id").selectpicker("refresh");
                            $(".suburb-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Get profession according to category.
         */
        getProfessions: function($source) {
            var $source = $(".update-hcp-profession-form");

            $source.on("change", ".category-profession", function() {
                var $this = $(this);
                var category = $this.val();

                if (category != "") {
                    $(".profession-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            category_id: category
                        },
                        success: function(response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });


                            $("#professions_id").html(options);
                            $("#professions_id").selectpicker("refresh");
                            $(".profession-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Get levels according to profession.
         */
        getLevels: function($source) {
            var $source = $(".update-hcp-profession-form");

            $source.on("change", ".profession-level", function() {
                var $this = $(this);
                var profession = $this.val();

                if (profession != "") {
                    $(".level-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            profession_id: profession
                        },
                        success: function(response) {
                            var data = response._data;
                            var options = '';

                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            if(data.length > 0){
                                $("select[name='professions[0][level_id]']").rules("add", {
                                    required: true,
                                    messages: {
                                        required: "Please select level."
                                    }
                                });
                                Hcps.addLevelIdInDocument(profession, 0);
                            } else {
                                Hcps.getProfessionDocument(profession, 0);
                            }

                            $("#level_id").html(options);
                            $("#level_id").selectpicker("refresh");
                            $(".level-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Get profession document.
         */
        getProfessionDocument: function(professionId, counter, levelId = '') {
            if ($("#professions_count").length != 0) {
                var professions_count = parseInt($("#professions_count").val()) + parseInt(1);
            } else {
                var professions_count = 1;
            }

            var document_count = $("#profession-details input:file").length;
            
            $('.document-box-'+counter).html('Please wait document are loading...');
            $.ajax({
                type: "GET",
                url: $('.profession-details-div').data("profession-document-url"),
                data: {
                    profession_id: professionId,
                    level_id: levelId,
                    professions_count: professions_count,
                    document_count: document_count,
                    counter: counter
                },
                success: function(response) {
                    if(response._status == true){
                        $('.document-box-'+counter).html(response._content);

                        // Expiry Date
                        var expiryDays = DEV_CONFIG["expiry_date_limit"]["config_value"];
                        var expiry_date = new Date();
                        expiry_date.setDate(expiry_date.getDate() + parseInt(expiryDays));
                        //------------

                        // Expiry date picker
                        var $formDocument = $('.document-box-'+counter);
                        var $expiry_date_picker = $formDocument.find(".expiry-date");

                        if ($expiry_date_picker.length) {
                            $expiry_date_picker.flatpickr({
                                format: "Y-m-d",
                                minDate: expiry_date
                            });
                        }
                        //-------------------

                        if ($("#professions_count").length != 0) {
                            var professions_count = response._professions_count;
                        } else {
                            var professions_count = response._document_count;
                        }

                        if ($("#document_count").length != 0) {
                            var document_count = response._document_count;
                        } 
                        // else {
                        //     var document_count = 1;
                        // }


                        for (let index = 1; index <= professions_count; index++) {
                            $(".profession-document-file-"+index).rules("add", {
                                required: {
                                    depends: function() {
                                        return $(".profession-document-mandatory-status-"+index).val() == "yes";
                                    }
                                },
                                extension: "pdf|png|jpg|jpeg",
                                messages: {
                                    required: "Please select file.",
                                    extension: "Please select file only pdf,jpg,png format."
                                }
                            });

                            $(".profession-document-expiry-date-required-"+index).rules("add", {
                                required: {
                                    depends: function() {
                                        return $("#profession-document-file-"+index).val() != "";
                                    }
                                },
                                messages: {
                                    required: "Please select expiry date."
                                }
                            });
                        }

                    }
                    else{
                        $('.document-box-'+counter).html('');
                    }
                }
            });
        },

        /**
         * Validate hcps profession form.
         */
        validateHcpsProfessionForm: function() {
            var $form = $(".update-hcp-profession-form");

            $form.find("select").change(function() {
                $(this).valid();
            });

            $form.validate({
                ignore: "input[type='text']:hidden *",

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    "professions[0][category_id]": {
                        required: true
                    },
                    "professions[0][professions_id]": {
                        required: true
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    "professions[0][category_id]": {
                        required: 'Please select category.'
                    },
                    "professions[0][professions_id]": {
                        required: 'Please select profession.'
                    },
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });

            if ($("#professions_count").length != 0) {
                var counter = $("#professions_count").val();
            } else {
                var counter = 0;
            }

            for (let index = 0; index <= counter; index++) {
                $(".edit-profession-document-file-"+index).rules("add", {
                    required: {
                        depends: function() {
                            return $(".edit-profession-document-mandatory-status-"+index).val() == "yes";
                        }
                    },
                    extension: "pdf|png|jpg|jpeg",
                    messages: {
                        required: "Please select file.",
                        extension: "Please select file only pdf,jpg,png format."
                    }
                });

                $(".edit-profession-document-expiry-date-required-"+index).rules("add", {
                    required: {
                        depends: function() {
                            return $("#edit-profession-document-file-"+index).val() != "";
                        }
                    },
                    messages: {
                        required: "Please select expiry date."
                    }
                });
            }

        },

        /**
         * Add more profession.
         */
        addMoreProfessions: function() {
            var $source = $(".update-hcp-profession-form");

            if ($("#professions_count").length != 0) {
                var counter = $("#professions_count").val();
            } else {
                var counter = 0;
            }

            $source.on("click", ".add-more", function() {
                var $this = $(this);
                counter++;
                $.ajax({
                    url: $source.find(".add-more").data("url"),
                    type: "POST",
                    data: {
                        counter: counter
                    },
                    beforeSend: function() {
                        $(".add-more").html("Please wait..");
                    },
                    success: function(response) {
                        if (response._status == true) {
                            var $profession = $(response._content);

                            $source.find(".hcp-category-row").append($profession.html());

                            if ($("#professions_count").length != 0) {
                                var selectbox_count = counter;
                            } else {
                                var selectbox_count = counter;
                            }

                            $source.on(
                                "change",
                                ".category-profession-" + selectbox_count,
                                function() {
                                    var $this = $(this);
                                    var category = $this.val();

                                    if (category != "") {
                                        $(
                                            ".profession-div-" + selectbox_count
                                        ).append(
                                            '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                                        );
                                        $.ajax({
                                            type: "GET",
                                            url: $this.data("url"),
                                            data: {
                                                category_id: category
                                            },
                                            success: function(response) {
                                                var data = response._data;
                                                var options = '';
                                                $.each(data, function(
                                                    index,
                                                    data
                                                ) {
                                                    options +=
                                                        '<option value="' +
                                                        data.id +
                                                        '">' +
                                                        data.name +
                                                        "</option>";
                                                });
                                                $(
                                                    "#professions_id_" +
                                                        selectbox_count
                                                ).html(options);
                                                $(
                                                    "#professions_id_" +
                                                        selectbox_count
                                                ).selectpicker("refresh");
                                                $(
                                                    ".profession-div-" +
                                                        selectbox_count +
                                                        " .input-loading"
                                                ).hide();
                                            }
                                        });
                                    }
                                }
                            );

                            $source.on(
                                "change",
                                ".profession-level-" + selectbox_count,
                                function() {
                                    var $this = $(this);
                                    var profession = $this.val();

                                    if (profession != "") {

                                        $(".level-div-" + selectbox_count).append(
                                            '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                                        );

                                        $.ajax({
                                            type: "GET",
                                            url: $this.data("url"),
                                            data: {
                                                profession_id: profession
                                            },
                                            success: function(response) {
                                                var data = response._data;
                                                var options = '';

                                                $.each(data, function(
                                                    index,
                                                    data
                                                ) {
                                                    options +=
                                                        '<option value="' +
                                                        data.id +
                                                        '">' +
                                                        data.name +
                                                        "</option>";
                                                });

                                                if(data.length > 0){
                                                    $("#level_id_"+selectbox_count).rules("add", {
                                                        required: true,
                                                        messages: {
                                                            required: "Please select level."
                                                        }
                                                    });
                                                    Hcps.addLevelIdInDocument(profession, selectbox_count);
                                                } else {
                                                    Hcps.getProfessionDocument(profession, selectbox_count);
                                                }

                                                $(
                                                    "#level_id_" +
                                                        selectbox_count
                                                ).html(options);
                                                $(
                                                    "#level_id_" +
                                                        selectbox_count
                                                ).selectpicker("refresh");
                                                $(
                                                    ".level-div-" +
                                                        selectbox_count +
                                                        " .input-loading"
                                                ).hide();
                                            }
                                        });
                                    }
                                }
                            );

                            $(".cat-select").each(function() {
                                $(this).rules("add", {
                                    required: true,
                                    messages: {
                                        required: "Please select category."
                                    }
                                });
                            });

                            $(".profession-select").each(function() {
                                $(this).rules("add", {
                                    required: true,
                                    messages: {
                                        required: "Please select profession."
                                    }
                                });
                            });

                            $(".level-select").each(function() {
                                $(this).rules("add", {
                                    required: false,
                                    messages: {
                                        required: "Please select level."
                                    }
                                });
                            });

                            // Bootstrap select
                            Components.bootstrapSelect($source);
                            //-----------------
                        }
                    },
                    error: function(response) {},
                    complete: function(response) {
                        $(".add-more").html("Add More");
                    }
                });
            });
        },

        /**
         * Remove profession.
         */
        removeProfessions: function() {
            var $source = $(".update-hcp-profession-form");

            $source.on("click", ".remove-block", function() {
                $this = $(this);
                var panel_id = $this.data("id");
                $source.find("#line-" + panel_id).remove();
                $source.find("#panel-" + panel_id).html("");
                $source.find("#panel-" + panel_id).remove();
                $source.find(".document-box-" + panel_id).html("");
                $source.find(".document-box-" + panel_id).remove();
            });

            $source.on("click", ".remove-profession", function() {
                $this = $(this);
                var panel_id = $this.data("id");
                var url = $this.data("url");
                $.ajax({
                    url: url,
                    type: "DELETE",
                    data: {
                        id: panel_id,
                        profession_id: $this.data("profession-id"),
                        hcp_id: $this.data('hcp-id'),
                    },
                    beforeSend: function() {
                        //
                    },
                    success: function(response) {
                        if (response._status == true) {
                            var data = response._data;

                            $source.find("#line-" + panel_id).remove();
                            $source.find("#panel-" + panel_id).html("");
                            $source.find("#panel-" + panel_id).remove();
                            $source.find(".document-box-" + panel_id).html("");
                            $source.find(".document-box-" + panel_id).remove();
                        }
                    },
                    error: function(response) {
                        //
                    },
                    complete: function(response) {
                        //
                    }
                });
            });
        },

        /**
         * Add level id in document.
         */
        addLevelIdInDocument: function(profession = '', counter) {
            var $source = $(".update-hcp-profession-form");
            // $source.on("change", ".level-select", function() {
            var id='#level_id';
            if(counter!=''){
                id="#level_id_"+counter;
            }    
            $source.on("change", id, function() {
                var $this = $(this);
                var levelId = $this.val();
                if (levelId != "" && profession != "") {
                    Hcps.getProfessionDocument(profession, counter, levelId);
                }
            });
        },
    };
})();

Hcps.init();
