var Levels = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            Levels.initializeComponents();
            Levels.validateLevelsForm();
            Levels.getProfessions();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            var $form = $(".add-levels-form");

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------

            $('#hcp_rate').on("blur",function(){
                var facility_rate = '';
                facility_rate = parseInt($('#hcp_rate').val()) + parseInt($('#admin_fees').val());
                if($('#hcp_rate').val() != '') {
                    $('#facility_rate').val(facility_rate);
                } else {
                    $('#facility_rate').val('');
                }
            });

            $(document).keypress(
            function(event){
                if (event.which == '13') {
                event.preventDefault();
                }
            });
        },

        /**
         * Get professions.
         */
        getProfessions: function($source) {
            var $source = $(".add-levels-form");

            $source.on("change", ".change-category", function() {
                var $this = $(this);
                var category = $this.val();
                if (category != "") {
                    $(".level-profession-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            category_id: category
                        },
                        success: function(response) {
                            var data = response._data;
                            var options =
                                '<option selected="selected" value=""> Select Profession </option>';

                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });
                            $("#profession").html(options);
                            $("#profession").selectpicker("refresh");
                            $(".level-profession-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Validate levels form.
         */
        validateLevelsForm: function() {
            var $form = $(".add-levels-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    profession: {
                        required: true
                    },
                    category: {
                        required: true
                    },
                    name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    hcp_rate: {
                        required: true,
                        min: "1",
                        number: true
                    },
                    facility_rate: {
                        required: true,
                        min: "1",
                        number: true
                    },
                    admin_fees: {
                        required: true,
                        min: "1",
                        number: true
                    }
                },
                //------------------

                // @validation error messages
                messages: {
                    profession: {
                        required: "Please select profession."
                    },
                    category: {
                        required: "Please select category."
                    },
                    name: {
                        required: "Please enter name."
                    },
                    hcp_rate: {
                        required: "Please enter hcp rate.",
                        number: "Please enter valid hcp rate."
                    },
                    facility_rate: {
                        required: "Please enter facility rate.",
                        number: "Please enter valid facility rate."
                    },
                    admin_fees: {
                        required: "Please enter shcs commission.",
                        number: "Please enter valid shcs commission."
                    }
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        }
    };
})();

Levels.init();
