var Docs = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            Docs.initializeComponents();
            Docs.validateDocsForm();
            Docs.linkAction();
            Docs.checkReqBy();
            Docs.uploadDocumentModal();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            var $form = $(".add-doc-form");

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------
        },

        /**
         * Validate docs form.
         */
        validateDocsForm: function() {
            var $form = $(".add-doc-form");

            $form.find("select").change(function() {
                $(this).valid();
            });

            $form.validate({

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    required_for: {
                        required: true
                    },
                    status: {
                        required: true
                    },
                    expiry_date_mandatory: {
                        required: {
                            depends: function() {
                                return $("#required_for").val() == "hcp";
                            }
                        },
                    },
                    mandatory_status: {
                        required: {
                            depends: function() {
                                return $("#required_for").val() == "hcp";
                            }
                        },
                    },
                    doc_type: {
                        required: true
                    },
                    facility_profession: {
                        required: {
                            depends: function() {
                                return $("#required_for").val() == "facility";
                            }
                        },
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    name: {
                        required: "Please enter name."
                    },
                    status: {
                        required: "Please select status."
                    },
                    required_for: {
                        required: "Please select required for."
                    },
                    expiry_date_mandatory: {
                        required: "Please select expiry date required."
                    },
                    mandatory_status: {
                        required: "Please select mandatory status."
                    },
                    doc_type: {
                        required: "Please select document type."
                    },
                    facility_profession: {
                        required: "Please select profession."
                    },
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },

        /**
         * Link Action.
         */
        linkAction: function() {
            var $source = $(".datatable-action");

            // Handle form submission event
            $source.on("click", ".link-action", function() {
                $this = $(this);
                iziToast.question({
                    timeout: 20000,
                    close: false,
                    overlay: true,
                    displayMode: "once",
                    color: "yellow",
                    id: "question",
                    zindex: 99999,
                    title: "Hey!",
                    message: "Are you sure to want to change status?",
                    position: "center",
                    progressBar: false,
                    buttons: [
                        [
                            "<button><b>YES</b></button>",
                            function (instance, toast) {
                                $.ajax({
                                    type: "GET",
                                    url: $this.data("url"),
                                    beforeSend: function () {
                                        //
                                    },
                                    success: function (response) {
                                        App.showNotification(response);
                                        location.reload(true);
                                    },
                                    error: function () {},
                                    complete: function () {
                                        //
                                    },
                                });
                                instance.hide(
                                    { transitionOut: "fadeOut" },
                                    toast,
                                    "button"
                                );
                            },
                            true,
                        ],
                        [
                            "<button>NO</button>",
                            function (instance, toast) {
                                instance.hide(
                                    { transitionOut: "fadeOut" }, toast,  "button"
                                );
                            },
                        ],
                    ],
                    onClosing: function (instance, toast, closedBy) {
                        //
                    },
                    onClosed: function (instance, toast, closedBy) {
                        //
                    },
                });
            });
        },

        /**
         * Check Required By.
         */
        checkReqBy: function() {
            var $source = $(".add-doc-form");

            $source.on("change", ".required-for-change", function() {
                var $this = $(this);
                var required_by = $this.val();
                if (required_by != "") {
                    $(".doc-type-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            required_by: required_by
                        },
                        success: function(response) {
                            if (required_by == 'facility') {
                                $('.facility-profession-div').removeClass('hide');
                                $('.mandatory-status-div').addClass('hide');
                                $('.expiry-date-div').addClass('hide');
                            } else {
                                $('.facility-profession-div').addClass('hide');
                                $('.mandatory-status-div').removeClass('hide');
                                $('.expiry-date-div').removeClass('hide');
                            }

                            var data = response._data;
                            var options = '';
                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.value +
                                    '">' +
                                    data.caption +
                                    "</option>";
                            });
                            $("#doc_type").html(options);
                            $("#doc_type").selectpicker("refresh");
                            $(".doc-type-div .input-loading").hide();
                        }
                    });
                }
            });
        },

        /**
         * Validate upload document.
         */
        validateUploaddocument: function() {
            var $form = $(".facility-upload-document-form");

            $form.find("select").change(function() {
                $(this).valid();
            });

            $form.validate({
                ignore: "input[type='text']:hidden, .note-editor *",

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    document_file: {
                        required: true,
                        extension: "pdf"
                    },
                    expiry_date: {
                        required: true
                    },

                },
                //------------------

                // @validation error messages
                messages: {
                    document_file: {
                        required: "Please select file.",
                        extension: "Please select file only pdf."
                    },
                    expiry_date: {
                        required: "Please select expiry date.",
                    },
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },


        /**
         * Upload document modal.
         */
        uploadDocumentModal: function() {
            var $source = $(".datatable-action");
            $source.on(
                "click",
                ".upload-document",
                function() {
                    var $this = $(this);
                    var $page_modal = $("#pageModalMedium");

                    $page_modal.modal("show");
                    $page_modal
                        .find(".modal-content")
                        .load($this.data("url"), function() {

                            // Expiry Date
                            var expiryDays = DEV_CONFIG["expiry_date_limit"]["config_value"];
                            var expiry_date = new Date();
                            expiry_date.setDate(expiry_date.getDate() + parseInt(expiryDays));
                            //------------

                            // Date picker
                            var $expiry_date_picker = $(".expiry-date");

                            if ($expiry_date_picker.length) {
                                $expiry_date_picker.flatpickr({
                                    format: "Y-m-d",
                                    minDate: expiry_date
                                });
                            }
                            //------------

                            Docs.validateUploaddocument();
                        });

                    $page_modal.on("hidden.bs.modal", function() {
                        App.resetModal($page_modal);
                    });
                }
            );
        },
    };
})();

Docs.init();
