var Notification = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            Notification.initializeComponents();
            Notification.validateNotificationForm();
            Notification.dataTableCustomFilter();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            var $form = $(".add-notification-form");

            // Bootstrap select
            Components.bootstrapSelect($form);

            // filter form
            var $filter_form = $(".custom-datatable-filter-form");
            Components.bootstrapSelect($filter_form);
            //------------

            // Date picker
            var $date_picker = $filter_form.find(".date-picker");
            if ($date_picker.length) {
                $date_picker.flatpickr({
                    format: "Y-m-d",
                    mode: "range",
                    onClose: function(selectedDates, dateStr, instance) {
                        //
                    }
                });
            }
            //------------

            // Apply filter
            $(".apply-filter").on("click", function(e) {
                var checked = []
                $("input[name='states[]']:checked").each(function () {
                    checked.push(parseInt($(this).val()));
                });
                if( checked.length || $('#plan_type').val() !='' || $('#plan_cycle').val() !='' || $('#plan_end_date').val() !='') {
                    $filter_form.submit();
                    $('.filter-error').hide();
                    $(".custom-datatable-filter").toggleClass("hide");
                    e.preventDefault();
                } else {
                    $('.filter-error').show();
                }
            });
            //-------------

            // Clear filter
            $(".clear-filter").on("click", function(e) {
                $(".custom-datatable-filter-form")[0].reset();
                $source = $(".custom-datatable-filter-form");
                $select = $source.find(".select-picker");
                $select.selectpicker("refresh");
                $source.find('.btn-custom-outline').removeClass('active');
                $(".filter-button").addClass('btn-dark');
                $(".filter-button").removeClass('btn-primary');
                $(".custom-datatable-filter").toggleClass("hide");
                window.location.replace(window.location.pathname);
                e.preventDefault();
            });
            //-----------------

            // Check Hcp
            $("#send_to").on("change", function(e) {
                if($(this).val() == 'all-hcp') {
                    $("#title").attr("disabled", "disabled");
                } else {
                    $("#title").removeAttr("disabled");
                }
            });
            //-------------

        },

        /**
         * Datatable custom filter.
         */
        dataTableCustomFilter: function() {
            $(".filter-button").click(function() {
                var $this = $(this);
                $(".custom-datatable-filter").toggleClass("hide");
                $this.addClass('btn-primary');
                $this.removeClass('btn-dark');
            });
        },



        /**
         * Validate notification form.
         */
        validateNotificationForm: function() {
            var $form = $(".add-notification-form");

            $form.find("select").change(function() {
                $(this).valid();
            });

            $form.validate({

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    title: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    send_to: {
                        required: true
                    },
                    message: {
                        required: true
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    title: {
                        required: "Please enter title."
                    },
                    message: {
                        required: "Please enter message."
                    },
                    send_to: {
                        required: "Please select send to."
                    },
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },
    };
})();

Notification.init();
