var Plan = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            Plan.initializeComponents();
            Plan.validatePlanForm();
            Plan.validateUpdatePlanForm();
            Plan.getPlanPrice();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            var $form = $(".update-facilityPlan-form");

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------

            // Plan Discount
            $('.plan-year-discount-1').on('blur', function() {
                var $this = $(this);
                var plan_1_year_price = ($this.val()*($('.plan-monthly-price-1').val()/100));
                $('.plan-year-price-1').val(plan_1_year_price.toFixed(2));
            });

            $('.plan-year-discount-2').on('blur', function() {
                var $this = $(this);
                var plan_1_year_price = ($this.val()*($('.plan-monthly-price-2').val()/100));
                $('.plan-year-price-2').val(plan_1_year_price.toFixed(2));
            });

            $('.plan-year-discount-3').on('blur', function() {
                var $this = $(this);
                var plan_1_year_price = ($this.val()*($('.plan-monthly-price-3').val()/100));
                $('.plan-year-price-3').val(plan_1_year_price.toFixed(2));
            });
            //--------------

        },

        /**
         * Validate plan form.
         */
        validatePlanForm: function() {
            var $form = $(".update-plan-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                errorPlacement: function(error, element) {
                    if (element.attr("name") == "plan[1][profession][]") {
                        error.insertAfter(".plan-professions-error1");
                    } else if (element.attr("name") == "plan[2][profession][]") {
                        error.insertAfter(".plan-professions-error2");
                    } else if (element.attr("name") == "plan[3][profession][]") {
                        error.insertAfter(".plan-professions-error3");
                    } else if (element.attr("name") == "plan[4][profession][]") {
                        error.insertAfter(".plan-professions-error4");
                    } else {
                        error.insertAfter(element);
                    }
                },

                // @validation rules
                rules: {
                    "plan[1][profession][]": {
                        required: true
                    },
                    "plan[2][profession][]": {
                        required: true
                    },
                    "plan[3][profession][]": {
                        required: true
                    },
                    "plan[4][profession][]": {
                        required: true
                    },
                    "plan[1][monthly_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[2][monthly_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[3][monthly_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[1][6_month_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[2][6_month_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[3][6_month_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[1][yearly_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[2][yearly_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[3][yearly_price]": {
                        required: true,
                        min: 1,
                    },
                    "plan[1][yearly_discount]": {
                        required: true,
                        min: 1,
                    },
                    "plan[2][yearly_discount]": {
                        required: true,
                        min: 1,
                    },
                    "plan[3][yearly_discount]": {
                        required: true,
                        min: 1,
                    },
                    "plan[1][monthly_price_key]": {
                        required: true,
                    },
                    "plan[2][monthly_price_key]": {
                        required: true,
                    },
                    "plan[3][monthly_price_key]": {
                        required: true,
                    },
                    "plan[1][6_month_price_key]": {
                        required: true,
                    },
                    "plan[2][6_month_price_key]": {
                        required: true,
                    },
                    "plan[3][6_month_price_key]": {
                        required: true,
                    },
                    "plan[1][yearly_price_key]": {
                        required: true,
                    },
                    "plan[2][yearly_price_key]": {
                        required: true,
                    },
                    "plan[3][yearly_price_key]": {
                        required: true,
                    }
                },
                //------------------

                // @validation error messages
                messages: {
                    "plan[1][profession][]": {
                        required: "Please select plan professions."
                    },
                    "plan[2][profession][]": {
                        required: "Please select plan professions."
                    },
                    "plan[3][profession][]": {
                        required: "Please select plan professions."
                    },
                    "plan[4][profession][]": {
                        required: "Please select plan professions."
                    },
                    "plan[1][monthly_price]": {
                        required: "Please enter price."
                    },
                    "plan[2][monthly_price]": {
                        required: "Please enter price."
                    },
                    "plan[3][monthly_price]": {
                        required: "Please enter price."
                    },
                    "plan[1][6_month_price]": {
                        required: "Please enter price."
                    },
                    "plan[2][6_month_price]": {
                        required: "Please enter price."
                    },
                    "plan[3][6_month_price]": {
                        required: "Please enter price."
                    },
                    "plan[1][yearly_price]": {
                        required: "Please enter price."
                    },
                    "plan[2][yearly_price]": {
                        required: "Please enter price."
                    },
                    "plan[3][yearly_price]": {
                        required: "Please enter price."
                    },
                    "plan[1][yearly_discount]": {
                        required: "Please enter discount."
                    },
                    "plan[2][yearly_discount]": {
                        required: "Please enter discount."
                    },
                    "plan[3][yearly_discount]": {
                        required: "Please enter discount."
                    },

                    "plan[1][monthly_price_key]": {
                        required: "Please enter stripe monthly price key."
                    },
                    "plan[2][monthly_price_key]": {
                        required: "Please enter stripe monthly price key."
                    },
                    "plan[3][monthly_price_key]": {
                        required: "Please enter stripe monthly price key."
                    },
                    "plan[1][6_month_price_key]": {
                        required: "Please enter stripe 6 month price key."
                    },
                    "plan[2][6_month_price_key]": {
                        required: "Please enter stripe 6 month price key."
                    },
                    "plan[3][6_month_price_key]": {
                        required: "Please enter stripe 6 month price key."
                    },
                    "plan[1][yearly_price_key]": {
                        required: "Please enter stripe yearly price key."
                    },
                    "plan[2][yearly_price_key]": {
                        required: "Please enter stripe yearly price key."
                    },
                    "plan[3][yearly_price_key]": {
                        required: "Please enter stripe yearly price key."
                    }
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },

        /**
         * Validate update plan form.
         */
        validateUpdatePlanForm: function() {
            var $form = $(".update-facilityPlan-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    plan_id: {
                        required: true
                    },
                    plan_cycle: {
                        required: true
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    plan_id: {
                        required: "Please select plan."
                    },
                    plan_cycle: {
                        required: "Please select plan cycle."
                    }
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },

        /**
         * Get plan price.
         */
        getPlanPrice: function() {
            var $source = $(".update-facilityPlan-form");

            $source.on("change", ".change-price", function() {
                var $this = $(this);
                var plan_id = $('#plan_id').val();
                var plan_cycle = $('#plan_cycle').val();

                if(plan_id !='' && plan_cycle !='' ){
                    $(".amount-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    if ($('#plan_cycle').data("url") != undefined) {
                        $.ajax({
                            type: "POST",
                            url: $('#plan_cycle').data("url"),
                            data: {
                                plan_id: plan_id,
                                plan_type: plan_cycle,
                            },
                            success:function(response)
                            {
                                $('#amount').val(response);
                                $(".amount-div .input-loading").hide();
                            }
                        });
                    }
                }
            });

        },

    };
})();

Plan.init();
