var Professions = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            Professions.initializeComponents();
            Professions.validateProfessionsForm();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            var $form = $(".add-professions-form");

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------

            $(".has-levels").click(function() {
                $this = $(this);
                if ($this.val() == "no") {
                    $(".hcp-group").removeClass("hide");
                } else {
                    $(".hcp-group").addClass("hide");
                }
            });

            $('#hcp_rate').on("blur",function(){
                var facility_rate = '';
                facility_rate = parseInt($('#hcp_rate').val()) + parseInt($('#admin_fees').val());
                if($('#hcp_rate').val() != '') {
                    $('#facility_rate').val(facility_rate);
                } else {
                    $('#facility_rate').val('');
                }
            });

            $(document).keypress(
            function(event){
                if (event.which == '13') {
                event.preventDefault();
                }
            });

        },

        /**
         * Validate professions form.
         */
        validateProfessionsForm: function() {
            var $form = $(".add-professions-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                errorPlacement: function(error, element) {
                    if (element.attr("name") == "has_levels") {
                        error.insertAfter(".has-levels-group");
                    } else {
                        error.insertAfter(element);
                    }
                },

                // @validation rules
                rules: {
                    category: {
                        required: true
                    },
                    name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    has_levels: {
                        required: true
                    },
                    hcp_rate: {
                        required: {
                            depends: function() {
                                return (
                                    $("input[name=has_levels]:checked").val() ==
                                    "no"
                                );
                            }
                        },
                        min: "1",
                        number: true
                    },
                    facility_rate: {
                        required: {
                            depends: function() {
                                return (
                                    $("input[name=has_levels]:checked").val() ==
                                    "no"
                                );
                            }
                        },
                        min: "1",
                        number: true
                    },
                    admin_fees: {
                        required: {
                            depends: function() {
                                return (
                                    $("input[name=has_levels]:checked").val() ==
                                    "no"
                                );
                            }
                        },
                        min: "1",
                        number: true
                    }
                },
                //------------------

                // @validation error messages
                messages: {
                    category: {
                        required: "Please select category."
                    },
                    name: {
                        required: "Please enter name."
                    },
                    has_levels: {
                        required: "Please select has level."
                    },
                    hcp_rate: {
                        required: "Please enter hcp rate.",
                        number: "Please enter valid hcp rate."
                    },
                    facility_rate: {
                        required: "Please enter facility rate.",
                        number: "Please enter valid facility rate."
                    },
                    admin_fees: {
                        required: "Please enter shcs commission.",
                        number: "Please enter valid shcs commission."
                    }
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        }
    };
})();

Professions.init();
