var Profile = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            Profile.initializeComponents();
            Profile.validateProfileForm();
            Profile.customValidationMethods();
            Profile.validateChangePasswordForm();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            $(".toggle-current-password").click(function() {
                $(this).toggleClass("fa-eye fa-eye-slash");
                var input = $($(this).attr("toggle"));
                if (input.attr("type") == "password") {
                    input.attr("type", "text");
                } else {
                    input.attr("type", "password");
                }
            });

            $(".toggle-new-password").click(function() {
                $(this).toggleClass("fa-eye fa-eye-slash");
                var input = $($(this).attr("toggle"));
                if (input.attr("type") == "password") {
                    input.attr("type", "text");
                } else {
                    input.attr("type", "password");
                }
            });

            $(".toggle-confirm-password").click(function() {
                $(this).toggleClass("fa-eye fa-eye-slash");
                var input = $($(this).attr("toggle"));
                if (input.attr("type") == "password") {
                    input.attr("type", "text");
                } else {
                    input.attr("type", "password");
                }
            });
        },

        /**
         * Custom validation methods.
         */
        customValidationMethods: function() {
            jQuery.validator.addMethod(
                "emailChecker",
                function(value, element) {
                    return (
                        this.optional(element) ||
                        /^([a-zA-Z0-9_\.\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/i.test(
                            value
                        )
                    );
                },
                "Please enter a valid email address."
            );


            jQuery.validator.addMethod(
                "mobileNumber",
                function(value, element) {
                    return (
                        this.optional(element) ||
                        /^\+[1-9]{1}[0-9]{8,14}$/i.test(value)
                    );
                },
                "Please enter valid number e.g. +61474567894"
            );
        },

        /**
         * Validate profile form.
         */
        validateProfileForm: function() {
            var $form = $(".edit-profile-form");

            $form.find("select").change(function() {
                $(this).valid();
            });

            $form.validate({

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    first_name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },

                    last_name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },

                    surname: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },

                    email: {
                        required: true,
                        emailChecker: true,
                        maxlength: DEV_CONFIG["email_length"]["config_value"]
                    },
                    contact_number: {
                        required: true,
                        mobileNumber: true
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    first_name: {
                        required: "Please enter first name."
                    },

                    last_name: {
                        required: "Please enter last name."
                    },

                    name: {
                        required: "Please enter name."
                    },

                    surname: {
                        required: "Please enter surname."
                    },

                    email: {
                        required: "Please enter email.",
                        emailChecker: "Please enter valid email",
                    },

                    contact_number: {
                        required: "Please select contact number.",
                    },
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },

        /**
         * Validate change password.
         */
        validateChangePasswordForm: function() {
            var $form = $(".change-password-form");

            $form.validate({

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    current_password: {
                        required: true
                    },
                    new_password: {
                        required: true
                    },
                    confirm_new_password: {
                        required: true,
                        equalTo: "#new_password"
                    }
                },
                //------------------

                // @validation error messages
                messages: {
                    current_password: {
                        required: 'Please enter current password.',
                    },
                    new_password: {
                        required: 'Please enter new password.',
                    },
                    confirm_new_password: {
                        required: 'Please enter confirm password.',
                        equalTo: 'Your password and confirmation password do not match.',
                    }
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },

    };
})();

Profile.init();
