var PublicHoliday = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            PublicHoliday.initializeComponents();
            PublicHoliday.validatePublicHolidayForm();
            PublicHoliday.getStates();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            var $form = $(".add-public-holiday-form");

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------

            // Holiday date picker
            var $holiday_date_picker = $form.find(".holiday-date");

            if ($holiday_date_picker.length) {
                $holiday_date_picker.flatpickr({
                    format: "Y-m-d",
                    minDate: "today"
                });
            }
            //--------------------
        },

        /**
         * Validate public Holiday form.
         */
        validatePublicHolidayForm: function() {
            var $form = $(".add-public-holiday-form");

            $form.validate({
                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    name: {
                        required: true,
                        maxlength: DEV_CONFIG["name_length"]["config_value"]
                    },
                    holiday_date: {
                        required: true
                    },
                    country_id: {
                        required: true
                    },
                    "state_id[]": {
                        required: true
                    }
                },
                //------------------

                // @validation error messages
                messages: {
                    name: {
                        required: "Please enter name."
                    },
                    holiday_date: {
                        required: "Please select holiday date."
                    },
                    country_id: {
                        required: "Please select country."
                    },
                    "state_id[]": {
                        required: "Please select state."
                    }
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },

         /**
         * Get states according to country.
         */
        getStates: function($source) {
            var $source = $(".add-public-holiday-form");

            $source.on("change", ".country-state", function() {
                var $this = $(this);
                var country = $this.val();

                if (country != "") {
                    $(".state-div").append(
                        '<div class="input-loading"> <i class="fa fa-refresh fa-spin"></i> </div>'
                    );

                    $.ajax({
                        type: "GET",
                        url: $this.data("url"),
                        data: {
                            country_id: country
                        },
                        success: function(response) {
                            var data = response._data;
                            var options = '';
                            $.each(data, function(index, data) {
                                options +=
                                    '<option value="' +
                                    data.id +
                                    '">' +
                                    data.name +
                                    "</option>";
                            });

                            $("#state_id").html(options);
                            $("#state_id").selectpicker("refresh");
                            $(".state-div .input-loading").hide();
                        }
                    });
                }
            });
        },
    };
})();

PublicHoliday.init();
