var SupportingPages = (function() {
    return {
        /**
         * Initialization.
         */
        init: function() {
            SupportingPages.initializeComponents();
            SupportingPages.validateSupportingPagesForm();
        },

        /**
         * Initialize components.
         */
        initializeComponents: function() {
            var $form = $(".add-supporting-pages-form");

            // Bootstrap select
            Components.bootstrapSelect($form);
            //-----------------

        },

        /**
         * Validate supporting pages form.
         */
        validateSupportingPagesForm: function() {
            var $form = $(".add-supporting-pages-form");

            $form.validate({
                ignore: "input[type='text']:hidden, .summernote *",

                // @validation states + elements
                errorClass: "invalid-feedback",
                errorElement: "span",
                //------------------------------

                // @validation rules
                rules: {
                    term_condition_hcp_file: {
                        required: {
                            depends: function() {
                                return (
                                    $(
                                        "input[name=term_condition_hcp_file]"
                                    ).val() != ""
                                );
                            }
                        },
                        extension: "html"
                    },
                    supporting_pages_faq_hcp: {
                        required: {
                            depends: function() {
                                return (
                                    $(
                                        "input[name=supporting_pages_faq_hcp]"
                                    ).val() != ""
                                );
                            }
                        },
                        extension: "html"
                    },
                    supporting_pages_policy_hcp: {
                        required: {
                            depends: function() {
                                return (
                                    $(
                                        "input[name=supporting_pages_policy_hcp]"
                                    ).val() != ""
                                );
                            }
                        },
                        extension: "html"
                    },
                    about_us_hcp_file: {
                        required: true,
                        url: true
                    },
                    contact_us_hcp_file: {
                        required: true,
                        url: true
                    },
                    term_condition_facility_link: {
                        required: true,
                        url: true
                    },
                    policy_facility_link: {
                        required: true,
                        url: true
                    },
                    term_condition_facility_plan: {
                        required: true,
                    },
                },
                //------------------

                // @validation error messages
                messages: {
                    term_condition_hcp_file: {
                        required: "Please select term & condition.",
                        extension:"Select valid HTML file format."
                    },
                    supporting_pages_faq_hcp: {
                        required: "Please select faq.",
                        extension:"Select valid HTML file format."
                    },
                    supporting_pages_policy_hcp: {
                        required: "Please select privacy policy.",
                        extension:"Select valid HTML file format."
                    },
                    about_us_hcp_file: {
                        required: "Please enter about us link.",
                        extension:"Select valid HTML file format."
                    },
                    contact_us_hcp_file: {
                        required: "Please enter contact us link.",
                        extension:"Select valid HTML file format."
                    },
                    term_condition_facility_link: {
                        required: "Please enter term & condition link."
                    },
                    policy_facility_link: {
                        required: "Please enter privacy policy link."
                    },
                    term_condition_facility_plan: {
                        required: "Please enter facility plan term & condition."
                    },
                },
                //---------------------------

                highlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-danger")
                        .removeClass("has-success");
                    $(element)
                        .addClass("is-invalid")
                        .removeClass("is-valid");
                },
                unhighlight: function(element, errorClass, validClass) {
                    $(element)
                        .closest(".form-group")
                        .addClass("has-success")
                        .removeClass("has-danger");
                    $(element)
                        .addClass("is-valid")
                        .removeClass("is-invalid");
                },
                submitHandler: function(form) {
                    App.formLoading($form);
                    form.submit();
                }
            });
        },

    };
})();

SupportingPages.init();
