@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.facilities_subscription_accounts').' | '.__('language.page_main_title').'')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <h5>{{ __('language.facilities_subscription_accounts') }}</h5>
                        </div>
                        <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                            @if (!empty($request))
                                @php $filterApply = 'filter-icon-apply'; @endphp
                            @else
                                @php $filterApply = 'filter-icon'; @endphp
                            @endif
                            <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                                <i class="fa fa-filter"></i>
                            </button>
                        </div>
                    </div>

                    <div>
                        {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                        route('adminPanel.accounts.facilitySubscriptionAccount'), 'id' => 'filter-form']) !!}
                        <div class="row">
                            <div class="col-md-12">
                                <div class="custom-datatable-filter hide">
                                    <div class="row">
                                        <div class="col-md-12">
                                            <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-3">
                                            <div class="form-group">
                                                {!! Form::text('date_from', old('date_from', ($request['date_from'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_from', 'placeholder' => __('language.account_filter_date_from')]) !!}
                                            </div>
                                        </div>

                                        <div class="col-md-3">
                                            <div class="form-group">
                                                {!! Form::text('date_to', old('date_from', ($request['date_to'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_to', 'placeholder' => __('language.account_filter_date_to')]) !!}
                                            </div>
                                        </div>

                                        <div class="col-md-2">
                                            <div class="form-group">
                                                {!! Form::select('status', create_select_options(config('constants.transactions_subscription_status'), 'caption', 'value',  null), old('status', ($request['status'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status', 'title' => __('language.facility_filter_status')]) !!}
                                            </div>
                                        </div>

                                        <div class="col-md-12">
                                            <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-4 mb2">
                                            {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-primary apply-filter', 'type' => 'submit'] )}}
                                            {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                        </div>
                                    </div>
                                    <div class="filter-border"></div>
                                </div>
                            </div>
                        </div>
                        <div class="row pl-3 mt-3">
                            <div class="col-md-8">
                                <div class="float-left">
                                    <label> {{ __('language.table_result') }} </label>
                                    {!! Form::select('per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('per_page', ($request['per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                                </div>

                                <div class="float-left pl-2 search-box">
                                    {!! Form::text('search', old('search', ($request['search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                    <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                                </div>
                                <div class="clearfix"></div>
                            </div>

                            <div class="col-md-4 text-right">
                                <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.accounts.facilitySubscriptionAccountExport',['request' => $request])}}">
                                    Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                                </a>
                            </div>
                        </div>
                        {!! Form::close() !!}
                    </div>
                </div>


                <div class="container-fluid page-heading">
                    <div class="table-responsive pb-5">
                        <table class="table mb-4 mt-3">
                            <thead>
                            <tr>
                                <th> {{ __('language.accounts_table_invoice_id') }} </th>
                                @if($authUser->hasRole('Facility Group Admin') == true)
                                    <th> {{ __('language.facility') }} </th>
                                @endif
                                <th> {{ __('language.accounts_table_subscription_plan') }} </th>
                                <th> {{ __('language.accounts_table_subscription_plan_cycle') }} </th>
                                <th> {{ __('language.accounts_table_subscription_new_plan_date') }} </th>
                                <th> {{ __('language.accounts_table_subscription_plan_purchased') }} </th>
                                <th> {{ __('language.accounts_table_amount') }} </th>
                                <th> {{ __('language.status') }} </th>
                            </tr>
                            </thead>
                            <tbody>
                            @forelse($transactions as $transaction)
                                @php
                                    $planDetails = json_decode($transaction->facility_plan_json, true);
                                @endphp
                                <tr>
                                    <td>{{$transaction->invoice_id}}</td>
                                    @if($authUser->hasRole('Facility Group Admin') == true)
                                       <td> {{$transaction->facility->name}}</td>
                                    @endif
                                    <td> {!! $planDetails['name'] !!}  </td>
                                    <td> {!! ucwords( $planDetails['plan_cycle']) !!}  </td>
                                    <td>
                                        @if (!empty($transaction['stripe_plan_expire_date']))
                                            {{ Carbon\Carbon::parse($transaction['stripe_plan_expire_date'])->timezone($transaction->facility->state->time_zone_name)->format('d F, Y h:i A') }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>{{ date("d M, Y", strtotime($transaction->created_at)) }}</td>
                                    <td>${{ $transaction->total_facility_amount }}</td>
                                    <td>
                                        @php
                                            $status = '';
                                            if ($transaction->status == 'completed') {
                                                $status .= '<div class="text-success font-weight-bold"> ' . __("language.account_status_completed") . ' </div>';
                                            } else if ($transaction->status == 'pending') {
                                                $status .= '<div class="text-warning font-weight-bold"> ' . __("language.account_status_pending") . ' </div>';
                                            } else if ($transaction->status == 'cancelled') {
                                                $status .= '<div class="text-danger font-weight-bold"> ' . __("language.account_status_cancelled") . ' </div>';
                                            }
                                        @endphp
                                        {!! $status !!}
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="15" class="text-center"> {{ __('language.no_record_found') }} </td>
                                </tr>
                            @endforelse
                            </tbody>
                        </table>

                        <div class="pagination">
                            {{ $transactions->appends($request)->render() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/account/view.js') }}"></script>

@endpush
