@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.account_hcp_statement_details').' | '.__('language.page_main_title').'')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2 top-header">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <h5><span class="text-primary">{{ucwords($hcp->first_name.' '.$hcp->last_name)}} </span> - Statement</h5>
                            @if (isset($details[0]['statement_id']) && !empty($details[0]['statement_id']))
                                <h6>
                                    <span class="text-primary">Statement Id:</span> {{ $details[0]->statement_prefix.$details[0]->statement_id }},
                                    <span class="text-primary">Statement Duration:</span> {{ $details[0]->invoice_generated_date_range }}
                                </h6>
                            @endif
                        </div>
                        <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                            @if (isset($details[0]['statement_id']) && !empty($details[0]['statement_id']))
                                @if (!empty($details[0]['statement_id']) && $details[0]['hcp_payment_status'] == 'pending')
                                    <a class="btn btn-sm btn-primary hcp-pay-now-link" data-url="{{route('adminPanel.accounts.hcpPay')}}"> {{ __('language.account_pay_button') }} </a>
                                @endif

                                @php
                                    if ($details[0]->statement_id != '' ) {
                                        $filename = $details[0]['invoice_file_name'];
                                        if (config('filesystems.default') == config('constants.file_systems.PUBLIC.value')) {
                                            $attach = url('public/storage/' . config('constants.hcps.invoice_path')) . '/'.urlencode($filename);
                                        } elseif (config('filesystems.default') == config('constants.file_systems.S3.value')) {
                                            $bucket = env('AWS_BUCKET');
                                            $region = env('AWS_DEFAULT_REGION');
                                            $bucketBaseUrl = 'https://s3.' . $region . '.amazonaws.com/'. $bucket.'/';
                                            // $attach = $bucketBaseUrl.config('constants.hcps.invoice_path').urlencode($filename);

                                            $S3NewURL = env('AWS_CloudFront_URL').'/'.config('constants.hcps.invoice_path').urlencode($filename);
                                            $attach = str_replace('#', '%23', $S3NewURL);
                                        }
                                    } else {
                                        $attach = null;
                                    }
                                @endphp

                                @if (!empty($attach))
                                    <a class="btn btn-sm btn-info" href="{{$attach}}" target="_blank" download>  {{ __("language.account_statement_download") }} </a>
                                @endif

                                {!! Form::hidden('statement_ids', old('statement_ids', ($details[0]['statement_id'] ?? null)), ['class' => 'form-control', 'id' => 'statement_ids']) !!}

                                <a class="btn btn-sm btn-dark hcp-refer-btn" data-url="{{route('adminPanel.accounts.hcpReferrals', ['statement_id' => $details[0]['statement_id'], 'hcp_id' => $hcp->id])}}"> {{ __('language.account_refer_button') }} </a>
                            @endif

                            @if (!empty($request))
                                @php $filterApply = 'filter-icon-apply'; @endphp
                            @else
                                @php $filterApply = 'filter-icon'; @endphp
                            @endif
                            <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                                <i class="fa fa-filter"></i>
                            </button>
                        </div>
                    </div>

                    <div class="row page-heading mt-3 mb-3">
                        <div class="col-lg-2">
                            <div class="border border-dark p-2 shadow">
                                <p class="text-center">Total Schedule Shift</p>
                                <p class="text-center">{{$totalShifts}}</p>
                            </div>
                        </div>
                        <div class="col-lg-2">
                            <div class="border border-dark p-2 shadow">
                                <p class="text-center">Total Completed</p>
                                <p class="text-center">{{$completedShifts}}</p>
                            </div>
                        </div>
                        <div class="col-lg-2">
                            <div class="border border-dark p-2 shadow">
                                <p class="text-center">Total Cancelled</p>
                                <p class="text-center">{{$cancelledShifts}}</p>
                            </div>
                        </div>
                        <div class="col-lg-2">
                            <div class="border border-dark p-2 shadow">
                                <p class="text-center">Total Approved</p>
                                <p class="text-center">{{count($shiftDetails)}}</p>
                            </div>
                        </div>
                        <div class="col-lg-2">
                            <div class="border border-dark p-2 shadow">
                                <p class="text-center">Admin Fee for {{count($shiftDetails)}} shifts</p>
                                @php $totalRevenue = 0; @endphp
                                @if (count($shiftDetails))
                                    @foreach ($shiftDetails as $detail)
                                        @php
                                            $totalRevenue += $detail->total_admin_fees_with_loading;
                                        @endphp
                                    @endforeach
                                @endif
                                <p class="text-center">${{number_format($totalRevenue, 2)}}</p>
                            </div>
                        </div>
                        <div class="col-lg-2">
                            <div class="border border-dark p-2 shadow">
                                <p class="text-center">Amount of {{count($referralsDetails)}} Referrals</p>
                                <p class="text-center"> ${{number_format($referralsDetails->sum('hcp_amount'), 2)}} </p>
                            </div>
                        </div>
                    </div>

                    @if (isset($request['statement_id']) && $request['statement_id'] !='')
                        @php $statementId = $request['statement_id']; @endphp
                    @else
                        @php $statementId = ''; @endphp
                    @endif

                    <div>
                        {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'id' => 'filter-form', 'url' =>
                        route('adminPanel.accounts.hcpDetails', ['hcpId' => ev($request['hcp_id']), 'statementId' => ev($statementId)])]) !!}
                        <div class="row">
                            <div class="col-md-12">
                                <div class="custom-datatable-filter hide">
                                    <div class="row">
                                        <div class="col-md-12">
                                            <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-2 hide">
                                            <div class="form-group">
                                                {!! Form::select('status', create_select_options(config('constants.transactions_hcp_status'), 'caption', 'value',  null), old('status', ($request['status'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status', 'title' => __('language.facility_filter_status')]) !!}
                                            </div>
                                        </div>

                                        <div class="col-md-2">
                                            <div class="form-group">
                                                {!! Form::text('date_from', old('date_from', ($request['date_from'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_from', 'placeholder' => __('language.account_filter_date_from')]) !!}
                                            </div>
                                        </div>

                                        <div class="col-md-2">
                                            <div class="form-group">
                                                {!! Form::text('date_to', old('date_from', ($request['date_to'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_to', 'placeholder' => __('language.account_filter_date_to')]) !!}
                                            </div>
                                        </div>

                                        <div class="col-md-12">
                                            <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-4 mb2">
                                            {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-primary apply-filter', 'type' => 'button'] )}}
                                            {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                        </div>
                                    </div>
                                    <div class="filter-border"></div>
                                </div>
                            </div>
                        </div>

                        <div class="row pl-3 mt-3">
                            <div class="col-md-8">
                                <div class="float-left">
                                    <label> {{ __('language.table_result') }} </label>
                                    {!! Form::select('per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('per_page', ($request['per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                                </div>

                                <div class="float-left pl-2 search-box">
                                    {!! Form::text('search', old('search', ($request['search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                    <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                                </div>
                                <div class="clearfix"></div>
                            </div>

                            <div class="col-md-4 text-right">
                                <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.accounts.hcp-details-export',['request' => $request])}}">
                                    Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                                </a>
                            </div>
                        </div>
                        {!! Form::close() !!}
                    </div>
                </div>

                <div class="container-fluid page-heading">
                    <div class="table-responsive pb-5">
                        <table class="table mb-4 mt-3">
                            <thead>
                            <tr>
                                <th> {{ __('language.shift_id') }} </th>
                                <th> {{ __('language.shift_type') }} </th>
                                <th> {{ __('language.cat_pro') }} </th>
                                <th> {{ __('language.account_table_hcp') }} </th>
                                <th> {{ __('language.account_table_hcp_id') }} </th>
                                <th> {{ __('language.account_table_facility') }} </th>
                                <th> {{ __('language.shift_start') }} </th>
                                <th> {{ __('language.shift_end') }} </th>
                                <th> {{ __('language.accounts_table_approved_date') }} </th>
                                <th> {{ __('language.account_table_facility_invoice_id') }} </th>
                                <th> {{ __('language.account_table_facility_invoice_status') }} </th>
                                <th> {{ __('language.total_hours') }} </th>
                                <th> {{ __('language.shift_base_rate') }} </th>
                                <th> {{ __('language.shift_loading_pay') }} </th>
                                <th> {{ __('language.shift_total_pay') }} </th>
                                <th> {{ __('language.account_table_hcp_paid_date') }} </th>
                                <th> {{ __('language.account_table_hcp_pay_status') }} </th>
                                <th> {{ __('language.action') }} </th>
                            </tr>
                            </thead>
                            <tbody>
                            @forelse($details as $detail)
                                <tr>
                                    <td>
                                        <a href="{{ route('adminPanel.accounts.shift_details', ['id' => ev($detail['shift']->id)]) }}">
                                            {{ $detail['shift']->shift_prefix.$detail['shift']->id }}
                                        </a>
                                    </td>
                                    <td>
                                        @if (!empty($detail['shift']->shift_type))
                                            {{ ucwords($detail['shift']->shift_type) }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        <div>{{ ucwords($detail['shift']->profession->name)}}</div>
                                        <div class="font-size-12"> {{ ucwords($detail['shift']->category->name)}} </div>
                                    </td>
                                    <td>
                                        @if (!empty($detail['shift']->hcp))
                                        <a href="{{route('adminPanel.hcps.details', ['id' => ev($detail['shift']->hcp->id)])}}" class="text-primary">
                                            <div>{{ ucwords($detail['shift']->hcp->first_name.' '.$detail['shift']->hcp->last_name) }}</div>
                                        </a>
                                        <div class="font-size-12">
                                            @if (!empty($detail['shift']->hcp))
                                                {{ $detail['shift']->hcp->contact_number }}
                                            @endif
                                        </div>
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        @if (!empty($detail['shift']->hcp))
                                            <a href="{{route('adminPanel.hcps.details', ['id' => ev($detail['shift']->hcp->id)])}}" class="text-primary">
                                                {{ $detail['shift']->hcp->hcp_prefix.$detail['shift']->hcp->id }}
                                            </a>
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        <a href="{{ route('adminPanel.facilities.details', ['id' => ev($detail['shift']->facility->id)]) }}">
                                            <div> {{ ucwords($detail['shift']->facility->name)}}</div>
                                        </a>
                                        <div class="font-size-12">
                                            @if (!empty($detail['shift']['facility']->address))
                                                {{ $detail['shift']['facility']->address }}
                                            @endif
                                        </div>
                                    </td>
                                    @if (!empty($detail['shift']->shift_approved_time))
                                    <td>
                                        @if (!empty($detail['shift']->approved_shift_start_time))
                                            {{ date("d M, Y h:i A", strtotime($detail['shift']->approved_shift_start_time)) }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>

                                    <td>
                                        @if (!empty($detail['shift']->approved_shift_end_time))
                                            {{ date("d M, Y h:i A", strtotime($detail['shift']->approved_shift_end_time)) }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>
                                    @else
                                    <td>
                                        @if (!empty($detail['shift']->start_time))
                                            {{ date("d M, Y h:i A", strtotime($detail['shift']->start_time)) }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>

                                    <td>
                                        @if (!empty($detail['shift']->end_time))
                                            {{ date("d M, Y h:i A", strtotime($detail['shift']->end_time)) }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>
                                    @endif
                                    <td>
                                        @if (!empty($detail['shift']->shift_approved_time))
                                            {{ date("d M, Y h:i A", strtotime($detail['shift']->shift_approved_time)) }}
                                        @endif
                                    </td>
                                    <td>
                                        @if (!empty($detail->invoice_id))
                                            {{ $detail->invoice_prefix.$detail->invoice_id }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>
                                    <td>
                                        @php
                                            $status = '';
                                            if ($detail->status == 'completed') {
                                                $status .= '<div class="text-success font-weight-bold"> ' . __("language.account_status_completed") . ' </div>';
                                            } else if ($detail->invoice_id != '' && $detail->status == 'pending') {
                                                $status .= '<div class="text-dark font-weight-bold"> ' . __("language.account_status_invoiced") . ' </div>';
                                            }  else if ($detail->status == 'pending') {
                                                $status .= '<div class="text-warning font-weight-bold"> ' . __("language.account_status_approved") . ' </div>';
                                            } else if ($detail->status == 'cancelled') {
                                                $status .= '<div class="text-danger font-weight-bold"> ' . __("language.account_status_cancelled") . ' </div>';
                                            } else if ($detail->status == 'overdue') {
                                                $status .= '<div class="text-danger font-weight-bold"> ' . __("language.account_status_overdue") . ' </div>';
                                            }
                                        @endphp
                                        {!! $status !!}
                                    </td>
                                    <td>
                                        {{ $detail['shift']->working_hours }} Hrs
                                    </td>
                                    <td>
                                        ${{ $detail['shift']->hcp_per_rate }}
                                    </td>
                                    <td>
                                        @if (is_numeric($detail['shift']->shift_loading))
                                            ${{ number_format($detail['shift']->shift_loading*($detail['shift']->hcp_per_rate/100), 2) }}
                                        @else
                                            {{ '$0.00' }}
                                        @endif
                                    </td>
                                    <td>
                                        ${{$detail['shift']->hcp_amount}}
                                    </td>
                                    <td>
                                        @if (!empty($detail->hcp_paid_on))
                                            {{ date("d M, Y", strtotime($detail->hcp_paid_on)) }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>
                                    <td>
                                        @php
                                            $status = '';
                                            if ($detail->hcp_payment_status == 'completed') {
                                                $status .= '<div class="text-success font-weight-bold"> ' . __("language.account_status_completed") . ' </div>';
                                            } else if ($detail->statement_id != '' && $detail->hcp_payment_status == 'pending') {
                                                $status .= '<div class="text-warning font-weight-bold"> ' . __("language.account_status_approved") . ' </div>';
                                            }  else if ($detail->hcp_payment_status == 'pending') {
                                                $status .= '<div class="text-warning font-weight-bold"> ' . __("language.account_status_approved") . ' </div>';
                                            } else if ($detail->hcp_payment_status == 'cancelled') {
                                                $status .= '<div class="text-danger font-weight-bold"> ' . __("language.account_status_cancelled") . ' </div>';
                                            } else if ($detail->hcp_payment_status == 'overdue') {
                                                $status .= '<div class="text-danger font-weight-bold"> ' . __("language.account_status_overdue") . ' </div>';
                                            }
                                        @endphp
                                        {!! $status !!}
                                    </td>
                                    <td>
                                        <ul class="datatable-action">
                                            <li>
                                                <div class="dropdown custom-dropdown-icon">
                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                    </a>
                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                        <a href="{{route('adminPanel.accounts.shift_details',['id'=>ev($detail['shift']->id)])}}" class="dropdown-item"> {{ __("language.details") }} </a>
                                                    </div>
                                                </div>
                                            </li>
                                        </ul>
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="20" class="text-center"> {{ __('language.no_record_found') }} </td>
                                </tr>
                            @endforelse
                            </tbody>
                        </table>

                        <div class="pagination">
                            {{ $details->appends($request)->render() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/account/view.js') }}"></script>
@endpush
