@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.revenue_statement').' | '.__('language.page_main_title').'')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <h5>{{ __('language.revenue_statement') }}</h5>
                        </div>
                        <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                            @if (!empty($request))
                                @php $filterApply = 'filter-icon-apply'; @endphp
                            @else
                                @php $filterApply = 'filter-icon'; @endphp
                            @endif
                            <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                                <i class="fa fa-filter"></i>
                            </button>
                        </div>
                    </div>

                    <div class="row page-heading mt-3 mb-3">
                        <div class="col-lg-2 border border-dark mr-3 p-2 shadow">
                            <p class="text-center">Total Invoice Value</p>
                            <p class="text-center">${{ number_format($shiftDetails->sum('total_facility_amount'), 2) }}</p>
                        </div>
                    </div>

                    <div class="top-header">
                        {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' => route('adminPanel.accounts.revenueStatement'), 'id' => 'filter-form']) !!}
                        <div class="row">
                            <div class="col-md-12">
                                <div class="custom-datatable-filter hide">
                                    <div class="row">
                                        <div class="col-md-12">
                                            <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-12">
                                            @if ($authUser->hasRole('Facility') != true)
                                            @if (!empty($states))
                                                <div class="form-group btn-group btn-group-toggle btn-checkbox-group" data-toggle="buttons">
                                                    @foreach($states as $state)
                                                        <label class="btn btn-custom-outline {{ !empty($request['states']) && in_array($state->id, $request['states']) ? ' active' : '' }}">
                                                            <input type="checkbox" id="states" class="states" name="states[]" value="{{$state->id}}" autocomplete="off" {{ !empty($request['states']) && in_array($state->id, $request['states']) ? ' checked' : '' }}> {{$state->short_form}}
                                                        </label>
                                                    @endforeach
                                                </div>
                                            @endif
                                            @endif
                                        </div>

                                        <div class="col-md-2">
                                            <div class="form-group">
                                                {!! Form::text('date_from', old('date_from', ($request['date_from'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_from', 'placeholder' => __('language.account_filter_date_from')]) !!}
                                            </div>
                                        </div>

                                        <div class="col-md-2">
                                            <div class="form-group">
                                                {!! Form::text('date_to', old('date_from', ($request['date_to'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_to', 'placeholder' => __('language.account_filter_date_to')]) !!}
                                            </div>
                                        </div>

                                        @if ($authUser->hasRole('Facility') != true)
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                {!! Form::select('facility', create_select_options($facilities, 'name', 'id',  __('language.facility')), old('facility', ($request['facility'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'facility' ]) !!}
                                            </div>
                                        </div>
                                        @endif

                                        <div class="col-md-2 hide">
                                            <div class="form-group">
                                                {!! Form::select('status', create_select_options(config('constants.invoice_status_super_admin'), 'caption', 'value',  null), old('status', ($request['status'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status', 'title' => __('language.facility_filter_status')]) !!}
                                            </div>
                                        </div>

                                        <div class="col-md-12">
                                            <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-4 mb2">
                                            {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-primary apply-filter', 'type' => 'submit'] )}}
                                            {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                        </div>
                                    </div>
                                    <div class="filter-border"></div>
                                </div>
                            </div>
                        </div>
                        <div class="row pl-3 mt-3">
                            <div class="col-md-8">
                                <div class="float-left">
                                    <label> {{ __('language.table_result') }} </label>
                                    {!! Form::select('per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('per_page', ($request['per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                                </div>

                                <div class="float-left pl-2 search-box">
                                    {!! Form::text('search', old('search', ($request['search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                    <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                                </div>
                                <div class="clearfix"></div>
                            </div>

                            <div class="col-md-4 text-right">
                                <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.accounts.revenueStatementExport',['request' => $request])}}">
                                    Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                                </a>
                            </div>
                        </div>
                        {!! Form::close() !!}

                        {!! Form::hidden('invoice_ids', old('invoice_ids', ($request['invoice_ids'] ?? null)), ['class' => 'form-control', 'id' => 'invoice_ids']) !!}
                    </div>
                </div>

                <div class="container-fluid page-heading">
                    <div class="table-responsive pb-5">
                        <table class="table mb-4 mt-3">
                            <thead>
                                <tr>
                                    <th> {{ __('language.account_table_facility') }} </th>
                                    <th> {{ __('language.account_table_facility_contact_number') }} </th>
                                    <th> {{ __('language.account_table_invoice_id') }} </th>
                                    <th> {{ __('language.account_table_invoice_date') }} </th>
                                    <th> {{ __('language.account_table_due_date') }} </th>
                                    <th> {{ __('language.account_table_paid_date') }} </th>
                                    <th> {{ __('language.account_table_amount') }} </th>
                                    <th> {{ __('language.account_table_admin_fees') }} </th>
                                    <th> {{ __('language.action') }} </th>
                                </tr>
                            </thead>
                            <tbody>
                            @php
                                $facilityAmount = 0;
                                $adminFees = 0;
                            @endphp
                            @forelse($transactions as $transaction)
                                @php
                                    $facilityAmount = $facilityAmount+$transaction->total_facility_amount;
                                    $adminFees = $adminFees+$transaction->final_total_admin_fees_with_loading;
                                @endphp
                                <tr>
                                    <td>
                                        <a href="{{ route('adminPanel.facilities.details', ['id' => ev($transaction['facility']->id)]) }}">
                                            <div> {{ ucwords($transaction['facility']->name)}}</div>
                                        </a>
                                        <div class="font-size-12">
                                            @if (!empty($transaction['facility']->address))
                                                {{ $transaction['facility']->address }}
                                            @endif
                                        </div>
                                    </td>
                                    <td>
                                        {{$transaction['facility']->contact_number}}
                                    </td>
                                    <td>
                                        @if (!empty($transaction->invoice_id))
                                            {{ $transaction->invoice_prefix.$transaction->invoice_id }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>

                                    <td>
                                        @if (!empty($transaction->invoice_created_at))
                                            {{ date("d M, Y", strtotime($transaction->invoice_created_at)) }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>
                                    <td>
                                        @if (!empty($transaction->invoice_overdue_date))
                                        {{ date("d M, Y", strtotime($transaction->invoice_overdue_date)) }}
                                        @else
                                            <b>----</b>
                                        @endif
                                    </td>
                                    <td>
                                        @if (!empty($transaction->paid_on))
                                            {{ date("d M, Y", strtotime($transaction->paid_on)) }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>${{ $transaction->total_facility_amount }}</td>
                                    <td>
                                        @if (!empty($transaction->final_total_admin_fees_with_loading))
                                            ${{ $transaction->final_total_admin_fees_with_loading }}
                                        @else
                                            $0.00
                                        @endif
                                    </td>
                                    <td>
                                        <ul class="datatable-action">
                                            <li>
                                                <div class="dropdown custom-dropdown-icon">
                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                    </a>
                                                    @php
                                                        if ($transaction->invoice_id != '' ) {
                                                            $filename = $transaction['invoice_file_name'];
                                                            if (config('filesystems.default') == config('constants.file_systems.PUBLIC.value')) {
                                                                $attach = url('public/storage/' . config('constants.facility.invoice_path')) . '/'.urlencode($filename);
                                                            } elseif (config('filesystems.default') == config('constants.file_systems.S3.value')) {
                                                                $bucket = env('AWS_BUCKET');
                                                                $region = env('AWS_DEFAULT_REGION');
                                                                $bucketBaseUrl = 'https://s3.' . $region . '.amazonaws.com/'. $bucket.'/';
                                                                // $attach = $bucketBaseUrl.config('constants.facility.invoice_path').urlencode($filename);

                                                                $S3NewURL = env('AWS_CloudFront_URL').'/'.config('constants.facility.invoice_path').urlencode($filename);
                                                                $attach = str_replace('#', '%23', $S3NewURL);
                                                            }
                                                        }
                                                    @endphp
                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                        <a href="{{route('adminPanel.accounts.revenueStatementDetails',['facilityId' => ev($transaction->facility_id), 'invoiceId' => ev($transaction->invoice_id) , 'invoiceId' => ev($transaction->invoice_id)])}}" class="dropdown-item"> {{ __("language.details") }} </a>

                                                        <a href="{{$attach}}" target="_blank" download  class="dropdown-item"> {{ __("language.account_invoice_download") }} </a>
                                                    </div>
                                                </div>
                                            </li>
                                        </ul>
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="15" class="text-center"> {{ __('language.no_record_found') }} </td>
                                </tr>
                            @endforelse
                            @if(!$transactions->isEmpty())
                            <tr>
                                <td colspan="6" class="text-right"><b>{{ __('language.account_table_total') }}: </b></td>
                                <td><b>${{ number_format($facilityAmount, 2) }}</b></td>
                                <td colspan="4"><b>${{ number_format($adminFees, 2) }}</b></td>
                            </tr>
                            @endif
                            </tbody>
                        </table>

                        <div class="pagination">
                            {{ $transactions->appends($request)->render() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/account/view.js') }}"></script>

<script>
    $('#todoAll').click(function(e){
        var table= $(e.target).closest('table');
        $('td input:checkbox',table).prop('checked',this.checked);
    });

    $(".todochkbox").change(function() {
        var invoice = [];
        $.each($("input[name='invoice_checkbox']:checked"), function(){
            invoice.push($(this).val());
        });
        $('#invoice_ids').val(invoice.join(","));
        $('#invoice_ids').valid();
    });
</script>
@endpush
