@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.profile_page_title').' ')

@push('styles')
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">

        <!-- Validation error -->
        @component('admin-panel.validation.errors') @endcomponent
        <!-- / Validation error -->


        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-4 col-lg-4 col-md-4 col-4 page-heading">
                        <label>{{ __('language.facility_change_plan') }}</label>
                    </div>
                </div>
                {!! Form::open(['class' => 'update-facilityPlan-form', 'method' => 'post', 'url' => route('adminPanel.facilities.updatePlan') ]) !!}
                <div class="row">
                    <div class="col-xl-10 col-lg-10 col-md-10 col-10 page-heading mt2">
                        <div class="form-row mb-2">
                            <div class="form-group col-md-3">
                                {!! Form::select('plan_id', create_select_options($plans, 'name', 'id', null),old('plan_id', ($request['plan_id'] ?? null)),  ['class' => 'form-control select-picker change-price', 'id' => 'plan_id', 'title' =>  __('language.facility_plan')])  !!}
                            </div>

                            @if ($facilityActivePlan['plan_cycle'] == 'monthly')
                            <div class="form-group col-md-3">
                                {!! Form::select('plan_cycle', create_select_options(config('constants.plan_configurations.plan_cycle'), 'caption', 'value', null), null,  ['class' => 'form-control select-picker change-price', 'id' => 'plan_cycle', 'title' => __('language.facility_plan_cycle'), 'data-url' => route('adminPanel.plans.getPlanPrice')]) !!}
                            </div>
                            @else
                            <div class="form-group col-md-3">
                                {!! Form::select('plan_cycle', create_select_options(config('constants.plan_configurations.plan_cycle_yearly'), 'caption', 'value', null), 'yearly',  ['class' => 'form-control select-picker change-price', 'id' => 'plan_cycle', 'title' => __('language.facility_plan_cycle'), 'data-url' => route('adminPanel.plans.getPlanPrice')]) !!}
                            </div>
                            @endif
                        </div>
                        <div class="form-row mb-2">
                            <div class="form-group col-md-3 amount-div">
                                {!! Form::text('amount','', ['class' => 'form-control input-readonly-new', 'id' => 'amount', 'placeholder' => __('language.facility_plan_amount'), 'readonly']) !!}
                            </div>
                        </div>
                    </div>
                </div>

                <div class="row hide">
                    <div class="col-xl-12 col-lg-12 col-md-12 col-12 page-heading">
                        <h6 class="mt-3 mb-2 text-primary"> {{ __('language.facility_creditcard_details') }} </h6>
                    </div>
                </div>
                <hr class="m-1 hide"/>
                <div class="row hide">
                    <div class="col-xl-10 col-lg-10 col-md-10 col-10 page-heading mt2">
                        <div class="row mb-3">
                            <div class="col-md-3">
                                <label> {{ __('language.facility_card_number') }} </label>
                                <p class="text-dark">
                                    @if (!empty($profile->card_number))
                                    {{ substr($profile->card_number, -4) }}
                                    @else
                                    N/A
                                    @endif
                                </p>
                            </div>

                            <div class="col-md-3">
                                <label> {{ __('language.facility_card_expiry_date') }} </label>
                                <p class="text-dark">
                                    @if (!empty($profile->card_expiry_date))
                                    {{ date("M/Y", strtotime($profile->card_expiry_date)) }}
                                    @else
                                    N/A
                                    @endif
                                </p>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="row mb-2">
                    <div class="col-md-4 page-heading">
                        <button type="submit" class="btn btn-primary">{{ __('language.facility_upgrade_plan_btn') }}</button>
                    </div>
                </div>
                {!! Form::close() !!}

                <div class="row">
                    <div class="col-xl-12 col-lg-12 col-md-12 col-12 page-heading mt1">
                        <h6 class="mt-3 mb-2 text-primary"> {{ __('language.facility_current_plan_details') }} </h6>
                    </div>
                </div>
                <hr class="m-1 mb-4"/>

                <div class="row mt-2">
                    <div class="col-xl-4 col-lg-4 col-md-4 col-4 page-heading">
                        @if(!empty($facilityActivePlan))
                        <h6>Fees:
                            @if (!empty($facilityActivePlan->payment_amount))
                            ${{ $facilityActivePlan->payment_amount }}
                            @if ($facilityActivePlan->plan_cycle == 'yearly')
                            ({{ __('language.plan_profession_per_month') }})
                            @endif
                            @else
                            N/A
                            @endif
                        </h6>
                        <h6>Plan: {{ ucwords($facilityActivePlan['plan']->name) }}</h6>
                        <h6>Plan Type: {{ ucwords($facilityActivePlan->plan_cycle) }}</h6>
                        <h6>Date Of Subscription: {{ Carbon\Carbon::parse($facilityActivePlan->created_at)->timezone($profile->state->time_zone_name)->format('d F, Y h:i A') }}</h6>
                        @if (!empty($subscription['current_period_end']))
                        <h6>Expire Date: {{ Carbon\Carbon::parse($subscription['current_period_end'])->timezone($profile->state->time_zone_name)->format('d F, Y h:i A') }}</h6>
                        @endif
                        @else
                        <p> {{ __('language.no_record_found') }} </p>
                        @endif
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/plans/plans.js') }}"></script>
@endpush
