@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.create_facility_page_title').' ')


@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">

        <!-- Validation error -->
        @component('admin-panel.validation.errors') @endcomponent
        <!-- / Validation error -->

        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                        <h5> {{ __('language.create_facility_page_title') }} </h5>
                    </div>
                </div>

                <div class="form p-3">
                    {!! Form::open(['class' => 'add-facilities-form', 'method' => 'post', 'url' => route('adminPanel.facilities.store'), 'files' => true ]) !!}

                        <div class="form-row mb-2">
                            <div class="form-group col-md-3">
                                <label for="facility_group"> {{ __('language.facility_group') }} </label>
                                {!! Form::select('facility_group', create_select_options($facilityGroups, 'name', 'id', null), null,  ['class' => 'form-control select-picker facility-group', 'id' => 'facility_group', 'title' => __('language.facility_group'), 'data-url' => route('adminPanel.facility-names.getFacilityNames')]) !!}
                            </div>

                            <div class="form-group col-md-3 facility-name-div">
                                <label for="facility_name_id"> {{ __('language.facility_name') }} </label>
                                {!! Form::select('facility_name_id', create_select_options([], 'name', 'id', null), null,  ['class' => 'form-control select-picker facility-name', 'id' => 'facility_name_id', 'title' => __('language.facility_name'), 'data-url' => route('adminPanel.facility-names.getFacilityNameDetails')]) !!}
                            </div>

                            <div class="form-group col-md-3 facility-name-div">
                                <label for="legal_entity_name"> {{ __('language.legal_entity_name') }} </label>
                                {!! Form::text('legal_entity_name', '', ['class' => 'form-control', 'id' => 'legal_entity_name', 'placeholder' => __('language.legal_entity_name')]) !!}
                            </div>

                            {!! Form::hidden('name', '', ['class' => 'form-control', 'id' => 'name', 'placeholder' => __('language.facility_name')]) !!}
                        </div>

                        <div class="form-row mb-2">
                            <div class="form-group col-md-3">
                                <label for="contact_person"> {{ __('language.facility_contact_person') }} </label>
                                {!! Form::text('contact_person', '', ['class' => 'form-control', 'id' => 'contact_person', 'placeholder' => __('language.facility_contact_person')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label for="email"> {{ __('language.facility_email') }} </label>
                                {!! Form::email('email', '', ['class' => 'form-control', 'id' => 'email', 'placeholder' => __('language.facility_email'), 'data-url' => route('adminPanel.dashboard.checkUserEmail')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label for="contact_number"> {{ __('language.facility_contact_number') }} </label>
                                {!! Form::text('contact_number', '', ['class' => 'form-control', 'id' => 'contact_number', 'placeholder' => __('language.facility_contact_number')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label for="email"> {{ __('language.additional_email') }} </label>
                                {!! Form::text('additional_email', old('additional_email', ($facility->additional_email ?? null)), ['class' => 'form-control', 'id' => 'additional_email', 'placeholder' => __('language.facility_enter_emails_separated_by_comma')]) !!}
                            </div>
                        </div>

                        <div class="form-row mb-2">
                            <div class="form-group col-md-3">
                                <label for="mobile_number"> {{ __('language.facility_mobile_number') }} </label>
                                {!! Form::text('mobile_number', old('mobile_number', ($facility->mobile_number ?? null)), ['class' => 'form-control', 'id' => 'mobile_number', 'placeholder' => __('language.facility_mobile_number')]) !!}
                            </div>
                            
                            <div class="form-group col-md-3 state-div">
                                <label for="state_id"> {{ __('language.facility_state') }} </label>
                                {!! Form::select('state_id', create_select_options($states, 'name', 'id', null), null,  ['class' => 'form-control select-picker state-city', 'id' => 'state_id', 'data-url' => route('adminPanel.state.getCities'), 'title' => __('language.facility_state')]) !!}
                            </div>

                            <div class="form-group col-md-3 address-div">
                                <label for="address"> {{ __('language.facility_address') }} </label>
                                {!! Form::text('address', '', ['class' => 'form-control', 'id' => 'address', 'placeholder' => __('language.facility_address')]) !!}
                            </div>

                            <div class="form-group col-md-3 city-div">
                                <label for="city_id"> {{ __('language.facility_city') }} </label>
                                {!! Form::text('city_name', '', ['class' => 'form-control input-readonly-new',  'id' => 'city_name',   'placeholder' => __('language.facility_city'), 'readonly' ]) !!}
                            </div>
                        </div>

                        <div class="form-row mb-2">
                            <div class="form-group col-md-3 suburb-div">
                                <label for="suburb_id"> {{ __('language.facility_suburd') }} </label>
                                {!! Form::text('suburb_name', '', ['class' => 'form-control input-readonly-new',  'id' => 'suburb_name',   'placeholder' => __('language.hcp_suburb'), 'readonly' ]) !!}
                            </div>

                            <div class="form-group col-md-3 post-code-div">
                                <label for="post_code"> {{ __('language.facility_post_code') }} </label>
                                {!! Form::text('post_code', '', ['class' => 'form-control input-readonly-new', 'id' => 'postcode', 'placeholder' => __('language.facility_post_code'), 'readonly']) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label for="email"> Additional Nurse Email </label>
                                {!! Form::text('additional_nurse_email', old('additional_nurse_email', ($facility->additional_nurse_email ?? null)), ['class' => 'form-control', 'id' => 'additional_nurse_email', 'placeholder' => __('language.facility_enter_emails_separated_by_comma')]) !!}
                            </div>

                            {!! Form::hidden('latitude', '', ['class' => 'form-control', 'id' => 'latitude', 'autocomplete' => 'off']) !!}
                            {!! Form::hidden('longitude', '', ['class' => 'form-control', 'id' => 'longitude', 'autocomplete' => 'off']) !!}
                        </div>

                        {{-- <div class="mt-4 mb-4">
                            <h6 class="mb-2 text-primary"> {{ __('language.facility_plan_details') }} </h6>
                            <hr>

                            <div class="form-row mb-2">
                                <div class="form-group col-md-3">
                                    <label for="plan"> {{ __('language.facility_plan') }} </label>
                                    <select name="plan" id="plan" class="form-control select-picker" data-live-search="true" title="{{__('language.facility_plan')}}">
                                        @if (!empty($plans))
                                            @foreach ($plans as $plan)
                                                <option value="{{ $plan->id }}">{{ $plan->name }}</option>
                                            @endforeach
                                        @endif
                                    </select>
                                </div>

                                <div class="form-group col-md-3">
                                    <label for="plan_cycle"> {{ __('language.facility_plan_cycle') }} </label>
                                    {!! Form::select('plan_cycle', create_select_options(config('constants.plan_configurations.plan_cycle'), 'caption', 'value', null), null,  ['class' => 'form-control select-picker', 'id' => 'plan_cycle', 'title' => __('language.facility_plan_cycle')]) !!}
                                </div>
                            </div>

                            <div class="form-row mb-2">
                                <div class="form-group col-md-3">
                                    <label for="plan_start_date"> {{ __('language.facility_plan_start_date') }} </label>
                                    {!! Form::text('plan_start_date', '', ['class' => 'form-control start-date-picker date-picker', 'id' => 'plan_start_date', 'placeholder' => __('language.facility_plan_start_date')]) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label for="plan_end_date"> {{ __('language.facility_plan_end_date') }} </label>
                                    {!! Form::text('plan_end_date', '', ['class' => 'form-control end-date-picker date-picker', 'id' => 'plan_end_date', 'placeholder' => __('language.facility_plan_end_date')]) !!}
                                </div>
                            </div>

                            <div class="form-row mb-2">
                                <div class="form-group col-md-6">
                                    <div class="custom-control custom-checkbox">
                                        <input type="checkbox" class="custom-control-input" value="1" id="plan_auto_renewal" name="plan_auto_renewal" checked>
                                        <label class="custom-control-label pt-0" for="plan_auto_renewal"> {{ __('language.facility_plan_auto_renewal') }} </label>
                                    </div>
                                </div>
                            </div>
                        </div> --}}

                        {{-- <div class="mt-4 mb-4 hide">
                            <h6 class="mb-2 text-primary"> {{ __('language.facility_credit_card_details') }} </h6>
                            <hr>

                            <div class="form-row mb-2">
                                <div class="form-group col-md-3">
                                    <label for="card_number"> {{ __('language.facility_card_number') }} </label>
                                    {!! Form::text('card_number', '', ['class' => 'form-control', 'id' => 'card_number', 'placeholder' => __('language.facility_card_number')]) !!}
                                </div>

                                <div class="form-group col-md-3 ">
                                    <label for="card_expiry_date"> {{ __('language.facility_card_expiry_date') }} </label>
                                    {!! Form::text('card_expiry_date', '', ['class' => 'form-control date-picker card-expiry-date', 'id' => 'card_expiry_date', 'placeholder' => __('language.facility_card_expiry_date')]) !!}
                                </div>
                            </div>

                            <div class="form-row mb-2">
                                <div class="form-group col-md-3">
                                    <label for="card_ccv"> {{ __('language.facility_card_cvv') }} </label>
                                    {!! Form::text('card_cvv', '', ['class' => 'form-control', 'id' => 'card_cvv', 'placeholder' => __('language.facility_card_cvv')]) !!}
                                </div>
                            </div>
                        </div> --}}

                        {{-- <div class="mt-4 mb-4">
                            <h6 class="mb-2 text-primary"> {{ __('language.facility_upload_document') }} </h6>
                            <hr>

                            @if (!empty($documents))
                            <div class="form-row">
                                {!! Form::hidden('document_count', count($documents), ['class' => 'form-control
                                ', 'id' => 'document_count']) !!}
                                @foreach ($documents as $key => $document)
                                <div class="col-md-6 mb-3">
                                    <div class="panel panel-border">
                                        <h6 class="text-left">
                                            {{ $document->name }}
                                            @if ($document->mandatory_status == 'yes')
                                                <span class="text-danger">*</span>
                                            @endif
                                        </h6>
                                        @if ($document->expiry_date_mandatory == 'yes')
                                            @php $requiredExpiryDateClass = 'expiry-date-required-'.$key; @endphp
                                        @else
                                            @php $requiredExpiryDateClass = ''; @endphp
                                        @endif

                                        {!! Form::hidden('documents['.$key.'][document_id]', $document->id, ['class' =>
                                        'form-control']) !!}

                                        {!! Form::hidden('documents['.$key.'][document_name]', $document->name, ['class' =>
                                        'form-control']) !!}

                                        {!! Form::hidden('documents['.$key.'][document_required]', $document->mandatory_status, ['class' => 'form-control mandatory-status-'.$key]) !!}

                                        <div class="form-row">
                                            <div class="form-group col-md-6">
                                                <label for="upload_document"> {{ __('language.facility_upload_document') }}</label>
                                                {!! Form::file('documents['.$key.'][file]', ['class' =>
                                                'form-control-file document-file-'.$key.'', 'id'=>'file-'.$key.'',
                                                'autocomplete' => 'off', ]) !!}
                                            </div>

                                            @if ($document->expiry_date_mandatory == 'yes')
                                                <div class="form-group col-md-6">
                                                    <label for="expiry_date"> {{ __('language.hcp_expiry_date') }} </label>
                                                    {!! Form::text('documents['.$key.'][expiry_date]', null, ['class' =>
                                                    'form-control expiry-date date-input '.$requiredExpiryDateClass.' ', 'id' =>
                                                    'expiry-date-'.$key.'', 'placeholder' => __('language.hcp_expiry_date')])
                                                    !!}
                                                </div>
                                            @endif
                                        </div>

                                    </div>
                                </div>
                                @endforeach
                            @else
                            <div class="form-group col-md-12">
                                {{ __('messages.no_document_found') }}
                            </div>
                            @endif
                            </div>
                        </div> --}}

                        {{ Form::button( '<i class="fa fa-save"></i> &nbsp;'. __('language.save'), ['class' => 'btn btn-primary btn-submit mt-2', 'type' => 'submit'] )}}

                    {!! Form::close() !!}
                </div>
            </div>

        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/facilities/facilities.js') }}"></script>
<script src="https://maps.googleapis.com/maps/api/js?libraries=places&output=json&key={{env('GOOGLE_API_KEY')}}"  defer></script>
<script>
    $(document).ready(function() {
        var options = {
            componentRestrictions: {country: ['AU']}
        };
        var autocomplete = new google.maps.places.Autocomplete(address, options);
        autocomplete.addListener('place_changed', function() {
            var place = autocomplete.getPlace();
            var latitude = place.geometry.location.lat();
            var longitude = place.geometry.location.lng();
            $('#latitude').val(latitude);
            $('#longitude').val(longitude);

            for (var i = 0; i < place.address_components.length; i++) {
                for (var j = 0; j < place.address_components[i].types.length; j++) {

                    if (place.address_components[i].types[j] == "administrative_area_level_2") {
                        $('#city_name').val(place.address_components[i].long_name);
                    }

                    if (place.address_components[i].types[j] == "locality") {
                        $('#suburb_name').val(place.address_components[i].long_name);
                    }

                    if (place.address_components[i].types[j] == "postal_code") {
                        $('#postcode').prop( "disabled", false );
                        $('#postcode').val(place.address_components[i].long_name);
                    }
                }
            }
        });
    });
</script>
@endpush
