@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.facilities_details_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/elements/avatar.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/components/tabs-accordian/custom-tabs.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-12 col-lg-12 col-md-12 col-12 page-heading">
                        <div class="row">
                            <div class="col-md-3">
                                <div class="media">
                                    <div class="media-body profile-info ml-1">
                                        <h6>
                                            @if (!empty($facility->facility_name))
                                                {{ ucwords($facility->facility_name->name) }}
                                            @else
                                                {{ ucwords($facility->name) }}
                                            @endif
                                        </h6>
                                        <p class="meta-date-time">
                                            {{ $facility->facility_prefix.$facility->id }}
                                            <span class="profile-rating"> <i data-feather="star" class="feather-16"></i>
                                                @if (!empty($facility->average_rating))
                                                    {{ round($facility->average_rating*2)/2 }}
                                                @else
                                                    0
                                                @endif
                                            </span>
                                        </p>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-3"></div>
                            <div class="col-md-6 text-right">
                                <div class="float-right">
                                    <ul class="page-top-action">
                                        <li>
                                            <div class="dropdown custom-dropdown-icon pt0">
                                                <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                    <i class="fa fa-ellipsis-v" aria-hidden="true"></i>
                                                </a>
                                                <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">

                                                    @if ($authUser->can('Edit Facilities'))
                                                    <a href="{{ route('adminPanel.facilities.edit', ['id' => ev($facility->id)]) }}" class="dropdown-item"> {{ __("language.edit") }} </a>
                                                    @endif

                                                    <a href="{{ route('adminPanel.facilities.viewAllFavoritesHcps', ['id' => ev($facility->id)]) }}" class="dropdown-item"> {{ __("language.facility_view_favourite") }} </a>

                                                    <a href="{{ route('adminPanel.facilities.viewAllBlockedHcps', ['id' => ev($facility->id)]) }}" class="dropdown-item"> {{ __("language.facility_view_blocked") }} </a>

                                                    @php
                                                        $pendingTransactionCount = get_facility_shift_pending_transactions($facility->id);
                                                    @endphp

                                                    @if ($facility->status == 'active')
                                                        @if ($pendingTransactionCount == 0)
                                                        <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.facilities.changeStatus', ['id' => ev($facility->id), 'status' => 'inactive']) }}"> {{ __("language.inactive") }} </a>
                                                        @endif
                                                    @elseif ($facility->status == 'inactive' || $facility->status == 'pending-approval')
                                                        <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.facilities.changeStatus', ['id' => ev($facility->id), 'status' => 'active']) }}"> {{ __("language.active") }} </a>
                                                    @endif

                                                    @if ($pendingTransactionCount == 0)
                                                    <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.facilities.changeStatus', ['id' => ev($facility->id), 'status' => 'archived']) }}"> {{ __("language.facility_archived") }} </a>
                                                    @endif

                                                    @if(!empty($facility->plans[0]) && $facility->plans[0]->id == 4)
                                                        <a href="#" class="dropdown-item" data-toggle="modal" data-target="#exampleModal"> Edit Trail Plan </a>
                                                    @endif
                                                </div>
                                            </div>
                                        </li>
                                    </ul>
                                </div>

                                @if(!empty($facility->plans[0]) && $facility->plans[0]->id != 4)
                                    <h5 class="text-warning float-right pr2">
                                        <b>{{ __('language.facility_plan') }} {{ ucwords($facility->plans[0]->name) }}
                                            @if (!empty($subscription))
                                            , Next Payment Date {{ date('d M, Y', $subscription['current_period_end']) }}
                                            @endif
                                        </b>
                                    </h5>
                                @elseif(!empty($facility->plans[0]) && $facility->plans[0]->id == 4)
                                <h5 class="text-warning float-right pr2">
                                    <b>{{ __('language.facility_plan') }} {{ ucwords($facility->plans[0]->name) }}, Expiry Date {{ date('d M, Y', strtotime($facility->plans[0]->pivot->expiry_date)) }}</b>
                                </h5>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>

                <div class="widget-content widget-content-area animated-underline-content box-shadow-none">
                    <ul class="nav nav-tabs panel-tabs mb-3" id="animateLine" role="tablist">
                        <li class="nav-item">
                            <a class="nav-link active" id="profile-tab" data-toggle="tab" href="#profile" role="tab" aria-controls="profile" aria-selected="false">
                                {{ __('language.facility_profile_tab_heading') }}
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="document-tab" data-toggle="tab" href="#document" role="tab" aria-controls="document" aria-selected="true">
                                {{ __('language.facility_document_tab_heading') }}
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="shift-tab" data-toggle="tab" href="#shift" role="tab" aria-controls="shift" aria-selected="true">
                                {{ __('language.facility_shift_tab_heading') }}
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="history-tab" data-toggle="tab" href="#history" role="tab" aria-controls="history" aria-selected="true">
                                {{ __('language.facility_history_tab_heading') }}
                            </a>
                        </li>
                        <li class="nav-item hide">
                            <a class="nav-link" id="favourite-tab" data-toggle="tab" href="#favourite" role="tab" aria-controls="favourite" aria-selected="false">
                                {{ __('language.facility_favourite') }}
                            </a>
                        </li>
                        <li class="nav-item hide">
                            <a class="nav-link" id="blocklist-tab" data-toggle="tab" href="#blocklist" role="tab" aria-controls="blocklist" aria-selected="false">
                                {{ __('language.facility_blocked') }}
                            </a>
                        </li>
                    </ul>

                    <div class="tab-content" id="animateLineContent-4">
                        <div class="tab-pane fade show active" id="profile" role="tabpanel" aria-labelledby="profile-tab">
                            <div class="row">
                                <div class="col-md-8">
                                    <div class="row mb-2">
                                        <div class="col-md-3">
                                            <label> {{ __('language.facility_address') }} </label>
                                            <p class="text-dark"> {{ $facility->address ?? 'N/A'  }} </p>
                                        </div>

                                        <div class="col-md-3">
                                            <label> {{ __('language.facility_suburd_name') }} </label>
                                            <p class="text-dark"> {{ $facility->suburb_name ?? 'N/A' }} </p>
                                        </div>

                                        <div class="col-md-3">
                                            <label> {{ __('language.facility_state_name') }} </label>
                                            <p class="text-dark">
                                                @if (!empty($facility->state))
                                                    {{ $facility->state->name ?? 'N/A' }}
                                                @else
                                                N/A
                                                @endif
                                            </p>
                                        </div>

                                        <div class="col-md-3">
                                            <label> {{ __('language.facility_post_code') }} </label>
                                            <p class="text-dark"> {{ $facility->post_code ?? 'N/A' }} </p>
                                        </div>
                                    </div>

                                    <div class="row mb-2">
                                        <div class="col-md-3">
                                            <label> {{ __('language.facility_email') }} </label>
                                            <p class="text-dark"> {{ $facility->user->email }} </p>
                                        </div>

                                        <div class="col-md-3">
                                            <label> {{ __('language.facility_contact_number') }} </label>
                                            <p class="text-dark"> {{ $facility->contact_number }} </p>
                                        </div>

                                        <div class="col-md-3">
                                            <label> {{ __('language.facility_contact_person') }} </label>
                                            <p class="text-dark"> {{ ucwords($facility->contact_person ?? 'N/A') }} </p>
                                        </div>

                                        <div class="col-md-3">
                                            <label> {{ __('language.facility_group') }} </label>
                                            <p class="text-dark"> {{ ucwords($facility->facility_group->name ?? 'N/A') }} </p>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="mt-4 mb-4">
                                <h6 class="mb-2 text-primary"> {{ __('language.facility_plan_details') }} </h6>
                                <hr>

                                <div class="row mb-2">
                                    <div class="col-md-8">
                                        @if(isset($facility->plans) && !empty($facility->plans[0]))
                                            <div class="row mb-2">
                                                <div class="col-md-3">
                                                    <label> {{ __('language.facility_plan') }} </label>
                                                    <p class="text-dark"> {{ $facility->plans[0]->name }} </p>
                                                </div>

                                                <div class="col-md-3">
                                                    <label> {{ __('language.facility_plan_cycle') }} </label>
                                                    @if (!empty($facility->plans[0]->pivot->plan_cycle))
                                                    <p class="text-dark"> {{ ucwords(str_replace('_', ' ', $facility->plans[0]->pivot->plan_cycle)) }} </p>
                                                    @else
                                                    <p class="text-dark">  N/A </p>
                                                    @endif
                                                </div>

                                                <div class="col-md-3">
                                                    <label> {{ __('language.facility_plan_start_date') }} </label>
                                                    <p class="text-dark">
                                                         {{ date("d F, Y", strtotime($facility->plans[0]->pivot->start_date)) }}
                                                    </p>
                                                </div>

                                                @if(!empty($facility->plans[0]) && $facility->plans[0]->id != 4)
                                                <div class="col-md-3">
                                                    <label> Next Payment Date </label>
                                                    <p class="text-dark">
                                                        @if (!is_null($subscription))
                                                            {{ date('d M, Y', $subscription['current_period_end']) }}
                                                        @else
                                                        N/A
                                                        @endif
                                                    </p>
                                                </div>
                                                @else
                                                <div class="col-md-3">
                                                    <label> Expiy Date </label>
                                                    <p class="text-dark">
                                                        {{ date("d F, Y", strtotime($facility->plans[0]->pivot->expiry_date)) }}
                                                    </p>
                                                </div>
                                                @endif
                                            </div>

                                            <div class="row mb-2">
                                                <div class="col-md-3">
                                                    <label> {{ __('language.facility_plan_last_payment_date') }} </label>
                                                    <p class="text-dark">
                                                        @if (!empty($facility->plans[0]->pivot->last_payment_date))
                                                        {{ date("d F, Y", strtotime($facility->plans[0]->pivot->last_payment_date)) }}
                                                        @else
                                                        N/A
                                                        @endif
                                                    </p>
                                                </div>

                                                <div class="col-md-3">
                                                    <label> {{ __('language.facility_plan_amount') }} </label>
                                                    <p class="text-dark">
                                                        @if (!empty($facility->plans[0]->pivot->payment_amount))
                                                        ${{ $facility->plans[0]->pivot->payment_amount }}
                                                        @else
                                                        N/A
                                                        @endif
                                                    </p>
                                                </div>
                                            </div>
                                        @else
                                            <div class="row">
                                                <div class="col-md-12">
                                                    N/A
                                                </div>
                                            </div>
                                        @endif
                                    </div>

                                    <div class="col-md-4 text-right">
                                        @if(!empty($facility->plans[0]))
                                            @if(!empty($facility->plans[0]) && $facility->plans[0]->pivot->status == 'active')
                                            <h6 class="text-primary">Currently {{ ucwords($facility->plans[0]->pivot->status) }}</h6>
                                            @else
                                            <h6 class="text-danger">{{ ucwords($facility->plans[0]->pivot->status) }}</h6>
                                            @endif
                                        @endif
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="tab-pane" id="document" role="tabpanel" aria-labelledby="document-tab">
                            <div class="row">
                                <div class="col-md-8">
                                    <h5> {{ __('language.hcp_documents') }} </h5>
                                </div>
                            </div>

                            <div>
                            {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'id' => 'filter-form', 'url' =>
                            route('adminPanel.facilities.details', ['id' => ev($facility->id), '#document'])]) !!}

                            <div class="row mt-3">
                                <div class="col-md-8">
                                    <div class="float-left">
                                        <label> {{ __('language.table_result') }} </label>
                                        {!! Form::select('document_per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('document_per_page', ($request['document_per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                                    </div>

                                    <div class="float-left pl-2 search-box">
                                        {!! Form::text('document_search', old('document_search', ($request['document_search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                        <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                                    </div>
                                    <div class="clearfix"></div>
                                </div>
                            </div>
                            {!! Form::close() !!}
                            </div>

                            <div class="pb-4">
                                <div class="table-responsive">
                                    <table class="table mb-4 mt-4" id="dataTable-documents-hcp">
                                        <thead>
                                            <th> {{ __('language.hcp_document_table_id') }} </th>
                                            <th> {{ __('language.hcp_document_table_name') }} </th>
                                            <th> {{ __('language.hcp_document_table_expiry') }} </th>
                                            <th> {{ __('language.hcp_professions_details') }} </th>
                                            <th> {{ __('language.table_action') }} </th>
                                        </thead>
                                        <tbody>
                                            @if (count($documents))
                                                @foreach ($documents as $document)
                                                <tr>
                                                    <td>

                                                        <div>{{ $document['document']->document_prefix . $document->document_id }}</div>

                                                    </td>
                                                    <td> {{ ucwords($document['document']->name) }} </td>
                                                    <td>
                                                        @if (!empty($document->expiry_date))
                                                            {{ date("d F Y", strtotime($document->expiry_date)) }}
                                                        @else
                                                            N/A
                                                        @endif
                                                    </td>
                                                    <td>
                                                        @if (!empty($document['document']->profession_id))
                                                            {{ $document['document']['profession']->name }}
                                                        @else
                                                            N/A
                                                        @endif
                                                    </td>
                                                    <td>
                                                        @php
                                                        $documentUrl = get_file_url(config('constants.facility.facility_path') . $facility->facility_prefix . $facility->id . '/documents/',
                                                        $document->document_name);
                                                        @endphp
                                                        <ul class="datatable-action">
                                                            <li>
                                                                <div class="dropdown custom-dropdown-icon">
                                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                                    </a>
                                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                                        <a href="{{$documentUrl}}" class="dropdown-item" target="_blank">
                                                                            {{ __("language.download") }}

                                                                        </a>
                                                                    </div>
                                                                </div>
                                                            </li>
                                                        </ul>
                                                    </td>
                                                </tr>
                                                @endforeach
                                            @else
                                                <tr>
                                                    <td colspan="12" class="text-center"> No record found...</td>
                                                </tr>
                                            @endif
                                        </tbody>
                                    </table>
                                    <div class="pagination">
                                        {{ $documents->appends($request)->render() }}
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="tab-pane" id="shift" role="tabpanel" aria-labelledby="shift-tab">
                            <div class="row">
                                <div class="col-md-8">
                                    <h5> {{ __('language.hcp_shift') }} </h5>
                                </div>
                                <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                                    @if (!empty($request))
                                        @php $filterApply = 'filter-icon-apply'; @endphp
                                    @else
                                        @php $filterApply = 'filter-icon'; @endphp
                                    @endif
                                    <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                                        <i class="fa fa-filter"></i>
                                    </button>
                                </div>
                            </div>

                            <div>
                                {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'id' => 'shift-filter-form', 'url' =>
                                route('adminPanel.facilities.details', ['id' => ev($facility->id), '#shift'])]) !!}
                                <div class="row">
                                    <div class="col-md-12">
                                        <div class="custom-datatable-filter hide pl-0">
                                            <div class="row">
                                                <div class="col-md-12">
                                                    <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                                </div>
                                            </div>
                                            <div class="row">
                                                <div class="col-md-3">
                                                    <div class="form-group">
                                                        {!! Form::select('status', create_select_options(config('constants.shifts.status'), 'caption', 'value',  __('language.status')), old('status', ($request['status'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status' ]) !!}
                                                    </div>
                                                </div>

                                                <div class="col-md-3">
                                                    <div class="form-group">
                                                        {!! Form::text('date_range', old('date_range', ($request['date_range'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_range', 'placeholder' => __('language.shift_date_range')]) !!}
                                                    </div>
                                                </div>

                                                <div class="col-md-3">
                                                    <div class="form-group">
                                                        {!! Form::select('shift_type', create_select_options(config('constants.shifts.shift_types'), 'caption', 'value',  __('language.shift_type')), old('shift_type', ($request['shift_type'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'shift_type' ]) !!}
                                                    </div>
                                                </div>

                                                <div class="col-md-12">
                                                    <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                                </div>
                                            </div>
                                            <div class="row">
                                                <div class="col-md-4 mb2">
                                                    {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-primary apply-filter', 'type' => 'button'] )}}
                                                    {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                                </div>
                                            </div>

                                            <div class="filter-border"></div>
                                        </div>
                                    </div>
                                </div>

                                <div class="row mt-3">
                                    <div class="col-md-8">
                                        <div class="float-left">
                                            <label> {{ __('language.table_result') }} </label>
                                            {!! Form::select('shift_per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('shift_per_page', ($request['shift_per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                                        </div>

                                        <div class="float-left pl-2 search-box">
                                            {!! Form::text('shift_hcp_search', old('shift_hcp_search', ($request['shift_hcp_search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                            <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#shift-filter-form').submit();"></i> </span>
                                        </div>
                                        <div class="clearfix"></div>
                                    </div>

                                    <div class="col-md-4 text-right">
                                        <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.shift.shiftExport', ['request' => $request, 'status' => 'all', 'facilityId' => $facility->id])}}">
                                            Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                                        </a>
                                    </div>
                                </div>
                                {!! Form::close() !!}
                            </div>

                            <div class="pb-4">
                                <div class="table-responsive">
                                    <table class="table mb-4 mt-4" id="dataTable-documents-hcp">
                                        <thead>
                                            <th> {{ __('language.shift_id') }} </th>
                                            <th> {{ __('language.booking_date') }} </th>
                                            <th> {{ __('language.shift_type') }} </th>
                                            <th> {{ __('language.cat_pro') }} </th>
                                            <th> {{ __('language.hcp_name') }} </th>
                                            <th> {{ __('language.word_wing') }}  </th>
                                            <th> {{ __('language.start_time') }} </th>
                                            <th> {{ __('language.end_time') }}  </th>
                                            <th> {{ __('language.total_hours') }}  </th>
                                            <th> {{ __('language.shift_suburb') }} </th>
                                            <th> {{ __('language.shift_state') }} </th>
                                            <th> {{ __('language.table_status') }} </th>
                                            <th> {{ __('language.table_action') }} </th>
                                        </thead>
                                        <tbody>
                                            @if (count($shifts))
                                                @foreach ($shifts as $shift)
                                                <tr>
                                                    <td>
                                                        <a href="{{ route('adminPanel.shift.details', ['id' => ev($shift->id)]) }}" class="text-primary">
                                                            <div>{{ $shift->shift_prefix . $shift->id }}</div>
                                                        </a>
                                                    </td>
                                                    <td>
                                                        {{ date("d M Y", strtotime($shift->created_at)) }}
                                                    </td>
                                                    <td> {{ ucwords($shift->shift_type) }} </td>
                                                    <td>
                                                        <div>{{ ucwords($shift->profession->name)}}</div>
                                                        <div class="font-size-12"> {{ ucwords($shift->category->name)}} </div>
                                                    </td>
                                                    <td>
                                                        @if (!empty($shift['hcp']))
                                                        <a href="{{route('adminPanel.hcps.details', ['id' => ev($shift['hcp']->id)])}}" class="text-primary">
                                                            <div>{{ ucwords($shift['hcp']->first_name.' '.$shift['hcp']->last_name) }}</div>
                                                        </a>
                                                        <div class="font-size-12">
                                                            @if (!empty($shift['hcp']))
                                                                {{ $shift['hcp']->contact_number }}
                                                            @endif
                                                        </div>
                                                        @else
                                                            N/A
                                                        @endif
                                                    </td>
                                                    <td> {{ $shift->word_wing }}</td>
                                                    <td>
                                                        <div>{{ date("d F", strtotime($shift->start_time)) }}</div>
                                                        {{ date("h:i A", strtotime($shift->start_time)) }}
                                                    </td>
                                                    <td>
                                                        <div>{{ date("d F", strtotime($shift->end_time)) }}</div>
                                                        {{ date("h:i A", strtotime($shift->end_time)) }}
                                                    </td>
                                                    <td> {{ $shift->hours }} Hrs</td>
                                                    <td>
                                                        @if (!empty($shift['facility']->suburb_name))
                                                            {{ $shift['facility']->suburb_name }}
                                                        @endif
                                                    </td>
                                                    <td>
                                                        @if (!empty($shift['facility']->state))
                                                            {{ $shift['facility']->state->short_form }}
                                                        @endif
                                                    </td>
                                                    <td>
                                                        @if ($shift['shift_status'] == '0')
                                                            <div class="text-warning font-weight-bold"> {{ __("language.shift_status_pending") }} </div>
                                                        @elseif ($shift['shift_status'] == '1')
                                                            <div class="text-info font-weight-bold"> {{ __("language.shift_status_scheduled") }} </div>
                                                        @elseif ($shift['shift_status'] == '2')
                                                            <div class="text-success font-weight-bold"> {{ __("language.shift_status_running") }} </div>
                                                        @elseif ($shift['shift_status'] == '3')
                                                            <div class="text-danger font-weight-bold"> {{ __("language.shift_status_cancelled") }} </div>
                                                        @elseif ($shift['shift_status'] == '4')
                                                            <div class="text-success font-weight-bold"> {{ __("language.shift_status_completed") }} </div>
                                                        @elseif ($shift['shift_status'] == '5')
                                                            <div class="text-info font-weight-bold"> {{ __("language.shift_status_transfered") }} </div>
                                                        @elseif ($shift['shift_status'] == '6')
                                                            <div class="text-success font-weight-bold"> {{ __("language.shift_status_past") }} </div>
                                                        @endif
                                                    </td>

                                                    <td>
                                                        <ul class="datatable-action">
                                                            <li>
                                                                <div class="dropdown custom-dropdown-icon">
                                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                                    </a>
                                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                                        <a href="{{ route('adminPanel.shift.details', ['id' => ev($shift->id)]) }}" class="dropdown-item">
                                                                            {{ __("language.details") }}
                                                                        </a>
                                                                    </div>
                                                                </div>
                                                            </li>
                                                        </ul>
                                                    </td>
                                                </tr>
                                                @endforeach
                                            @else
                                                <tr>
                                                    <td colspan="15" class="text-center"> No record found...</td>
                                                </tr>
                                            @endif
                                        </tbody>
                                    </table>
                                    <div class="pagination">
                                        {{ $shifts->appends($request)->render() }}
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="tab-pane" id="history" role="tabpanel" aria-labelledby="history-tab">
                            <div class="row">
                                <div class="col-md-8">
                                    <h5> {{ __('language.facility_history_tab_heading') }} </h5>
                                </div>
                            </div>

                            <div class="pb-4">
                                <div class="table-responsive">
                                    <table class="table mb-4 mt-2" id="dataTable-history-hcp">
                                        <tbody>
                                            @if (count($facilityActivities))
                                                @foreach ($facilityActivities as $activity)
                                                    <tr>
                                                        <td class="pl-0">
                                                            @if (!empty($activity->user))
                                                                <b class="text-primary"> {{ ucwords($activity->user['name']) }} </b>
                                                                <div class="">
                                                                    @if ($activity->user['role_name'] == 'sub-admin')
                                                                        {{ ucwords('Sub Admin') }}
                                                                    @elseif ($activity->user['role_name'] == 'super-admin')
                                                                        {{ ucwords('Super Admin') }}
                                                                    @elseif ($activity->user['role_name'] == 'facility')
                                                                        {{ ucwords('Facility') }}
                                                                    @endif
                                                                </div>
                                                            @else
                                                                <b class="text-primary"> {{ ucwords('System Generated') }} </b>
                                                            @endif
                                                        </td>
                                                        <td> {{ ucwords($activity->message) }} </td>
                                                        <td>
                                                            @if (!empty($activity->created_at))
                                                                {{ date("d M, Y h:i A", strtotime($activity->created_at)) }}
                                                            @else
                                                                N/A
                                                            @endif
                                                        </td>
                                                    </tr>
                                                @endforeach
                                            @else
                                            <tr>
                                                <td colspan="10" class="text-center"> No record found...</td>
                                            </tr>
                                            @endif
                                        </tbody>
                                    </table>

                                    <div class="pagination">
                                        {{ $facilityActivities->appends($request)->render() }}
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="tab-pane hide" id="favourite" role="tabpanel" aria-labelledby="favourite-tab">
                            <div class="row mb-4">
                                <div class="col-md-6">
                                    <h5> {{ __('language.facility_favourite_hcp') }} </h5>
                                </div>
                                <div class="col-md-6 text-right">
                                    <a href="{{ route('adminPanel.hcps.viewAllHcpForFavoritesAndBlocklist', ['facilityId' => ev($facility->id)]) }}">
                                        <button class="btn btn-icon btn-primary btn-sm  mb-2">
                                            <i class="fa fa-plus"></i> &nbsp; {{ __('language.add_new') }}
                                        </button>
                                    </a>
                                </div>
                            </div>

                            <div>
                                <div class="table-responsive">
                                    <table class="table mb-4" id="dataTable-favourite-hcp">
                                        <thead>
                                            <tr>
                                                <th> {{ __('language.table_hcp_id') }} </th>
                                                <th> {{ __('language.table_hcp_name') }} </th>
                                                <th> {{ __('language.table_hcp_category') }} </th>
                                                <th> {{ __('language.table_hcp_profession') }} </th>
                                                <th> {{ __('language.table_hcp_contact_number') }} </th>
                                                <th> {{ __('language.table_hcp_email') }} </th>
                                                <th> {{ __('language.table_hcp_suburb') }} </th>
                                                <th> {{ __('language.table_hcp_state') }} </th>
                                                <th> {{ __('language.table_action') }} </th>
                                            </tr>
                                            @if (count($hcpFavourites))
                                                @foreach ($hcpFavourites as $favourite)
                                                    <tr>
                                                        <td>
                                                            <a href="{{route('adminPanel.hcps.details', ['id' => ev($favourite['hcp']->id)])}}">
                                                                {{ $favourite['hcp']->hcp_prefix . $favourite['hcp']->id }}
                                                            </a>
                                                        </td>

                                                        <td>
                                                            {{ucwords($favourite['hcp']->first_name . ' ' . $favourite['hcp']->last_name)}}
                                                        </td>

                                                        <td>
                                                            @if (count($favourite['hcp']->hcp_professions))
                                                                {{ $favourite['hcp']->hcp_professions[0]['category']['name'] }}
                                                            @else
                                                                N/A
                                                            @endif
                                                        </td>

                                                        <td>
                                                            @if (count($favourite['hcp']->hcp_professions))
                                                                {{ $favourite['hcp']->hcp_professions[0]['profession']['name'] }}
                                                            @else
                                                                N/A
                                                            @endif
                                                        </td>

                                                        <td> {{ $favourite['hcp']->contact_number }} </td>

                                                        <td> {{ $favourite['hcp']->user->email }} </td>

                                                        <td> {{ $favourite['hcp']->suburb_name ?? 'N/A' }} </td>
                                                        <td>
                                                            @if (!empty($favourite['hcp']->state))
                                                                {{ $favourite['hcp']->state->short_form }}
                                                            @else
                                                                N/A
                                                            @endif
                                                        </td>
                                                        <td>
                                                            <ul class="datatable-action">
                                                                <li>
                                                                    <div class="dropdown custom-dropdown-icon">
                                                                        <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                                            <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                                        </a>
                                                                        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                                            <a href="{{ route('adminPanel.facilities.removeFavouriteHcp', ['id' => $favourite['id'], 'facilityId' => $favourite['facility_id'] ]) }}" class="dropdown-item"> {{ __("language.remove") }} </a>
                                                                        </div>
                                                                    </div>
                                                                </li>
                                                            </ul>
                                                        </td>
                                                    </tr>
                                                @endforeach
                                            @else
                                                <tr>
                                                    <td colspan="12" class="text-center"> No record found...</td>
                                                </tr>
                                            @endif
                                        </thead>
                                    </table>
                                </div>
                            </div>
                        </div>

                        <div class="tab-pane hide" id="blocklist" role="tabpanel" aria-labelledby="blocklist-tab">
                            <div class="row mb-4">
                                <div class="col-md-6">
                                    <h5> {{ __('language.facility_blocked_hcp') }} </h5>
                                </div>
                                <div class="col-md-6 text-right">
                                    <a href="{{ route('adminPanel.hcps.viewAllHcpForFavoritesAndBlocklist', ['facilityId' => ev($facility->id)]) }}">
                                        <button class="btn btn-icon btn-primary btn-sm  mb-2">
                                            <i class="fa fa-plus"></i> &nbsp; {{ __('language.add_new') }}
                                        </button>
                                    </a>
                                </div>
                            </div>

                            <div>
                                <div class="table-responsive">
                                    <table class="table mb-4" id="dataTable-favourite-hcp">
                                        <thead>
                                            <tr>
                                                <th> {{ __('language.table_hcp_id') }} </th>
                                                <th> {{ __('language.table_hcp_name') }} </th>
                                                <th> {{ __('language.table_hcp_category') }} </th>
                                                <th> {{ __('language.table_hcp_profession') }} </th>
                                                <th> {{ __('language.table_hcp_contact_number') }} </th>
                                                <th> {{ __('language.table_hcp_email') }} </th>
                                                <th> {{ __('language.table_hcp_suburb') }} </th>
                                                <th> {{ __('language.table_hcp_state') }} </th>
                                                <th> {{ __('language.table_action') }} </th>
                                            </tr>
                                            @if (count($hcpBlocklist))
                                                @foreach ($hcpBlocklist as $blocklist)
                                                    <tr>
                                                        <td>
                                                            <a href="{{route('adminPanel.hcps.details', ['id' => ev($blocklist['hcp']->id)])}}">
                                                                {{ $blocklist['hcp']->hcp_prefix . $blocklist['hcp']->id }}
                                                            </a>
                                                        </td>

                                                        <td>
                                                            {{ucwords($blocklist['hcp']->first_name . ' ' . $blocklist['hcp']->last_name)}}
                                                        </td>

                                                        <td>
                                                            @if (count($blocklist['hcp']->hcp_professions))
                                                                {{ $blocklist['hcp']->hcp_professions[0]['category']['name'] }}
                                                            @else
                                                                N/A
                                                            @endif
                                                        </td>

                                                        <td>
                                                            @if (count($blocklist['hcp']->hcp_professions))
                                                                {{ $blocklist['hcp']->hcp_professions[0]['profession']['name'] }}
                                                            @else
                                                                N/A
                                                            @endif
                                                        </td>

                                                        <td> {{ $blocklist['hcp']->contact_number ?? 'N/A' }} </td>

                                                        <td> {{ $blocklist['hcp']->user->email }} </td>

                                                        <td> {{ $blocklist['hcp']->suburb_name ?? 'N/A' }} </td>
                                                        <td>
                                                            @if (!empty($blocklist['hcp']->state))
                                                                {{ $blocklist['hcp']->state->short_form }}
                                                            @else
                                                                N/A
                                                            @endif
                                                        </td>
                                                        <td>
                                                            <ul class="datatable-action">
                                                                <li>
                                                                    <div class="dropdown custom-dropdown-icon">
                                                                        <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                                            <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                                        </a>
                                                                        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                                            <a href="{{ route('adminPanel.facilities.removeFavouriteHcp', ['id' => $blocklist['id'], 'facilityId' => $blocklist['facility_id'] ]) }}" class="dropdown-item"> {{ __("language.remove") }} </a>
                                                                        </div>
                                                                    </div>
                                                                </li>
                                                            </ul>
                                                        </td>
                                                    </tr>
                                                @endforeach
                                            @else
                                                <tr>
                                                    <td colspan="12" class="text-center"> No record found...</td>
                                                </tr>
                                            @endif
                                        </thead>
                                    </table>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

{{-- Extend Trial Plan Modal --}}
<div class="modal fade" id="exampleModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
  <div class="modal-dialog" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="exampleModalLabel">Edit Trail Plan</h5>
        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
      {!! Form::open(['class'=> 'modify_trial_plan_form', 'method' => 'post', 'url' => route('adminPanel.facilities.modify_trial_plan')])!!}
      <div class="modal-body">
            <div class="row">
                {!! Form::hidden('plan_id', 4) !!}
                @if(isset($facility->plans) && !empty($facility->plans[0]) )
                    {!! Form::hidden('facility_plan_id', $facility->plans[0]->pivot->id) !!}
                @endif
                {!! Form::hidden('facility_id', $facility->id) !!}
                <div class="col-md-12">
                    <div class="form-group">
                        <label> Expire Date </label>
                        {!! Form::text('modify_expire_date', old('modify_expire_date', (isset($facility->plans) && !empty($facility->plans[0]) &&  $facility->plans[0]->pivot->expiry_date ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_from']) !!}
                    </div>
                </div>
            </div>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
        <button type="submit" class="btn btn-primary">Save changes</button>
      </div>
      {!! Form::close() !!}
    </div>
  </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/facilities/facilities.js') }}"></script>

<script>
    $(function(){
        var hash = window.location.hash;
        hash && $('ul.nav a[href="' + hash + '"]').tab('show');

        $('.nav-tabs a').click(function (e) {
            $(this).tab('show');
            var scrollmem = $('body').scrollTop();
            window.location.hash = this.hash;
            $('html,body').scrollTop(scrollmem);
        });
    });


    $(document).ready(function(){
        var $form = $(".modify_trial_plan_form");
        var $card_expiry_picker = $form.find(".date-picker");
        if ($card_expiry_picker.length) {
            $card_expiry_picker.flatpickr({
                format: "Y-m-d",
                minDate: "today",
            });
        }
    });
</script>
@endpush
