@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.pending_approval_facilities_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                        <h5>{{ __('language.pending_approval_facilities_page_title') }}</h5>
                    </div>

                    <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                        @if ($authUser->can('Add Facilities'))
                        <a href="{{ route('adminPanel.facilities.create') }}" class="btn btn-primary btn-sm mr-1">
                            {{ __('language.add_button') }}
                        </a>
                        @endif

                        @if (!empty($request))
                            @php $filterApply = 'filter-icon-apply'; @endphp
                        @else
                            @php $filterApply = 'filter-icon'; @endphp
                        @endif
                        <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                            <i class="fa fa-filter"></i>
                        </button>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-12">
                        <div class="custom-datatable-filter hide">
                            {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                            route('adminPanel.facilities.pendingApproval')]) !!}
                            <div class="row">
                                <div class="col-md-12">
                                    <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                </div>
                            </div>
                            <div class="row">
                                @if (!empty($states))
                                <div class="col-md-3">
                                        <div class="form-group">
                                            {!! Form::select('state_id', create_select_options($states, 'name', 'id',  __('language.facility_filter_state')), old('state_id', ($request['state_id'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'state_id']) !!}
                                        </div>
                                </div>
                                @endif

                                <div class="col-md-3">
                                    <div class="form-group">
                                        {!! Form::select('plan_type', create_select_options($plans, 'name', 'id',  __('language.facility_plan_type')), old('plan_type', ($request['plan_type'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'plan_type',   ]) !!}
                                    </div>
                                </div>

                                <div class="col-md-3 hide">
                                    <div class="form-group">
                                        {!! Form::select('plan_cycle', create_select_options(config('constants.plan_configurations.plan_cycle'), 'caption', 'value',  __('language.facility_plan_cycle')), old('plan_cycle', ($request['plan_cycle'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'plan_cycle' ]) !!}
                                    </div>
                                </div>

                                <div class="col-md-3">
                                    <div class="form-group">
                                        {!! Form::text('plan_end_date', old('plan_end_date', ($request['plan_end_date'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'plan_end_date', 'placeholder' => __('language.facility_filter_plan_end_date')]) !!}
                                    </div>
                                </div>

                                <div class="col-md-12">
                                    <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-md-4 mb2">
                                    {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-primary apply-filter', 'type' => 'button'] )}}
                                    {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                </div>
                            </div>
                            {!! Form::close() !!}
                        </div>
                    </div>
                </div>
            </div>

            <div class="container-fluid page-heading">
                <div class="table-responsive pb-5">
                    <table id="active-hcp" class="table mb-4 mt-3">
                        <thead>
                            <tr>
                                <th> {{ __('language.table_facility_id') }} </th>
                                <th> {{ __('language.table_facility_name') }} </th>
                                <th> {{ __('language.table_facility_address') }} </th>
                                <th> {{ __('language.table_facility_suburb') }} </th>
                                <th> {{ __('language.table_facility_state') }} </th>
                                <th> {{ __('language.table_facility_email') }} </th>
                                <th> {{ __('language.table_facility_plan_type') }} </th>
                                <th> {{ __('language.table_facility_plan_cycle') }} </th>
                                <th> {{ __('language.table_facility_plan_end_date') }} </th>
                                <th> {{ __('language.table_action') }} </th>
                            </tr>
                        </thead>
                        <tbody>

                            @if (count($facilities))
                                @foreach ($facilities as $facility)
                                <tr>
                                    <td>
                                        <a href="{{ route('adminPanel.facilities.details', ['id' => ev($facility->id)]) }}">
                                            {{ $facility->facility_prefix . $facility->id }}
                                        </a>
                                    </td>
                                    <td>
                                        {{ ucwords($facility->name)}}
                                    </td>
                                    <td> {{ $facility->address ?? 'N/A' }} </td>
                                    <td> {{ $facility->suburb_name ?? 'N/A' }} </td>
                                    <td>
                                        @if (!empty($facility->state))
                                            {{ $facility->state->short_form }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td> {{ $facility->user->email }} </td>
                                    <td>
                                        @if (!empty($facility->plans[0]))
                                            {{ $facility->plans[0]->name }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        @if (!empty($facility->plans[0]))
                                            {{ ucwords(str_replace("_", " ", $facility->plans[0]->pivot->plan_cycle)) }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        @if (!empty($facility->plans[0]))
                                            {{ $facility->plans[0]->pivot->expiry_date }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        <ul class="datatable-action">
                                            <li>
                                                <div class="dropdown custom-dropdown-icon">
                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                    </a>
                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">

                                                        @if ($authUser->can('Edit Facilities'))
                                                        <a href="{{ route('adminPanel.facilities.edit', ['id' => ev($facility->id)]) }}" class="dropdown-item"> {{ __("language.edit") }} </a>
                                                        @endif

                                                        <a href="{{ route('adminPanel.facilities.details', ['id' => ev($facility->id)]) }}" class="dropdown-item"> {{ __("language.details") }} </a>

                                                        <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.facilities.changeStatus', ['id' => ev($facility->id), 'status' => 'active']) }}"> {{ __("language.facility_active") }} </a>
                                                    </div>
                                                </div>
                                            </li>
                                        </ul>
                                    </td>
                                </tr>
                                @endforeach
                            @else
                                <tr>
                                    <td colspan="12" class="text-center"> No record found...</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>

                    <div class="pagination">
                        {{ $facilities->render() }}
                    </div>
                </div>
            </div>

        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/facilities/view.js') }}"></script>
@endpush
