@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.facility_select_plan_page').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/forms/switches.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/pricing-table/css/component.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">

        <!-- Validation error -->
        @component('admin-panel.validation.errors') @endcomponent
        <!-- / Validation error -->

        <div class="alert alert-danger mb-4 cusstom-error hide" role="alert">
            <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <i data-feather="x" class="feather-16"></i> </button>
            <strong>Error!</strong>
            <div id="error-message"></div>
        </div>



        <div class="widget-content widget-content-area br-6">
            {!! Form::open(['class' => 'buy-form', 'method' => 'post', 'url' => route('adminPanel.facilities.buyTrialPlan')]) !!}
            <div class="container-fluid">
                <div class="row">
                    <div class="col-md-12">
                        <div class="billing-cycle-radios mt-5">
                            <div class="radio billed-yearly-radio">
                                <div class="d-flex justify-content-center">
                                    <span class="txt-monthly">Monthly</span>
                                    <label class="switch s-icons s-outline  s-outline-success">
                                        <input type="checkbox" id="radio-6">
                                        <span class="slider round"></span>
                                    </label>
                                    <span class="txt-yearly">Yearly <span class="badge badge-pill badge-primary">20% Off</span></span>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div id="pricingWrapper" class="row">
                    @if (!empty($plans))
                        @foreach ($plans as $plan)
                        <div class="col-md-4 col-lg-3">
                            <div class="card stacked mt-5">
                                <div class="card-header pt-0">
                                    @if ($plan->id == 4)
                                        <span class="card-price"> Free </span>
                                    @else
                                        <span class="card-price">
                                            <span class="monthly-show-card-price">${{ number_format($plan->monthly_price, 2) }}</span>
                                            <span class="yearly-show-card-price hide">${{ number_format($plan->yearly_price, 2) }}</span>
                                            <small>/ monthly</small>
                                        </span>

                                        {!! Form::hidden('play_type', old('play_type', ($request['play_type'] ?? 'monthly')), ['class' => 'form-control play-type', 'id' => 'play-type-'.$plan->id]) !!}
                                    @endif
                                    <h3 class="card-title mt-3 mb-1">{{ ucwords($plan->name) }}</h3>

                                    @if ($plan->id == 4)
                                    {{--<div> Shift Posting Limit : {{ $freePlan['shift_posting_limit_in_trial_acc'] }} </div>
                                    <div> Day Of Shift Posting Limit : {{ $freePlan['days_of_shift_posting_limit_in_trial_acc'] }}
                                    </div>--}}
                                        {!! Form::hidden('plan_id', $plan->id, ['class' => 'form-control']) !!}
                                    @endif
                                </div>
                                <div class="card-body">
                                    <ul class="list-group list-group-minimal mb-3">
                                        @if (!empty($plan->professions))
                                            @foreach($plan->professions as $profession)
                                            <li class="list-group-item d-flex align-items-center">
                                                <i class="fa fa-arrow-right"></i> &nbsp; {{ $profession->name }}
                                            </li>
                                            @endforeach
                                        @endif
                                    </ul>

                                    @if ($plan->id == 4)
                                    @php
                                        $facilityTrailPlan = get_facility_trial_plan($authUser->facility->id);
                                    @endphp
                                        @if (!empty($facilityTrailPlan))
                                            <button class="btn btn-block btn-warning" type="button">Only Purchase One Time</button>
                                        @else
                                            <button class="btn btn-block btn-primary buy-now" type="button" data-plan="{{$plan->id}}">Buy Now</button>
                                        @endif
                                    @else
                                    <button class="btn btn-block btn-primary buy-now" type="button" data-plan="{{$plan->id}}">Buy Now</button>
                                    @endif
                                </div>
                            </div>
                        </div>
                        @endforeach
                    @endif
                </div>
            </div>
            {!! Form::close() !!}

            <div class="text-center">
                <button class="btn btn-outline-info mb-2" type="button"  data-toggle="modal" data-target="#pageModal">View Term & Condition</button>
            </div>
        </div>

        <!-- Modal -->
        <div class="modal fade" id="pageModal" tabindex="-1" role="dialog" aria-labelledby="pageModalLabel" aria-hidden="true">
            <div class="modal-dialog modal-lg" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title"> Term & Condition </h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <i class="fa fa-close"></i>
                        </button>
                    </div>

                    <div class="modal-body">
                        <div class="row">
                            <div class="col-md-12">
                                <p>
                                    {!! $supportingPage[0]['term_condition_facility_plan'] !!}
                                </p>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button class="btn btn-dark" data-dismiss="modal">Discard</button>
                    </div>
                </div>
            </div>
        </div>
        <!-- / Modal -->

    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="https://js.stripe.com/v3/"></script>
<script>
</script>

<script>
    var getInputStatus = document.getElementById('radio-6');
    var getPricingContainer = document.getElementsByClassName('pricing-plans-container')[0];
    var getYearlySwitch = document.getElementsByClassName('billed-yearly-radio')[0];
    getInputStatus.addEventListener('change', function() {
        var isChecked = getInputStatus.checked;
        if (isChecked) {
            $('.yearly-show-card-price').removeClass('hide');
            $('.monthly-show-card-price').addClass('hide');
            $(".yearly-price").prop('disabled', false);
            $(".monthly-price").prop('disabled', true);
            $(".play-type").val('yearly');
        } else {
            $('.monthly-show-card-price').removeClass('hide');
            $('.yearly-show-card-price').addClass('hide');
            $(".yearly-price").prop('disabled', true);
            $(".monthly-price").prop('disabled', false);
            $(".play-type").val('monthly');
        }
    })
</script>

<script>
var createCheckoutSession = function(planId, planType) {
  return fetch("{{ route('adminPanel.facilities.buyPlan') }}", {
    method: "POST",
    headers: {
        "Content-Type": "application/json",
        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
    },
    body: JSON.stringify({
        planId: planId,
        planType: planType,
    })
  }).then(function(result) {
        return result.json();
  });
};

// Handle any errors returned from Checkout
var handleResult = function(result) {
    if (result.error) {
        $('.cusstom-error').removeClass('hide');
        var displayError = document.getElementById("error-message");
        displayError.textContent = result.error.message;
    }
};

$(".buy-now").click(function(){
    var $this = $(this);
    var publishableKey = "{{ env('STRIPE_KEY') }}";
    var planId = $this.data("plan");
    var planType = $('#play-type-'+planId).val();
    var stripe = Stripe(publishableKey);

    $(".buy-now").prop('disabled', true);
    $this.html('<i class="fa fa-spinner fa-spin"></i> Please wait...');

    if (publishableKey !='' && planId !='' && planType !='' && planId !='4') {
        $('.cusstom-error').addClass('hide');

        createCheckoutSession(planId, planType).then(function(data) {
            // Call Stripe.js method to redirect to the new Checkout page
            if (data.hasOwnProperty('sessionId')) {
                stripe
                .redirectToCheckout({
                    sessionId: data.sessionId
                })
                .then(handleResult)
                .catch((error) => {
                    console.error('Error:', error);
                });
            } else {
                $('.cusstom-error').removeClass('hide');
                $('#error-message').html(data.error.message);
                $(".buy-now").prop('disabled', false);
                $this.html('Buy Now');
            }
        });

    } else if (planId !='' && planType !='' && planId =='4') {

        $('.buy-form').submit();

    } else {
        $('.cusstom-error').removeClass('hide');
        $('#error-message').html('Oops, Something Went Wrong');
    }
});

</script>
@endpush
