@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.manage_document').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/datatables.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <h5>{{ __('language.manage_document') }}</h5>
                        </div>
                    </div>

                    <div>
                        {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                        route('adminPanel.facility-manage-document.index'), 'id' => "filter-form"]) !!}
                        <div class="row pl-3 mt-3">
                            <div class="col-md-8">
                                <div class="float-left">
                                    <label> {{ __('language.table_result') }} </label>
                                    {!! Form::select('per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('per_page', ($request['per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                                </div>

                                <div class="float-left pl-2 search-box">
                                    {!! Form::text('search', old('search', ($request['search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                    <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                                </div>
                                <div class="clearfix"></div>
                            </div>

                            <div class="col-md-4 text-right">
                                <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.facility-manage-document.facilityDocumentsExport', ['id' => $facility->id, 'request' => $request])}}">
                                    Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                                </a>
                            </div>
                        </div>
                        {!! Form::close() !!}
                    </div>
                </div>

                <div class="container-fluid page-heading">
                    <div class="table-responsive pb-5">
                        <table class="table mb-4 mt-3">
                            <thead>
                                <tr>
                                    <th>{{__('language.document_id')}}</th>
                                    <th>{{__('language.doc_name')}}</th>
                                    <th>{{__('language.facility_profession')}}</th>
                                    <th>{{__('language.expiry_date')}}</th>
                                    <th>{{__('language.status')}}</th>
                                    <th>{{__('language.action')}}</th>
                                </tr>
                            </thead>
                            <tbody>
                            @forelse($documents as $document)
                                <tr>
                                    <td> {{ $document->document_prefix.$document->id }} </td>
                                    <td> {{ $document->name }}</td>
                                    <td> {{ $document->profession ? $document->profession->name : 'N/A' }}</td>
                                    <td>
                                        @if (!empty($document->facility_document->expiry_date))
                                            {{ date("d F Y", strtotime($document->facility_document->expiry_date)) }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        @if (!empty($document->facility_document))
                                        @php
                                            $status = '';
                                            if ($document->facility_document->document_approval == 'approved') {
                                                $status .= '<div class="text-success font-weight-bold"> ' . __("language.document_approved") . ' </ladivbel>';
                                            } else if ($document->facility_document->document_approval == 'pending') {
                                                $status .= '<div class="text-warning font-weight-bold"> ' . __("language.document_pending") . ' </div>';
                                            } else if ($document->facility_document->document_approval == 'pending-reapproval') {
                                                $status .= '<div class="text-warning font-weight-bold"> ' . __("language.document_pending_approved") . ' </div>';
                                            } else if ($document->facility_document->document_approval == 'reapproved') {
                                                $status .= '<div class="text-success font-weight-bold"> ' . __("language.document_reapproved") . ' </div>';
                                            }
                                        @endphp
                                        <div class="text-success font-weight-bold"> {{ __("language.facility_document_uploaded") }} </div>
                                        @else
                                        <div class="text-warning font-weight-bold"> {{ __("language.facility_document_not_uploaded") }} </div>
                                        @endif
                                    </td>
                                    <td>
                                        <ul class="datatable-action">
                                            <li>
                                                <div class="dropdown custom-dropdown-icon">
                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                    </a>
                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                        @if (!empty($document->facility_document))
                                                            @php
                                                                $documentUrl = get_file_url(config('constants.facility.facility_path') . $facility->facility_prefix . $facility->id . '/documents/', $document->facility_document->document_name);
                                                            @endphp
                                                            <a href="{{$documentUrl}}" class="dropdown-item" target="_blank" download> {{ __("language.download") }} </a>

                                                            <a href="#" class="dropdown-item upload-document" data-url="{{ route('adminPanel.facility-manage-document.uploadDocumentModal', ['documentId' => $document->id])}}"> {{ __("language.facility_upload_document") }} </a>
                                                        @else
                                                            <a href="#" class="dropdown-item upload-document" data-url="{{ route('adminPanel.facility-manage-document.uploadDocumentModal', ['documentId' => $document->id])}}"> {{ __("language.facility_upload_document") }} </a>
                                                        @endif
                                                    </div>
                                                </div>
                                            </li>
                                        </ul>
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="15" class="text-center"> {{ __('language.no_record_found') }} </td>
                                </tr>
                            @endforelse
                            </tbody>
                        </table>

                        <div class="pagination">
                            {{ $documents->appends($request)->render() }}
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/manage-document/manage-document.js') }}"></script>
@endpush
