@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.edit_facility_name_list_page_title').' ')


@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">

        <!-- Validation error -->
        @component('admin-panel.validation.errors') @endcomponent
        <!-- / Validation error -->

        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                        <h5> {{ __('language.edit_facility_name_list_page_title') }} </h5>
                    </div>
                </div>

                <div class="form p-3">
                    {!! Form::open(['class' => 'add-facility-name-form', 'method' => 'post', 'url' => route('adminPanel.facility-names.update', ['id' => ev($facilityName->id)]), 'files' => true ]) !!}

                        <div class="form-row mb-2">
                            <div class="form-group col-md-3">
                                <label for="facility_group"> {{ __('language.facility_name_list_group') }} </label>
                                {!! Form::select('facility_group', create_select_options($facilityGroups, 'name', 'id', null), old('facility_group', ($facilityName->facility_group_id ?? null)),  ['class' => 'form-control select-picker', 'id' => 'facility_group', 'title' => __('language.facility_name_list_group')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label for="name"> {{ __('language.facility_name_list_name') }} </label>
                                {!! Form::text('name', old('name', ($facilityName->name ?? null)), ['class' => 'form-control', 'id' => 'name', 'placeholder' => __('language.facility_name_list_name')]) !!}
                            </div>
                        </div>

                        <div class="form-row mb-2">
                            <div class="form-group col-md-3 state-div">
                                <label for="state_id"> {{ __('language.facility_name_list_state') }} </label>
                                {!! Form::select('state_id', create_select_options($states, 'name', 'id', null), old('state_id', ($facilityName->state_id ?? null)),  ['class' => 'form-control select-picker', 'id' => 'state_id', 'title' => __('language.facility_name_list_state')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label for="address"> {{ __('language.facility_name_list_address') }} </label>
                                {!! Form::text('address', old('address', ($facilityName->address ?? null)), ['class' => 'form-control', 'id' => 'address', 'placeholder' => __('language.facility_name_list_address')]) !!}
                            </div>

                            <div class="form-group col-md-3 city-div">
                                <label for="city_id"> {{ __('language.facility_name_list_city') }} </label>
                                {!! Form::text('city_name', old('city_name', ($facilityName->city_name ?? null)), ['class' => 'form-control input-readonly-new',  'id' => 'city_name',   'placeholder' => __('language.facility_name_list_city'), 'readonly' ]) !!}
                            </div>
                        </div>

                        <div class="form-row mb-4">
                            <div class="form-group col-md-3 suburb-div">
                                <label for="suburb_id"> {{ __('language.facility_name_list_suburb') }} </label>
                                {!! Form::text('suburb_name', old('suburb_name', ($facilityName->suburb_name ?? null)), ['class' => 'form-control input-readonly-new',  'id' => 'suburb_name',   'placeholder' => __('language.facility_name_list_suburb'), 'readonly' ]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label for="post_code"> {{ __('language.facility_name_list_post_code') }} </label>
                                {!! Form::text('post_code', old('post_code', ($facilityName->post_code ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'postcode', 'placeholder' => __('language.facility_name_list_post_code'), 'readonly' ]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label for="status"> {{ __('language.status') }} </label>
                                {!! Form::select('status', create_select_options(config('constants.facility_name_status'), 'caption', 'value',  null), old('status', ($facilityName->status ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status', 'title' => __('language.status')]) !!}
                            </div>

                            {!! Form::hidden('latitude', old('latitude', ($facilityName->latitude ?? null)), ['class' => 'form-control', 'id' => 'latitude', 'autocomplete' => 'off']) !!}
                            {!! Form::hidden('longitude', old('longitude', ($facilityName->longitude ?? null)), ['class' => 'form-control', 'id' => 'longitude', 'autocomplete' => 'off']) !!}
                        </div>

                        {{ Form::button( '<i class="fa fa-save"></i> &nbsp;'. __('language.update'), ['class' => 'btn btn-primary btn-submit', 'type' => 'submit'] )}}

                    {!! Form::close() !!}
                </div>
            </div>

        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/facility-names/facility-names.js') }}"></script>
<script src="https://maps.googleapis.com/maps/api/js?libraries=places&output=json&key={{env('GOOGLE_API_KEY')}}"  defer></script>
<script>
    $(document).ready(function() {
        var options = {
            componentRestrictions: {country: ['AU', 'IN']}
        };
        var autocomplete = new google.maps.places.Autocomplete(address, options);
        autocomplete.addListener('place_changed', function() {
            var place = autocomplete.getPlace();
            var latitude = place.geometry.location.lat();
            var longitude = place.geometry.location.lng();
            $('#latitude').val(latitude);
            $('#longitude').val(longitude);

            for (var i = 0; i < place.address_components.length; i++) {
                for (var j = 0; j < place.address_components[i].types.length; j++) {

                    if (place.address_components[i].types[j] == "administrative_area_level_2") {
                        $('#city_name').val(place.address_components[i].long_name);
                    }

                    if (place.address_components[i].types[j] == "locality") {
                        $('#suburb_name').val(place.address_components[i].long_name);
                    }

                    if (place.address_components[i].types[j] == "postal_code") {
                        $('#postcode').prop( "disabled", false );
                        $('#postcode').val(place.address_components[i].long_name);
                    }
                }
            }
        });
    });
</script>
@endpush
