@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.facility_name_list_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                        <h5>{{ __('language.facility_name_list_page_title') }}</h5>
                    </div>

                    <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                        <a href="#" data-url="{{ route('adminPanel.facility-names.importExcelModal') }}" class="btn btn-primary btn-sm mr-1 import-excel-btn">
                            {{ __('language.import_file_button') }}
                        </a>

                        <a href="{{ route('adminPanel.facility-names.create') }}" class="btn btn-primary btn-sm mr-1">
                            {{ __('language.add_button') }}
                        </a>

                        @if (!empty($request))
                            @php $filterApply = 'filter-icon-apply'; @endphp
                        @else
                            @php $filterApply = 'filter-icon'; @endphp
                        @endif
                        <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                            <i class="fa fa-filter"></i>
                        </button>
                    </div>
                </div>

                <div>
                    {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                    route('adminPanel.facility-names.index'), 'id' => "filter-form"]) !!}
                    <div class="row">
                        <div class="col-md-12">
                            <div class="custom-datatable-filter hide">
                                <div class="row">
                                    <div class="col-md-12">
                                        <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="form-group col-md-3">
                                        {!! Form::select('facility_group', create_select_options($facilityGroups, 'name', 'id', null), old('facility_group', ($request['facility_group'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'facility_group', 'title' => __('language.facility_name_list_group')]) !!}
                                    </div>

                                    <div class="col-md-3">
                                        <div class="form-group">
                                            {!! Form::select('state', create_select_options($states, 'name', 'id',  __('language.facility_name_list_state')), old('status', ($request['state'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'state']) !!}
                                        </div>
                                    </div>

                                    <div class="col-md-3">
                                        <div class="form-group">
                                            {!! Form::select('status', create_select_options(config('constants.facility_name_status'), 'caption', 'value',  __('language.status')), old('status', ($request['status'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status']) !!}
                                        </div>
                                    </div>

                                    <div class="col-md-12">
                                        <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-4 mb2">
                                        {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-sm btn-primary apply-filter', 'type' => 'button'] )}}
                                        {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-sm  btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                    </div>
                                </div>
                                <div class="filter-border"></div>
                            </div>
                        </div>
                    </div>

                    <div class="row pl-3 mt-3">
                        <div class="col-md-8">
                            <div class="float-left">
                                <label> {{ __('language.table_result') }} </label>
                                {!! Form::select('per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('per_page', ($request['per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                            </div>

                            <div class="float-left pl-2 search-box">
                                {!! Form::text('search', old('search', ($request['search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                            </div>
                            <div class="clearfix"></div>
                        </div>

                        <div class="col-md-4 text-right">
                            <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.facility-names.export', ['request' => $request])}}">
                                Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                            </a>
                        </div>
                    </div>
                    {!! Form::close() !!}
                </div>
            </div>

            <div class="container-fluid page-heading">
                <div class="table-responsive pb-5">
                    <table class="table mb-4 mt-3" id="">
                        <thead>
                            <tr>
                                <th> {{ __('language.table_facility_name_list_id') }} </th>
                                <th> {{ __('language.table_facility_name_list_group') }} </th>
                                <th> {{ __('language.table_facility_name_list_name') }} </th>
                                <th> {{ __('language.table_facility_name_list_address') }} </th>
                                <th> {{ __('language.table_facility_name_list_suburb') }} </th>
                                <th> {{ __('language.table_facility_name_list_state') }} </th>
                                <th> {{ __('language.table_status') }} </th>
                                <th> {{ __('language.table_action') }} </th>
                            </tr>
                        </thead>
                        <tbody>
                            @if (count($facilityNames))
                                @foreach ($facilityNames as $facilityName)
                                    <tr>
                                        <td> {{  $facilityName->facility_name_prefix . $facilityName->id }} </td>
                                        <td>
                                            @if ($facilityName->facility_group)
                                                {{ ucwords($facilityName->facility_group->name) }}
                                            @else
                                                N/A
                                            @endif
                                        </td>
                                        <td> {{ ucwords($facilityName->name) }} </td>
                                        <td> {{ $facilityName->address }}  </td>
                                        <td> {{ ucwords($facilityName->suburb_name) }}  </td>
                                        <td>
                                            @if (!empty($facilityName->state))
                                                {{ $facilityName->state->short_form }}
                                            @else
                                                N/A
                                            @endif
                                        </td>
                                        <td>
                                            @if ($facilityName->status == 'inactive')
                                                <div class="text-warning font-weight-bold">{{ __("language.inactive") }}</div>
                                            @else
                                                <div class="text-success font-weight-bold">{{ __("language.active") }}</div>
                                            @endif
                                        </td>
                                        <td>
                                            <ul class="datatable-action">
                                                <li>
                                                    <div class="dropdown custom-dropdown-icon">
                                                        <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                            <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                        </a>
                                                        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                            <a href="{{ route('adminPanel.facility-names.edit', ['id' => ev($facilityName->id)]) }}" class="dropdown-item"> {{ __("language.edit") }} </a>

                                                            @if ($facilityName->status == 'inactive')
                                                                <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.facility-names.changeStatus', ['id' => ev($facilityName->id), 'status' => 'active']) }}"> {{ __("language.active") }} </a>
                                                            @else
                                                                <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.facility-names.changeStatus', ['id' => ev($facilityName->id), 'status' => 'inactive']) }}"> {{ __("language.inactive") }} </a>
                                                            @endif
                                                        </div>
                                                    </div>
                                                </li>
                                            </ul>
                                        </td>
                                    </tr>
                                @endforeach
                            @else
                                <tr>
                                    <td colspan="15" class="text-center"> No record found...</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>

                    <div class="pagination">
                        {{ $facilityNames->appends($request)->render() }}
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/facility-names/view.js') }}"></script>
@endpush
