@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.hcps_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                        <h5>{{ __('language.hcps_page_title') }}</h5>
                    </div>
                </div>
            </div>

            <div class="container-fluid page-heading">
                <div class="table-responsive">
                    <table class="table mb-4 mt-3" id="dataTable-favourite-hcp">
                        <thead>
                            <tr>
                                <th> {{ __('language.table_hcp_id') }} </th>
                                <th> {{ __('language.table_hcp_name') }} </th>
                                <th> {{ __('language.table_hcp_category') }} </th>
                                <th> {{ __('language.table_hcp_profession') }} </th>
                                @if ($authUser->hasRole('Facility') != true)
                                <th> {{ __('language.table_hcp_email') }} </th>
                                @endif
                                <th> {{ __('language.table_hcp_contact_number') }} </th>
                                @if ($authUser->hasRole('Facility') != true)
                                <th> {{ __('language.table_hcp_suburb') }} </th>
                                <th> {{ __('language.table_hcp_state') }} </th>
                                @endif
                                <th> {{ __('language.table_action') }} </th>
                            </tr>
                        </thead>
                        <tbody>
                            @if (count($hcps))
                                @foreach ($hcps as $hcp)
                                <tr>
                                    <td>
                                        <a href="{{route('adminPanel.hcps.details', ['id' => ev($hcp->id)])}}">
                                            {{ $hcp->hcp_prefix . $hcp->id }}
                                        </a>
                                    </td>
                                    <td>
                                        <div>{{ucwords($hcp->first_name . ' ' . $hcp->last_name)}} </div>
                                        <div class="rating">
                                            @for($i = 0; $i < 5; $i++)
                                                <span><i class="fa fa-star{{ $hcp->average_rating <= $i ? '-o' : '' }}"></i></span>
                                            @endfor
                                        </div>
                                    </td>
                                    <td>
                                        @if (count($hcp->hcp_professions))
                                            {{ $hcp->hcp_professions[0]['category']['name'] }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        @if (count($hcp->hcp_professions))
                                            {{ $hcp->hcp_professions[0]['profession']['name'] }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    @if ($authUser->hasRole('Facility') != true)
                                    <td> {{ $hcp->user->email }} </td>
                                    @endif
                                    <td> {{ $hcp->contact_number ?? 'N/A' }} </td>
                                    @if ($authUser->hasRole('Facility') != true)
                                    <td> {{ $hcp->suburb_name ?? 'N/A' }} </td>
                                    <td>
                                        @if (!empty($hcp->state))
                                            {{ $hcp->state->short_form }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    @endif
                                    <td>
                                        <ul class="datatable-action">
                                            <li>
                                                <div class="dropdown custom-dropdown-icon">
                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                    </a>
                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                        <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.facilities.addHcpFavorites', ['hcpId' => $hcp->id, 'facilityId' => $facilityId, 'type' => 'favorites']) }}"> {{ __("language.add_to_favorites") }} </a>

                                                        <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.facilities.addHcpBlocklist', ['hcpId' => $hcp->id, 'facilityId' => $facilityId, 'type' => 'blocklist']) }}"> {{ __("language.add_to_blocked") }} </a>
                                                    </div>
                                                </div>
                                            </li>
                                        </ul>
                                    </td>
                                </tr>
                                @endforeach
                            @else
                                <tr>
                                    <td colspan="15" class="text-center"> No record found...</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>

                    <div class="pagination">
                        {{ $hcps->render() }}
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/hcps/view.js') }}"></script>
@endpush
