@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.notifications').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/components/tabs-accordian/custom-tabs.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-12 col-lg-12 col-md-12 col-12 page-heading">
                            <div class="row">
                                <div class="col-xl-8 col-lg-8 col-md-8 col-8 padding-left-2">
                                    <h5> {{ __('language.notifications') }} </h5>
                                </div>

                                <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                                    <a href="{{ route('adminPanel.notification.create') }}" class="btn btn-primary btn-sm mr-1">
                                        {{ __('language.add_button') }}
                                    </a>

                                    @if (!empty($request))
                                        @php $filterApply = 'btn-primary'; @endphp
                                    @else
                                        @php $filterApply = 'btn-dark'; @endphp
                                    @endif
                                    <button type="button" class="btn rounded-circle filter-button hide {{$filterApply}}">
                                        <i data-feather="filter" class="feather-16"></i>
                                    </button>
                                </div>
                            </div>


                            <div class="row">
                                <div class="col-md-12">
                                    <div class="custom-datatable-filter hide mt2">
                                        {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                                        route('adminPanel.rating-review.facilityRatings')]) !!}
                                        <div class="row">
                                            <div class="col-md-12">
                                                <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-3">
                                                <div class="form-group">
                                                    {!! Form::text('date_range', old('date_range', ($request['date_range'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_range', 'placeholder' => __('language.shift_date_range')]) !!}
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                            </div>
                                        </div>

                                        <div class="row">
                                            <div class="col-md-4 mb2">
                                                {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-primary apply-filter', 'type' => 'button'] )}}
                                                {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                            </div>
                                        </div>
                                        {!! Form::close() !!}
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="container-fluid page-heading">
                    <div class="table-responsive  pb-5">
                        <table class="table mb-4 mt-3">
                            <thead>
                                <tr>
                                    <th>{{__('language.notification_table_message')}}</th>
                                    <th>{{__('language.notification_table_shift_id')}}</th>
                                    <th>{{__('language.date_time')}}</th>
                                </tr>
                            </thead>
                            <tbody>
                            @forelse($notifications as $notification)
                                <tr>
                                    <td>
                                        <div> <b>{{ $notification->title }} </b> </div>
                                        {{ $notification->message }}
                                    </td>
                                    <td>
                                        @if(!empty($notification->shift))
                                            <a href="{{ route('adminPanel.shift.details', ['id' => ev($notification->shift->id)]) }}">
                                                {{ $notification->shift->shift_prefix . $notification->shift->id }}
                                            </a>
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td width="300">
                                        @if(!empty($notification->shift) && !empty($notification->shift->state))
                                            {{ Carbon\Carbon::parse($notification->created_at)->format('Y-m-d h:i A') }}
                                        @elseif (!empty($notification->facility) && !empty($notification->facility->state))
                                            {{ Carbon\Carbon::parse($notification->created_at)->format('Y-m-d h:i A') }}
                                        @elseif(!empty($notification->hcp) && !empty($notification->hcp->state))
                                            {{ Carbon\Carbon::parse($notification->created_at)->setTimezone('Australia/Perth')->format('Y-m-d h:i A') }}
                                        @else
                                            {{ Carbon\Carbon::parse($notification->created_at)->setTimezone('Australia/Perth')->format('Y-m-d h:i A') }}
                                        @endif
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="10" class="text-center"> {{ __('language.no_record_found') }} </td>
                                </tr>
                            @endforelse
                            </tbody>
                        </table>
                        <div class="pagination">
                            {{ $notifications->render() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script>
    $(function(){
        var hash = window.location.hash;
        hash && $('ul.nav a[href="' + hash + '"]').tab('show');

        $('.nav-tabs a').click(function (e) {
            $(this).tab('show');
            var scrollmem = $('body').scrollTop();
            window.location.hash = this.hash;
            $('html,body').scrollTop(scrollmem);
        });
    });
</script>
@endpush
