@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.public_holiday_facility_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                        <h5>{{ __('language.public_holiday_facility_page_title') }} ({{ucwords($state->name)}})</h5>
                    </div>

                    <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right pb1">
                        @if (!empty($request))
                            @php $filterApply = 'filter-icon-apply'; @endphp
                        @else
                            @php $filterApply = 'filter-icon'; @endphp
                        @endif
                        <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                            <i class="fa fa-filter"></i>
                        </button>
                    </div>
                </div>

                <div>
                {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                route('adminPanel.public-holidays.getFacilityPublicHoliday')]) !!}
                <div class="row">
                    <div class="col-md-12">
                        <div class="custom-datatable-filter hide">
                            <div class="row">
                                <div class="col-md-12">
                                    <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-3">
                                    <div class="form-group">
                                        {!! Form::select('status', create_select_options(config('constants.public_holiday_status'), 'caption', 'value',  __('language.public_holiday_status')), old('status', ($request['status'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status']) !!}
                                    </div>
                                </div>

                                <div class="col-md-3">
                                    <div class="form-group">
                                        {!! Form::text('date_range', old('date_range', ($request['date_range'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_range', 'placeholder' => __('language.public_holiday_date_range')]) !!}
                                    </div>
                                </div>

                                <div class="col-md-12">
                                    <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-4 mb2">
                                    {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-sm btn-primary apply-filter', 'type' => 'button'] )}}
                                    {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-sm  btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                </div>
                            </div>
                            <div class="filter-border"></div>
                        </div>
                    </div>
                </div>

                <div class="row pl-3 mt-3">
                    <div class="col-md-8">
                        <div class="float-left">
                            <label> {{ __('language.table_result') }} </label>
                            {!! Form::select('per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('per_page', ($request['per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                        </div>

                        <div class="float-left pl-2 search-box">
                            {!! Form::text('search', old('search', ($request['search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                            <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                        </div>
                        <div class="clearfix"></div>
                    </div>

                    <div class="col-md-4 text-right">
                        <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.public-holidays.facilityExport', ['request' => $request])}}">
                            Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                        </a>
                    </div>
                </div>
                {!! Form::close() !!}
                </div>
            </div>

            <div class="container-fluid page-heading">
                <div class="table-responsive pb-5">
                    <table class="table mb-4 mt-3" id="dataTable-favourite-hcp">
                        <thead>
                            <tr>
                                <th> {{ __('language.public_holiday_table_name') }} </th>
                                <th> {{ __('language.public_holiday_table_date') }} </th>
                                <th> {{ __('language.table_status') }} </th>
                            </tr>
                        </thead>
                        <tbody>
                            @if (count($publicHolidays))
                                @php $currentDate  = Carbon\Carbon::now(); @endphp
                                @foreach ($publicHolidays as $publicHoliday)
                                    <tr>
                                        <td> {{ ucwords($publicHoliday->name) }} </td>
                                        <td> {{ date("l dS F Y", strtotime($publicHoliday->holiday_date)) }} </td>
                                        <td>
                                            @if ($publicHoliday->status == 'inactive')
                                                <div class="text-warning font-weight-bold">{{ __("language.inactive") }}</div>
                                            @else
                                                <div class="text-success font-weight-bold">{{ __("language.active") }}</div>
                                            @endif
                                        </td>
                                    </tr>
                                @endforeach
                            @else
                                <tr>
                                    <td colspan="15" class="text-center"> No record found...</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>

                    <div class="pagination">
                        {{ $publicHolidays->appends($request)->render() }}
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/public-holiday/view.js') }}"></script>
@endpush
