@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.rating_and_reviews').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/components/tabs-accordian/custom-tabs.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-12 col-lg-12 col-md-12 col-12 page-heading">
                            <div class="row">
                                <div class="col-xl-8 col-lg-8 col-md-8 col-8 padding-left-2">
                                    <h5> {{ __('language.rating_and_reviews') }} </h5>
                                </div>

                                <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                                    @if (!empty($request))
                                        @php $filterApply = 'filter-icon-apply'; @endphp
                                    @else
                                        @php $filterApply = 'filter-icon'; @endphp
                                    @endif
                                    <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                                        <i class="fa fa-filter"></i>
                                    </button>
                                </div>
                            </div>

                            <div>
                            {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                            route('adminPanel.rating-review.facilityRatings'), 'id' => 'filter-form']) !!}
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="custom-datatable-filter hide pl-0">
                                        <div class="row">
                                            <div class="col-md-12">
                                                <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-3">
                                                <div class="form-group">
                                                    {!! Form::text('date_range', old('date_range', ($request['date_range'] ?? null)), ['class' => 'form-control date-picker', 'id' => 'date_range', 'placeholder' => __('language.shift_date_range')]) !!}
                                                </div>
                                            </div>

                                            <div class="col-md-12">
                                                <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-4 mb2">
                                                {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-primary apply-filter', 'type' => 'button'] )}}
                                                {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                            </div>
                                        </div>
                                        <div class="filter-border"></div>
                                    </div>
                                </div>
                            </div>

                            <div class="row pl-3 mt-3">
                                <div class="col-md-8">
                                    <div class="float-left">
                                        <label> {{ __('language.table_result') }} </label>
                                        {!! Form::select('per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('per_page', ($request['per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                                    </div>

                                    <div class="float-left pl-2 search-box">
                                        {!! Form::text('hcp_search', old('hcp_search', ($request['hcp_search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                        <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                                    </div>
                                    <div class="clearfix"></div>
                                </div>

                                <div class="col-md-4 text-right">
                                    <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.rating-review.facilityRatingsExport', ['request' => $request])}}">
                                        Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                                    </a>
                                </div>
                            </div>
                            {!! Form::close() !!}
                            </div>
                        </div>
                    </div>
                </div>

                <div class="container-fluid page-heading">
                    <div class="table-responsive pb-5">
                        <table class="table mb-4 mt-3">
                            <thead>
                                <tr>
                                    <th>{{__('language.shift_id')}}</th>
                                    <th>{{__('language.date_time')}}</th>
                                    <th>{{__('language.hcps')}}</th>
                                    <th>{{__('language.rating_by_hcp')}} </th>
                                    <th>{{__('language.rating_by_facility')}} </th>
                                    <th>{{__('language.action')}}</th>
                                </tr>
                            </thead>
                            <tbody>
                            @forelse($ratings as $rating)
                                <tr>
                                    <td>
                                        <a href="#" class="text-primary">
                                            <div>{{ $rating->shift->shift_prefix . $rating->shift_id }}</div>
                                        </a>
                                    </td>
                                    <td>
                                        @php
                                            $dateTime = Carbon\Carbon::parse($rating->created_at)->setTimezone($rating->shift->state['time_zone_name']);
                                        @endphp
                                        <div>{{ date("d M", strtotime($dateTime)) }}</div>
                                        {{ date("h:i A", strtotime($dateTime)) }}
                                    </td>
                                    <td>
                                        @if (!empty($rating['hcp']))
                                        <a href="{{route('adminPanel.hcps.details', ['id' => ev($rating['hcp']->id)])}}" class="text-primary">
                                            <div>{{ ucwords($rating['hcp']->first_name.' '.$rating['hcp']->last_name) }}</div>
                                        </a>
                                        <small> {{ $rating['hcp']->hcp_prefix . $rating['hcp']->id }} </small>
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        <div class="rating">
                                            @for($i = 1; $i < 6; $i++)
                                                @php
                                                    if ( round( $rating->facility_rating - .25 ) >= $i ) {
                                                        echo "<i class='fa fa-star'></i>";
                                                    } elseif ( round( $rating->facility_rating + .25 ) >= $i ) {
                                                        echo "<i class='fa fa-star-half-o'></i>";
                                                    } else {
                                                        echo "<i class='fa fa-star-o'></i>";
                                                    }
                                                @endphp
                                            @endfor
                                        </div>
                                        {{ $rating->comment }}
                                    </td>
                                    <td>
                                        @php
                                            $hcpRating = get_rating_by_facility($rating->facility_id, $rating->shift_id)
                                        @endphp
                                        @if (!empty($hcpRating))
                                        <div class="rating">
                                            @for($i = 1; $i < 6; $i++)
                                                @php
                                                    if ( round( $hcpRating->hcp_rating - .25 ) >= $i ) {
                                                        echo "<i class='fa fa-star'></i>";
                                                    } elseif ( round( $hcpRating->hcp_rating + .25 ) >= $i ) {
                                                        echo "<i class='fa fa-star-half-o'></i>";
                                                    } else {
                                                        echo "<i class='fa fa-star-o'></i>";
                                                    }
                                                @endphp
                                            @endfor
                                        </div>
                                        {{ $hcpRating->hcp_comment }}
                                        @else
                                        N/A
                                        @endif
                                    </td>
                                    <td>
                                        <ul class="datatable-action">
                                            <li>
                                                <div class="dropdown custom-dropdown-icon">
                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                    </a>
                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                        <a href="{{ route('adminPanel.shift.details', ['id' => ev($rating->shift_id)]) }}" class="dropdown-item"> {{ __("language.review_and_ratings_shift") }} </a>
                                                    </div>
                                                </div>
                                            </li>
                                        </ul>
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="15" class="text-center"> {{ __('language.no_record_found') }} </td>
                                </tr>
                            @endforelse
                            </tbody>
                        </table>
                        <div class="pagination">
                            {{ $ratings->appends($request)->render() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/rating-reviews/rating-reviews.js') }}"></script>
<script>
    $(function(){
        var hash = window.location.hash;
        hash && $('ul.nav a[href="' + hash + '"]').tab('show');

        $('.nav-tabs a').click(function (e) {
            $(this).tab('show');
            var scrollmem = $('body').scrollTop();
            window.location.hash = this.hash;
            $('html,body').scrollTop(scrollmem);
        });
    });
</script>
@endpush
