@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.shifts').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <h5>{{__('language.shift_total_request_last_days')}} {{ __('language.shifts_page_title') }}</h5>
                        </div>
                        <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                            @if (!empty($request))
                                @php $filterApply = 'filter-icon-apply'; @endphp
                            @else
                                @php $filterApply = 'filter-icon'; @endphp
                            @endif
                            <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                                <i class="fa fa-filter"></i>
                            </button>
                        </div>
                    </div>
                    <div>
                    {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' => route('adminPanel.shift.allShifts'), 'id' => 'shift-filter-form']) !!}
                    <div class="row">
                        <div class="col-md-12">
                            <div class="custom-datatable-filter hide">
                                <div class="row">
                                    <div class="col-md-12">
                                        <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                    </div>
                                </div>
                                <div class="row">

                                    {!! Form::hidden('last_days', old('last_days', ($request['last_days'] ?? null)), ['class' => 'form-control', 'id' => 'last_days']) !!}

                                    <div class="col-md-12">
                                        @if ($authUser->hasRole('Facility') != true)
                                            @if (!empty($states))
                                                <div class="form-group btn-group btn-group-toggle btn-checkbox-group" data-toggle="buttons">
                                                    @foreach($states as $state)
                                                        <label class="btn btn-custom-outline {{ !empty($request['states']) && in_array($state->id, $request['states']) ? ' active' : '' }}">
                                                            <input type="checkbox" id="states" class="states" name="states[]" value="{{$state->id}}" autocomplete="off" {{ !empty($request['states']) && in_array($state->id, $request['states']) ? ' checked' : '' }}> {{$state->short_form}} : {{$state->shifts_count}}
                                                        </label>
                                                    @endforeach
                                                </div>
                                            @endif
                                        @endif
                                    </div>

                                    <div class="col-md-2">
                                        <div class="form-group">
                                            {!! Form::select('category', create_select_options($categories, 'name', 'id',  __('language.hcp_category')), old('category', ($request['category'] ?? null)),  ['class' => 'form-control select-picker category-profession', 'id' => 'category', 'data-url' => route('adminPanel.categories.getProfessions')  ]) !!}
                                        </div>
                                    </div>

                                    <div class="col-md-2 profession-div">
                                        <div class="form-group">
                                            {!! Form::select('profession', create_select_options($professions, 'name', 'id',  __('language.hcp_professions')), old('profession', ($request['profession'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'profession' ]) !!}
                                        </div>
                                    </div>

                                    @if ($authUser->hasRole('Facility') != true)
                                    <div class="col-md-2">
                                        <div class="form-group">
                                            {!! Form::select('facility', create_select_options($facilities, 'name', 'id',  __('language.facility')), old('facility', ($request['facility'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'facility' ]) !!}
                                        </div>
                                    </div>
                                    @endif

                                    <div class="col-md-2">
                                        <div class="form-group">
                                            {!! Form::select('shift_type', create_select_options(config('constants.shifts.shift_types'), 'caption', 'value',  __('language.shift_types')), old('shift_type', ($request['shift_type'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'shift_type' ]) !!}
                                        </div>
                                    </div>

                                    <div class="col-md-2">
                                        <div class="form-group">
                                            {!! Form::select('shortby_filter', create_select_options(config('constants.shifts.shift_shortby_filter'), 'caption', 'value',  __('language.shift_shortby_filter')), old('shortby_filter', ($request['shortby_filter'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'shortby_filter' ]) !!}
                                        </div>
                                    </div>

                                    <div class="col-md-12">
                                        <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-4 mb2">
                                        {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-primary apply-filter', 'type' => 'button'] )}}
                                        {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                    </div>
                                </div>
                                <div class="filter-border"></div>
                            </div>
                        </div>
                    </div>

                    <div class="row pl-3 mt-3">
                        <div class="col-md-8">
                            <div class="float-left">
                                <label> {{ __('language.table_result') }} </label>
                                {!! Form::select('shift_per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('shift_per_page', ($request['shift_per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                            </div>

                            <div class="float-left pl-2 search-box">
                                {!! Form::text('shift_hcp_search', old('shift_hcp_search', ($request['shift_hcp_search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#shift-filter-form').submit();"></i> </span>
                            </div>
                            <div class="clearfix"></div>
                        </div>

                        <div class="col-md-4 text-right">
                            <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.shift.shiftExport', ['request' => $request, 'status' => 'all'])}}">
                                Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                            </a>
                        </div>
                    </div>
                    {!! Form::close() !!}
                    </div>
                </div>

                <div class="container-fluid page-heading">
                    <div class="table-responsive pb-5">
                        <table class="table mb-4 mt-3">
                            <thead>
                            <tr>
                                <th> {{ __('language.shift_id') }} </th>
                                <th> {{ __('language.booking_date') }} </th>
                                <th> {{ __('language.shift_type') }} </th>
                                <th> {{ __('language.cat_pro') }} </th>
                                @if ($authUser->hasRole('Facility') != true)
                                <th> {{ __('language.fac_name') }} </th>
                                @endif
                                <th> {{ __('language.hcp_name') }} </th>
                                <th> {{ __('language.word_wing') }} </th>
                                <th> {{ __('language.shift_start') }} </th>
                                <th> {{ __('language.shift_end') }} </th>
                                <th> {{ __('language.total_hours') }} </th>
                                @if ($authUser->hasRole('Facility') != true)
                                <th> {{ __('language.shift_suburb') }} </th>
                                <th> {{ __('language.shift_state') }} </th>
                                @endif
                                <th> {{ __('language.table_status') }} </th>
                                <th> {{ __('language.action') }} </th>
                            </tr>
                            </thead>
                            <tbody>
                            @forelse($shifts as $shift)
                                <tr>
                                    <td>
                                        <a href="{{ route('adminPanel.shift.details', ['id' => ev($shift->id)]) }}">
                                            {{ $shift->shift_prefix . $shift->id }}
                                        </a>
                                    </td>
                                    <td>
                                        {{ date("d M Y", strtotime($shift->created_at)) }}
                                    </td>
                                    <td>
                                        @if (!empty($shift->shift_type))
                                            {{ ucwords($shift->shift_type) }}
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td>
                                        <div>{{ ucwords($shift->profession->name)}}</div>
                                        <div class="font-size-12"> {{ ucwords($shift->category->name)}} </div>
                                    </td>
                                    @if ($authUser->hasRole('Facility') != true)
                                    <td>
                                        <a href="{{ route('adminPanel.facilities.details', ['id' => ev($shift->facility->id)]) }}">
                                            <div> {{ ucwords($shift->facility->name)}}</div>
                                        </a>
                                        <div class="font-size-12">
                                            @if (!empty($shift['facility']->address))
                                                {{ $shift['facility']->address }}
                                            @endif
                                        </div>
                                    </td>
                                    @endif
                                    <td>
                                        @if (!empty($shift['hcp']))
                                        <a href="{{route('adminPanel.hcps.details', ['id' => ev($shift['hcp']->id)])}}" class="text-primary">
                                            <div>{{ ucwords($shift['hcp']->first_name.' '.$shift['hcp']->last_name) }}</div>
                                        </a>
                                        <div class="font-size-12">
                                            @if (!empty($shift['hcp']))
                                                {{ $shift['hcp']->contact_number }}
                                            @endif
                                        </div>
                                        @else
                                            N/A
                                        @endif
                                    </td>
                                    <td> {{ $shift->word_wing }} </td>
                                    <td>
                                        <div>{{ date("d M", strtotime($shift->start_time)) }}</div>
                                        {{ date("h:i A", strtotime($shift->start_time)) }}
                                    </td>
                                    <td>
                                        <div>{{ date("d M", strtotime($shift->end_time)) }}</div>
                                        {{ date("h:i A", strtotime($shift->end_time)) }}
                                    </td>
                                    <td> {{ $shift->hours }} Hrs </td>
                                    @if ($authUser->hasRole('Facility') != true)
                                    <td>
                                        @if (!empty($shift['facility']->suburb_name))
                                            {{ $shift['facility']->suburb_name }}
                                        @endif
                                    </td>
                                    <td>
                                        @if (!empty($shift['facility']->state))
                                            {{ $shift['facility']->state->short_form }}
                                        @endif
                                    </td>
                                    @endif
                                    <td>
                                        @if ($shift['shift_status'] == '0')
                                            <div class="text-warning font-weight-bold"> {{ __('language.shift_status_pending') }} </div>
                                        @elseif ($shift['shift_status'] == '1')
                                            <div class="text-info font-weight-bold"> {{ __('language.shift_status_scheduled') }} </div>
                                        @elseif ($shift['shift_status'] == '2')
                                            <div class="text-success font-weight-bold"> {{ __('language.shift_status_running') }} </div>
                                        @elseif ($shift['shift_status'] == '3')
                                            <div class="text-danger font-weight-bold"> {{ __('language.shift_status_cancelled') }} </div>
                                        @elseif ($shift['shift_status'] == '4')
                                            <div class="text-success font-weight-bold"> {{ __('language.shift_status_completed') }} </div>
                                        @elseif ($shift['shift_status'] == '5')
                                            <div class="text-info font-weight-bold"> {{ __('language.shift_status_transfered') }} </div>
                                        @elseif ($shift['shift_status'] == '6')
                                            <div class="text-success font-weight-bold"> {{ __('language.shift_status_past') }} </div>
                                        @endif
                                    </td>
                                    <td>
                                        <ul class="datatable-action">
                                            <li>
                                                <div class="dropdown custom-dropdown-icon">
                                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                        <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                    </a>
                                                    <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">
                                                        @if ($authUser->can('Edit Shifts') || $authUser->can('Facility Edit Shifts') && $shift['shift_status'] == '0')
                                                        <a href="{{ route('adminPanel.shift.edit', ['id' => ev($shift->id)]) }}" class="dropdown-item">
                                                            {{ __("language.edit") }}
                                                        </a>
                                                        @endif
                                                        <a href="{{ route('adminPanel.shift.details', ['id' => ev($shift->id)]) }}" class="dropdown-item"> {{ __("language.details") }} </a>
                                                        <a href="{{ route('adminPanel.shift.shiftRebroadcast', ['id' => ev($shift->id)]) }}" class="dropdown-item"> {{ __("language.re_broadcast") }} </a>
                                                    </div>
                                                </div>

                                            </li>
                                        </ul>
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="15" class="text-center"> {{ __('language.no_record_found') }} </td>
                                </tr>
                            @endforelse
                            </tbody>
                        </table>

                        <div class="pagination">
                            {{ $shifts->appends($request)->render() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/shift/view.js') }}"></script>
@endpush
