@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.create_buddy_shifts_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">

            <!-- Validation error -->
            @component('admin-panel.validation.errors') @endcomponent
            <!-- / Validation error -->

            <div class="alert alert-danger mb-4 hide" role="alert" id="shift-error-div">
                <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <i data-feather="x" class="feather-16"></i> </button>
                <strong>Error!</strong>
                <div class="error-msg"> </div>
            </div>

            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <h5>
                                {{ __('language.create_buddy_shifts_page_title') }}
                                ({{ __('language.hcp_name') }}: {{ $buddyShiftRequest['buddy_hcp']['first_name'].' '.$buddyShiftRequest['buddy_hcp']['last_name'] }})
                            </h5>
                        </div>
                    </div>

                    <div class="form p-3">
                        {!! Form::open(['class'=> 'add-shift-form', 'method' => 'post', 'url' => route('adminPanel.shift.storeBuddyShift'), 'files'=> true])!!}
                            <div class="form-row">

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.shift_facility_group') }} </label>
                                    {!! Form::select('facility_group', create_select_options($facilityGroups, 'name', 'id', null), ($shift->facility_group_id ?? null),  ['class' => 'form-control select-picker select-facility-group-for-shift', 'id' => 'facility_group', 'data-url' => route('adminPanel.facility-groups.getFacilitiesForShift'), 'title' =>  __('language.shift_facility_group') ]) !!}
                                </div>

                                <div class="form-group col-md-3 facility-div">
                                    <label> {{ __('language.shift_facility') }} </label>
                                    <select name="facility" id="facility" class="form-control select-picker get-facility" title="{{__('language.shift_facility')}}" data-url="{{ route('adminPanel.categories.getCategory') }}">
                                        @foreach ($facilities as $facility)
                                        <option value="{{$facility->id}}" {{ $shift ? ($shift->facility_id == $facility->id ? 'selected' : '') : '' }}>
                                            @if (!empty($facility->facility_name))
                                                {{$facility->facility_name->name}}
                                            @else
                                                {{$facility->name}}
                                            @endif
                                        </option>
                                        @endforeach
                                    </select>
                                </div>

                                <div class="form-group col-md-3">
                                    <label for="word_wing"> {{ __('language.word_wing') }} </label>
                                    {!! Form::text('word_wing', old('word_wing', ($shift['word_wing'] ?? null)), ['class' => 'form-control', 'id' => 'word_wing', 'placeholder' => __('language.word_wing')]) !!}
                                </div>

                                <div class="form-group col-md-3 category-div">
                                    <label> {{ __('language.shift_category') }} </label>
                                    {!! Form::select('category_id', create_select_options($categories, 'name', 'id', null), old('category_id', ($buddyShiftRequest['category_id'] ?? null)),  ['class' => 'form-control select-picker category-profession', 'id' => 'category_id', 'title' =>  __('language.shift_category'), 'data-url' => route('adminPanel.shift.getProfessions'), ($buddyShiftRequest['category_id'] ? '' : '') ]) !!}
                                </div>

                                <div class="form-group col-md-3 profession-div">
                                    <label> {{ __('language.shift_professions') }} </label>
                                    {!! Form::select('profession_id', create_select_options($professions, 'name', 'id', null), old('profession_id', ($buddyShiftRequest['profession_id'] ?? null)),  ['class' => 'form-control select-picker profession-level', 'id' => 'profession_id', 'title' =>  __('language.shift_professions'), 'data-url' => route('adminPanel.professions.getLevels'),  ($buddyShiftRequest['profession_id'] ? '' : '')]) !!}
                                </div>

                                <div class="form-group col-md-3 level-div">
                                    <label> {{ __('language.shift_level') }} </label>
                                    {!! Form::select('hcp_level_id', create_select_options(($buddyShiftRequest['level_id'] ? $levels : []), 'name', 'id', null), old('hcp_level_id', ($buddyShiftRequest['level_id'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'hcp_level_id', 'title' =>  __('language.shift_level'), ($buddyShiftRequest['level_id'] ? '' : '')]) !!}
                                </div>

                                @if (!empty($shift))
                                {!! Form::hidden('current_time', Carbon\Carbon::now($shift->state->time_zone_name)->format('Y-m-d h:i a'), ['class' => 'form-control', 'id' => 'current_time']) !!}
                                @else
                                {!! Form::hidden('current_time', '', ['class' => 'form-control', 'id' => 'current_time']) !!}
                                @endif

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.start_time') }} </label>
                                    {!! Form::text('start_time', old('start_time', ($shift['start_time'] ?? null)), ['class' => 'form-control start-time date-picker', 'id' => 'start_time', 'placeholder' => __('language.start_time')]) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.end_time') }} </label>
                                    {!! Form::text('end_time', old('end_time', ($shift['end_time'] ?? null)), ['class' => 'form-control end-time  date-picker', 'id' => 'end_time', 'placeholder' => __('language.end_time')]) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.booked_by') }} </label>
                                    {!! Form::text('booked_by', '', ['class' => 'form-control', 'id' => 'booked_by', 'placeholder' => __('language.booked_by')]) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.shift_types') }} </label>
                                    {!! Form::text('shift_types', 'buddy', ['class' => 'form-control input-readonly-new text-capitalize', 'id' => 'shift_types', 'placeholder' => __('language.shift_types'), 'readonly']) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.break_time') }} </label>
                                    {!! Form::text('break', old('break', ($shift['break'] ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'break', 'placeholder' => __('language.break_time'), 'readonly']) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.total_hours') }} </label>
                                    {!! Form::text('hours', old('hours', ($shift['hours'] ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'hours', 'placeholder' => __('language.total_hours'), 'readonly']) !!}
                                </div>
                            </div>

                            <div class="form-row">
                                <div class="col-md-6">
                                    <div class="form-row">
                                        <div class="form-group col-md-6">
                                            <label> {{ __('language.shift_loading') }} </label>
                                            {!! Form::text('shift_loading', '', ['class' => 'form-control input-readonly-new', 'id' => 'shift_loading', 'placeholder' => __('language.shift_loading'), 'readonly']) !!}
                                        </div>

                                        <div class="form-group col-md-6">
                                            <label> {{ __('language.no_of_opening') }} </label>
                                            {!! Form::number('no_of_openings', '1', ['class' => 'form-control input-readonly-new', 'id' => 'no_of_openings', 'placeholder' => __('language.no_of_opening'), 'min' => 1 , 'max' => 10, 'readonly']) !!}
                                        </div>

                                        @if (!empty($shift['hcp']))
                                            @php
                                                $addReadOnly = 'readonly';
                                                $addReadOnlyClass = 'input-readonly-new';
                                                $hcpName = $shift['hcp']['first_name'].' '.$shift['hcp']['last_name'];
                                            @endphp
                                        @else
                                            @php
                                                $addReadOnly = '';
                                                $addReadOnlyClass = '';
                                                $hcpName = '';
                                            @endphp
                                        @endif
                                        <div class="form-group col-md-6">
                                            <label> {{ __('language.mentor_name') }} </label>
                                            {!! Form::text('mentor_hcp_name', old('mentor_hcp_name', ($hcpName ?? null)), ['class' => 'form-control '.$addReadOnlyClass, 'id' => 'buddy_hcp_name', 'placeholder' => __('language.mentor_name'), $addReadOnly]) !!}
                                        </div>

                                        <div class="form-group col-md-6">
                                            <label> {{ __('language.mentor_email') }} </label>
                                            {!! Form::email('mentor_hcp_email', old('mentor_hcp_email', ($shift['hcp']['user']['email'] ?? null)), ['class' => 'form-control '.$addReadOnlyClass, 'id' => 'mentor_hcp_email', 'placeholder' => __('language.mentor_email'), $addReadOnly]) !!}
                                        </div>

                                        <div class="form-group col-md-12">
                                            <label> {{ __('language.notes') }} </label>
                                            {!! Form::textarea('notes', '', ['class' => 'form-control address-textarea', 'id' => 'notes', 'placeholder' => __('language.notes')]) !!}
                                        </div>
                                    </div>

                                    {!! Form::hidden('scheduled_shift_id', old('scheduled_shift_id', ($shift->id ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'scheduled_shift_id', 'readonly']) !!}
                                    {!! Form::hidden('buddy_request_id', old('buddy_request_id', ($buddyShiftRequest->id ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'buddy_request_id', 'placeholder' => 'Buddy Hcp Id', 'readonly']) !!}
                                    {!! Form::hidden('assign_hcp', old('assign_hcp', ($buddyShiftRequest->hcp_id ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'assign_hcp', 'placeholder' => 'Hcp Id', 'readonly']) !!}
                                    {!! Form::hidden('mentor_hcp_id', old('mentor_hcp_id', ($shift->hcp_id ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'mentor_hcp_id', 'placeholder' => 'Hcp Id', 'readonly']) !!}
                                    {!! Form::hidden('shift_time', '', ['class' => 'form-control', 'id' => 'shift_time']) !!}
                                    {!! Form::hidden('working_hours', '', ['class' => 'form-control', 'id' => 'working_hours']) !!}
                                    {!! Form::hidden('hcp_amount', '', ['class' => 'form-control', 'id' => 'hcp_amount']) !!}
                                    {!! Form::hidden('facility_amount', '', ['class' => 'form-control', 'id' => 'facility_amount']) !!}
                                    {!! Form::hidden('admin_amount', '', ['class' => 'form-control', 'id' => 'admin_amount']) !!}
                                    {!! Form::hidden('admin_fees', '', ['class' => 'form-control', 'id' => 'admin_fees']) !!}
                                    {!! Form::hidden('facility_per_rate', '', ['class' => 'form-control', 'id' => 'facility_per_rate']) !!}
                                    {!! Form::hidden('hcp_per_rate', '', ['class' => 'form-control', 'id' => 'hcp_per_rate']) !!}
                                    {!! Form::hidden('admin_fees_with_loading', '', ['class' => 'form-control', 'id' => 'admin_fees_with_loading']) !!}
                                    {!! Form::hidden('final_hours_time', '', ['class' => 'form-control', 'id' => 'final_hours_time']) !!}
                                    {!! Form::hidden('total_hours_time', '', ['class' => 'form-control', 'id' => 'total_hours_time']) !!}
                                    {!! Form::hidden('hcp_shift_loading', '', ['class' => 'form-control', 'id' => 'hcp_shift_loading']) !!}
                                    {!! Form::hidden('hcp_shift_total_loading', '', ['class' => 'form-control', 'id' => 'hcp_shift_total_loading']) !!}
                                    {!! Form::hidden('facility_shift_loading', '', ['class' => 'form-control', 'id' => 'facility_shift_loading']) !!}
                                    {!! Form::hidden('facility_shift_total_loading', '', ['class' => 'form-control', 'id' => 'facility_shift_total_loading']) !!}
                                </div>

                                <div class="col-md-6" id="shift-estimates" data-url="{{ route('adminPanel.shift.calculatePrice') }}">
                                    <label> Shift Estimates </label>
                                    <div class="table-responsive">
                                        <table class="table" width="100%"  cellpadding="5">
                                            <tr>
                                                <th> {{ __('language.break_time') }} </th>
                                                <td class="break-time"> 0 </td>

                                                <th> {{ __('language.final_hours') }} </th>
                                                <td class="final-hour"> 0 </td>
                                            </tr>
                                            <tr>
                                                <th> {{ __('language.hcp_rate') }}  </th>
                                                <td class="hcp-rate"> 0 </td>

                                                <th> {{ __('language.admin_fees') }} </th>
                                                <td class="admin-fees"> 0 </td>
                                            </tr>
                                            <tr>
                                                <th> {{ __('language.facility_rate') }} </th>
                                                <td class="facility-rate"> 0 </td>

                                                <th> {{ __('language.shift_loading') }} </th>
                                                <td class="shift-loading"> 0 </td>
                                            </tr>
                                            <tr>
                                                <th> {{ __('language.hcp_shift_total') }} </th>
                                                <td class="hcp-shift-total"> 0 </td>

                                                <th> {{ __('language.facility_shift_total') }} </th>
                                                <td class="facility-shift-total"> 0 </td>
                                            </tr>
                                        </table>
                                    </div>
                                </div>
                            </div>
                            {{ Form::button('<i class="fa fa-save"></i> &nbsp;'. __('language.shift_create_buddy_shift'), ['class' => 'btn btn-primary btn-submit mt-2', 'type' => 'submit', 'id' => 'shift-submit'] )}}

                        {!! Form::close() !!}
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script>
    var TIME_LOADING = JSON.parse(@json("$loadingTimeConfiguration"));
    var GENERAL_CONFIGURATION = JSON.parse(@json("$generalConfiguration"));
    var MIN_SHIFT_HOURS = GENERAL_CONFIGURATION['min_shift_booking_hours'];
    var MAX_SHIFT_HOURS = GENERAL_CONFIGURATION['max_shift_booking_hours'];
    var DEFAULT_SHIFT_HOURS = GENERAL_CONFIGURATION['default_hours_shift'];
</script>

@if ($shiftType != 'scheduled')
<script>
    var PROFESSION_ID = "{{ $request['profession_id'] }}";
    var CATEGORY_ID = "{{ $request['category_id'] }}";
    var LEVEL_ID = "{{ $request['level_id'] }}";
    var HCP_LATITUDE = "{{ $request['latitude'] }}";
    var HCP_LONGITUDE = "{{ $request['longitude'] }}";
    var CONIG_RADIUS = "{{ $request['radius'] }}";
    var HCP_STATE_ID = "{{ $request['state_id'] }}";
</script>
@endif

<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/shift/shift.js') }}"></script>
@endpush
