@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.create_shifts_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/elements/popover.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">

            <!-- Validation error -->
            @component('admin-panel.validation.errors') @endcomponent
            <!-- / Validation error -->

            <div class="alert alert-danger mb-4 hide" role="alert" id="shift-error-div">
                <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <i data-feather="x" class="feather-16"></i> </button>
                <strong>Error!</strong>
                <div class="error-msg" id="error-msg-id" style="color: white"> </div>
            </div>

            <div class="widget-content widget-content-area br-6">
                {!! Form::open(['class'=> 'add-shift-form', 'method' => 'post', 'url' => route('adminPanel.shift.store'), 'files'=> true])!!}
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <div>
                                <h5 class="float-left"> {{ __('language.create_shifts_page_title') }} </h5>
                                <div class="float-left custom-control custom-checkbox ml-5">
                                    <input type="checkbox" class="custom-control-input multiple-shifts" id="multiple_shifts" name="multiple_shift_true" data-url="{{ route('adminPanel.shift.multipleShiftsModal') }}">
                                    <label class="custom-control-label text-dark" for="multiple_shifts"> {{ __('language.multiple_shifts') }} </label>
                                </div>
                                <div class="float-left custom-control custom-checkbox ml-5">
                                    <input type="checkbox" class="custom-control-input sleepover-shifts" id="sleepover_shifts" name="sleepover_shift_true">
                                    <label class="custom-control-label text-dark" for="sleepover_shifts"> {{ __('language.sleepover_shifts') }} </label>
                                </div>
                                <div class="float-left multiple-shifts-error hide"> {{ __('messages.multiple_shifts_error') }} </div>
                                <div class="clearfix"></div>
                            </div>
                        </div>
                    </div>

                    <div class="form p-3">
                        <div class="form-row">
                            <div class="form-group col-md-3">
                                <label> {{ __('language.shift_facility_group') }} </label>
                                @if($authUser->hasRole('Facility Group') == true || $authUser->hasRole('Facility Group Sub Admin') == true)
                                    {!! Form::hidden('facility_group', "{{$facilityGroups->id}}", ['class' => 'form-control', 'id' => 'facility_group', 'placeholder' => __('language.facility_group')]) !!}

                                   {!! Form::text('facility_group_text', $facilityGroups->name, ['class' => 'form-control', 'readonly', 'placeholder' => __('language.facility_group')]) !!}
                                @else
                                    {!! Form::select('facility_group', create_select_options($facilityGroups, 'name', 'id', null), null,  ['class' => 'form-control select-picker select-facility-group', 'id' => 'facility_group', 'data-url' => route('adminPanel.facility-groups.getFacilities'), 'title' =>  __('language.shift_facility_group') ]) !!}
                                @endif
                            </div>

                            <div class="form-group col-md-3 facility-div">
                                <label> {{ __('language.shift_facility') }} </label>
                                <select name="facility" id="facility" class="form-control select-picker facility-plan" title="{{__('language.shift_facility')}}" data-url="{{ route('adminPanel.categories.getCategory') }}">
                                    @foreach ($facilities as $facility)
                                    <option value="{{$facility->id}}">
                                        @if (!empty($facility->facility_name))
                                            {{$facility->facility_name->name}}
                                        @else
                                            {{$facility->name}}
                                        @endif
                                    </option>
                                    @endforeach
                                </select>
                            </div>

                            <div class="form-group col-md-3">
                                <label for="word_wing"> {{ __('language.word_wing') }} </label>
                                {!! Form::text('word_wing', '', ['class' => 'form-control', 'id' => 'word_wing', 'placeholder' => __('language.word_wing')]) !!}
                            </div>

                            <div class="form-group col-md-3 category-div">
                                <label> {{ __('language.shift_category') }} </label>
                                {!! Form::select('category_id', create_select_options([], 'name', 'id', null), old('category_id', ($buddyShiftRequest['category_id'] ?? null)),  ['class' => 'form-control select-picker category-profession', 'id' => 'category_id', 'title' =>  __('language.shift_category'), 'data-url' => route('adminPanel.shift.getProfessions') ]) !!}
                            </div>

                            <div class="form-group col-md-3 profession-div">
                                <label> {{ __('language.shift_professions') }} </label>
                                {!! Form::select('profession_id', create_select_options([], 'name', 'id', null), old('profession_id', ($buddyShiftRequest['profession_id'] ?? null)),  ['class' => 'form-control select-picker profession-level', 'id' => 'profession_id', 'title' =>  __('language.shift_professions'), 'data-url' => route('adminPanel.professions.getLevels')]) !!}
                            </div>

                            {!! Form::hidden('current_time', '', ['class' => 'form-control', 'id' => 'current_time']) !!}

                            <div class="form-group col-md-3 level-div">
                                <label> {{ __('language.shift_level') }} </label>
                                {!! Form::select('hcp_level_id', create_select_options([], 'name', 'id', null), old('hcp_level_id', ($buddyShiftRequest['level_id'] ?? null)),  ['class' => 'hcp_level_id form-control select-picker', 'id' => 'hcp_level_id', 'title' =>  __('language.shift_level')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label> {{ __('language.start_time') }} </label>
                                {!! Form::text('start_time', '', ['class' => 'form-control start-time date-picker', 'id' => 'start_time', 'placeholder' => __('language.start_time')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label> {{ __('language.end_time') }} </label>
                                {!! Form::text('end_time', '', ['class' => 'form-control end-time  date-picker', 'id' => 'end_time', 'placeholder' => __('language.end_time')]) !!}
                            </div>

	 	<div class="form-group col-md-3 d-none sleepover_data">
                                <label> {{ __('language.sleepover_night_start_time') }} </label>
                                {!! Form::text('sleepover_night_start_time', '', ['class' => 'form-control sleepover_night_start_time date-picker', 'id' => 'sleepover_night_start_time', 'placeholder' => __('language.sleepover_night_start_time')]) !!}
                            </div>

                            <div class="form-group col-md-3 d-none sleepover_data">
                                <label> {{ __('language.sleepover_night_end_time') }} </label>
                                {!! Form::text('sleepover_night_end_time', '', ['class' => 'form-control sleepover_night_end_time  date-picker', 'id' => 'sleepover_night_end_time', 'placeholder' => __('language.sleepover_night_end_time')]) !!}
                            </div>

                            <div class="form-group col-md-3 d-none sleepover_data">
                                <label> {{ __('language.sleepover_start_time') }} </label>
                                {!! Form::text('sleepover_start_time', '', ['class' => 'form-control sleepover-start-time date-picker', 'id' => 'sleepover_start_time', 'placeholder' => __('language.sleepover_start_time')]) !!}
                            </div>

                            <div class="form-group col-md-3 d-none sleepover_data">
                                <label> {{ __('language.sleepover_end_time') }} </label>
                                {!! Form::text('sleepover_end_time', '', ['class' => 'form-control sleepover-end-time  date-picker', 'id' => 'sleepover_end_time', 'placeholder' => __('language.sleepover_end_time')]) !!}
                            </div>

                            <div class="form-group col-md-3 d-none sleepover_data">
                                <label> {{ __('language.sleepover_morning_start_time') }} </label>
                                {!! Form::text('sleepover_morning_start_time', '', ['class' => 'form-control sleepover_morning_start_time date-picker', 'id' => 'sleepover_morning_start_time', 'placeholder' => __('language.sleepover_morning_start_time')]) !!}
                            </div>

                            <div class="form-group col-md-3 d-none sleepover_data">
                                <label> {{ __('language.sleepover_morning_end_time') }} </label>
                                {!! Form::text('sleepover_morning_end_time', '', ['class' => 'form-control sleepover_morning_end_time  date-picker', 'id' => 'sleepover_morning_end_time', 'placeholder' => __('language.sleepover_morning_end_time')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label> {{ __('language.booked_by') }} </label>
                                {!! Form::text('booked_by', '', ['class' => 'form-control', 'id' => 'booked_by', 'placeholder' => __('language.booked_by')]) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label> {{ __('language.shift_types') }} </label>
                                {!! Form::text('shift_types', '', ['class' => 'form-control input-readonly-new text-capitalize', 'id' => 'shift_types', 'placeholder' => __('language.shift_types'), 'readonly']) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label> {{ __('language.break_time') }} </label>
                                {!! Form::text('break', '', ['class' => 'form-control input-readonly-new', 'id' => 'break', 'placeholder' => __('language.break_time'), 'readonly']) !!}
                            </div>

                            <div class="form-group col-md-3">
                                <label> {{ __('language.total_hours') }} </label>
                                {!! Form::text('hours', '', ['class' => 'form-control input-readonly-new', 'id' => 'hours', 'placeholder' => __('language.total_hours'), 'readonly']) !!}
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="col-md-6">
                                <div class="form-row">
                                    <div class="form-group col-md-6">
                                        <label> {{ __('language.shift_loading') }} </label>
                                        {!! Form::text('shift_loading', '', ['class' => 'form-control input-readonly-new', 'id' => 'shift_loading', 'placeholder' => __('language.shift_loading'), 'readonly']) !!}
                                    </div>

                                    <div class="form-group col-md-6">
                                        <label> {{ __('language.no_of_opening') }} </label>
                                        {!! Form::number('no_of_openings', '1', ['class' => 'form-control input-readonly-new', 'id' => 'no_of_openings', 'placeholder' => __('language.no_of_opening'), 'min' => 1, 'readonly' ]) !!}
                                    </div>

                                    <div class="form-group col-md-12">
                                        <label> {{ __('language.notes') }} </label>
                                        {!! Form::textarea('notes', '', ['class' => 'form-control address-textarea', 'id' => 'notes', 'placeholder' => __('language.notes')]) !!}
                                    </div>
                                </div>

                                {!! Form::hidden('shift_time', '', ['class' => 'form-control', 'id' => 'shift_time']) !!}
                                {!! Form::hidden('working_hours', '', ['class' => 'form-control', 'id' => 'working_hours']) !!}
                                {!! Form::hidden('hcp_amount', '', ['class' => 'form-control', 'id' => 'hcp_amount']) !!}
                                {!! Form::hidden('facility_amount', '', ['class' => 'form-control', 'id' => 'facility_amount']) !!}
                                {!! Form::hidden('admin_amount', '', ['class' => 'form-control', 'id' => 'admin_amount']) !!}
                                {!! Form::hidden('admin_fees', '', ['class' => 'form-control', 'id' => 'admin_fees']) !!}
                                {!! Form::hidden('facility_per_rate', '', ['class' => 'form-control', 'id' => 'facility_per_rate']) !!}
                                {!! Form::hidden('hcp_per_rate', '', ['class' => 'form-control', 'id' => 'hcp_per_rate']) !!}
                                {!! Form::hidden('admin_fees_with_loading', '', ['class' => 'form-control', 'id' => 'admin_fees_with_loading']) !!}
                                {!! Form::hidden('final_hours_time', '', ['class' => 'form-control', 'id' => 'final_hours_time']) !!}
                                {!! Form::hidden('total_hours_time', '', ['class' => 'form-control', 'id' => 'total_hours_time']) !!}
                                {!! Form::hidden('hcp_shift_loading', '', ['class' => 'form-control', 'id' => 'hcp_shift_loading']) !!}
                                {!! Form::hidden('hcp_shift_total_loading', '', ['class' => 'form-control', 'id' => 'hcp_shift_total_loading']) !!}
                                {!! Form::hidden('facility_shift_loading', '', ['class' => 'form-control', 'id' => 'facility_shift_loading']) !!}
                                {!! Form::hidden('facility_shift_total_loading', '', ['class' => 'form-control', 'id' => 'facility_shift_total_loading']) !!}

		{!! Form::hidden('sleepover_afternoon_admin_fees', '', ['class' => 'form-control', 'id' => 'sleepover_afternoon_admin_fees']) !!}
		{!! Form::hidden('sleepover_afternoon_loading', '', ['class' => 'form-control', 'id' => 'sleepover_afternoon_loading']) !!}
		{!! Form::hidden('sleepover_afternoon_working_hours', '', ['class' => 'form-control', 'id' => 'sleepover_afternoon_working_hours']) !!}
		{!! Form::hidden('sleepover_afternoon_faciliy_amount', '', ['class' => 'form-control', 'id' => 'sleepover_afternoon_faciliy_amount']) !!}
		{!! Form::hidden('sleepover_afternoon_hcp_amount', '', ['class' => 'form-control', 'id' => 'sleepover_afternoon_hcp_amount']) !!}

		{!! Form::hidden('sleepover_night_admin_fees', '', ['class' => 'form-control', 'id' => 'sleepover_night_admin_fees']) !!}
		{!! Form::hidden('sleepover_night_loading', '', ['class' => 'form-control', 'id' => 'sleepover_night_loading']) !!}
		{!! Form::hidden('sleepover_night_working_hours', '', ['class' => 'form-control', 'id' => 'sleepover_night_working_hours']) !!}
		{!! Form::hidden('sleepover_night_faciliy_amount', '', ['class' => 'form-control', 'id' => 'sleepover_night_facility_amount']) !!}
		{!! Form::hidden('sleepover_night_hcp_amount', '', ['class' => 'form-control', 'id' => 'sleepover_night_hcp_amount']) !!}

		{!! Form::hidden('sleepover_morning_admin_fees', '', ['class' => 'form-control', 'id' => 'sleepover_morning_admin_fees']) !!}
		{!! Form::hidden('sleepover_morning_loading', '', ['class' => 'form-control', 'id' => 'sleepover_morning_loading']) !!}
		{!! Form::hidden('sleepover_morning_working_hours', '', ['class' => 'form-control', 'id' => 'sleepover_morning_working_hours']) !!}
		{!! Form::hidden('sleepover_morning_faciliy_amount', '', ['class' => 'form-control', 'id' => 'sleepover_morning_faciliy_amount']) !!}
		{!! Form::hidden('sleepover_morning_hcp_amount', '', ['class' => 'form-control', 'id' => 'sleepover_morning_hcp_amount']) !!}
                            </div>

                            <div class="col-md-6" id="shift-estimates" data-url="{{ route('adminPanel.shift.calculatePrice') }}">
                                <label> Shift Estimates </label>
                                <div class="table-responsive">
                                    <table class="table" width="100%"  cellpadding="5">
                                        <tr>
                                            <th> {{ __('language.break_time') }} </th>
                                            <td class="break-time"> 0 </td>

                                            <th> {{ __('language.final_hours') }} </th>
                                            <td class="final-hour"> 0 </td>
                                        </tr>
                                        <tr>
                                            <th> {{ __('language.hcp_rate') }}  </th>
                                            <td class="hcp-rate"> 0 </td>

                                            <th> {{ __('language.admin_fees') }} </th>
                                            <td class="admin-fees"> 0 </td>
                                        </tr>
                                        <tr>
                                            <th> {{ __('language.facility_rate') }} </th>
                                            <td class="facility-rate"> 0 </td>

                                            <th> {{ __('language.shift_loading') }} </th>
                                            <td class="shift-loading"> 0 </td>
                                        </tr>
                                        <tr>
                                            <th> {{ __('language.hcp_shift_total') }} </th>
                                            <td class="hcp-shift-total"> 0 </td>

                                            <th> {{ __('language.facility_shift_total') }} </th>
                                            <td class="facility-shift-total"> 0 </td>
                                        </tr>
                                        <tr>
                                            <th> Sleepover Time </th>
                                            <td class="sleepover_time"> 0 </td>

                                            <th> HCP Sleepover Rate </th>
                                            <td class="hcp-sleepover-rate"> 0 </td>
                                        </tr>
			<tr>
			<th> Facility Sleepover Rate </th>
                                            <td class="facility-sleepover-rate"> 0 </td>
			</tr>
                                    </table>
		<button type="button" class="btn btn-info" data-toggle="collapse" data-target="#demo">Detatiled Calculations</button>
  			<div id="demo" class="collapse mt-3">
				Detatiled Calculations
 			 </div>
                                </div>
                            </div>
                        </div>

                        {{ Form::button( '<i class="fa fa-users"></i> &nbsp;'. __('language.shift_get_hcps'), ['class' => 'btn btn-primary btn-submit mt-4 mb-2 get-shift-hcp-bt', 'type' => 'button', 'id' => 'shift-get-hcps', 'data-url' => route('adminPanel.shift.getHcps')] )}}

{{--                        {{ Form::button('<i class="fa fa-save"></i> &nbsp;'. __('language.shift_submit_bt'), ['class' => 'btn btn-primary btn-submit mt-3', 'type' => 'submit', 'id' => 'shift-submit'] )}}--}}
                        {{ Form::button( '<i class="fa fa-users"></i> &nbsp;'. __('language.shift_submit_bt'), ['class' => 'btn btn-primary btn-submit mt-3 shift-submit-btn', 'type' => 'button', 'id' => 'shift-submit-btn', 'data-url' => route('adminPanel.shift.checkForProfessionLevel')] )}}
                        <div class="hcp-listing"></div>
                        <div class="form-group col-md-12">
                            {!! Form::hidden('hcp_ids', '', ['class' => 'form-control', 'id' => 'hcp_ids']) !!}
                        </div>

                        <!-- Modal -->
                        <div class="modal fade" id="multipleShiftModal" tabindex="-1" role="dialog" aria-labelledby="pageModalLabel" aria-hidden="true">
                            <div class="modal-dialog modal-lg" role="document">
                                <div class="modal-content" id="">
                                    <div class="modal-header">
                                        <h5 class="modal-title"> {{ __('language.multiple_shifts') }} </h5>
                                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                            <i class="fa fa-close"></i>
                                        </button>
                                    </div>
                                    <div class="modal-body">

                                        <div class="row">
                                            <div class="col-md-6">
                                                <label for="word_wing"> {{ __('language.word_wing') }} </label>
                                            </div>
                                            <div class="col-md-6">
                                                <label for="no_of_opening"> {{ __('language.no_of_opening') }} </label>
                                            </div>
                                        </div>
                                        @for ($i = 1; $i <= 10; $i++)
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    {!! Form::text('multiple_shifts['.$i.'][word_wing]', '', ['class' => 'form-control', 'id' => 'word-wing-'.$i, 'placeholder' => __('language.word_wing')]) !!}
                                                </div>
                                            </div>

                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    {!! Form::number('multiple_shifts['.$i.'][no_of_opening]', '', ['class' => 'form-control', 'id' => 'no-of-opening-'.$i, 'placeholder' => __('language.no_of_opening'), 'min' => 1, 'max' => 10, 'onblur' => 'multipleShiftNumberofOpeningCount()']) !!}
                                                </div>
                                            </div>
                                        </div>
                                        @endfor

                                    </div>
                                    <div class="modal-footer">
                                        <button class="btn btn-dark" data-dismiss="modal">Save</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <!-- / Modal -->

                        {{-- Form::button('<i class="fa fa-save"></i> &nbsp;'. __('language.shift_submit_bt'), ['class' => 'btn btn-primary btn-submit hide mt-2', 'type' => 'submit', 'id' => 'shift-submit'] )--}}
                    </div>
                </div>
                {!! Form::close() !!}
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script>
    var TIME_LOADING = JSON.parse(@json("$loadingTimeConfiguration"));
    var GENERAL_CONFIGURATION = JSON.parse(@json("$generalConfiguration"));
    var MIN_SHIFT_HOURS = GENERAL_CONFIGURATION['min_shift_booking_hours'];
    var MAX_SHIFT_HOURS = GENERAL_CONFIGURATION['max_shift_booking_hours'];
    var DEFAULT_SHIFT_HOURS = GENERAL_CONFIGURATION['default_hours_shift'];

    function multipleShiftNumberofOpeningCount(){
        var totVal = 0;
        var totValNe = 0;
        var loop = 10;
        var wardTextboxLength = 0;
        var openingTextboxLength = 0;

        if($("#no-of-opening-1").val() != '' && $("#word-wing-1").val() != ''){
            for (let i = 1; i <= loop; i++) {
                totVal = parseInt($("#no-of-opening-"+i).val());
                if ($("#no-of-opening-"+i).val() !='') {
                    wardTextboxLength += $("#no-of-opening-"+i).length;
                }

                if($("#word-wing-"+i).val() !='') {
                    openingTextboxLength += $("#word-wing-"+i).length;
                }

                if(Number.isInteger(totVal)){
                    totValNe += totVal;
                }
            }
        }

        if (totValNe !=0) {
            $("#no_of_openings").val(totValNe);
            $("#word_wing").prop("disabled", true);
            $("#word_wing").val('');
            $('.hcp-list-assign-button').addClass('hide');
            $('.hcp-list-assign-button-na').removeClass('hide');
        } else {
            $("#no_of_openings").val(1);
            $("#word_wing").prop("disabled", false);
            $('.hcp-list-assign-button').removeClass('hide');
            $('.hcp-list-assign-button-na').addClass('hide');

            for (let i = 1; i <= loop; i++) {
                $("#no-of-opening-"+i).val('');
                $("#word-wing-"+i).val('');
            }
        }
    }

    $("#multipleShiftModal").on("hidden.bs.modal", function() {
        var loop = 10;
        var wardTextboxLength = 0;
        var openingTextboxLength = 0;

        if($("#no-of-opening-1").val() != '' && $("#word-wing-1").val() != ''){
            for (let i = 1; i <= loop; i++) {
                if ($("#no-of-opening-"+i).val() !='') {
                    wardTextboxLength += $("#no-of-opening-"+i).length;
                }

                if($("#word-wing-"+i).val() !='') {
                    openingTextboxLength += $("#word-wing-"+i).length;
                }
            }
        }

        if($("#no-of-opening-1").val() == '' && $("#word-wing-1").val() == ''){
            $('.multiple-shifts').prop('checked', false);
            $("#no_of_openings").val(1);
            $("#word_wing").prop("disabled", false);
            $('.hcp-list-assign-button').removeClass('hide');
            $('.hcp-list-assign-button-na').addClass('hide');
            $('.multiple-shifts-error').removeClass('hide');
            for (let i = 1; i <= loop; i++) {
                $("#no-of-opening-"+i).val('');
                $("#word-wing-"+i).val('');
            }
        } else if(wardTextboxLength != openingTextboxLength) {
            $('.multiple-shifts').prop('checked', false);
            $("#no_of_openings").val(1);
            $("#word_wing").prop("disabled", false);
            $('.hcp-list-assign-button').removeClass('hide');
            $('.hcp-list-assign-button-na').addClass('hide');
            $('.multiple-shifts-error').removeClass('hide');
            for (let i = 1; i <= loop; i++) {
                $("#no-of-opening-"+i).val('');
                $("#word-wing-"+i).val('');
            }
        } else {
            $('.multiple-shifts-error').addClass('hide');
        }
    });
    $(document).on('change','#sleepover_shifts',function(){
        if($('#sleepover_shifts:checkbox:checked').length > 0){
            $(".sleepover_data").removeClass('d-none');
        }else{
            $(".sleepover_data").addClass('d-none');
        }
    });
</script>
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
{{--<script src="{{ asset('admin-assets/js/shift/shift.js') }}"></script>--}}
<script src="{{ asset('admin-assets/js/shift/shift.js') }}?v={{ time() }}"></script>
<script src="{{ asset('admin-assets/js/elements/popovers.js') }}"></script>
@endpush
