@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.edit_shifts_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">

            <!-- Validation error -->
            @component('admin-panel.validation.errors') @endcomponent
            <!-- / Validation error -->

            <div class="alert alert-danger mb-4 hide" role="alert" id="shift-error-div">
                <button type="button" class="close" data-dismiss="alert" aria-label="Close"> <i data-feather="x" class="feather-16"></i> </button>
                <strong>Error!</strong>
                <div class="error-msg"> </div>
            </div>

            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <h5> {{ __('language.edit_shifts_page_title') }} </h5>
                        </div>
                    </div>

                    <div class="form p-3">
                        {!! Form::open(['class'=> 'add-shift-form', 'method' => 'post', 'url' => route('adminPanel.shift.update', ['id' => ev($shift->id)]), 'files'=> true])!!}
                            <div class="form-row">
                                @php
                                    if (!empty($authUser->facility)) {
                                        $facility = $authUser->facility;
                                    } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                                        $facility = $authUser->sub_admin->facility;
                                    } else {
                                        $facility = null;
                                    }
                                @endphp

                                {!! Form::hidden('facility_group', old('facility_group', ($facility->facility_group_id ?? null)), ['class' => 'form-control', 'id' => 'facility_group', 'placeholder' => __('language.shift_facility_group')]) !!}

                                {!! Form::hidden('facility', old('facility', ($facility->id ?? null)), ['class' => 'form-control', 'id' => 'facility', 'placeholder' => __('language.shift_facility')]) !!}


                                <div class="form-group col-md-3">
                                    <label> {{ __('language.shift_category') }} </label>
                                    {!! Form::select('category_id', create_select_options($categories, 'name', 'id', null), old('category_id', ($shift['category_id'] ?? null)),  ['class' => 'form-control select-picker category-profession', 'id' => 'category_id', 'title' =>  __('language.shift_category'), 'data-url' => route('adminPanel.shift.getProfessions') ]) !!}
                                </div>

                                <div class="form-group col-md-3 profession-div">
                                    <label> {{ __('language.shift_professions') }} </label>
                                    {!! Form::select('profession_id', create_select_options($professions, 'name', 'id', null), old('profession_id', ($shift['profession_id'] ?? null)),  ['class' => 'form-control select-picker profession-level', 'id' => 'profession_id', 'title' =>  __('language.shift_professions'), 'data-url' => route('adminPanel.professions.getLevels')]) !!}
                                </div>

                                <div class="form-group col-md-3 level-div">
                                    <label> {{ __('language.shift_level') }} </label>
                                    {!! Form::select('hcp_level_id', create_select_options($levels, 'name', 'id', null), old('hcp_level_id', ($shift['hcp_level_id'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'hcp_level_id', 'title' =>  __('language.shift_level')]) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label for="word_wing"> {{ __('language.word_wing') }} </label>
                                    {!! Form::text('word_wing', old('word_wing', ($shift['word_wing'] ?? null)), ['class' => 'form-control', 'id' => 'word_wing', 'placeholder' => __('language.word_wing')]) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.booked_by') }} </label>
                                    {!! Form::text('booked_by', old('booked_by', ($shift['booked_by'] ?? null)), ['class' => 'form-control', 'id' => 'booked_by', 'placeholder' => __('language.booked_by')]) !!}
                                </div>

                                {!! Form::hidden('current_time', Carbon\Carbon::now($facility->state->time_zone_name)->format('Y-m-d h:i a'), ['class' => 'form-control', 'id' => 'current_time']) !!}

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.start_time') }} </label>
                                    {!! Form::text('start_time', old('start_time', ($shift['start_time'] ?? null)), ['class' => 'form-control start-time date-picker', 'id' => 'start_time', 'placeholder' => __('language.start_time')]) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.end_time') }}  </label>
                                    {!! Form::text('end_time', old('end_time', ($shift['end_time'] ?? null)), ['class' => 'form-control end-time  date-picker', 'id' => 'end_time', 'placeholder' => __('language.end_time')]) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.shift_types') }} </label>
                                    {!! Form::text('shift_types', old('shift_type', ($shift['shift_type'] ?? null)), ['class' => 'form-control input-readonly-new text-capitalize', 'id' => 'shift_types', 'placeholder' => __('language.shift_types'), 'readonly']) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.break_time') }} </label>
                                    {!! Form::text('break', old('break', ($shift['break'] ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'break', 'placeholder' => __('language.break_time'), 'readonly']) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.total_hours') }} </label>
                                    {!! Form::text('hours', old('hours', ($shift['hours'] ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'hours', 'placeholder' => __('language.total_hours'), 'readonly']) !!}
                                </div>


                                <div class="form-group col-md-3">
                                    <label> {{ __('language.shift_loading') }} </label>
                                    {!! Form::text('shift_loading', old('shift_loading', ($shift['shift_loading'] ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'shift_loading', 'placeholder' => __('language.shift_loading'), 'readonly']) !!}
                                </div>

                                <div class="form-group col-md-3">
                                    <label> {{ __('language.no_of_opening') }} </label>
                                    {!! Form::number('no_of_openings', old('no_of_openings', ($shift['no_of_openings'] ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'no_of_openings', 'placeholder' => __('language.no_of_opening'), 'min' => 1 , 'max' => 10, 'readonly']) !!}
                                </div>


                                @if (!empty($shift) && $shift['shift_type'] == 'buddy')
                                    <div class="form-group col-md-3">
                                        <label> {{ __('language.buddy_name') }} </label>
                                        @php
                                            if (!empty($buddyShiftRequest['buddy_hcp'])) {
                                                $buddyHcpName = $buddyShiftRequest['buddy_hcp']->hcp_prefix . $buddyShiftRequest['buddy_hcp']->id.' - '.$buddyShiftRequest['buddy_hcp']['first_name'].' '.$buddyShiftRequest['buddy_hcp']['last_name'];
                                                $buddyHcpId = $buddyShiftRequest['buddy_hcp']['id'];
                                            } else {
                                                $buddyHcpName = '';
                                                $buddyHcpId = '';
                                            }
                                        @endphp

                                        <select name="buddy_hcp_id" id="buddy_hcp_id" class="form-control select-picker" title="{{__('language.buddy_name')}}">
                                            @if (!empty($hcps))
                                                @foreach ($hcps as $hcp)
                                                <option value="{{$hcp->id}}" data-subtext="{{$hcp->hcp_prefix.$hcp->id}}" {{ ($shift->buddy_hcp_id == $hcp->id ? 'selected' : '') }}>{{$hcp->first_name.' '.$hcp->last_name}}</option>
                                                @endforeach
                                            @endif
                                        </select>

                                        {!! Form::hidden('buddy_hcp_id', old('buddy_hcp_id', ($buddyHcpId ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'buddy_hcp_id', 'placeholder' => 'Buddy Hcp Id', 'readonly']) !!}

                                        {!! Form::hidden('buddy_request_id', old('buddy_request_id', ($buddyShiftRequest->id ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'buddy_request_id', 'placeholder' => 'Buddy Hcp Id', 'readonly']) !!}
                                    </div>
                                @else
                                    <div class="form-group col-md-3 buddy-hcp-div hide">
                                        <label> {{ __('language.buddy_name') }} </label>
                                        {!! Form::select('buddy_hcp_id', create_select_options([], 'name', 'id', null), 'buddy',  ['class' => 'form-control select-picker', 'id' => 'buddy_hcp_id', 'title' =>  __('language.buddy_name') ]) !!}
                                    </div>
                                @endif
                            </div>

                            <div class="form-row">
                                <div class="col-md-6">
                                    <div class="form-row">
                                        <div class="form-group col-md-12">
                                            <label> {{ __('language.notes') }} </label>
                                            {!! Form::textarea('notes', old('notes', ($shift['notes'] ?? null)), ['class' => 'form-control address-textarea', 'id' => 'notes', 'placeholder' => __('language.notes')]) !!}
                                        </div>
                                    </div>

                                    {!! Form::hidden('shift_time', old('shift_time', ($shift['shift_time'] ?? null)), ['class' => 'form-control', 'id' => 'shift_time']) !!}
                                    {!! Form::hidden('working_hours', old('working_hours', ($shift['working_hours'] ?? null)), ['class' => 'form-control', 'id' => 'working_hours']) !!}
                                    {!! Form::hidden('hcp_amount', old('hcp_amount', ($shift['hcp_amount'] ?? null)), ['class' => 'form-control', 'id' => 'hcp_amount']) !!}
                                    {!! Form::hidden('facility_amount', old('facility_amount', ($shift['facility_amount'] ?? null)), ['class' => 'form-control', 'id' => 'facility_amount']) !!}
                                    {!! Form::hidden('admin_fees', old('admin_fees', ($shift['admin_fees'] ?? null)), ['class' => 'form-control', 'id' => 'admin_fees']) !!}
                                    {!! Form::hidden('facility_per_rate', old('facility_per_rate', ($shift['facility_per_rate'] ?? null)), ['class' => 'form-control', 'id' => 'facility_per_rate']) !!}
                                    {!! Form::hidden('hcp_per_rate', old('hcp_per_rate', ($shift['hcp_per_rate'] ?? null)), ['class' => 'form-control', 'id' => 'hcp_per_rate']) !!}
                                    {!! Form::hidden('admin_fees_with_loading', '', ['class' => 'form-control', 'id' => 'admin_fees_with_loading']) !!}
                                    {!! Form::hidden('final_hours_time', '', ['class' => 'form-control', 'id' => 'final_hours_time']) !!}
                                    {!! Form::hidden('total_hours_time', '', ['class' => 'form-control', 'id' => 'total_hours_time']) !!}
                                    {!! Form::hidden('hcp_shift_loading', '', ['class' => 'form-control', 'id' => 'hcp_shift_loading']) !!}
                                    {!! Form::hidden('hcp_shift_total_loading', '', ['class' => 'form-control', 'id' => 'hcp_shift_total_loading']) !!}
                                    {!! Form::hidden('facility_shift_loading', '', ['class' => 'form-control', 'id' => 'facility_shift_loading']) !!}
                                    {!! Form::hidden('facility_shift_total_loading', '', ['class' => 'form-control', 'id' => 'facility_shift_total_loading']) !!}
                                </div>

                                <div class="col-md-6" id="shift-estimates" data-url="{{ route('adminPanel.shift.calculatePrice') }}">
                                    <label> Shift Estimates </label>
                                    <div class="table-responsive">
                                        <table class="table" width="100%"  cellpadding="5">
                                            <tr>
                                                <th> {{ __('language.break_time') }} </th>
                                                <td class="break-time"> {{ $shift['break'] ?? 0 }} </td>

                                                <th> {{ __('language.final_hours') }} </th>
                                                <td class="final-hour"> {{ $shift['working_hours'] ?? 0 }} </td>
                                            </tr>
                                            <tr>
                                                <th> {{ __('language.hcp_rate') }}  </th>
                                                <td class="hcp-rate"> {{ $shift['hcp_per_rate'] ?? 0 }} </td>

                                                <th> {{ __('language.admin_fees') }} </th>
                                                <td class="admin-fees"> {{ $shift['admin_fees'] ?? 0 }} </td>
                                            </tr>
                                            <tr>
                                                <th> {{ __('language.facility_rate') }} </th>
                                                <td class="facility-rate"> {{ $shift['facility_per_rate'] ?? 0 }} </td>

                                                <th> {{ __('language.shift_loading') }} </th>
                                                <td class="shift-loading"> {{ $shift['shift_loading'] ?? 0 }} </td>
                                            </tr>
                                            <tr>
                                                @if ($authUser->hasRole('Super Admin') == true || $authUser->hasRole('Sub Admin') == true)
                                                    <th> {{ __('language.hcp_shift_total') }} </th>
                                                    <td class="hcp-shift-total"> {{ $shift['hcp_amount'] ?? 0 }} </td>

                                                    <th> {{ __('language.facility_shift_total') }} </th>
                                                    <td class="facility-shift-total"> {{ $shift['facility_amount'] ?? 0 }} </td>
                                                @else
                                                    <th> {{ __('language.facility_shift_total') }} </th>
                                                    <td colspan="3" class="facility-shift-total"> {{ $shift['facility_amount'] ?? 0 }} </td>
                                                @endif
                                            </tr>
                                        </table>
                                    </div>
                                </div>
                            </div>
                            {{ Form::button( '<i class="fa fa-save"></i> &nbsp;'. __('language.update'), ['class' => 'btn btn-primary btn-submit', 'type' => 'submit'] )}}
                        {!! Form::close() !!}
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script>
    var TIME_LOADING = JSON.parse(@json("$loadingTimeConfiguration"));
    var GENERAL_CONFIGURATION = JSON.parse(@json("$generalConfiguration"));
    var MIN_SHIFT_HOURS = GENERAL_CONFIGURATION['min_shift_booking_hours'];
    var MAX_SHIFT_HOURS = GENERAL_CONFIGURATION['max_shift_booking_hours'];
    var DEFAULT_SHIFT_HOURS = GENERAL_CONFIGURATION['default_hours_shift'];
</script>
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/shift/shift.js') }}"></script>
@endpush
