@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.shifts').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/forms/theme-checkbox-radio.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
    <div class="row layout-top-spacing">
        <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
            <div class="widget-content widget-content-area br-6">
                <div class="container-fluid mt2">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                            <h5>Shift Notifications</h5>
                        </div>
                    </div>

                    <div>
                        {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                        route('adminPanel.shift.viewAllShiftNotification', ['id' => $shiftId]),  'id' => 'shift-filter-form']) !!}
                        <div class="row pl-3 mt-3">
                            <div class="col-md-8">
                                <div class="float-left">
                                    <label> {{ __('language.table_result') }} </label>
                                    {!! Form::select('shift_per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('shift_per_page', ($request['shift_per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                                </div>

                                <div class="float-left pl-2 search-box">
                                    {!! Form::text('shift_hcp_search', old('shift_hcp_search', ($request['shift_hcp_search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                                    <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#shift-filter-form').submit();"></i> </span>
                                </div>
                                <div class="clearfix"></div>
                            </div>

                        </div>
                        {!! Form::close() !!}
                    </div>
                </div>

                <div class="container-fluid page-heading">
                    <div class="table-responsive pb-5">
                        <table class="table mb-4 mt-3">
                            <thead>
                            <tr>
                                <th> {{ __('language.shift_id') }} </th>
                                <th> Hcp </th>
                                <th> Title </th>
                                <th> Message </th>
                                <th> Shift Broadcast Type </th>
                                <th> Time </th>
                            </tr>
                            </thead>
                            <tbody>
                            @forelse($notifications as $notification)
                                <tr>
                                    <td>
                                        <a href="{{ route('adminPanel.shift.details', ['id' => ev($notification->shift_id)]) }}">
                                            {{ $notification->shift->shift_prefix . $notification->shift->id }}
                                        </a>
                                    </td>
                                    <td>
                                        @if (!empty($notification->hcp))
                                            {{ $notification->hcp->first_name.' '.$notification->hcp->last_name }}
                                        @endif
                                    </td>
                                    <td>
                                        {{ $notification->title }}
                                    </td>
                                    <td>
                                        {{ $notification->message }}
                                    </td>
                                    <td>
                                        {{ ucwords($notification->shift_broadcast_type ?? 'N/A') }}
                                    </td>

                                    @php
                                        $time = Carbon\Carbon::parse($notification->created_at);
                                    @endphp
                                    <td> {{ $time->format('d M Y h:i:s A') }} </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="15" class="text-center"> {{ __('language.no_record_found') }} </td>
                                </tr>
                            @endforelse
                            </tbody>
                        </table>

                        <div class="pagination">
                            {{ $notifications->appends($request)->render() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/shift/view.js') }}"></script>
@endpush
