@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.edit_sub_admins_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/plugins/dropify/dropify.css') }}" rel="stylesheet">
<link href="{{ asset('admin-assets/css/flatpickr.min.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">

        <!-- Validation error -->
        @component('admin-panel.validation.errors') @endcomponent
        <!-- / Validation error -->

        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                        <h5> {{ __('language.edit_sub_admins_page_title') }} </h5>
                    </div>
                </div>

                <div class="form p-3">
                    {!! Form::open(['class' => 'add-sub-admins-form', 'method' => 'post', 'url' =>  route('adminPanel.sub-admins.update', ['id' => ev($subAdmin->id)]), 'files' => true ]) !!}

                        <div class="form-row">
                            <div class="col-md-8">
                                <div class="form-row mb-2">
                                    <div class="form-group col-md-6">
                                        <label for="name"> {{ __('language.sub_admins_name') }} </label>
                                        {!! Form::text('name', old('name', ($subAdmin->name ?? null)), ['class' => 'form-control', 'id' => 'name', 'placeholder' => __('language.sub_admins_name')]) !!}
                                    </div>

                                    <div class="form-group col-md-6">
                                        <label for="username"> {{ __('language.sub_admins_username') }} </label>
                                        {!! Form::text('username', old('username', ($subAdmin->username ?? null)), ['class' => 'form-control', 'id' => 'surname', 'placeholder' => __('language.sub_admins_username')]) !!}
                                    </div>
                                </div>

                                <div class="form-row mb-2">
                                    <div class="form-group col-md-6">
                                        <label for="email"> {{ __('language.sub_admins_email') }} </label>
                                        {{-- Form::email('email', old('email', ($subAdmin->user->email ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'email', 'placeholder' => __('language.sub_admins_email'), 'readonly', 'data-url' => route('adminPanel.sub-admins.checkUserEmail', ['id' => $subAdmin->user->id])]) --}}

                                        {!! Form::email('email', old('email', ($subAdmin->user->email ?? null)), ['class' => 'form-control input-readonly-new', 'id' => 'email', 'placeholder' => __('language.sub_admins_email'), 'data-url' => route('adminPanel.sub-admins.checkUserEmail', ['id' => $subAdmin->user->id])]) !!}
                                    </div>

                                    <div class="form-group col-md-6">
                                        <label for="contact_number"> {{ __('language.sub_admins_contact_no') }} </label>
                                        {!! Form::text('contact_number', old('contact_number', ($subAdmin->contact_number ?? null)), ['class' => 'form-control', 'id' => 'contact_no', 'placeholder' => __('language.sub_admins_contact_no')]) !!}
                                    </div>

                                    <div class="form-group col-md-6">
                                        <label for="status"> {{ __('language.sub_admins_status') }} </label>
                                        {!! Form::select('status', create_select_options(config('constants.sub_admins_status'), 'caption', 'value',  null), old('status', ($subAdmin->status ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status', 'title' => __('language.sub_admins_status')]) !!}
                                    </div>
                                </div>
                            </div>

                            <div class="col-md-4">
                                <div class="form-group custom-dropify text-center">
                                @if (!empty($subAdmin->image) )
                                    @php $image = get_file_url(config('constants.sub_admins.sub_admins_path') . $subAdmin->sub_admin_prefix .
                                    $subAdmin->id . '/image/',
                                    $subAdmin->image); @endphp
                                    @else
                                    @php $image = asset('admin-assets/images/user.png'); @endphp
                                    @endif
                                    {!! Form::file('image', ['class' => 'image-preview', 'id' => 'image', 'autocomplete' =>
                                    'off', 'data-show-remove' => 'false', 'accept' => 'image/*', "data-default-file" =>
                                    $image ]) !!}
                                    <label for="name"> {{ __('language.sub_admins_upload_image') }} </label>
                                </div>
                            </div>
                        </div>

                        @if ($authUser->hasRole('Facility Group'))
                            <div class="mb-4">
                                <h6 class="mb-2 text-primary"> {{ __('language.assign') }} {{ __('language.facilities') }} </h6>
                                <hr>

                                <div class="form-row">
                                    @if ( !empty($facilities) )
                                        @php
                                           $fac_arr = json_decode($subAdmin->assigned_facilities);
                                        @endphp
                                        <div class="col-md-2">
                                            <div class="form-group">
                                                {!! Form::select('facility[]', create_select_options($facilities, 'name', 'id',  NULL), old('facility', ($fac_arr ?? null)),  ['class' => 'form-control select-picker', 'id' => 'facility','multiple' => 'multiple' ]) !!}
                                            </div>
                                        </div>
                                    @else
                                    <div class="col-md-12">
                                        No record found...
                                    </div>
                                    @endif
                                </div>
                                <div id="permissions_error" class="mb-4"></div>
                            </div>
                        @else
                            <div class="mb-4">
                                <h6 class="mb-2 text-primary"> {{ __('language.sub_admins_permissions') }} </h6>
                                <hr>

                                <div class="form-row">
                                    @if ( !empty($permissions) )
                                        @foreach($permissions as $key => $permission)
                                        <div class="col-md-12">
                                            <div class="">
                                                <div class="form-row">
                                                    <div class="form-group col-md-3">
                                                        <label class="text-primary"> {{ ucwords(str_replace('-', ' ', $key)) }} </label>
                                                    </div>
                                                    @foreach ($permission as $item)
                                                        <div class="form-group col-md-3">
                                                            <div class="n-chk permission-group">
                                                                <label class="new-control new-checkbox checkbox-primary text-dark {{$item['slug']}}-class">
                                                                    {!! Form::checkbox('permission[]',  $item['id'], $userPermissions->contains($item['id']), ['class' => 'new-control-input permission-checkbox' , 'id' => $item['slug'], 'data-permission' => $item['slug']  ]) !!}
                                                                    <span class="new-control-indicator"></span>{{  $item['name'] }}
                                                                </label>
                                                            </div>
                                                        </div>
                                                    @endforeach
                                                </div>
                                            </div>
                                        </div>
                                        @endforeach
                                    @else
                                    <div class="col-md-12">
                                        No record found...
                                    </div>
                                    @endif
                                </div>
                                <div id="permissions_error" class="mb-4"></div>
                            </div>
                        @endif
                        {{ Form::button( '<i class="fa fa-save"></i> &nbsp;'. __('language.update'), ['class' => 'btn btn-primary btn-submit', 'type' => 'submit'] )}}

                    {!! Form::close() !!}
                </div>
            </div>

        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/plugins/dropify/dropify.min.js') }}"></script>
<script src="{{ asset('admin-assets/js/flatpickr.js') }}"></script>
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/sub-admins/sub-admins.js') }}"></script>
@endpush
