@extends('admin-panel.layouts.main-layout')

@section('page-title', ' '.__('language.sub_admins_page_title').' ')

@push('styles')
<link href="{{ asset('admin-assets/css/plugins/table/datatable/dt-global_style.css') }}" rel="stylesheet">
@endpush

@section('content')
<div class="row layout-top-spacing">
    <div class="col-xl-12 col-lg-12 col-md-12 col-12 layout-spacing">
        <div class="widget-content widget-content-area br-6">
            <div class="container-fluid mt2">
                <div class="row">
                    <div class="col-xl-8 col-lg-8 col-md-8 col-8 page-heading">
                        <h5>{{ __('language.sub_admins_page_title') }}</h5>
                    </div>

                    <div class="col-xl-4 col-lg-4 col-md-4 col-4 text-right">
                        @if ($authUser->can('Add Sub Admins') || $authUser->can('Facility Add Sub Admins'))
                        <a href="{{ route('adminPanel.sub-admins.create') }}" class="btn btn-primary btn-sm mr-1">
                            {{ __('language.add_button') }}
                        </a>
                        @endif

                        @if (!empty($request))
                            @php $filterApply = 'filter-icon-apply'; @endphp
                        @else
                            @php $filterApply = 'filter-icon'; @endphp
                        @endif
                        <button type="button" class="btn btn-sm filter-button btn-primary {{$filterApply}}">
                            <i class="fa fa-filter"></i>
                        </button>
                    </div>
                </div>

                <div>
                {!! Form::open(['class' => 'custom-datatable-filter-form', 'method' => 'get', 'url' =>
                route('adminPanel.sub-admins.index'), 'id' => 'filter-form']) !!}
                <div class="row">
                    <div class="col-md-12">
                        <div class="custom-datatable-filter hide">
                            <div class="row">
                                <div class="col-md-12">
                                    <h6 class="text-primary"> {{ __('language.filters') }} </h6>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-3">
                                    <div class="form-group">
                                        {!! Form::select('status', create_select_options(config('constants.sub_admins_status'), 'caption', 'value',  __('language.sub_admins_status')), old('status', ($request['status'] ?? null)),  ['class' => 'form-control select-picker', 'id' => 'status']) !!}
                                    </div>
                                </div>
                                <div class="col-md-12">
                                    <div class="filter-error invalid-feedback"> {{ __('messages.filter_apply_error')}} </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-4 mb2">
                                    {{ Form::button( __('language.filter_apply'), ['class' => 'btn btn-sm btn-primary apply-filter', 'type' => 'button'] )}}
                                    {{ Form::button( __('language.filter_clear'), ['class' => 'btn btn-sm  btn-custom-outline clear-filter', 'type' => 'button'] )}}
                                </div>
                            </div>
                            <div class="filter-border"></div>
                        </div>
                    </div>
                </div>

                <div class="row pl-3 mt-3">
                    <div class="col-md-8">
                        <div class="float-left">
                            <label> {{ __('language.table_result') }} </label>
                            {!! Form::select('per_page', create_select_options(config('constants.per_page_limit'), 'caption', 'value',  null), old('per_page', ($request['per_page'] ?? config('constants.pagination_limit'))),  ['class' => 'form-control result-selectbox', 'id' => 'per_page', "onchange" => "this.form.submit()",]) !!}
                        </div>

                        <div class="float-left pl-2 search-box">
                            {!! Form::text('search', old('search', ($request['search'] ?? null)), ['class' => 'form-control', 'id' => 'search', 'placeholder' => __('language.table_search')]) !!}
                            <span class="search-btn"> <i data-feather="search" class="feather-16" onclick="$('#filter-form').submit();"></i> </span>
                        </div>
                        <div class="clearfix"></div>
                    </div>

                    <div class="col-md-4 text-right">
                        <a class="btn btn-sm btn-custom-outline" href="{{route('adminPanel.sub-admins.export', ['request' => $request])}}">
                            Excel &nbsp;  <i data-feather="download" class="feather-16"></i>
                        </a>
                    </div>
                </div>
                {!! Form::close() !!}
                </div>

            </div>

            <div class="container-fluid page-heading">
                <div class="table-responsive  pb-5">
                    <table class="table mb-4 mt-3" id="dataTable-favourite-hcp">
                        <thead>
                            <tr>
                                <th> {{ __('language.table_sub_admins_id') }} </th>
                                <th> {{ __('language.table_sub_admins_name') }} </th>
                                <th> {{ __('language.table_sub_admins_added_on') }} </th>
                                @if($authUser->hasRole('Facility Group'))
                                <th> {{ __('language.assigned') }} {{ __('language.facilities') }} </th>
                                @else
                                <th> {{ __('language.table_sub_admins_permissions') }} </th>
                                @endif
                                <th> {{ __('language.table_sub_admins_email') }} </th>
                                <th> {{ __('language.table_sub_admins_contact_number') }} </th>
                                <th> {{ __('language.table_status') }} </th>
                                <th> {{ __('language.table_action') }} </th>
                            </tr>
                        </thead>
                        <tbody>
                            @if (count($subAdmins))
                                @foreach ($subAdmins as $subAdmin)
                                    <tr>
                                        <td>
                                            <a href="{{ route('adminPanel.sub-admins.details', ['id' => ev($subAdmin->id)]) }}">
                                                {{  $subAdmin->sub_admin_prefix . $subAdmin->id }}
                                            </a>
                                        </td>
                                        <td> {{ ucwords($subAdmin->name) }} </td>
                                        <td> {{ date("d M Y", strtotime($subAdmin->created_at)) }} </td>
                                        <td>
                                            @if($authUser->hasRole('Facility Group'))
                                                {{$subAdmin->assigned_facilities}}
                                            @else
                                                @if (!empty($subAdmin->user->getPermissionNames()))
                                                    @foreach ($subAdmin->user->getPermissionNames() as $permissions)
                                                        {{ $permissions.',' }}
                                                    @endforeach
                                                @endif
                                            @endif
                                        </td>
                                        <td> {{ $subAdmin->user->email }} </td>
                                        <td> {{ $subAdmin->contact_number }} </td>
                                        <td>
                                            @if ($subAdmin->status == 'inactive')
                                                <div class="text-warning font-weight-bold">{{ __("language.inactive") }}</div>
                                            @else
                                                <div class="text-success font-weight-bold">{{ __("language.active") }}</div>
                                            @endif
                                        </td>
                                        <td>
                                            <ul class="datatable-action">
                                                <li>
                                                    <div class="dropdown custom-dropdown-icon">
                                                        <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink-4" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                            <i class="fa fa-ellipsis-h" aria-hidden="true"></i>
                                                        </a>
                                                        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdownMenuLink-4">

                                                            @if ($authUser->can('Edit Sub Admins') || $authUser->can('Facility Edit Sub Admins'))
                                                            <a href="{{ route('adminPanel.sub-admins.edit', ['id' => ev($subAdmin->id)]) }}" class="dropdown-item"> {{ __("language.edit") }} </a>
                                                            @endif

                                                            <a href="{{ route('adminPanel.sub-admins.details', ['id' => ev($subAdmin->id)]) }}" class="dropdown-item"> {{ __("language.details") }} </a>

                                                            @if ($subAdmin->status == 'inactive')
                                                                <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.sub-admins.changeStatus', ['id' => ev($subAdmin->id), 'status' => 'active','page' => 'listing']) }}"> {{ __("language.active") }} </a>
                                                            @else
                                                                <a href="#" class="dropdown-item link-action" data-url="{{ route('adminPanel.sub-admins.changeStatus', ['id' => ev($subAdmin->id), 'status' => 'inactive','page' => 'listing']) }}"> {{ __("language.inactive") }} </a>
                                                            @endif
                                                        </div>
                                                    </div>
                                                </li>
                                            </ul>
                                        </td>
                                    </tr>
                                @endforeach
                            @else
                                <tr>
                                    <td colspan="12" class="text-center"> No record found...</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>

                    <div class="pagination">
                        {{ $subAdmins->appends($request)->render() }}
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@push('scripts')
<script src="{{ asset('admin-assets/js/components.js') }}"></script>
<script src="{{ asset('admin-assets/js/sub-admins/view.js') }}"></script>
@endpush
