<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

if(env('APP_ENV') === 'production') {
    \URL::forceScheme('https');
}

Route::prefix('api')->group(function (){

    Route::get('/test', function (Request $request) {
//        return $request->fullUrl();

        $cron_controller = app(\App\Http\Controllers\AdminPanel\GenerateInvoiceController::class);
//
//        // Call the hcp() method
        $cron_controller->facility($request);

        dd("done");
    });

    // Auth routes
    Route::post('register', 'API\Auth\RegisterController@create');
    Route::post('login', 'API\Auth\LoginController@authenticate');
    Route::post('verify-token', 'API\Auth\LoginController@verifyToken');
    Route::post('logout', 'API\Auth\LoginController@logout');
    Route::post('guest-login', 'API\Auth\LoginController@guestLogin');
    Route::post('forgot-password', 'API\Auth\LoginController@forgotPassword');
    Route::post('reset-password', 'API\Auth\ResetPasswordController@resetPassword');
    //------------

    // Get Total Shifts and Hours completed
    Route::post('get-total-shifts-and-hours-completed', 'API\CommonContentController@getShiftsAndHoursCompleted');
    //-------------------

    // Get Common Content
    Route::post('get-common-content', 'API\CommonContentController@getCommonContent');
    //-------------------

    // Get Countries
    Route::post('get-countries', 'API\CommonContentController@getCountries');
    //--------------

    // Get States
    Route::post('get-states', 'API\CommonContentController@getStates');
    //-----------

    // Get Cities
    Route::post('get-cities', 'API\CommonContentController@getCities');
    //-----------

    // Get Suburbs
    Route::post('get-suburbs', 'API\CommonContentController@getSuburbs');
    //------------

    // Get Categories
    Route::post('get-categories', 'API\CommonContentController@getCategories');
    //---------------

    // Get Professions
    Route::post('get-professions', 'API\CommonContentController@getProfessions');
    //----------------

    // Get Levels
    Route::post('get-levels', 'API\CommonContentController@getLevels');
    //-----------

    // Hcp
    Route::prefix('hcp')->group(function () {
        Route::post('register', 'API\HCPController@register');
        Route::post('personal-details', 'API\HCPController@updatePersonalDetails');
        Route::post('update-registration-number', 'API\HCPController@updateRegistrationNumber');
        Route::post('update-thank-you-screen-status', 'API\HCPController@updateThankYouScreenStatus');
        Route::post('add-update-document', 'API\HCPController@addUpdateDocument');
        Route::post('add-update-profession', 'API\HCPController@addUpdateProfession');
        Route::post('profile', 'API\HCPController@profile');
        Route::post('update-available-job-status', 'API\HCPController@updateAvailableForJobStatus');
        Route::post('documents', 'API\HCPController@getHcpDocuments');
        Route::post('notifications', 'API\HCPController@getHcpNotifications');
        Route::post('refer-and-earn', 'API\HCPController@referAndEarn');
        Route::post('get-my-buddy-shift', 'API\HCPController@getMyBuddyShift');
        Route::post('dashboard', 'API\HCPController@dashboard');
        Route::post('update-device-id', 'API\HCPController@updateDeviceId');
        Route::post('add-update-profession-new', 'API\HCPController@addUpdateProfessionNew');
        Route::post('get-hcp-professions', 'API\HCPController@getHcpProfessions');
        Route::post('get-profession-documents', 'API\HCPController@getProfessionDocuments');
        Route::post('add-update-profession-document', 'API\HCPController@addUpdateProfessionDocument');
        Route::post('update-hcp-profession-status', 'API\HCPController@updateHcpProfessionStatus');
        Route::post('update-account-details', 'API\HCPController@updateAccountDetails');
        Route::post('delete-hcp-profession', 'API\HCPController@deleteHcpProfession');
        Route::post('update-app-registration-screen', 'API\HCPController@updateAppRegistrationScreen');
        Route::post('send-email-verification', 'API\HCPController@sendEmailVerification');
        Route::post('send-mobile-verification', 'API\HCPController@sendMobileVerification');
        Route::post('verify-email', 'API\HCPController@verifyEmail');
        Route::post('verify-mobile', 'API\HCPController@verifyMobile');
        Route::post('ratings', 'API\HCPController@getHcpRating');
        Route::post('change-password', 'API\HCPController@changePassword');
    });
    //----

    // Hcps
    Route::prefix('hcps')->group(function () {
        Route::post('/', 'API\HCPController@getHcps');
    });
    //-----

    // Facility
    Route::prefix('facility')->group(function () {
        Route::post('/', 'API\FacilityController@getFacilities');
    });
    //----

    // Shifts
    Route::prefix('shift')->group(function () {
        Route::post('/', 'API\ShiftController@getShifts');
        Route::post('/details', 'API\ShiftController@getShiftDetails');
        Route::post('/accept', 'API\ShiftController@acceptShift');
        Route::post('/reject', 'API\ShiftController@rejectShift');
        Route::post('/create-swap-request', 'API\ShiftController@createSwapRequest');
        Route::post('/swap-requests', 'API\ShiftController@getSwapRequests');
        Route::post('/accept-swap-request', 'API\ShiftController@acceptSwapRequest');
        Route::post('/reject-swap-request', 'API\ShiftController@rejectSwapRequest');
        Route::post('/swap-request-details', 'API\ShiftController@getSwapRequestDetails');
        Route::post('/give-rating', 'API\ShiftController@giveRating');
        Route::post('/create-buddy-shift-request', 'API\ShiftController@createBuddyShiftRequest');
        Route::post('/cancel', 'API\ShiftController@cancelShift');
        Route::post('/buddy-shifts', 'API\ShiftController@getBuddyShifts');
        Route::post('shift-tracking', 'API\ShiftController@shiftTracking');
        Route::post('/transfer', 'API\ShiftController@createTransferRequest');
        Route::post('/accept-transfer-request', 'API\ShiftController@acceptTransferRequest');
        Route::post('/reject-transfer-request', 'API\ShiftController@rejectTransferRequest');
        Route::post('/start', 'API\ShiftController@startShift');
        Route::post('/payments', 'API\ShiftController@shiftPayment');
        Route::post('/payment-details', 'API\ShiftController@shiftPaymentDetails');
        Route::post('/end', 'API\ShiftController@endShift');
        Route::post('/cancel-transfer-request', 'API\ShiftController@cancelTransferRequest');
    });
    //-------

});

