<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Artisan;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

if(env('APP_ENV') === 'production') {
   \URL::forceScheme('https');
}

Route::get('/', function () {
    return redirect('admin-panel');
});

Route::get('/clear-cache', function () {
    $exitCode = Artisan::call('cache:clear');
    $exitCode = Artisan::call('view:clear');
    $exitCode = Artisan::call('route:clear');
    $exitCode = Artisan::call('storage:link');
    return "All cache is cleared";
});

Route::get('/privacy-policy', function () {
    return view('privacy_policy');
});

// Hcp delete Account from playstore
Route::get('/hcp/login', 'AdminPanel\Auth\HcpLoginController@showLoginForm')->name('hcp.login');
Route::post('/hcp/login/', 'AdminPanel\Auth\HcpLoginController@login')->name('hcp.login.submit');

Route::group(['middleware' => ['user']], function () {
   Route::get('/hcp/details', 'AdminPanel\Auth\HcpLoginController@showDetails')->name('hcp.details');
    Route::post('/hcp/delete/', 'AdminPanel\Auth\HcpLoginController@hcpDelete')->name('hcp.delete');
    Route::get('/hcp/logout', ['as' => 'hcp.logout', 'uses' => 'AdminPanel\Auth\HcpLoginController@logout']);
});

// Admin panel
Route::prefix('admin-panel')->group(function () {

    // Auth
    Route::get('login', 'AdminPanel\Auth\LoginController@showLoginForm')->name('adminPanel.login');
    Route::post('login', 'AdminPanel\Auth\LoginController@login')->name('adminPanel.login');
    Route::get('logout', 'AdminPanel\Auth\LoginController@logout')->name('adminPanel.logout');
    Route::get('register', 'AdminPanel\Auth\RegisterController@showRegistrationForm')->name('adminPanel.register');
    Route::post('register', 'AdminPanel\Auth\RegisterController@register')->name('adminPanel.register');
    Route::get('password/reset', 'AdminPanel\Auth\ForgotPasswordController@showLinkRequestForm')->name('adminPanel.passwordRest');
    Route::post('password/email', 'AdminPanel\Auth\ForgotPasswordController@sendResetLinkEmail')->name('adminPanel.passwordEmail');
    Route::get('password/reset/{token}/{email}', 'AdminPanel\Auth\ResetPasswordController@showResetForm')->name('adminPanel.passwordRestPage');
    Route::post('password/reset', 'AdminPanel\Auth\ResetPasswordController@reset')->name('adminPanel.passwordRest');
    //-----

    Route::middleware(['preventBackHistory', 'checkUserStatus', 'auth.admin'])->group(function () {

        // Check User Email
        Route::post('/check-user-email', 'AdminPanel\DashboardController@checkUserEmail')->name('adminPanel.dashboard.checkUserEmail');
        //-----------------

        // Dashboard
        Route::get('/', 'AdminPanel\DashboardController@index')->name('adminPanel.dashboard');
        Route::get('/dashboard', 'AdminPanel\DashboardController@index')->name('adminPanel.dashboard');
        //---------

        // Categories
        Route::prefix('categories')->group(function () {
            Route::get('/', 'AdminPanel\CategoryController@index')->name('adminPanel.categories.index');
            Route::get('/get-categories', 'AdminPanel\CategoryController@getCategories')->name('adminPanel.categories.getCategories');
            Route::get('/create', 'AdminPanel\CategoryController@create')->name('adminPanel.categories.create');
            Route::post('/', 'AdminPanel\CategoryController@store')->name('adminPanel.categories.store');
            Route::get('/{id}/edit', 'AdminPanel\CategoryController@edit')->name('adminPanel.categories.edit');
            Route::post('/{id}/update', 'AdminPanel\CategoryController@update')->name('adminPanel.categories.update');
            Route::get('/change-status', 'AdminPanel\CategoryController@changeStatus')->name('adminPanel.categories.changeStatus');
            Route::get('/get-professions', 'AdminPanel\CategoryController@getProfessions')->name('adminPanel.categories.getProfessions');
            Route::get('/get-category','AdminPanel\CategoryController@getCategory')->name('adminPanel.categories.getCategory');
        });
        //-----------

        // Professions
        Route::prefix('professions')->group(function () {
            Route::get('/', 'AdminPanel\ProfessionController@index')->name('adminPanel.professions.index');
            Route::get('/get-professions', 'AdminPanel\ProfessionController@getProfessions')->name('adminPanel.professions.getProfessions');
            Route::get('/create', 'AdminPanel\ProfessionController@create')->name('adminPanel.professions.create');
            Route::post('/', 'AdminPanel\ProfessionController@store')->name('adminPanel.professions.store');
            Route::get('/{id}/edit', 'AdminPanel\ProfessionController@edit')->name('adminPanel.professions.edit');
            Route::post('/{id}/update', 'AdminPanel\ProfessionController@update')->name('adminPanel.professions.update');
            Route::post('/change-status', 'AdminPanel\ProfessionController@changeStatus')->name('adminPanel.professions.changeStatus');
            Route::get('/get-levels', 'AdminPanel\ProfessionController@getLevels')->name('adminPanel.professions.getLevels');
            Route::get('/get-profession-document', 'AdminPanel\ProfessionController@getProfessionsDocument')->name('adminPanel.professions.getProfessionsDocument');
        });
        //------------

        // Levels
        Route::prefix('levels')->group(function () {
            Route::get('/', 'AdminPanel\LevelController@index')->name('adminPanel.levels.index');
            Route::get('/get-levels', 'AdminPanel\LevelController@getLevels')->name('adminPanel.levels.getLevels');
            Route::get('/create', 'AdminPanel\LevelController@create')->name('adminPanel.levels.create');
            Route::post('/', 'AdminPanel\LevelController@store')->name('adminPanel.levels.store');
            Route::get('/{id}/edit', 'AdminPanel\LevelController@edit')->name('adminPanel.levels.edit');
            Route::post('/{id}/update', 'AdminPanel\LevelController@update')->name('adminPanel.levels.update');
            Route::post('/change-status', 'AdminPanel\LevelController@changeStatus')->name('adminPanel.levels.changeStatus');
            Route::get('/get-professions', 'AdminPanel\LevelController@getProfessions')->name('adminPanel.levels.getProfessions');
        });
        //-------

        // Facilities
        Route::prefix('facilities')->group(function () {
            Route::get('/active', 'AdminPanel\FacilityController@active')->name('adminPanel.facilities.active')->middleware('permission:View Facilities');
            Route::get('/pending-approval', 'AdminPanel\FacilityController@pendingApproval')->name('adminPanel.facilities.pendingApproval')->middleware('permission:View Facilities');
            Route::get('/archived', 'AdminPanel\FacilityController@archived')->name('adminPanel.facilities.archived')->middleware('permission:View Facilities');
            Route::get('/{id}/details', 'AdminPanel\FacilityController@details')->name('adminPanel.facilities.details')->middleware('permission:View Facilities');
            Route::get('/create', 'AdminPanel\FacilityController@create')->name('adminPanel.facilities.create')->middleware('permission:Add Facilities');
            Route::post('/', 'AdminPanel\FacilityController@store')->name('adminPanel.facilities.store');
            Route::get('/{id}/edit', 'AdminPanel\FacilityController@edit')->name('adminPanel.facilities.edit')->middleware('permission:Edit Facilities');
            Route::post('/{id}/update', 'AdminPanel\FacilityController@update')->name('adminPanel.facilities.update');
            Route::get('/change-status/{id}/{status}', 'AdminPanel\FacilityController@changeStatus')->name('adminPanel.facilities.changeStatus');
            Route::get('/remove-favourites-hcp/{id}/{facilityId}', 'AdminPanel\FacilityController@removeFavouriteHcp')->name('adminPanel.facilities.removeFavouriteHcp');
            Route::get('/remove-blocklist-hcp/{id}/{facilityId}', 'AdminPanel\FacilityController@removeBlocklistHcp')->name('adminPanel.facilities.removeBlocklistHcp');
            Route::get('/add-hcp-blocklist/{hcpId}/{facilityId}/{type?}', 'AdminPanel\FacilityController@addHcpBlocklist')->name('adminPanel.facilities.addHcpBlocklist');
            Route::get('/add-hcp-favourites/{hcpId}/{facilityId}/{type?}', 'AdminPanel\FacilityController@addHcpFavorites')->name('adminPanel.facilities.addHcpFavorites');
            Route::get('/view-all-for-favorites-blocklist/{facilityId}', 'AdminPanel\FacilityController@viewAllHcpForFavoritesAndBlocklist')->name('adminPanel.hcps.viewAllHcpForFavoritesAndBlocklist');
            Route::get('/view-all-favorites-hcps/{id}', 'AdminPanel\FacilityController@viewAllFavoritesHcps')->name('adminPanel.facilities.viewAllFavoritesHcps');
            Route::get('/view-all-blocked-hcps/{id}', 'AdminPanel\FacilityController@viewAllBlockedHcps')->name('adminPanel.facilities.viewAllBlockedHcps');
            Route::get('/export', 'AdminPanel\FacilityController@facilityExport')->name('adminPanel.facilities.facilityExport');
            Route::post('/updatePlan','AdminPanel\FacilityController@updatePlan')->name('adminPanel.facilities.updatePlan');
            Route::get('/export-facility-hcp', 'AdminPanel\FacilityController@facilityHcpExport')->name('adminPanel.facilities.facilityHcpExport');
            Route::get('/current-plan','AdminPanel\FacilityController@currentPlan')->name('adminPanel.facilities.currentPlan');
            Route::get('/change-plan','AdminPanel\FacilityController@changePlan')->name('adminPanel.facilities.changePlan');
            Route::get('/disable-plan', 'AdminPanel\FacilityController@disablePlan')->name('adminPanel.facilities.disablePlan');
            Route::get('/cancel-plan', 'AdminPanel\FacilityController@cancelPlan')->name('adminPanel.facilities.cancelPlan');
            Route::get('/reactive-plan', 'AdminPanel\FacilityController@reactivePlan')->name('adminPanel.facilities.reactivePlan');
            Route::get('/select-plan', 'AdminPanel\FacilityController@selectPlan')->name('adminPanel.facilities.selectPlan');
            Route::post('/buy-plan', 'AdminPanel\FacilityController@buyPlan')->name('adminPanel.facilities.buyPlan');
            Route::post('/buy-trial-plan', 'AdminPanel\FacilityController@buyTrialPlan')->name('adminPanel.facilities.buyTrialPlan');
            Route::get('/payment-success', 'AdminPanel\FacilityController@paymentSuccuess')->name('adminPanel.facilities.payment-success');
            Route::get('/payment-cancel', 'AdminPanel\FacilityController@paymentCancel')->name('adminPanel.facilities.payment-cancel');
            Route::post('/accept-term-condition', 'AdminPanel\FacilityController@acceptTermCondition')->name('adminPanel.facilities.acceptTermCondition');
            Route::post('/modify_trial_plan', 'AdminPanel\FacilityController@modifyTrialPlan')->name('adminPanel.facilities.modify_trial_plan');
        });
        //-----------

        // HCPs (Health Care Provider)
        Route::prefix('hcps')->group(function () {
            Route::get('/active', 'AdminPanel\HCPController@activeHcps')->name('adminPanel.hcps.activeHcps')->middleware('permission:View HCPs|Active Hcp');
            Route::get('/pending-approval', 'AdminPanel\HCPController@pendingApprovalHcps')->name('adminPanel.hcps.pendingApproval')->middleware('permission:View HCPs');
            Route::get('/incomplete-profile', 'AdminPanel\HCPController@incompleProfileHcps')->name('adminPanel.hcps.incompleteProfile')->middleware('permission:View HCPs');
            Route::get('/archived', 'AdminPanel\HCPController@archived')->name('adminPanel.hcps.archived')->middleware('permission:View HCPs');
            Route::get('/blocked', 'AdminPanel\HCPController@blockedHcps')->name('adminPanel.hcps.blockedHcps')->middleware('permission:View HCPs');
            Route::get('/{id}/hcps.block-modal', 'AdminPanel\HCPController@blockHcpModal')->name('adminPanel.hcps.block-modal')->middleware('permission:View HCPs|Active Hcp');
            Route::post('/{id}/hcps.block', 'AdminPanel\HCPController@blockHcp')->name('adminPanel.hcps.block')->middleware('permission:View HCPs|Active Hcp');
            Route::get('/get-hcps', 'AdminPanel\HCPController@getHcps')->name('adminPanel.hcps.getHcps');
            Route::get('/create', 'AdminPanel\HCPController@create')->name('adminPanel.hcps.create')->middleware('permission:Add HCPs');
            Route::post('/', 'AdminPanel\HCPController@store')->name('adminPanel.hcps.store');
            Route::get('/{id}/edit', 'AdminPanel\HCPController@edit')->name('adminPanel.hcps.edit')->middleware('permission:Edit HCPs');
            Route::post('/{id}/update', 'AdminPanel\HCPController@update')->name('adminPanel.hcps.update');
            Route::post('/{id}/upload-document', 'AdminPanel\HCPController@uploadDocument')->name('adminPanel.hcps.uploadDocument');
            Route::post('/{id}/update-profession', 'AdminPanel\HCPController@updateProfession')->name('adminPanel.hcps.updateProfession');
            Route::get('/{id}/details', 'AdminPanel\HCPController@details')->name('adminPanel.hcps.details')->middleware('permission:View HCPs|Active Hcp');
            Route::post('/change-status', 'AdminPanel\HCPController@changeStatus')->name('adminPanel.hcps.changeStatus');
            Route::post('/move-to-archived', 'AdminPanel\HCPController@moveToArchived')->name('adminPanel.hcps.moveToArchived');
            Route::post('/add-more-professions', 'AdminPanel\HCPController@addMoreProfessions')->name('adminPanel.hcps.addMoreProfessions');
            Route::delete('/remove-profession', 'AdminPanel\HCPController@removeProfession')->name('adminPanel.hcps.removeProfession');
            Route::get('/{id}/documents', 'AdminPanel\HCPController@getHcpDocuments')->name('adminPanel.hcps.getHcpDocuments');
            Route::get('/{id}/{hcpId}/document-approved', 'AdminPanel\HCPController@documentApproved')->name('adminPanel.hcps.documentApproved');
            Route::get('/{id}/{hcpId}/document-reapproved', 'AdminPanel\HCPController@documentReapproved')->name('adminPanel.hcps.documentReapproved');
            Route::get('/change-status/{id}/{status}', 'AdminPanel\HCPController@detailsChangeStatus')->name('adminPanel.hcps.detailsChangeStatus');
            Route::get('/remove-favourites-facility/{id}/{hcpId}', 'AdminPanel\HCPController@removeFavouriteFacility')->name('adminPanel.hcps.removeFavouriteFacility');
            Route::get('/remove-blocklist-facility/{id}/{hcpId}', 'AdminPanel\HCPController@removeBlocklistFacility')->name('adminPanel.hcps.removeBlocklistFacility');
            Route::get('/lms', 'AdminPanel\HCPController@hcpLms')->name('adminPanel.hcps.lms');
            Route::post('/add-update-lms', 'AdminPanel\HCPController@addUpdateLms')->name('adminPanel.hcps.addUpdateLms');
            Route::post('/check-registration-number', 'AdminPanel\HCPController@checkRegistrationNumber')->name('adminPanel.hcps.checkRegistrationNumber');
            Route::get('/add-hcp-favourites/{hcpId}/{facilityId}', 'AdminPanel\HCPController@addHcpFavorites')->name('adminPanel.hcps.addHcpFavorites');
            Route::get('/remove-favourites-hcp/{hcpId}/{facilityId}/{page?}', 'AdminPanel\HCPController@removeFavouriteHcp')->name('adminPanel.hcps.removeFavouriteHcp');
            Route::get('/add-hcp-blocklist/{hcpId}/{facilityId}', 'AdminPanel\HCPController@addHcpBlocklist')->name('adminPanel.hcps.addHcpBlocklist');
            Route::get('/remove-blocklist-hcp/{hcpId}/{facilityId}/{page?}', 'AdminPanel\HCPController@removeBlocklistHcp')->name('adminPanel.hcps.removeBlocklistHcp');
            Route::get('/blocklist', 'AdminPanel\HCPController@getFacilityBlocklistHcps')->name('adminPanel.hcps.getFacilityBlocklistHcps');
            Route::get('/favorites', 'AdminPanel\HCPController@getFacilityFavoritesHcps')->name('adminPanel.hcps.getFacilityFavoritesHcps');
            Route::get('{id}/reject-hcp-modal', 'AdminPanel\HCPController@rejectHcpModal')->name('adminPanel.hcps.rejectHcpModal');
            Route::post('{id}/reject-hcp', 'AdminPanel\HCPController@rejectHcp')->name('adminPanel.hcps.rejectHcp');
            Route::get('/export', 'AdminPanel\HCPController@hcpExport')->name('adminPanel.hcps.hcpExport');
            Route::get('/profession-pending-approval', 'AdminPanel\HCPController@professionPendingApprovalHcps')->name('adminPanel.hcps.professionPendingApprovalHcps');
            Route::get('/approve-pending-profession/{id}/{status?}', 'AdminPanel\HCPController@approvePendingProfession')->name('adminPanel.hcps.approvePendingProfession');
            Route::get('/reject-pending-profession-modal/{id}/', 'AdminPanel\HCPController@rejectPendingProfessionModal')->name('adminPanel.hcps.rejectPendingProfessionModal');
            Route::post('/reject-pending-profession/{id}', 'AdminPanel\HCPController@rejectPendingProfession')->name('adminPanel.hcps.rejectPendingProfession');
            Route::get('/rejected', 'AdminPanel\HCPController@rejectedHcps')->name('adminPanel.hcps.rejectedHcps')->middleware('permission:View HCPs');
            Route::get('/export-profession-pending-approval', 'AdminPanel\HCPController@professionPendingApprovalHcpExport')->name('adminPanel.hcps.professionPendingApprovalHcpExport');
        });
        //----------------------------

        // Shifts
        Route::prefix('shifts')->group(function (){
            Route::get('/pending','AdminPanel\ShiftController@pending')->name('adminPanel.shift.pending')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/scheduled','AdminPanel\ShiftController@scheduled')->name('adminPanel.shift.scheduled')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/cancelled','AdminPanel\ShiftController@cancelled')->name('adminPanel.shift.cancelled')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/past','AdminPanel\ShiftController@past')->name('adminPanel.shift.past')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/running','AdminPanel\ShiftController@running')->name('adminPanel.shift.running')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/completed','AdminPanel\ShiftController@completed')->name('adminPanel.shift.completed')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/transferred','AdminPanel\ShiftController@transferred')->name('adminPanel.shift.transferred')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/swapped','AdminPanel\ShiftController@swapped')->name('adminPanel.shift.swapped')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/buddy-requests','AdminPanel\ShiftController@buddyShiftRequest')->name('adminPanel.shift.buddy-requests')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/buddy-shifts','AdminPanel\ShiftController@buddyShiftRequest')->name('adminPanel.shift.buddy-shifts')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/create/{buddyRequestId?}/{type?}','AdminPanel\ShiftController@create')->name('adminPanel.shift.create')->middleware('permission:Add Shifts|Facility Add Shifts');
            Route::post('/store','AdminPanel\ShiftController@store')->name('adminPanel.shift.store');
            Route::get('{id}/edit','AdminPanel\ShiftController@edit')->name('adminPanel.shift.edit')->middleware('permission:Edit Shifts|Facility Edit Shifts');
            Route::post('{id}/update','AdminPanel\ShiftController@update')->name('adminPanel.shift.update');
            Route::post('/calculate-price','AdminPanel\ShiftController@calculatePrice')->name('adminPanel.shift.calculatePrice');
            Route::get('/get-hcps','AdminPanel\ShiftController@getHcps')->name('adminPanel.shift.getHcps');
            Route::get('/check-for-profession-level','AdminPanel\ShiftController@checkForProfessionLevel')->name('adminPanel.shift.checkForProfessionLevel');
            Route::get('{id}/rebroadcast','AdminPanel\ShiftController@shiftRebroadcast')->name('adminPanel.shift.shiftRebroadcast');
            Route::post('send-rebroadcast-notification','AdminPanel\ShiftController@sendRebroadcastNotification')->name('adminPanel.shift.sendRebroadcastNotification');
            Route::get('{id}/details','AdminPanel\ShiftController@details')->name('adminPanel.shift.details')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('{id}/cancel-shift-modal', 'AdminPanel\ShiftController@cancelShiftModal')->name('adminPanel.shift.cancelShiftModal');
            Route::post('{id}/cancel-shift', 'AdminPanel\ShiftController@cancelShift')->name('adminPanel.shift.cancelShift');
            Route::get('{id}/start-shift', 'AdminPanel\ShiftController@startShift')->name('adminPanel.shift.startShift');
            Route::get('{id}/end-shift', 'AdminPanel\ShiftController@endShift')->name('adminPanel.shift.endShift');
            Route::get('{id}/approved-shift-modal', 'AdminPanel\ShiftController@approvedShiftModal')->name('adminPanel.shift.approvedShiftModal');
            Route::post('{id}/approved-shift', 'AdminPanel\ShiftController@approvedShift')->name('adminPanel.shift.approvedShift');
            Route::post('{id}/update-approved-shift', 'AdminPanel\ShiftController@updateApprovedShift')->name('adminPanel.shift.updateApprovedShift');
	Route::post('{id}/approved-sleepover-shift', 'AdminPanel\ShiftController@approvedSleepoverShift')->name('adminPanel.shift.approvedSleepoverShift');
            Route::get('track-hcp/{id}','AdminPanel\TrackHCPController@TrackHCP')->name('adminPanel.shift.track-hcp');
            Route::get('hcp-tracker/{id}','AdminPanel\TrackHCPController@hcpTracker')->name('adminPanel.shift.hcp-tracker');
            Route::post('track-running-hcp','AdminPanel\TrackHCPController@TrackRunningHCP')->name('adminPanel.shift.track-running-hcp');
            Route::get('get-schedule-hcp-latlon/{id}','AdminPanel\TrackHCPController@getScheduleHCPLatlong')->name('adminPanel.shift.get-schedule-hcp-latlon');
            Route::get('get-running-hcp-latlon','AdminPanel\TrackHCPController@getRunningHCPLatlong')->name('adminPanel.shift.get-running-hcp-latlon');
            Route::get('get-running-hcp-latlon/{id}','AdminPanel\TrackHCPController@getRunningHCPLatlong')->name('adminPanel.shift.get-running-hcp-latlon');
            Route::get('/get-facility-plan','AdminPanel\ShiftController@getFacilityPlan')->name('adminPanel.shift.getFacilityPlan');
            Route::get('/get-professions','AdminPanel\ShiftController@getProfessions')->name('adminPanel.shift.getProfessions');
            Route::get('/get-buddy-hcps','AdminPanel\ShiftController@getBuddyHcps')->name('adminPanel.shift.getBuddyHcps');
            Route::get('/get-transfer-hcps/{id}','AdminPanel\ShiftController@getTransferHcp')->name('adminPanel.shift.getTransferHcp');
            Route::post('/transfer-shift','AdminPanel\ShiftController@transferShift')->name('adminPanel.shift.transferShift');
            Route::get('/export', 'AdminPanel\ShiftController@shiftExport')->name('adminPanel.shift.shiftExport');
            Route::get('/create-buddy-shift/{id}/{shiftType}', 'AdminPanel\ShiftController@createBuddyShift')->name('adminPanel.shift.createBuddyShift');
            Route::post('/store-buddy-shift', 'AdminPanel\ShiftController@storeBuddyShift')->name('adminPanel.shift.storeBuddyShift');
            Route::get('/choose-scheduled-shift/{id}', 'AdminPanel\ShiftController@assingBuddyShiftFromScheduledShift')->name('adminPanel.shift.assingBuddyShiftFromScheduledShift');
            Route::get('/all-shifts','AdminPanel\ShiftController@allShifts')->name('adminPanel.shift.allShifts')->middleware('permission:View Shifts|Facility View Shifts');
            Route::get('/export-transferred', 'AdminPanel\ShiftController@shiftTransferredExport')->name('adminPanel.shift.shiftTransferredExport');
            Route::get('/export-swap', 'AdminPanel\ShiftController@shiftSwapExport')->name('adminPanel.shift.shiftSwapExport');
            Route::get('/export-buddy-requests', 'AdminPanel\ShiftController@shiftBuddyRequestExport')->name('adminPanel.shift.shiftBuddyRequestExport');
            Route::get('{id}/assign-hcp','AdminPanel\ShiftController@assignHcpList')->name('adminPanel.shift.assignHcpList');
            Route::post('assign-hcp','AdminPanel\ShiftController@assignHcp')->name('adminPanel.shift.assignHcp');
            Route::get('/multiple-shifts-modal','AdminPanel\ShiftController@multipleShiftsModal')->name('adminPanel.shift.multipleShiftsModal');
            Route::get('/mark-complete-buddy-shift-request','AdminPanel\ShiftController@markCompleteBuddyShiftRequest')->name('adminPanel.shift.markCompleteBuddyShiftRequest');
            Route::get('{id}/rate-shift-modal', 'AdminPanel\ShiftController@rateShiftModal')->name('adminPanel.shift.rateShiftModal');
            Route::post('{id}/rate-shift', 'AdminPanel\ShiftController@rateShift')->name('adminPanel.shift.rateShift');
            Route::get('{id}/cancel-pending-shift-modal', 'AdminPanel\ShiftController@cancelPendingShiftModal')->name('adminPanel.shift.cancelPendingShiftModal');
            Route::post('{id}/cancel-pending-shift', 'AdminPanel\ShiftController@cancelPendingShift')->name('adminPanel.shift.cancelPendingShift');
            Route::get('/view-location-modal/{id}','AdminPanel\ShiftController@viewLocationModal')->name('adminPanel.shift.viewLocationModal');

            Route::get('/update-shift-amount','AdminPanel\ShiftController@updateShiftAmount')->name('adminPanel.shift.updateShiftAmount');
            Route::get('/shift-notification/{id}','AdminPanel\ShiftController@viewAllShiftNotification')->name('adminPanel.shift.viewAllShiftNotification');
            Route::get('/request-buddy-shift/{id}', 'AdminPanel\ShiftController@requestBuddyShift')->name('adminPanel.shift.requestBuddyShift');
	Route::get('/approve-sleepover-shift/{id}', 'AdminPanel\ShiftController@approveSleepoverShift')->name('adminPanel.shift.approveSleepoverShift');
	Route::post('{id}/update-approved-sleepover-shift', 'AdminPanel\ShiftController@updateApprovedSleepoverShift')->name('adminPanel.shift.updateApprovedSleepoverShift');
        });
        //-------

        // Accounts
        Route::prefix('accounts')->group(function () {
            Route::get('/facility', 'AdminPanel\AccountController@facility')->name('adminPanel.accounts.facility')->middleware('permission:Facilities Accounts');
            Route::get('/details/{facilityId?}/{invoiceId?}', 'AdminPanel\AccountController@details')->name('adminPanel.accounts.details');
            Route::get('/pay', 'AdminPanel\AccountController@pay')->name('adminPanel.accounts.pay');
            Route::get('/send-reminder', 'AdminPanel\AccountController@facilitySendReminder')->name('adminPanel.accounts.facilitySendReminder');
            Route::get('/facility-export', 'AdminPanel\AccountController@facilityExport')->name('adminPanel.accounts.facility-export');
            Route::get('/facility-details-export', 'AdminPanel\AccountController@facilityDetailsExport')->name('adminPanel.accounts.facility-details-export');
            Route::get('/hcp', 'AdminPanel\AccountController@hcp')->name('adminPanel.accounts.hcp')->middleware('permission:Hcp Accounts');
            Route::get('/hcp-completed-shift', 'AdminPanel\AccountController@hcpCompletedShift')->name('adminPanel.accounts.hcpCompletedShift')->middleware('permission:Hcp Accounts');
            Route::get('/hcp-completed-shift-export', 'AdminPanel\AccountController@hcpCompletedShiftExport')->name('adminPanel.accounts.hcpCompletedShiftExport');
            Route::get('/hcp_details/{hcpId?}/{statementId?}', 'AdminPanel\AccountController@hcpDetails')->name('adminPanel.accounts.hcpDetails');
            Route::get('/hcp-export', 'AdminPanel\AccountController@hcpExport')->name('adminPanel.accounts.hcp-export');
            Route::get('/hcp-pay', 'AdminPanel\AccountController@hcpPay')->name('adminPanel.accounts.hcpPay');
            Route::get('/hcp-details-export', 'AdminPanel\AccountController@hcpDetailsExport')->name('adminPanel.accounts.hcp-details-export');
            Route::get('/shift_details/{id}', 'AdminPanel\AccountController@shiftDetails')->name('adminPanel.accounts.shift_details');

            Route::get('/shift-transactions', 'AdminPanel\AccountController@facilityShiftAccount')->name('adminPanel.accounts.facilityShiftAccount')->middleware('permission:Shift Transactions');
            Route::get('/export-shift-transactions', 'AdminPanel\AccountController@exportfacilityShiftAccount')->name('adminPanel.accounts.exportfacilityShiftAccount');
            Route::get('/shift-transactions-details/{facilityId?}/{invoiceId?}', 'AdminPanel\AccountController@facilityShiftAccountDetails')->name('adminPanel.accounts.facilityShiftAccountDetails');
            Route::get('/export-shift-transactions-details', 'AdminPanel\AccountController@exportfacilityShiftAccountDetails')->name('adminPanel.accounts.export-shift-transactions-details');

            Route::get('/subscription-transactions', 'AdminPanel\AccountController@facilitySubscriptionAccount')->name('adminPanel.accounts.facilitySubscriptionAccount')->middleware('permission:Subscription Invoices');
            Route::get('/subscription-transactions-export', 'AdminPanel\AccountController@facilitySubscriptionAccountExport')->name('adminPanel.accounts.facilitySubscriptionAccountExport');

            Route::get('/revenue-statement', 'AdminPanel\AccountController@revenueStatement')->name('adminPanel.accounts.revenueStatement')->middleware('permission:Revenue Statement');
            Route::get('/revenue-statement-export', 'AdminPanel\AccountController@revenueStatementExport')->name('adminPanel.accounts.revenueStatementExport');
            Route::get('/revenue-statement-details/{facilityId?}/{invoiceId?}', 'AdminPanel\AccountController@revenueStatementDetails')->name('adminPanel.accounts.revenueStatementDetails');
            Route::get('/revenue-statement-details-export', 'AdminPanel\AccountController@revenueStatementDetailsExport')->name('adminPanel.accounts.revenueStatementDetailsExport');
            Route::get('/hcp-referrals', 'AdminPanel\AccountController@hcpReferrals')->name('adminPanel.accounts.hcpReferrals');
            Route::get('/view-referrals', 'AdminPanel\AccountController@viewReferrals')->name('adminPanel.accounts.viewReferrals');
            Route::get('/export-referrals', 'AdminPanel\AccountController@viewReferralsExport')->name('adminPanel.accounts.viewReferralsExport');
            Route::get('/facility-completed-shift', 'AdminPanel\AccountController@facilityCompletedShift')->name('adminPanel.accounts.facilityCompletedShift')->middleware('permission:Facilities Accounts');
            Route::get('/facility-completed-shift-export', 'AdminPanel\AccountController@facilityCompletedShiftExport')->name('adminPanel.accounts.facilityCompletedShiftExport')->middleware('permission:Facilities Accounts');
        });
        //----------

        // Manage Documents
        Route::prefix('manage-document')->group(function () {
            Route::get('/', 'AdminPanel\ManageDocumentController@index')->name('adminPanel.documents.index')->middleware('permission:View Documents');
            Route::get('/create', 'AdminPanel\ManageDocumentController@create')->name('adminPanel.documents.create')->middleware('permission:Add Documents');
            Route::post('/store', 'AdminPanel\ManageDocumentController@store')->name('adminPanel.documents.store');
            Route::get('{id}/edit', 'AdminPanel\ManageDocumentController@edit')->name('adminPanel.documents.edit')->middleware('permission:Edit Documents');
            Route::post('{id}/update', 'AdminPanel\ManageDocumentController@update')->name('adminPanel.documents.update');
            Route::get('/change-status/{id}/{status}', 'AdminPanel\ManageDocumentController@changeStatus')->name('adminPanel.documents.changeStatus');
            Route::get('/get-document-types', 'AdminPanel\ManageDocumentController@getDocumentType')->name('adminPanel.documents.getDocumentType');
            Route::get('/export', 'AdminPanel\ManageDocumentController@documentExport')->name('adminPanel.documents.documentExport');
        });
        //-----------------

        // Facility Manage Documents
        Route::prefix('facility-manage-document')->group(function () {
            Route::get('/', 'AdminPanel\FacilityManageDocumentController@index')->name('adminPanel.facility-manage-document.index')->middleware('permission:Manage Document');
            Route::get('/upload-document-modal/{documentId}', 'AdminPanel\FacilityManageDocumentController@uploadDocumentModal')->name('adminPanel.facility-manage-document.uploadDocumentModal');
            Route::post('/upload-document', 'AdminPanel\FacilityManageDocumentController@uploadDocument')->name('adminPanel.facility-manage-document.uploadDocument');
            Route::get('/export/{id}', 'AdminPanel\FacilityManageDocumentController@facilityDocumentsExport')->name('adminPanel.facility-manage-document.facilityDocumentsExport');
        });
        //--------------------------

        // Rating Reviews
        Route::prefix('rating-reviews')->group(function () {
            Route::get('/', 'AdminPanel\RatingController@index')->name('adminPanel.rating-review.index')->middleware('permission:View Review & Ratings');
            Route::get('/change-status/{id}/{status}/{fragment?}', 'AdminPanel\RatingController@changeStatus')->name('adminPanel.rating-review.changeStatus');
            Route::get('/facility-ratings', 'AdminPanel\RatingController@facilityRatings')->name('adminPanel.rating-review.facilityRatings')->middleware('permission:Review & Ratings');
            Route::get('/facility-export', 'AdminPanel\RatingController@facilityRatingsExport')->name('adminPanel.rating-review.facilityRatingsExport');
            Route::get('/hcp-export', 'AdminPanel\RatingController@hcpRatingsExport')->name('adminPanel.rating-review.hcpRatingsExport');
        });
        //---------------

        // Country
        Route::prefix('country')->group(function () {
            Route::get('/get-states', 'AdminPanel\CountryController@getStates')->name('adminPanel.country.getStates');
        });
        //--------

        // State
        Route::prefix('state')->group(function () {
            Route::get('/get-cities', 'AdminPanel\StateController@getCities')->name('adminPanel.state.getCities');
        });
        //------

        // City
        Route::prefix('city')->group(function () {
            Route::get('/get-suburbs', 'AdminPanel\CityController@getSuburbs')->name('adminPanel.city.getSuburbs');
        });
        //-----

        // Cron Test
        Route::prefix('cron-test')->group(function () {
            Route::get('/', 'AdminPanel\CronTestController@index')->name('adminPanel.cron-test.index');
        });
        //----------

        // Dev Configuration
        Route::prefix('dev-configuration')->group(function () {
            Route::get('/edit', 'AdminPanel\DevConfigurationController@edit')->name('adminPanel.dev-configuration.edit');
            Route::post('/update', 'AdminPanel\DevConfigurationController@update')->name('adminPanel.dev-configuration.update');
        });
        //------------------

        // Notifications
        Route::prefix('notifications')->group(function () {
            Route::get('/', 'AdminPanel\NotificationController@index')->name('adminPanel.notification.index')->middleware('permission:View Notifications');
            Route::get('/create', 'AdminPanel\NotificationController@create')->name('adminPanel.notification.create');
            Route::post('/', 'AdminPanel\NotificationController@store')->name('adminPanel.notification.store');
            Route::get('/get-topbar-notifications', 'AdminPanel\NotificationController@getNotificationForTopBar')->name('adminPanel.notification.getNotificationForTopBar');
            Route::get('/mark-as-read', 'AdminPanel\NotificationController@markAsRead')->name('adminPanel.notification.markAsRead');
            Route::get('/get-unread-notification-count', 'AdminPanel\NotificationController@getUnreadNotificationCount')->name('adminPanel.notification.getUnreadNotificationCount');
            Route::get('/facilities', 'AdminPanel\NotificationController@getFacilityNotifications')->name('adminPanel.notification.getFacilityNotifications');
            Route::get('/admin-notifications', 'AdminPanel\NotificationController@getAdminNotifications')->name('adminPanel.notification.getAdminNotifications')->middleware('permission:View Notifications');
            Route::get('/get-admin-unread-notification-count', 'AdminPanel\NotificationController@getAdminUnreadNotificationCount')->name('adminPanel.notification.getAdminUnreadNotificationCount');
            Route::get('/get-admin-topbar-notifications', 'AdminPanel\NotificationController@getAdminNotificationForTopBar')->name('adminPanel.notification.getAdminNotificationForTopBar');
            Route::get('/admin-mark-as-read', 'AdminPanel\NotificationController@adminMarkAsRead')->name('adminPanel.notification.adminMarkAsRead');
        });
        //--------------

        // Doc Noitfications
        Route::prefix('document-notification')->group(function () {
            Route::get('/index', 'AdminPanel\DocumentNotificationController@index')->name('adminPanel.doc_notify.index')->middleware('permission:Documents Notifications');
            Route::get('/expiring-doc-export', 'AdminPanel\DocumentNotificationController@expiringDocExport')->name('adminPanel.document-notification.expiringDocExport');
            Route::get('/recent-doc-export', 'AdminPanel\DocumentNotificationController@recentDocExport')->name('adminPanel.document-notification.recentDocExport');
        });
        //------------------

        // Config
        Route::prefix('config')->group(function () {
            Route::get('/general', 'AdminPanel\GeneralConfigController@index')->name('adminPanel.config.general')->middleware('permission:General Configuration');
            Route::post('/save', 'AdminPanel\GeneralConfigController@store')->name('adminPanel.config.save');
	Route::post('/sleepover-rates', 'AdminPanel\GeneralConfigController@sleepoverRateStore')->name('adminPanel.config.sleepover-rates');
	Route::post('/extra-night-rates', 'AdminPanel\GeneralConfigController@extraNightRateStore')->name('adminPanel.config.extra-night-rates');
        });
        //-------

        // Public Holidays
        Route::prefix('public-holidays')->group(function () {
            Route::get('/', 'AdminPanel\PublicHolidayController@index')->name('adminPanel.public-holidays.index')->middleware('permission:View Public Holiday');
            Route::get('/create', 'AdminPanel\PublicHolidayController@create')->name('adminPanel.public-holidays.create')->middleware('permission:Add Public Holiday');
            Route::post('/', 'AdminPanel\PublicHolidayController@store')->name('adminPanel.public-holidays.store');
            Route::get('/{id}/edit', 'AdminPanel\PublicHolidayController@edit')->name('adminPanel.public-holidays.edit')->middleware('permission:Edit Public Holiday');
            Route::post('/{id}/update', 'AdminPanel\PublicHolidayController@update')->name('adminPanel.public-holidays.update');
            Route::get('/change-status/{id}/{status}', 'AdminPanel\PublicHolidayController@changeStatus')->name('adminPanel.public-holidays.changeStatus');
            Route::get('/facilities', 'AdminPanel\PublicHolidayController@getFacilityPublicHoliday')->name('adminPanel.public-holidays.getFacilityPublicHoliday')->middleware('permission:Public Holiday');
            Route::get('/facility-export', 'AdminPanel\PublicHolidayController@facilityExport')->name('adminPanel.public-holidays.facilityExport');
            Route::get('/export', 'AdminPanel\PublicHolidayController@export')->name('adminPanel.public-holidays.export');
        });
        //----------------

        // Sub Admin
        Route::prefix('sub-admins')->group(function () {
            Route::get('/', 'AdminPanel\SubAdminController@index')->name('adminPanel.sub-admins.index')->middleware('permission:View Sub Admins|Facility View Sub Admins');
            Route::get('/create', 'AdminPanel\SubAdminController@create')->name('adminPanel.sub-admins.create')->middleware('permission:Add Sub Admins|Facility Add Sub Admins');
            Route::post('/', 'AdminPanel\SubAdminController@store')->name('adminPanel.sub-admins.store');
            Route::get('/{id}/edit', 'AdminPanel\SubAdminController@edit')->name('adminPanel.sub-admins.edit')->middleware('permission:Edit Sub Admins|Facility Edit Sub Admins');
            Route::post('/{id}/update', 'AdminPanel\SubAdminController@update')->name('adminPanel.sub-admins.update');
            Route::get('/change-status/{id}/{status}/{page?}', 'AdminPanel\SubAdminController@changeStatus')->name('adminPanel.sub-admins.changeStatus');
            Route::get('/{id}/details', 'AdminPanel\SubAdminController@details')->name('adminPanel.sub-admins.details');
            Route::post('/check-user-email', 'AdminPanel\SubAdminController@checkUserEmail')->name('adminPanel.sub-admins.checkUserEmail');
            Route::get('/export', 'AdminPanel\SubAdminController@export')->name('adminPanel.sub-admins.export');
        });
        //----------

        // Facility Group Admin
        Route::prefix('facility-groups-admin')->group(function () {
            Route::get('/', 'AdminPanel\FacilityGroupAdminController@index')->name('adminPanel.facility-groups-admin.index')->middleware('permission:Facility Group');
            Route::get('/create', 'AdminPanel\FacilityGroupAdminController@create')->name('adminPanel.facility-groups-admin.create')->middleware('permission:Facility Group');
            Route::post('/', 'AdminPanel\FacilityGroupAdminController@store')->name('adminPanel.facility-groups-admin.store');
            Route::get('/{id}/edit', 'AdminPanel\FacilityGroupAdminController@edit')->name('adminPanel.facility-groups-admin.edit')->middleware('permission:Facility Group');
            Route::post('/{id}/update', 'AdminPanel\FacilityGroupAdminController@update')->name('adminPanel.facility-groups-admin.update');
            Route::get('/change-status/{id}/{status}', 'AdminPanel\FacilityGroupController@changeStatus')->name('adminPanel.facility-groups.changeStatus');
            Route::get('/{id}/view-facilities', 'AdminPanel\FacilityGroupController@viewFacilities')->name('adminPanel.facility-groups.viewFacilities');
            Route::get('get-facilities', 'AdminPanel\FacilityGroupController@getFacilities')->name('adminPanel.facility-groups.getFacilities');
            Route::get('get-facilities-for-shift', 'AdminPanel\FacilityGroupController@getFacilitiesForShift')->name('adminPanel.facility-groups.getFacilitiesForShift');
            Route::get('/export', 'AdminPanel\FacilityGroupController@export')->name('adminPanel.facility-groups.export');
        });
        //---------------

        // Facility Group
        Route::prefix('facility-groups')->group(function () {
            Route::get('/', 'AdminPanel\FacilityGroupController@index')->name('adminPanel.facility-groups.index')->middleware('permission:Facility Group');
            Route::get('/create', 'AdminPanel\FacilityGroupController@create')->name('adminPanel.facility-groups.create')->middleware('permission:Facility Group');
            Route::post('/', 'AdminPanel\FacilityGroupController@store')->name('adminPanel.facility-groups.store');
            Route::get('/{id}/edit', 'AdminPanel\FacilityGroupController@edit')->name('adminPanel.facility-groups.edit')->middleware('permission:Facility Group');
            Route::post('/{id}/update', 'AdminPanel\FacilityGroupController@update')->name('adminPanel.facility-groups.update');
            Route::get('/change-status/{id}/{status}', 'AdminPanel\FacilityGroupController@changeStatus')->name('adminPanel.facility-groups.changeStatus');
            Route::get('/{id}/view-facilities', 'AdminPanel\FacilityGroupController@viewFacilities')->name('adminPanel.facility-groups.viewFacilities');
            Route::get('get-facilities', 'AdminPanel\FacilityGroupController@getFacilities')->name('adminPanel.facility-groups.getFacilities');
            Route::get('get-facilities-for-shift', 'AdminPanel\FacilityGroupController@getFacilitiesForShift')->name('adminPanel.facility-groups.getFacilitiesForShift');
            Route::get('/export', 'AdminPanel\FacilityGroupController@export')->name('adminPanel.facility-groups.export');
        });
        //---------------

        // Sub Admin
        Route::prefix('facility-group-sub-admins')->group(function () {
            Route::get('/', 'AdminPanel\FacilityGroupSubAdminController@index')->name('adminPanel.facility-group-sub-admins.index')->middleware('permission:View Sub Admins|Facility View Sub Admins');
            Route::get('/create', 'AdminPanel\FacilityGroupSubAdminController@create')->name('adminPanel.facility-group-sub-admins.create')->middleware('permission:Add Sub Admins|Facility Add Sub Admins');
            Route::post('/', 'AdminPanel\FacilityGroupSubAdminController@store')->name('adminPanel.facility-group-sub-admins.store');
            Route::get('/{id}/edit', 'AdminPanel\FacilityGroupSubAdminController@edit')->name('adminPanel.facility-group-sub-admins.edit')->middleware('permission:Edit Sub Admins|Facility Edit Sub Admins');
            Route::post('/{id}/update', 'AdminPanel\FacilityGroupSubAdminController@update')->name('adminPanel.facility-group-sub-admins.update');
            Route::get('/change-status/{id}/{status}/{page?}', 'AdminPanel\SubAdminController@changeStatus')->name('adminPanel.sub-admins.changeStatus');
            Route::get('/{id}/details', 'AdminPanel\SubAdminController@details')->name('adminPanel.sub-admins.details');
            Route::post('/check-user-email', 'AdminPanel\SubAdminController@checkUserEmail')->name('adminPanel.sub-admins.checkUserEmail');
            Route::get('/export', 'AdminPanel\SubAdminController@export')->name('adminPanel.sub-admins.export');
        });
        //----------

        // Profile
        Route::prefix('profile')->group(function () {
            Route::get('/', 'AdminPanel\ProfileController@index')->name('adminPanel.profile.index');
            Route::get('/edit', 'AdminPanel\ProfileController@edit')->name('adminPanel.profile.edit');
            Route::post('/{id}/update', 'AdminPanel\ProfileController@update')->name('adminPanel.profile.update');
            Route::get('/change-password', 'AdminPanel\ProfileController@changePassword')->name('adminPanel.profile.changePassword');
            Route::post('/update-password', 'AdminPanel\ProfileController@updatePassword')->name('adminPanel.profile.updatePassword');
        });
        //--------

        // Plans
        Route::prefix('plans')->group(function (){
            Route::get('/','AdminPanel\PlanController@index')->name('adminPanel.plans.index')->middleware('permission:Plan Configuration');
            Route::get('/edit','AdminPanel\PlanController@edit')->name('adminPanel.plans.edit')->middleware('permission:Plan Configuration');
            Route::post('/update','AdminPanel\PlanController@update')->name('adminPanel.plans.update');
            Route::post('/get-plan-price','AdminPanel\PlanController@getPlanPrice')->name('adminPanel.plans.getPlanPrice');
        });
        //------

        // Supporting Pages
        Route::prefix('supporting-pages')->group(function () {
            Route::get('/', 'AdminPanel\SupportingPageController@index')->name('adminPanel.supporting-pages.index')->middleware('permission:Supporting Pages');
            Route::post('/store', 'AdminPanel\SupportingPageController@store')->name('adminPanel.supporting-pages.store');
        });
        //-----------------

        // Document Configurations
        Route::prefix('document-config')->group(function () {
            Route::get('/', 'AdminPanel\DocumentConfigurationController@index')->name('adminPanel.document-config.index')->middleware('permission:Document Configuration');
            Route::get('/{docId}/edit', 'AdminPanel\DocumentConfigurationController@edit')->name('adminPanel.document-config.edit')->middleware('permission:Document Configuration');
            Route::post('/{docId}/update', 'AdminPanel\DocumentConfigurationController@update')->name('adminPanel.document-config.update');
        });
        //-----------

        // Hcp Configuration
        Route::prefix('hcp-configuration')->group(function () {
            Route::get('/', 'AdminPanel\HcpConfiguration@index')->name('adminPanel.hcp-configuration.index')->middleware('permission:Hcp Configuration');
            Route::get('/category-change-status/{id}/{status}/{page?}', 'AdminPanel\HcpConfiguration@categoryChangeStatus')->name('adminPanel.hcp-configuration.categoryChangeStatus');
            Route::get('/category-change-status/{id}/{status}/{page?}', 'AdminPanel\HcpConfiguration@categoryChangeStatus')->name('adminPanel.hcp-configuration.categoryChangeStatus');
            Route::get('/profession-change-status/{id}/{status}/{page?}', 'AdminPanel\HcpConfiguration@professionChangeStatus')->name('adminPanel.hcp-configuration.professionChangeStatus');
            Route::get('/level-change-status/{id}/{status}/{page?}', 'AdminPanel\HcpConfiguration@levelChangeStatus')->name('adminPanel.hcp-configuration.levelChangeStatus');
            Route::get('/category-export','AdminPanel\HcpConfiguration@categoryExport')->name('adminPanel.hcp-configuration.categoryExport');
            Route::get('/profession-export','AdminPanel\HcpConfiguration@professionExport')->name('adminPanel.hcp-configuration.professionExport');
            Route::get('/level-export','AdminPanel\HcpConfiguration@levelExport')->name('adminPanel.hcp-configuration.levelExport');
        });
        //------------------

        // Facility Names
        Route::prefix('facility-names')->group(function () {
            Route::get('/', 'AdminPanel\FacilityNameController@index')->name('adminPanel.facility-names.index')->middleware('permission:Facility Names');
            Route::get('/create', 'AdminPanel\FacilityNameController@create')->name('adminPanel.facility-names.create');
            Route::post('/', 'AdminPanel\FacilityNameController@store')->name('adminPanel.facility-names.store');
            Route::get('/{id}/edit', 'AdminPanel\FacilityNameController@edit')->name('adminPanel.facility-names.edit');
            Route::post('/{id}/update', 'AdminPanel\FacilityNameController@update')->name('adminPanel.facility-names.update');
            Route::get('/change-status/{id}/{status}', 'AdminPanel\FacilityNameController@changeStatus')->name('adminPanel.facility-names.changeStatus');
            Route::get('/import-excel-modal', 'AdminPanel\FacilityNameController@importExcelModal')->name('adminPanel.facility-names.importExcelModal');
            Route::post('/import-excel', 'AdminPanel\FacilityNameController@importExcel')->name('adminPanel.facility-names.importExcel');
            Route::get('/get-facility-names', 'AdminPanel\FacilityNameController@getFacilityNames')->name('adminPanel.facility-names.getFacilityNames');
            Route::get('/get-facility-name-details', 'AdminPanel\FacilityNameController@getFacilityNameDetails')->name('adminPanel.facility-names.getFacilityNameDetails');
            Route::get('/export', 'AdminPanel\FacilityNameController@export')->name('adminPanel.facility-names.export');
        });
        //---------------

        // Delete Hcp Testing
        Route::prefix('shift-broadcast-test')->group(function (){
            Route::get('/', 'AdminPanel\ShiftBroadcastController@broadcast')->name('adminPanel.shift-broadcast.broadcast');
        });
        //-------------------

        // Generate Invoice
        Route::prefix('generate-invoice')->group(function () {
            Route::get('/facility-new', 'AdminPanel\GenerateInvoiceController@generateMissingInvoice')->name('adminPanel.generate-invoice.facility');
            Route::get('/facility', 'AdminPanel\GenerateInvoiceController@facility')->name('adminPanel.generate-invoice.facility');
            Route::get('/hcp', 'AdminPanel\GenerateInvoiceController@hcp')->name('adminPanel.generate-invoice.hcp');
        });
        //------------------

    });
});
//------------

// Stripe Webhooks
Route::stripeWebhooks('stripe-webhooks');
//----------------
