<?php

namespace App\Http\Controllers\AdminPanel;
use App\Http\Controllers\Controller;
use App\Http\Requests\AdminPanel\ValidateShift;
use App\Interfaces\CategoryInterface;
use App\Interfaces\CountryInterface;
use App\Interfaces\FacilityInterface;
use App\Interfaces\HcpInterface;
use App\Interfaces\LevelInterface;
use App\Interfaces\ProfessionInterface;
use App\Interfaces\ShiftInterface;
use App\Interfaces\StateInterface;
use App\Interfaces\FacilityGroupInterface;
use App\Interfaces\PublicHolidayInterface;
use App\Interfaces\TransactionInterface;
use App\Interfaces\CancelledShiftInterface;
use App\Interfaces\ShiftActivityInterface;
use App\Interfaces\BuddyShiftRequestInterface;
use App\Interfaces\ShiftTransferInterface;
use App\Interfaces\ShiftSwapRequestInterface;
use App\Interfaces\FacilityPlanInterface;
use App\Interfaces\RatingReviewInterface;
use App\Interfaces\HcpBlockTimeInterface;
use App\Interfaces\ReferralInterface;
use App\Interfaces\ShiftTrackingInterface;
use App\Jobs\AdminPanel\ShiftBroadcastJob;
use App\Models\ShiftTransfer;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\ShiftsExport;
use App\Exports\TransferredShiftsExport;
use App\Exports\SwapShiftExport;
use App\Exports\BuddyShiftExport;
use Carbon\Carbon;
use Illuminate\Support\Facades\Mail;
use App\Jobs\AdminPanel\SendEmailJob;
use App\Models\Notification;
use App\Interfaces\HcpProfessionInterface;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;

class ShiftController extends Controller
{
    private $shift,$country,$facility,$category,$profession,$level,$hcp,$state, $facilityGroup, $publicHoliday, $transaction, $cancelledShift, $shiftActivity, $buddyShiftRequest, $shiftTransfer, $shiftSwapRequest, $referral;

    public function __construct(ShiftInterface $shift, CountryInterface $country, FacilityInterface $facility, CategoryInterface $category,ProfessionInterface $profession, LevelInterface $level, HcpInterface $hcp, StateInterface $state, FacilityGroupInterface $facilityGroup, PublicHolidayInterface $publicHoliday, TransactionInterface $transaction, CancelledShiftInterface $cancelledShift, ShiftActivityInterface $shiftActivity, BuddyShiftRequestInterface $buddyShiftRequest, ShiftTransferInterface $shiftTransfer, ShiftSwapRequestInterface $shiftSwapRequest, FacilityPlanInterface $facilityPlan, RatingReviewInterface $ratingReview, HcpBlockTimeInterface $hcpBlockTime, ReferralInterface $referral, ShiftTrackingInterface $shiftTracking, HcpProfessionInterface $hcpProfession) {

        $this->shift = $shift;
        $this->country = $country;
        $this->facility = $facility;
        $this->category = $category;
        $this->profession = $profession;
        $this->level = $level;
        $this->hcp = $hcp;
        $this->state = $state;
        $this->facility_group = $facilityGroup;
        $this->public_holiday = $publicHoliday;
        $this->transaction = $transaction;
        $this->cancelled_shift = $cancelledShift;
        $this->shift_activity = $shiftActivity;
        $this->buddy_shift_request = $buddyShiftRequest;
        $this->shift_transfer = $shiftTransfer;
        $this->shift_swap_request = $shiftSwapRequest;
        $this->facility_plan = $facilityPlan;
        $this->ratingReview = $ratingReview;
        $this->hcp_block_time = $hcpBlockTime;
        $this->referral = $referral;
        $this->shift_tracking = $shiftTracking;
        $this->hcp_profession = $hcpProfession;
    }

    /**
     * Pending shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 09 Nov 2020
     */
    public function pending(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = '0';
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Shift Counts
            if (!empty($authUser->facility)) {
                $facilityId = $authUser->facility->id;
                $facilityRecord = $authUser->facility;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $facilityId = $authUser->sub_admin->facility_id;
                $facilityRecord = $authUser->sub_admin->facility;
            } else {
                $facilityId = null;
                $facilityRecord = null;
            }

            $blueShiftsArr = [];
            $amberShiftsArr = [];
            $redShiftsArr = [];
            $fillterBlueMintsArray = [];
            $fillterAmberMintsArray = [];
            $fillterRedMintsArray = [];
            if(count($facilities) && $facilityId == null) {
                foreach($facilities as $facility) {

                    // > 3hrs to shift start
                    $fillterBlueMintsArray = [
                        'shift_filter_traffic_lights' => 'blue',
                        'shift_status' => '0',
                        'current_time' => Carbon::now($facility->state->time_zone_name),
                        'facility_id' => $facility->id,
                    ];
                    $blueShifts = $this->shift->get_shift_count_starting_hours($fillterBlueMintsArray)->pluck('id');

                    if(count($blueShifts)) {
                        foreach($blueShifts as $blueShift){
                            $blueShiftsArr[] = $blueShift;
                        }
                    }
                    //----------------------

                    // < 3 hrs > 1hr to shift start
                    $fillterAmberMintsArray = [
                        'shift_filter_traffic_lights' => 'amber',
                        'shift_status' => '0',
                        'current_time' => Carbon::now($facility->state->time_zone_name),
                        'facility_id' => $facility->id,
                    ];

                    $amberShifts = $this->shift->get_shift_count_starting_hours($fillterAmberMintsArray)->pluck('id');
                    if(count($amberShifts)) {
                        foreach($amberShifts as $amberShift){
                            $amberShiftsArr[] = $amberShift;
                        }
                    }
                    //----------------------

                    // < 1hr to shift start
                    $fillterRedMintsArray = [
                        'shift_filter_traffic_lights' => 'red',
                        'shift_status' => '0',
                        'current_time' => Carbon::now($facility->state->time_zone_name),
                        'facility_id' => $facility->id,
                    ];
                    $redShifts = $this->shift->get_shift_count_starting_hours($fillterRedMintsArray)->pluck('id');
                    if(count($redShifts)) {
                        foreach($redShifts as $redShift){
                            $redShiftsArr[] = $redShift;
                        }
                    }
                    //----------------------

                }
            } else {
                if(!empty($facilityRecord)) {
                    // > 3hrs to shift start
                    $fillterBlueMintsArray = [
                        'shift_filter_traffic_lights' => 'blue',
                        'shift_status' => '0',
                        'current_time' => Carbon::now($facilityRecord->state->time_zone_name),
                        'facility_id' => $facilityRecord->id,
                    ];
                    $blueShifts = $this->shift->get_shift_count_starting_hours($fillterBlueMintsArray)->pluck('id');

                    if(count($blueShifts)) {
                        foreach($blueShifts as $blueShift){
                            $blueShiftsArr[] = $blueShift;
                        }
                    }
                    //----------------------

                    // < 3 hrs > 1hr to shift start
                    $fillterAmberMintsArray = [
                        'shift_filter_traffic_lights' => 'amber',
                        'shift_status' => '0',
                        'current_time' => Carbon::now($facilityRecord->state->time_zone_name),
                        'facility_id' => $facilityRecord->id,
                    ];

                    $amberShifts = $this->shift->get_shift_count_starting_hours($fillterAmberMintsArray)->pluck('id');
                    if(count($amberShifts)) {
                        foreach($amberShifts as $amberShift){
                            $amberShiftsArr[] = $amberShift;
                        }
                    }
                    //----------------------

                    // < 1hr to shift start
                    $fillterRedMintsArray = [
                        'shift_filter_traffic_lights' => 'red',
                        'shift_status' => '0',
                        'current_time' => Carbon::now($facilityRecord->state->time_zone_name),
                        'facility_id' => $facilityRecord->id,
                    ];
                    $redShifts = $this->shift->get_shift_count_starting_hours($fillterRedMintsArray)->pluck('id');
                    if(count($redShifts)) {
                        foreach($redShifts as $redShift){
                            $redShiftsArr[] = $redShift;
                        }
                    }
                    //----------------------
                }
            }
            //-----------------

            // Get Shift
            $shiftWhere = ['shift_status' => '0'];
            if (!empty($authUser->facility)) {
                $shiftWhere['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $shiftWhere['facility_id'] = $authUser->sub_admin->facility_id;
            }
            elseif($authUser->hasRole('Facility Group') == true){
                $shiftWhere['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $shifts = $this->shift->getAll($shiftWhere, true, $request);
            //----------

            $request->request->add(['shortby_filter'=>"1"]);
            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.pending',compact('shifts','facilities','categories','professions','states' , 'request', 'authUser', 'blueShiftsArr', 'amberShiftsArr', 'redShiftsArr'));

        } catch (\Exception $exception) {
            p($exception->getMessage());
            return dashboard_redirect($exception);
        }
    }

    /**
     * Scheduled shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 09 Nov 2020
     */
    public function scheduled(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = '1';
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Shift
            $shiftWhere = ['shift_status' => '1'];

            if (!empty($authUser->facility)) {
                $shiftWhere['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $shiftWhere['facility_id'] = $authUser->sub_admin->facility_id;
            }
            elseif($authUser->hasRole('Facility Group') == true){
                $shiftWhere['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $shifts = $this->shift->getAll($shiftWhere, true, $request);
            //----------

            $request->request->add(['shortby_filter'=>"1"]);
            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.scheduled', compact('shifts', 'facilities', 'categories', 'professions', 'states', 'request', 'authUser', 'generalConfiguration'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Running shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 09 Nov 2020
     */
    public function running(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = '2';
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Shift
            $shiftWhere = ['shift_status' => '2'];

            if (!empty($authUser->facility)) {
                $shiftWhere['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $shiftWhere['facility_id'] = $authUser->sub_admin->facility_id;
            }elseif($authUser->hasRole('Facility Group') == true){
                $shiftWhere['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $shifts = $this->shift->getAll($shiftWhere, true, $request);
            //----------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.running',compact('shifts','facilities','categories','professions','states', 'request', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Completed shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 09 Nov 2020
     */
    public function completed(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = '4';
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Shift
            $shiftWhere = ['shift_status' => '4'];

            if (!empty($authUser->facility)) {
                $shiftWhere['facility_id'] = $authUser->facility->id;
                $request['role'] = 'facility';
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $shiftWhere['facility_id'] = $authUser->sub_admin->facility_id;
                $request['role'] = 'facility';
            } elseif($authUser->hasRole('Facility Group') == true){
                $shiftWhere['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }else {
                $request['role'] = 'super-admin';
            }
            $shifts = $this->shift->getAll($shiftWhere, true, $request);
            //----------

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Loading & Time Configuration
            $loadingTimeConfiguration = get_loading_time_configuration();
            //-----------------------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.completed',compact('shifts','facilities','categories','professions','states', 'request', 'generalConfiguration', 'loadingTimeConfiguration', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Cancelled shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 09 Nov 2020
     */
    public function cancelled(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = '3';
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Shift
            $shiftWhere = ['shift_status' => '3'];

            if (!empty($authUser->facility)) {
                $shiftWhere['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $shiftWhere['facility_id'] = $authUser->sub_admin->facility_id;
            }elseif($authUser->hasRole('Facility Group') == true){
                $shiftWhere['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $shifts = $this->shift->getAll($shiftWhere, true, $request);
            //----------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.cancelled',compact('shifts','facilities','categories','professions','states', 'request', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Past shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 26 Nov 2020
     */
    public function past(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = '6';
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Shift
            $shiftWhere = ['shift_status' => '6'];

            if (!empty($authUser->facility)) {
                $shiftWhere['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $shiftWhere['facility_id'] = $authUser->sub_admin->facility_id;
            }elseif($authUser->hasRole('Facility Group') == true){
                $shiftWhere['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $shifts = $this->shift->getAll($shiftWhere, true, $request);
            //----------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.past',compact('shifts','facilities','categories','professions','states', 'request', 'authUser'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    /**
     * Buddy shift request.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 26 Nov 2020
     */
    public function buddyShiftRequest(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $facilities = $this->facility->getAll(['status' => 'active'], true);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftType = 'buddy';
            $states = $this->state->getAll(['status' => 'active'], true, null, $shiftType);
            //-----------

            // Get buddy shift request
            if (!empty($authUser->facility)) {
                $request['facility_id'] = $authUser->facility->id;
                $request['state_id'] = $authUser->facility->state_id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $request['facility_id'] = $authUser->sub_admin->facility_id;
                $request['state_id'] = $authUser->sub_admin->facility->state_id;
            }
            $buddyShiftRequests = $this->buddy_shift_request->getAll([], true, $request);
            //------------------------


            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.buddy-shift-requests', compact('facilities','categories','professions','states', 'request', 'buddyShiftRequests', 'authUser'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    /**
     * Transferred shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 27 Nov 2020
     */
    public function transferred(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftTransfered = 'yes';
            $states = $this->state->getAll(['status' => 'active'], true, null, null, $shiftTransfered);
            //-----------
            $shiftWhere =[];
            // Get transfer shift
            if (!empty($authUser->facility)) {
                $request['facility'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $request['facility'] = $authUser->sub_admin->facility_id;
            }elseif($authUser->hasRole('Facility Group') == true){
                $shiftWhere['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $shiftTransfers = $this->shift_transfer->getAll($shiftWhere, true, $request);
            //-------------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.transfer', compact('facilities','categories','professions','states', 'request', 'shiftTransfers', 'authUser'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    /**
     * Swapped shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 27 Nov 2020
     */
    public function swapped(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftSwapped = 'yes';
            $states = $this->state->getAll(['status' => 'active'], true, null, null, null, $shiftSwapped);
            //-----------

            // Get Swap shift
            $shiftWhere = [];
            if (!empty($authUser->facility)) {
                $request['facility'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $request['facility'] = $authUser->sub_admin->facility_id;
            }elseif($authUser->hasRole('Facility Group') == true){
                $shiftWhere['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $shiftSwapRequests = $this->shift_swap_request->getAll($shiftWhere, true, $request);
            //---------------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.swapped', compact('facilities','categories','professions','states', 'request', 'shiftSwapRequests', 'authUser'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }


    /**
     * Get All shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 22 Jan 2020
     */
    public function allShifts(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Facility
            $where = ['status' => 'active'];
            if($authUser->hasRole('Facility Group') == true){
                $where['facility_group_id'] = $authUser->facility_group->id;
            }
            elseif($authUser->hasRole('Facility Group Sub Admin') == true){
                $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);

            }
            elseif($authUser->hasRole('Facility Group Admin') == true){
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                // Get States
                $facility_groups = $this->facility_group->get_facility_group_without_pagination(['status'=>'active'], true, $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);
            }
            $facilities = $this->facility->getAll($where, true, $request);
            //-------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Professions
            $professions = $this->profession->getAll(['status' => 'active'], true);
            //----------------

            // Get States
            $shiftStatus = null;
            $states = $this->state->getAll(['status' => 'active'], true, $shiftStatus);
            //-----------

            // Get Shift
            if (!empty($authUser->facility)) {
                $request['facility_id'] = $authUser->facility->id;
                $request['state_id'] = $authUser->facility->state_id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $request['facility_id'] = $authUser->sub_admin->facility_id;
                $request['state_id'] = $authUser->sub_admin->facility->state_id;
            }

            if(isset($request['last_days']) && !empty($request['last_days'])){
                $request['last_days'] = $request['last_days'];
            } else {
                $request['last_days'] = 30;
            }

            $shiftWhere = [];
            $shifts = $this->shift->getAll($shiftWhere, true, $request);
            //----------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.all-shifts',compact('shifts','facilities','categories','professions','states' , 'request', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * View create shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 31 Oct 2020
     */
    public function create(Request $request, $buddyRequestId = null, $type = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            if (!empty($authUser->facility) && $authUser->facility->status != 'active') {
                return dashboard_redirect(__('messages.facility_page_access_error'));
            } else if(!empty($authUser->facility)) {
                $facilityActivePlan = get_facility_active_plan($authUser->facility->id);
                if (empty($facilityActivePlan)) {
                    return redirect()->route('adminPanel.facilities.selectPlan')->with('error', __('messages.facility_plan_expiry_error'));
                }
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $facilityActivePlan = get_facility_active_plan($authUser->sub_admin->facility_id);
                if (empty($facilityActivePlan)) {
                    return redirect()->route('adminPanel.facilities.selectPlan')->with('error', __('messages.facility_plan_expiry_error'));
                }
            }



            if($authUser->hasRole('Facility Group Admin') == true){
                // Get facility group
                $request->request->add(['facility_group_ids'=>json_decode($authUser->facility_group_admin->facility_group_id,true)]);
                $facilityGroups = $this->facility_group->get_list(['status' => 'active'], $request);
                $facility_group_ids = json_decode($authUser->facility_group_admin->facility_group_id,true);
                $request->request->add(['facility_group_ids'=>$facility_group_ids]);

                // Get Facilities
                $facilities = $this->facility->getAll(['status' => 'active'], true, $request);
                //---------------

            }elseif($authUser->hasRole('Facility Group') == true || $authUser->hasRole('Facility Group Sub Admin') == true)
            {
                // Get facility group
                if($authUser->hasRole('Facility Group') == true){
                    $facility_group_id = $authUser->facility_group->id;
                    // Get Facilities
                    $facilities = $this->facility->getAll(['status' => 'active','facility_group_id'=>$facility_group_id], true);
                    //---------------
                }else{
                    $request->request->add(['assigned_facilities'=>json_decode($authUser->sub_admin->assigned_facilities)]);
                    // Get Facilities
                    $facilities = $this->facility->getAll(['status'=>'active'], true, $request);

                    $facility_group_id = $authUser->sub_admin->facility_group_id;

                }
                $facilityGroups = $this->facility_group->find_facility_group($facility_group_id);
            }
            else{
                // Get facility group
                $facilityGroups = $this->facility_group->get_list(['status' => 'active']);
                // Get Facilities
                $facilities = $this->facility->getAll(['status' => 'active'], true);
                //---------------
            }
            //-------------------


            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Hcps
            //$hcps = $this->hcp->getAll(['status' => 'active'], true);
            //---------

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Loading & Time Configuration
            $loadingTimeConfiguration = get_loading_time_configuration();
            //-----------------------------

            // Get buddy shift request
            if(!empty($buddyRequestId)){

                // Get Buddy Shift Request
                $buddyShiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['id' => dv($buddyRequestId)]);
                //------------------------

                // Get Profession
                $professions = $this->profession->get(['category_id' => $buddyShiftRequest['category_id']]);
                //---------------

                // Get Levels
                $levels = $this->level->get(['profession_id' => $buddyShiftRequest['profession_id']]);
                //-----------

            } else {
                $buddyShiftRequest = null;
                $professions = null;
                $levels = null;
            }
            //------------------------

            // Request
            $request = $request->all();
            $request['type'] = $type;
            //--------

            if (!empty($authUser->facility)) {
                return view('admin-panel.shifts.facility-shift-create',compact('facilityGroups', 'facilities', 'categories', 'generalConfiguration', 'loadingTimeConfiguration', 'request', 'buddyShiftRequest', 'professions', 'levels', 'authUser'));
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                return view('admin-panel.shifts.facility-shift-create',compact('facilityGroups', 'facilities', 'categories', 'generalConfiguration', 'loadingTimeConfiguration', 'request', 'buddyShiftRequest', 'professions', 'levels', 'authUser'));
            } else {
                return view('admin-panel.shifts.create',compact('facilityGroups', 'facilities', 'categories', 'generalConfiguration', 'loadingTimeConfiguration', 'request', 'buddyShiftRequest', 'professions', 'levels', 'authUser'));
            }


        }catch (\Exception $exception){
            p($exception->getMessage());
            return dashboard_redirect($exception);
        }
    }

    /**
     * Store shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 09 Nov 2020
     */
    public function store(ValidateShift $request)
    {
//         p($request->all());
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;
        $data = [];

        DB::beginTransaction();
        try {
            // Get Facility
            if(!empty($request['facility'])){
                $facility = $this->facility->find_facility($request['facility']);
            }
            //-------------

            // Set time zone
            date_default_timezone_set($facility->state->time_zone_name);
            //--------------


            // Get buddy shift request
            if(!empty($request['buddy_request_id'])){
                $buddyShiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['id' => $request['buddy_request_id']]);
                $request['category_id'] = $buddyShiftRequest['category_id'];
                $request['profession_id'] = $buddyShiftRequest['profession_id'];
                $request['hcp_level_id'] = $buddyShiftRequest['level_id'];
                $request['shift_types'] = 'buddy';
            } else {
                $buddyShiftRequest = null;
            }
            //------------------------

            if(!empty($request['multiple_shift_true']) &&  $request['multiple_shift_true'] == 'on' && isset($request['multiple_shifts']) && !empty($request['multiple_shifts'])){
                foreach($request['multiple_shifts'] as $multipleShift){
                    if(!empty($multipleShift['word_wing']) && !empty($multipleShift['no_of_opening'])){
                        for ($i=1; $i <= $multipleShift['no_of_opening']; $i++) {
                            $data = [
                                'facility_group_id' => $request['facility_group'],
                                'facility_id' => $request['facility'],
                                'word_wing' => $multipleShift['word_wing'],
                                'category_id' => $request['category_id'],
                                'profession_id' => $request['profession_id'],
                                'hcp_level_id' => $request['hcp_level_id'],
                                'booked_by' => $request['booked_by'],
                                'shift_type' => strtolower($request['shift_types']),
                                'start_time' => Carbon::parse($request['start_time'])->format('Y-m-d H:i'),
                                'end_time' => Carbon::parse($request['end_time'])->format('Y-m-d H:i'),
                                'shift_time' => $request['shift_time'],
                                'break' => $request['break'],
                                'hours' => $request['hours'],
                                'shift_loading' => $request['shift_loading'],
                                'no_of_openings' => 1,
                                'notes' => $request['notes'],
                                'working_hours' => $request['working_hours'],
                                'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                                'facility_amount' => str_replace(",","",$request['facility_amount']),
                                'admin_fees' => $request['admin_fees'],
                                'facility_per_rate' => $request['facility_per_rate'],
                                'hcp_per_rate' => $request['hcp_per_rate'],
                                'admin_amount' => $request['admin_amount'],
                                'address' => $facility['address'],
                                'state_id' => $facility['state_id'],
                                'country_id' => $facility['country_id'],
                                'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                                'final_hours_time' => $request['final_hours_time'],
                                'total_hours_time' => $request['total_hours_time'],
                                'hcp_shift_loading' => $request['hcp_shift_loading'],
                                'hcp_shift_total_loading' => $request['hcp_shift_total_loading'],
                                'facility_shift_loading' => $request['facility_shift_loading'],
                                'facility_shift_total_loading' => $request['facility_shift_total_loading'],
                                'multiple_shifts' => 'yes',
                                'created_by' => $authUser->id,
                                'updated_by' => $authUser->id,
                            ];

                            if (isset($request['buddy_hcp_id']) && !empty($request['buddy_hcp_id'])) {
                                $data['buddy_hcp_id'] = $request['buddy_hcp_id'];
                            }

                            if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                                $data['hcp_id'] = $request['assign_hcp'];
                                $data['shift_status'] = '1';
                            }

                            $shift = $this->shift->store($data);

                            // Store transaction
                            $transactionData = [
                                'shift_id' => $shift->id,
                                'facility_id' => $request['facility'],
                                'facility_amount' => $request['facility_amount'],
                                'admin_fees' => $request['admin_amount'],
                                'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                                'amount_for' => 'facility',
                                'amount_type' => 'shift',
                                'status' => 'pending',
                            ];

                            $transaction = $this->transaction->store($transactionData);
                            //-------------------

                            // Update buddy shift request
                            if(!empty($request['buddy_request_id'])){
                                $this->buddy_shift_request->update(['status' => 'pending', 'shift_id' => $shift->id, 'facility_id' => $shift->facility_id], ['id' => $request['buddy_request_id']]);
                            }
                            //---------------------------

                            // Shift Activity
                            $shiftActivityData = [
                                'shift_id'      => $shift->id,
                                'activity'      => 'shift-created',
                                'created_by'    => $authUser->id,
                                'updated_by'    => $authUser->id,
                            ];

                            if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                                $shiftActivityData['hcp_id'] = $request['assign_hcp'];
                            }

                            $shiftActivity = $this->shift_activity->store($shiftActivityData);
                            //---------------
                            if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                                $hcpIds[] = $request['assign_hcp'];
                                send_shift_push_notification($shift->id, 'shift-assigned', $hcpIds);

                                // Shift Activity
                                $shiftActivityData = [
                                    'hcp_id'        => $shift->hcp_id,
                                    'shift_id'      => $shift->id,
                                    'activity'      => 'shift-direct-assigned',
                                    'created_by'    => $authUser->id,
                                    'updated_by'    => $authUser->id,
                                ];
                                $shiftActivity = $this->shift_activity->store($shiftActivityData);
                                //---------------

                            } else {
                                // ShiftBroadcastJob::dispatch()->delay(now()->addSeconds(5));
                            }

                            if (isset($request['buddy_hcp_id']) && !empty($request['buddy_hcp_id'])) {
                                $hcpIds[] = $request['buddy_hcp_id'];
                                send_shift_push_notification($shift->id, 'shift-assigned', $hcpIds);
                            }

                        }
                    } else {
                        unset($multipleShift);
                    }
                }
            } else {
                $data = [
                    'facility_group_id' => $request['facility_group'],
                    'facility_id' => $request['facility'],
                    'word_wing' => $request['word_wing'],
                    'category_id' => $request['category_id'],
                    'profession_id' => $request['profession_id'],
                    'hcp_level_id' => $request['hcp_level_id'],
                    'booked_by' => $request['booked_by'],
                    'shift_type' => strtolower($request['shift_types']),
                    'start_time' => Carbon::parse($request['start_time'])->format('Y-m-d H:i'),
                    'end_time' => Carbon::parse($request['end_time'])->format('Y-m-d H:i'),
                    'shift_time' => $request['shift_time'],
                    'break' => $request['break'],
                    'hours' => $request['hours'],
                    'shift_loading' => $request['shift_loading'],
                    'no_of_openings' => $request['no_of_openings'],
                    'notes' => $request['notes'],
                    'working_hours' => $request['working_hours'],
                    'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                    'facility_amount' => str_replace(",","",$request['facility_amount']),
                    'admin_fees' => $request['admin_fees'],
                    'facility_per_rate' => $request['facility_per_rate'],
                    'hcp_per_rate' => $request['hcp_per_rate'],
                    'admin_amount' => $request['admin_amount'],
                    'address' => $facility['address'],
                    'state_id' => $facility['state_id'],
                    'country_id' => $facility['country_id'],
                    'multiple_shifts' => 'no',
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'final_hours_time' => $request['final_hours_time'],
                    'total_hours_time' => $request['total_hours_time'],
                    'hcp_shift_loading' => $request['hcp_shift_loading'],
                    'hcp_shift_total_loading' => $request['hcp_shift_total_loading'],
                    'facility_shift_loading' => $request['facility_shift_loading'],
                    'facility_shift_total_loading' => $request['facility_shift_total_loading'],
                    'created_by' => $authUser->id,
                    'updated_by' => $authUser->id,
                ];

                if (isset($request['buddy_hcp_id']) && !empty($request['buddy_hcp_id'])) {
                    $data['buddy_hcp_id'] = $request['buddy_hcp_id'];
                }

                if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                    $data['hcp_id'] = $request['assign_hcp'];
                    $data['shift_status'] = '1';
                }

	//sleepover shift
	if(isset($request['sleepover_shift_true']) && $request['sleepover_shift_true']=='on'){
                    $data['is_sleepover_shift'] =1;
	 $generalConfiguration = get_general_configuration();
                    $data['hcp_sleepover_rate'] =$generalConfiguration['hcp_sleepover_rate'];
	   $data['facility_sleepover_rate'] =$generalConfiguration['facility_sleepover_rate'];
                    $data['sleepover_start_time'] = Carbon::parse($request['sleepover_start_time'])->format('Y-m-d H:i');
                    $data['sleepover_end_time'] = Carbon::parse($request['sleepover_end_time'])->format('Y-m-d H:i');
                    $data['sleepover_morning_start_time'] = Carbon::parse($request['sleepover_morning_start_time'])->format('Y-m-d H:i');
                    $data['sleepover_morning_end_time'] = Carbon::parse($request['sleepover_morning_end_time'])->format('Y-m-d H:i');
                    $data['sleepover_afternoon_start_time'] = Carbon::parse($request['start_time'])->format('Y-m-d H:i');
                    $data['sleepover_afternoon_end_time'] = Carbon::parse($request['end_time'])->format('Y-m-d H:i');
	$data['sleepover_night_start_time'] = Carbon::parse($request['sleepover_night_start_time'])->format('Y-m-d H:i');
                    $data['sleepover_night_end_time'] = Carbon::parse($request['sleepover_night_end_time'])->format('Y-m-d H:i');
                    $data['end_time'] = Carbon::parse($request['sleepover_morning_end_time'])->format('Y-m-d H:i');

		$data['sleepover_afternoon_admin_fees'] = $request->sleepover_afternoon_admin_fees;
$data['sleepover_afternoon_loading'] = $request->sleepover_afternoon_loading;
$data['sleepover_afternoon_working_hours'] = $request->sleepover_afternoon_working_hours;
$data['sleepover_afternoon_faciliy_amount'] = number_format($request->sleepover_afternoon_faciliy_amount,2);
$data['sleepover_afternoon_hcp_amount'] = number_format($request->sleepover_afternoon_hcp_amount,2);

$data['sleepover_night_admin_fees'] = $request->sleepover_night_admin_fees;
$data['sleepover_night_loading'] = $request->sleepover_night_loading;
$data['sleepover_night_working_hours'] = $request->sleepover_night_working_hours;
$data['sleepover_night_faciliy_amount'] = number_format($request->sleepover_night_faciliy_amount,2);
$data['sleepover_night_hcp_amount'] = number_format($request->sleepover_night_hcp_amount,2);

$data['sleepover_morning_admin_fees'] = $request->sleepover_morning_admin_fees;
$data['sleepover_morning_loading'] = $request->sleepover_morning_loading;
$data['sleepover_morning_working_hours'] = $request->sleepover_morning_working_hours;
$data['sleepover_morning_faciliy_amount'] = number_format($request->sleepover_morning_faciliy_amount,2);
$data['sleepover_morning_hcp_amount'] = number_format($request->sleepover_morning_hcp_amount,2);
                }

                $shift = $this->shift->store($data);

                // Store transaction
                $transactionData = [
                    'shift_id' => $shift->id,
                    'facility_id' => $request['facility'],
                    'facility_amount' => $request['facility_amount'],
                    'admin_fees' => $request['admin_amount'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'amount_for' => 'facility',
                    'amount_type' => 'shift',
                    'status' => 'pending',
                ];

                $transaction = $this->transaction->store($transactionData);
                //-------------------

                // Update buddy shift request
                if(!empty($request['buddy_request_id'])){
                    $this->buddy_shift_request->update(['status' => 'pending', 'shift_id' => $shift->id, 'facility_id' => $shift->facility_id], ['id' => $request['buddy_request_id']]);
                }
                //---------------------------

                // Shift Activity
                $shiftActivityData = [
                    'shift_id'      => $shift->id,
                    'activity'      => 'shift-created',
                    'created_by'    => $authUser->id,
                    'updated_by'    => $authUser->id,
                ];

                if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                    $shiftActivityData['hcp_id'] = $request['assign_hcp'];
                }

                $shiftActivity = $this->shift_activity->store($shiftActivityData);
                //---------------

                if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                    $hcpIds[] = $request['assign_hcp'];
                    send_shift_push_notification($shift->id, 'shift-assigned', $hcpIds);

                    // Shift Activity
                    $shiftActivityData = [
                        'hcp_id'        => $shift->hcp_id,
                        'shift_id'      => $shift->id,
                        'activity'      => 'shift-direct-assigned',
                        'created_by'    => $authUser->id,
                        'updated_by'    => $authUser->id,
                    ];
                    $shiftActivity = $this->shift_activity->store($shiftActivityData);
                    //---------------

                } else {

                    date_default_timezone_set($shift->state->time_zone_name);
                    //--------------

                    $currentTime = Carbon::now($shift->state->time_zone_name);

                    $getfacility = $this->facility->find_facility($shift['facility_id']);
                    $hcpFilter['shift_id'] = $shift['id'];
                    $hcpFilter['facility_id'] = $shift['facility_id'];
                    $hcpFilter['state_id'] = $shift['state_id'];
                    $hcpFilter['country_id'] = $shift['country_id'];
                    $hcpFilter['facility_latitude'] = $getfacility['latitude'];
                    $hcpFilter['facility_longitude'] = $getfacility['longitude'];
                    $hcpFilter['category_id'] = $shift['category_id'];
                    $hcpFilter['profession_id'] = $shift['profession_id'];
                    $hcpFilter['level_id'] = $shift['hcp_level_id'];
                    $hcpFilter['shift_start_time'] = $shift['start_time'];
                    $hcpFilter['shift_end_time'] = $shift['end_time'];
                    $hcpFilter['time_zone_name'] = $shift->state->time_zone_name;
                    $hcpFilter['check_transfer_case'] = 'true';
                    $hcpFilter['check_swap_case'] = 'true';
//                    dd($hcpFilter);
                    $allHcps = $this->hcp->get_hcp_listing_for_shift($hcpFilter);
                    $allHcpsIds = [];
                    if (count($allHcps)) {
                        foreach($allHcps as $allHcp){
                            $allHcpsIds[] = $allHcp->id;
                        }

                        send_shift_push_notification($shift->id, 'new-shift', array_unique($allHcpsIds));
                    // ShiftBroadcastJob::dispatch()->delay(now()->addSeconds(5));
                    }
                }

                if (isset($request['buddy_hcp_id']) && !empty($request['buddy_hcp_id'])) {
                    $hcpIds[] = $request['buddy_hcp_id'];
                    send_shift_push_notification($shift->id, 'shift-assigned', $hcpIds);
                }
            }

            // Get Current Plan
            if(!empty($authUser->facility)) {
                $facilityActivePlan = get_facility_active_plan($authUser->facility->id);

                if ($facilityActivePlan['plan_id'] == 4) {
                    // Get Current Shift Count
                    $shiftCount = $this->shift->shift_where(['facility_id' => $authUser->facility->id])->count();
                    //------------------------

                    if ($shiftCount >= $facilityActivePlan['shift_posting_limit_in_trial_account']) {
                        $this->facility_plan->update(['status' => 'expired', 'expiry_date' => date('Y-m-d'), 'notification_date' => null], ['id' => $facilityActivePlan['id']]);
                    }
                }
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $facilityActivePlan = get_facility_active_plan($authUser->sub_admin->facility_id);

                if ($facilityActivePlan['plan_id'] == 4) {
                    // Get Current Shift Count
                    $shiftCount = $this->shift->shift_where(['facility_id' => $authUser->sub_admin->facility_id])->count();
                    //------------------------

                    if ($shiftCount >= $facilityActivePlan['shift_posting_limit_in_trial_account']) {
                        $this->facility_plan->update(['status' => 'expired', 'expiry_date' => date('Y-m-d'), 'notification_date' => null], ['id' => $facilityActivePlan['id']]);
                    }
                }
            }
            //-----------------

            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            $errorMessage = $exception->getMessage();
            DB::rollback();
        }


        if (!is_null($shift)) {

            // General Configuration
            $generalConfiguration = get_general_configuration();

            if($generalConfiguration->send_email_on_shift_create==1){
                // Set email data
                $emailData['message'] = __('messages.new_shift_mail_subject');
                $emailData['subject'] = __('messages.new_shift_mail_subject');
                $emailData['sender'] = __('messages.new_shift_mail_subject');
                $emailData['email'] = env('SHIFT_ACTIVITY_EMAIL');
                $emailData['receiver'] = env('SHIFT_ACTIVITY_EMAIL');
                $emailData['shift'] = $shift;

                // Send email
                Mail::send('emails.admin-panel.shift-activity-email', $emailData, function ($message) use ($emailData) {
                    $message->to($emailData['email'], $emailData['receiver'])->subject($emailData['subject']);
                });
            }

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

            if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                return redirect()->route('adminPanel.shift.scheduled')->with(['notification' => $notification]);
            } else {
                return redirect()->route('adminPanel.shift.pending')->with(['notification' => $notification]);
            }

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.record_creation_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.create')->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * View edit shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 10 Nov 2020
     */
    public function edit(Request $request, $id)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));

            //----------

            // Get facility group
            $facilityGroups = $this->facility_group->get_list(['status' => 'active']);
            //-------------------

            // Get Facilities
            $facilities = $this->facility->getAll(['status' => 'active'], true);
            //---------------

            // Get Categories
            $categories = $this->category->getAll(['status' => 'active'], true);
            //---------------

            // Get Profession
            $professions = $this->profession->get(['category_id' => $shift['category_id']]);
            //---------------

            // Get Levels
            $levels = $this->level->get(['profession_id' => $shift['profession_id'], 'status' => 'active']);
            //-----------

            // Get Hcps
            $request['state_id'] = $shift['state_id'];
            $request['country_id'] = $shift['country_id'];
            $request['category_id'] = $shift['country_id'];
            $request['profession_id'] = $shift['profession_id'];
            $request['level_id'] = $shift['hcp_level_id'];
            $request['facility_id'] = $shift['facility_id'];
            $request['facility_latitude'] = $shift['facility']['latitude'];
            $request['facility_longitude'] = $shift['facility']['longitude'];
            $request['time_zone_name'] = $shift['state']['time_zone_name'];

            //---------

            // Get Buddy Shift Request
            if(!empty($shift) && $shift['shift_type'] == 'buddy'){
                $buddyShiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['shift_id' => $shift->id]);
            } else {
                $buddyShiftRequest = null;
            }
            //------------------------

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Loading & Time Configuration
            $loadingTimeConfiguration = get_loading_time_configuration();
            //-----------------------------

            if (!empty($authUser->facility)) {
	$hcps = $this->hcp->get_hcp_listing_for_shift($request);
                return view('admin-panel.shifts.facility-shift-edit', compact('shift', 'facilityGroups', 'facilities', 'categories', 'generalConfiguration', 'loadingTimeConfiguration', 'professions', 'levels', 'buddyShiftRequest', 'authUser', 'hcps'));

            } else {

                return view('admin-panel.shifts.edit', compact('shift', 'facilityGroups', 'facilities', 'categories', 'generalConfiguration', 'loadingTimeConfiguration', 'professions', 'levels', 'buddyShiftRequest', 'authUser'));
            }


        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Update shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 09 Nov 2020
     */
    public function update(Request $request, $id)
    {
        // p($request->all());
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;
        $data = [];

        DB::beginTransaction();
        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));

            if($shift->shift_status!='0'){
                // Set notification
                $notification = [
                    '_status' => false,
                    '_message' => __('messages.shift_already_accepted', ['record' => 'Shift']),
                    '_type' => 'error',
                ];
                //-----------------

                return redirect()->route('adminPanel.shift.edit', ['id' => $id])->withInput()->with(['notification' => $notification]);

            }

            //----------

            // Get Facility
            if(!empty($shift['facility_id'])){
                $facility = $this->facility->find_facility($shift['facility_id']);
            }
            //-------------

            // Set time zone
            date_default_timezone_set($facility->state->time_zone_name);
            //--------------

            if(!empty($request['start_time']) && !empty($request['end_time'])) {
                $data = [
                    'facility_group_id' => $request['facility_group'],
                    'facility_id' => $request['facility'],
                    'category_id' => $request['category_id'],
                    'profession_id' => $request['profession_id'],
                    'hcp_level_id' => $request['hcp_level_id'],
                    'word_wing' => $request['word_wing'],
                    'booked_by' => $request['booked_by'],
                    'shift_time' => $request['shift_time'],
                    'shift_type' => strtolower($request['shift_types']),
                    'start_time' => Carbon::parse($request['start_time'])->format('Y-m-d H:i'),
                    'end_time' => Carbon::parse($request['end_time'])->format('Y-m-d H:i'),
                    'break' => $request['break'],
                    'hours' => $request['hours'],
                    'shift_loading' => $request['shift_loading'],
                    'no_of_openings' => $request['no_of_openings'],
                    'notes' => $request['notes'],
                    'working_hours' => $request['working_hours'],
                    'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                    'facility_amount' => str_replace(",","",$request['facility_amount']),
                    'admin_fees' => $request['admin_fees'],
                    'admin_amount' => $request['admin_amount'],
                    'facility_per_rate' => $request['facility_per_rate'],
                    'hcp_per_rate' => $request['hcp_per_rate'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'final_hours_time' => $request['final_hours_time'],
                    'total_hours_time' => $request['total_hours_time'],
                    'hcp_shift_loading' => $request['hcp_shift_loading'],
                    'hcp_shift_total_loading' => $request['hcp_shift_total_loading'],
                    'facility_shift_loading' => $request['facility_shift_loading'],
                    'facility_shift_total_loading' => $request['facility_shift_total_loading'],
                    'updated_by' => $authUser->id,
                ];
            } else {
                $data = [
                    'word_wing' => $request['word_wing'],
                    'booked_by' => $request['booked_by'],
                    'notes' => $request['notes'],
                ];
            }

	//sleepover shift
	//p($request->all());
                if(isset($request['sleepover_shift_true']) && $request['sleepover_shift_true']=='on'){
                    $data['is_sleepover_shift'] =1;
                    $generalConfiguration = get_general_configuration();
                    $data['hcp_sleepover_rate'] =$generalConfiguration['hcp_sleepover_rate'];
	   $data['facility_sleepover_rate'] =$generalConfiguration['facility_sleepover_rate'];
                    $data['sleepover_start_time'] = Carbon::parse($request['sleepover_start_time'])->format('Y-m-d H:i');
                    $data['sleepover_end_time'] = Carbon::parse($request['sleepover_end_time'])->format('Y-m-d H:i');
                    $data['sleepover_morning_start_time'] = Carbon::parse($request['sleepover_morning_start_time'])->format('Y-m-d H:i');
                    $data['sleepover_morning_end_time'] = Carbon::parse($request['sleepover_morning_end_time'])->format('Y-m-d H:i');
                    $data['sleepover_afternoon_start_time'] = Carbon::parse($request['start_time'])->format('Y-m-d H:i');
                    $data['sleepover_afternoon_end_time'] = Carbon::parse($request['end_time'])->format('Y-m-d H:i');
	$data['sleepover_night_start_time'] = Carbon::parse($request['sleepover_night_start_time'])->format('Y-m-d H:i');
                    $data['sleepover_night_end_time'] = Carbon::parse($request['sleepover_night_end_time'])->format('Y-m-d H:i');
                    $data['end_time'] = Carbon::parse($request['sleepover_morning_end_time'])->format('Y-m-d H:i');

	$data['sleepover_afternoon_admin_fees'] = $request->sleepover_afternoon_admin_fees;
$data['sleepover_afternoon_loading'] = $request->sleepover_afternoon_loading;
$data['sleepover_afternoon_working_hours'] = $request->sleepover_afternoon_working_hours;
$data['sleepover_afternoon_faciliy_amount'] = number_format($request->sleepover_afternoon_faciliy_amount,2);
$data['sleepover_afternoon_hcp_amount'] = number_format($request->sleepover_afternoon_hcp_amount,2);

$data['sleepover_night_admin_fees'] = $request->sleepover_night_admin_fees;
$data['sleepover_night_loading'] = $request->sleepover_night_loading;
$data['sleepover_night_working_hours'] = $request->sleepover_night_working_hours;
$data['sleepover_night_faciliy_amount'] = number_format($request->sleepover_night_faciliy_amount,2);
$data['sleepover_night_hcp_amount'] = number_format($request->sleepover_night_hcp_amount,2);

$data['sleepover_morning_admin_fees'] = $request->sleepover_morning_admin_fees;
$data['sleepover_morning_loading'] = $request->sleepover_morning_loading;
$data['sleepover_morning_working_hours'] = $request->sleepover_morning_working_hours;
$data['sleepover_morning_faciliy_amount'] = number_format($request->sleepover_morning_faciliy_amount,2);
$data['sleepover_morning_hcp_amount'] = number_format($request->sleepover_morning_hcp_amount,2);

                }

            $shift = $this->shift->update($data, ['id' => dv($id)]);

            // Shift Activity
            $shiftActivityData = [
                'shift_id'      => dv($id),
                'activity'      => 'shift-updated',
                'created_by'    => $authUser->id,
                'updated_by'    => $authUser->id,
            ];

            $shiftActivity = $this->shift_activity->store($shiftActivityData);
            //---------------

            if(!empty($request['shift_types']) && !empty($request['start_time']) && !empty($request['end_time'])) {
                // Store transaction
                $transactionData = [
                    'facility_amount' => $request['facility_amount'],
                    'admin_fees' => $request['admin_amount'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'amount_for' => 'facility',
                    'amount_type' => 'shift',
                    'status' => 'pending',
                ];

                $transaction = $this->transaction->update($transactionData, ['shift_id' => dv($id)]);
                //-------------------
            }

            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_updated', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.pending')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_updation_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.edit', ['id' => $id])->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Get hcp listing.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 09 Nov 2020
     */
    public function getHcps(Request $request)
    {
        $hcps = null;
        $multipleShifts = '';
        try {

            if(isset($request['multiple_shifts']) && !empty($request['multiple_shifts'])){
                $multipleShifts = $request['multiple_shifts'];
            }

            $request['facility_id'] = $request['facility'];
            if(!empty($request['facility_id'])) {
                $facility = $this->facility->find_facility($request['facility_id']);
                $request['state_id'] = $facility['state_id'];
                $request['country_id'] = $facility['country_id'];
                $request['facility_latitude'] = $facility['latitude'];
                $request['facility_longitude'] = $facility['longitude'];
                $request['time_zone_name'] = $facility['state']['time_zone_name'];
            }

            // Set time zone
            date_default_timezone_set($facility->state->time_zone_name);
            $currentTime = Carbon::now($facility->state->time_zone_name);
            //--------------

            // fortnight
            $startDate = Carbon::parse($request['shift_start_time']);
            if($startDate->format('d') <= '15') {
                $firstDay = $startDate->firstOfMonth()->format('d-m-Y');
                $lastDay = Carbon::parse($firstDay)->addWeeks(2)->format('d-m-Y');
            } else {
                $firstDay = Carbon::parse('16-'.$startDate->format('m').'-'.$startDate->format('Y'))->format('d-m-Y');
                $lastDay = Carbon::parse($request['shift_start_time'])->lastOfMonth()->format('d-m-Y');
            }
            $request['fortnight_start'] = $firstDay;
            $request['fortnight_end'] = $lastDay;
            //----------
            if(!empty($request['profession_id']) && empty($request['level_id'])){
                $profession = $this->profession->find_profession($request['profession_id']);

                if($profession->has_levels == "yes"){
                    $response = [
                        '_status' => false,
                        '_data'   => null,
                        '_message' => __('messages.shift_level_id_required'),
                        '_type' => 'error',
                        '_content' => view('admin-panel.includes.shifts.hcp-listing')->with([
                            'hcps' => [],
                            'facility' => [],
                            'request' => $request,
                        ])->render(),
                    ];
                    return response()->json($response, 200);
                }

            }
            // Get Hcps
            $hcps = $this->hcp->get_hcp_listing_for_shift_admin($request);
            //---------

        } catch (\Exception $exception) {
            $hcps = null;
        }

        if (!empty($hcps)) {

            $response = [
                '_status' => true,
                '_data'   => null,
                '_message' => __('messages.records_found', ['records' => 'Hcp']),
                '_type' => 'success',
                '_content' => view('admin-panel.includes.shifts.hcp-listing')->with([
                    'hcps' => $hcps,
                    'facility' => $facility,
                    'multipleShifts' => $multipleShifts,
                    'request' => $request,
                ])->render(),
            ];

        } else {

            $response = [
                '_status' => false,
                '_data'   => null,
                '_message' => __('messages.records_not_found', ['records' => 'Hcp']),
                '_type' => 'error',
                '_content' => view('admin-panel.includes.shifts.hcp-listing')->with([
                    'hcps' => [],
                    'facility' => [],
                    'request' => $request,
                ])->render(),
            ];
        }

        return response()->json($response, 200);

    }

    public function checkForProfessionLevel(Request  $request){
        if(!empty($request->profession_id) && empty($request->level_id)){
            $profession = $this->profession->find_profession($request['profession_id']);

            if($profession->has_levels == "yes"){
                return response()->json(false, 200);
            }

        }
        return response()->json(true, 200);
    }

    /**
     * Shift Rebroadcast.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 20 Nov 2020
     */
    public function shiftRebroadcast(Request $request, $id = null)
    {
        $shift = null;

        try {

            // Get User
            $authUser = auth()->user();
            //---------

            // Update Shift Broadcast
            $shiftBroadcastWhere = ['id' => dv($id)];
            $shift = $this->shift->update(['shift_broadcast' => 'favourite'], $shiftBroadcastWhere);
            //-----------------------

            // ShiftBroadcastJob::dispatch()->delay(now()->addSeconds(1));
            remove_new_shift_notification(dv($id));

            $shiftActivityData = [
                'shift_id'      => dv($id),
                'activity'      => 'rebroadcast-shift',
                'created_by'    => $authUser->id,
                'updated_by'    => $authUser->id,
            ];
            $this->shift_activity->store($shiftActivityData);

            if (!is_null($shift)) {

                // Set notification
                $notification = [
                    '_status' => true,
                    '_message' => __('messages.job_notification_sent'),
                    '_type' => 'success',
                ];
                //-----------------

                return redirect()->route('adminPanel.shift.pending', ['id' => $id])->withInput()->with(['notification' => $notification]);

            } else {

                // Set notification
                $notification = [
                    '_status' => false,
                    '_message' => __('messages.job_notification_sent_failed'),
                    '_type' => 'error',
                ];
                //-----------------

                return redirect()->route('adminPanel.shift.pending', ['id' => $id])->withInput()->with(['notification' => $notification]);
            }

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Assign Hcp List.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 27 Jan 2021
     */
    public function assignHcpList(Request $request, $id = null)
    {
        try {

            // Get User
            $authUser = auth()->user();
            //---------

            $shiftId = dv($id);

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //---------

            // Set time zone
            date_default_timezone_set($shift->state->time_zone_name);
            $currentTime = Carbon::now($shift->state->time_zone_name);
            //--------------

            // fortnight
            $startDate = Carbon::parse($shift['start_time']);
            if($startDate->format('d') <= '15') {
                $firstDay = $startDate->firstOfMonth()->format('d-m-Y');
                $lastDay = Carbon::parse($firstDay)->addWeeks(2)->format('d-m-Y');
            } else {
                $firstDay = Carbon::parse('16-'.$startDate->format('m').'-'.$startDate->format('Y'))->format('d-m-Y');
                $lastDay = Carbon::parse($shift['start_time'])->lastOfMonth()->format('d-m-Y');
            }
            $request['fortnight_start'] = $firstDay;
            $request['fortnight_end'] = $lastDay;
            //----------

            $request['shift_start_time'] = $shift['start_time'];
            $request['shift_end_time'] = $shift['end_time'];

            // Shift Data
            $shiftData = [
                'category_id' => $shift['category_id'],
                'profession_id' => $shift['profession_id'],
                'level_id' => $shift['hcp_level_id'],
                'shift_id' => $shift['id'],
                'buddy_hcp_id' => $shift['buddy_hcp_id'],
                'facility_id' => $shift['facility_id'],
                'state_id' => $shift['state_id'],
                'country_id' => $shift['country_id'],
                'facility_latitude' => $shift['facility']['latitude'],
                'facility_longitude' => $shift['facility']['longitude'],
                'fortnight_start' => $firstDay,
                'fortnight_end' => $lastDay,
                'shift_start_time' => $shift['start_time'],
                'shift_end_time' => $shift['end_time'],
                'shift_id' => $shift['id'],
                'check_transfer_case' => 'true',
                'check_swap_case' => 'true',
                'search' => isset($request['search'])?$request['search']:'',
            ];
            //-----------

            // Get Hcps
            $hcps = $this->hcp->get_hcp_listing_for_shift_admin($shiftData);
            //---------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.assign-hcp', compact('hcps', 'request', 'shiftId', 'shift'));

        } catch (\Exception $exception) {
	//p($exception->getMessage());
            return dashboard_redirect($exception);
        }
    }

    /**
     * Shift Send Rebroadcast Notification.
     *
     * @author Sumit
     * @created 27 Jan 2021
    */
    public function assignHcp(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'shift_id' => [
                'required',
                Rule::exists('shifts', 'id')->where(function ($query) {
                    $query->wherein('shift_status', ['0']);
                }),
            ],
        ]);
        if ($validator->fails()) {
            $errors = $validator->messages()->all();
            // Set notification
            $notification = [
                '_status' => false,
                '_message' => $errors,
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.pending')->withInput()->with(['notification' => $notification]);
        }
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;

        try {

            if (!empty($request['assign_hcp']) && !empty($request['shift_id'])) {

                // Update Shift
                $where = ['id' => $request['shift_id']];
                $shift = $this->shift->update(['hcp_id' => $request['assign_hcp'], 'shift_status' =>'1'], $where);
                //-------------
                $shiftDetail = $this->shift->find_shift($request['shift_id']);

                // Get Facility
                $facility = $this->facility->find_facility($shiftDetail->facility_id);

                //-------------

                // Set time zone
                date_default_timezone_set($facility->state->time_zone_name);
                //--------------


                // Shift Activity
                $shiftActivityData = [
                    'hcp_id'        => $request['assign_hcp'],
                    'shift_id'      => $request['shift_id'],
                    'activity'      => 'shift-direct-assigned',
                    'created_by'    => $authUser->id,
                    'updated_by'    => $authUser->id,
                ];
                $shiftActivity = $this->shift_activity->store($shiftActivityData);
                //---------------

                // Send Notification
                $hcpIds[] = $request['assign_hcp'];
                send_shift_push_notification($request['shift_id'], 'shift-assigned', $hcpIds);
                //------------------
            }

        } catch (\Exception $exception) {
            $shift = null;
        }

        if (!is_null($shift)) {
            $shiftDetail = $shiftDetail->fresh();
            $hcp_name = $shiftDetail->hcp->first_name.' '.$shiftDetail->hcp->last_name;
            $facility_name = $shiftDetail->facility->name;
            $wing = $shiftDetail->word_wing;
            $prof = $shiftDetail->profession->name;
            $start = $shiftDetail->start_time;
            // Set email data
            $emailData['message'] =  __('messages.shift_assigned_text_message', ['facility' => $facility_name,'SHIFT' => $shiftDetail->shift_prefix." ".$shiftDetail->id,'HCP' => $hcp_name,'wing' => $wing,'prof' => $prof,'start' => $start]);
            $emailData['subject'] = __('messages.shift_assigned_mail_subject');
            $emailData['sender'] = __('messages.shift_assigned_mail_subject');
            $emailData['email'] = env('SHIFT_ACTIVITY_EMAIL');
            $emailData['receiver'] = env('SHIFT_ACTIVITY_EMAIL');
            $emailData['shift'] = $shiftDetail;

            // Send email
            Mail::send('emails.admin-panel.shift-activity-email', $emailData, function ($message) use ($emailData, $shiftDetail) {
                $message->to($emailData['email'], $emailData['receiver'])->subject($emailData['subject']);
                if(!empty($shiftDetail->facility->additional_nurse_email)){
                    $cc_emails=explode(",",$shiftDetail->facility->additional_nurse_email);
                    foreach($cc_emails as $cc){
                        $message->cc($cc);
                    }
                }
            });

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.job_notification_sent'),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.scheduled', ['id' => ev($request['shift_id'])])->withInput()->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.job_notification_sent_failed'),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.scheduled', ['id' => ev($request['shift_id'])])->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Shift Details.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 20 Nov 2020
     */
    public function details(Request $request, $id = null)
    {
        try {

            // Get User
            $authUser = auth()->user();
            //---------

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            return view('admin-panel.shifts.details', compact('shift', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Shift cancel modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 24 Nov 2020
     */
    public function cancelShiftModal(Request $request, $id = null)
    {
        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            return view('admin-panel.includes.shifts.cancel-shift-modal', compact('shift'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Shift cancel.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 26 Nov 2020
     */
    public function cancelShift(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;
        $penaltyPoint = 0;
        $penaltyAmount = 0;
        $cancelTime = date('Y-m-d H:i', strtotime($request['cancel_time']));

        DB::beginTransaction();
        try {

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            // Set time zone
            date_default_timezone_set($shift->state->time_zone_name);
            //--------------

            $cancelTime = Carbon::parse($cancelTime);

            // Check Time Diff
            $to = Carbon::parse($shift['start_time']);
            $from = Carbon::parse($cancelTime);
            $timeDiff = $to->diffInHours($from);
            //----------------

            // Check Penalty
            if($request['cancel_by'] == 'hcp' && $timeDiff <= $generalConfiguration['free_shift_cancel_period_for_hcp']){
                $penaltyPoint = $generalConfiguration['penalty_points_for_shift_cancellation'];
                $hcpPoint = $shift->hcp->points-$penaltyPoint;

                // Update Hcp
                if($hcpPoint <= 0) {
                    $hcpData = ['points'  => $hcpPoint, 'status' => 'blocked'];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $shift->hcp_id]);

                    // Store Hcp Block
                    $dataBlock = [
                        'hcp_id' => $shift->hcp_id,
                        'created_by' => $authUser->id,
                        'updated_by' => $authUser->id,
                    ];

                    $this->hcp_block_time->store($dataBlock);
                    //----------------

                    // Hcp Activity
                    create_hcp_activity($shift->hcp_id, 'account-blocked', __('hcp_activities.account_blocked'), $authUser->id);
                    //-------------

                } else {
                    $hcpData = ['points'  => $hcpPoint];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $shift->hcp_id]);
                }
                //-----------

            } else if($request['cancel_by'] == 'facility' && $timeDiff <= $generalConfiguration['free_shift_cancel_period_for_facillity']){
                $penaltyAmount = -$generalConfiguration['cancel_penalty_fee_for_facility'];

                // Update facility transaction
                $transactionUpdate = $this->transaction->update(['status' => 'cancelled'], ['shift_id' => $shift->id, 'facility_id' => $shift->facility_id]);
                //----------------------------

                // Cancel By Facility (Store transaction)
                $transactionData = [
                    'shift_id' => $shift->id,
                    'facility_id' => $shift->facility_id,
                    'facility_amount' => $penaltyAmount,
                    'amount_for' => 'facility',
                    'amount_type' => 'shift-cancel-penalty',
                    'status' => 'pending',
                ];

                $transaction = $this->transaction->store($transactionData);
                //---------------------------------------
            }
            //--------------

            // Cancel Trainee Shift
            if (!empty($shift->trainee_hcp_id)) {
                $buddyshiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['shift_id' => $shift->trainee_buddy_shift_id]);
                if(!empty($buddyshiftRequest)){
                    $this->buddy_shift_request->update(['status' => 'cancelled'], ['id' => $buddyshiftRequest->id]);
                }

                $shiftTraineeData = ['shift_status' => '3'];
                $this->shift->update($shiftTraineeData, ['id' => $shift->trainee_buddy_shift_id]);

                // Send Cancel Shift Notification To Trainee Hcp,Admin,Facility
                if (!empty($shift['trainee_hcp_id'])) {
                    send_shift_push_notification($shift->trainee_buddy_shift_id, 'trainee-buddy-shift-cancelled', $shift['trainee_hcp_id']);
                }
                //----------------------------------------------
            }
            //---------------------

            if($request['cancel_by'] == 'hcp'){

                // Update Shift
                if ($shift->shift_type == 'buddy') {
                    $mentorShiftData = ['trainee_hcp_name' => null, 'trainee_hcp_email' => null, 'trainee_hcp_id' => null, 'trainee_buddy_shift_id' => null];
                    $this->shift->update($mentorShiftData, ['trainee_buddy_shift_id' => $shift->id]);

                    $shiftData = ['shift_status' => '3'];
                    $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
                } else {
                    $shiftData = ['hcp_id' => null, 'shift_status' => '0'];
                    $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
                }
                //-------------

                if($shift->end_time > $cancelTime){
                    // Update Shift Broadcast
                    $shiftBroadcastWhere = ['id' => $shift->id];
                    $this->shift->update(['shift_broadcast' => 'favourite', 'shift_rebroadcast_time' => null], $shiftBroadcastWhere);
                    //-----------------------
                }


                remove_new_shift_notification($shift->id);
                // ShiftBroadcastJob::dispatch()->delay(now()->addSeconds(1));

            } else if($request['cancel_by'] == 'facility') {

                // Update Shift
                if ($shift->shift_type == 'buddy') {
                    $mentorShiftData = ['trainee_hcp_name' => null, 'trainee_hcp_email' => null, 'trainee_hcp_id' => null, 'trainee_buddy_shift_id' => null];
                    $this->shift->update($mentorShiftData, ['trainee_buddy_shift_id' => $shift->id]);

                    $shiftData = ['shift_status' => '3'];
                    $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
                } else {
                    $shiftData = ['shift_status' => '3'];
                    $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
                }
                //-------------
            }

            // Check Buddy Shift Request
            if ($shift->shift_type == 'buddy') {
                $buddyshiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['shift_id' => $shift->id]);
                if(!empty($buddyshiftRequest)){
                    $this->buddy_shift_request->update(['status' => 'cancelled'], ['id' => $buddyshiftRequest->id]);
                }
            }
            //--------------------------

            // Check Shift Transfer Request
            $shiftTransfer = $this->shift_transfer->find_shift_transfer(['shift_id' => $shift->id, 'status' => 'pending']);
            if(!empty($shiftTransfer)){
                $shiftTransferUpdate = $this->shift_transfer->update(['status' => 'cancelled'], ['id' => $shiftTransfer['id']]);
                if (!empty($shift['hcp_id'])) {
                    $hcpId = $shift['hcp_id'];
                    send_shift_push_notification($shift->id, 'shift-transfer-cancelled', $hcpId);
                }
            }
            //-----------------------------

            // Check Shift Swap Request
            $shiftSwap = $this->shift_swap_request->find_shift_swap_request(['shift_id' => $shift->id, 'status' => 'pending']);
            if(!empty($shiftSwap)){
                $this->shift_swap_request->update(['status' => 'cancelled'], ['id' => $shiftSwap->id]);
                if (!empty($shift['hcp_id'])) {
                    $hcpId = $shift['hcp_id'];
                    send_shift_push_notification($shift->id, 'shift-swap-cancelled', $hcpId);
                }
            }
            //-------------------------

            // Cancel Shift
            $cancelledShiftData = [
                'shift_id'      => $shift->id,
                'hcp_id'        => $shift->hcp_id,
                'cancel_by'     => $request['cancel_by'],
                'cancel_by_name' => $request['name'],
                'cancel_time'   => $cancelTime,
                'cancel_reason' => $request['cancel_reason'],
                'negative_points' => $penaltyPoint,
                'penalty_amount' => $penaltyAmount,
                'created_by'    => $authUser->id,
                'updated_by'    => $authUser->id,
            ];
            $cancelledShift = $this->cancelled_shift->store($cancelledShiftData);
            //-------------

            // Shift Activity
            $shiftActivityData = [
                'hcp_id'        => $shift->hcp_id,
                'shift_id'      => $shift->id,
                'activity'      => 'shift-cancelled',
                'created_by'    => $authUser->id,
                'updated_by'    => $authUser->id,
            ];
            $shiftActivity = $this->shift_activity->store($shiftActivityData, ['id' => $shift->id]);
            //---------------

            if (!empty($shift['hcp_id'])) {
                $hcpId = $shift['hcp_id'];
                send_shift_push_notification($shift->id, 'shift-cancelled', $hcpId);
            }

            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            if($generalConfiguration->send_email_on_shift_cancelled==1){
                // Set email data
                $emailData['message'] = __('messages.shift_cancel_mail_subject');
                $emailData['subject'] = __('messages.shift_cancel_mail_subject');
                $emailData['sender'] = __('messages.shift_cancel_mail_subject');
                $emailData['email'] = env('SHIFT_ACTIVITY_EMAIL');
                $emailData['receiver'] = env('SHIFT_ACTIVITY_EMAIL');
                $emailData['shift'] = $shift;
                $emailData['cancelledShift'] = $cancelledShift;

                // Send email
                Mail::send('emails.admin-panel.shift-activity-email', $emailData, function ($message) use ($emailData, $shift) {
                    $message->to($emailData['email'], $emailData['receiver'])->subject($emailData['subject']);
                    if(!empty($shift->facility->additional_nurse_email)){
                        $cc_emails=explode(",",$shift->facility->additional_nurse_email);
                        foreach($cc_emails as $cc){
                            $message->cc($cc);
                        }
                    }
                });
            }

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.scheduled')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.scheduled')->with(['notification' => $notification]);
        }
    }

    /**
     * Shift start.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 26 Nov 2020
     */
    public function startShift(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;

        DB::beginTransaction();
        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            // Set time zone
            date_default_timezone_set($shift->state->time_zone_name);
            //--------------

            $currentTime = Carbon::now($shift->state->time_zone_name);

            if (strtotime($currentTime) >= strtotime($shift->start_time)) {
                $startTime = $currentTime;
            } else {
                $startTime = $shift->start_time;
            }

            // Update Shift
            $shiftData = ['shift_status' => '2', 'hcp_shift_start_time' => $startTime];
            $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
            //-------------

            // Check Shift Transfer Request
            $shiftTransfer = $this->shift_transfer->find_shift_transfer(['shift_id' => $shift->id, 'status' => 'pending']);
            if(!empty($shiftTransfer)){
                $shiftTransferUpdate = $this->shift_transfer->update(['status' => 'cancelled'], ['id' => $shiftTransfer['id']]);
                if (!empty($shift['hcp_id'])) {
                    $hcpId = $shift['hcp_id'];
                    send_shift_push_notification($shift->id, 'shift-transfer-cancelled', $hcpId);
                }
            }
            //-----------------------------

            // Check Shift Swap Request
            $shiftSwap = $this->shift_swap_request->find_shift_swap_request(['shift_id' => $shift->id, 'status' => 'pending']);
            if(!empty($shiftSwap)){
                $this->shift_swap_request->update(['status' => 'cancelled'], ['id' => $shiftSwap->id]);
                if (!empty($shift['hcp_id'])) {
                    $hcpId = $shift['hcp_id'];
                    send_shift_push_notification($shift->id, 'shift-swap-cancelled', $hcpId);
                }
            }
            //-------------------------

            // Update buddy shift request
            if(!empty($shift) &&  $shift['shift_type'] == 'buddy'){
                $this->buddy_shift_request->update(['status' => 'running'], ['shift_id' => $shift->id]);
            }
            //---------------------------


            // Shift Activity
            $shiftActivityData = [
                'hcp_id'        => $shift->hcp_id,
                'shift_id'      => $shift->id,
                'activity'      => 'shift-started',
                'created_by'    => $authUser->id,
                'updated_by'    => $authUser->id,
            ];
            $shiftActivity = $this->shift_activity->store($shiftActivityData, ['id' => $shift->id]);
            //---------------

            if (!empty($shift['hcp_id'])) {
                $hcpId = $shift['hcp_id'];
                send_shift_push_notification($shift->id, 'shift-start', $hcpId);
            }


            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];

        }

        return response()->json($response, 200);
    }

    /**
     * Shift end.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 26 Nov 2020
     */
    public function endShift(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;

        DB::beginTransaction();
        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            // Set time zone
            date_default_timezone_set($shift->state->time_zone_name);
            //--------------

            $currentTime = Carbon::now($shift->state->time_zone_name);

            // Update Shift
            $shiftData = ['shift_status' => '4', 'hcp_shift_end_time' => $currentTime];
            $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
            //-------------

            // Update buddy shift request
            if(!empty($shift) &&  $shift['shift_type'] == 'buddy'){
                $this->buddy_shift_request->update(['status' => 'completed'], ['shift_id' => $shift->id]);
            }
            //---------------------------

            // Shift Activity
            $getShiftActivity = $this->shift_activity->find_shift_activity(['shift_id' => $shift->id, 'activity' => 'shift-end']);
            if(empty($getShiftActivity)) {
                $shiftActivityData = [
                    'hcp_id'        => $shift->hcp_id,
                    'shift_id'      => $shift->id,
                    'activity'      => 'shift-end',
                    'created_by'    => $authUser->id,
                    'updated_by'    => $authUser->id,
                ];
                $shiftActivity = $this->shift_activity->store($shiftActivityData, ['id' => $shift->id]);
            }
            //---------------

            // Send Admin Notification
            send_admin_notification('admin-hcp-shift-completed', 'admin', $shift->id);
            send_admin_notification('facility-hcp-shift-completed', 'facility', $shift->id, null, $shift->facility_id);
            //------------------------

            if (!empty($shift['hcp_id'])) {
                $hcpId = $shift['hcp_id'];
                send_shift_push_notification($shift->id, 'shift-completed', $hcpId);
            }


            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.status_changed'),
                '_type' => 'success',
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.status_change_failed'),
                '_type' => 'error',
            ];
        }

        return response()->json($response, 200);
    }

    /**
     * Shift approved modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 24 Nov 2020
     */
    public function approvedShiftModal(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            return view('admin-panel.includes.shifts.approved-shift-modal', compact('shift', 'authUser'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Shift approved.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 26 Nov 2020
     */
    public function approvedShift(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;

        DB::beginTransaction();
        try {

            // Get Shift
            $shiftRecord = $this->shift->find_shift(dv($id));
            //----------

            if($shiftRecord->shift_status == '6'){
                // Set notification
                $notification = [
                    '_status' => false,
                    '_message' => __('messages.already_approved_shift', ['record' => 'Shift']),
                    '_type' => 'error',
                ];
                //-----------------

                return redirect()->route('adminPanel.shift.completed')->with(['notification' => $notification]);
            }

            if(!empty($request['hcp_amount']) && !empty($request['hours']) && !empty($request['working_hours']) && !empty($request['hcp_per_rate'])) {

                // Set time zone
                date_default_timezone_set($shiftRecord->state->time_zone_name);
                //--------------

                // Current date
                $currentDate = Carbon::now($shiftRecord->state->time_zone_name)->toDateString();
                $currentTime = Carbon::now($shiftRecord->state->time_zone_name);
                //-------------

                // Get Hcp First Shift
                $getHcpFirstShift = $this->shift->find_shift_with_where(['hcp_id' => $shiftRecord->hcp_id, ['shift_status', '>=', '4']]);
                //--------------------

                if (!empty($getHcpFirstShift)) {

                    // Find referee
                    $referee = $this->referral->find_referral_by_code(['referee_hcp_id' => $shiftRecord->hcp_id, 'status' => 'pending']);
                    //-------------

                    if (!empty($referee)) {
                        $this->referral->update(['status' => 'completed', 'referral_completed_date' => $currentDate], ['id' => $referee->id]);

                        // Create transactions for referee
                        $this->transaction->store([
                            'shift_id' => $shiftRecord->id,
                            'hcp_id' => $referee->referee_hcp_id,
                            'referral_id' => $referee->id,
                            'hcp_amount' => str_replace(",","",$referee->referee_amount),
                            'amount_for' => 'hcp',
                            'amount_type' => 'refer-and-earn',
                            'hcp_payment_status' => 'pending',
                            'status' => 'pending',
                        ]);
                        //---------------------------------

                        if (!empty($referee->referee_hcp_id)) {
                            send_other_push_notification($referee->referee_hcp_id, 'refer-and-earn', 'hcp', null, null, null, $referee->referee_amount);
                        }

                        // Create transactions for referrer
                        $this->transaction->store([
                            'shift_id' => $shiftRecord->id,
                            'hcp_id' => $referee->referrer_hcp_id,
                            'referral_id' => $referee->id,
                            'hcp_amount' => str_replace(",","",$referee->referee_amount),
                            'amount_for' => 'hcp',
                            'amount_type' => 'refer-and-earn',
                            'hcp_payment_status' => 'pending',
                            'status' => 'pending',
                        ]);
                        //---------------------------------

                        if (!empty($referee->referrer_hcp_id)) {
                            send_other_push_notification($referee->referrer_hcp_id, 'refer-and-earn', 'hcp', null, null, null, $referee->referrer_amount);
                        }

                    }
                }

                $data = [
                    'shift_type' => $request['shift_types'],
                    'shift_time' => $request['shift_time'],
                    'approved_shift_start_time' => date('Y-m-d H:i', strtotime($request['approved_start_time'])),
                    'approved_shift_end_time' => date('Y-m-d H:i', strtotime($request['approved_end_time'])),
                    'break' => $request['break'],
                    'hours' => $request['hours'],
                    'shift_loading' => $request['shift_loading'],
                    'working_hours' => $request['working_hours'],
                    'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                    'facility_amount' => str_replace(",","",$request['facility_amount']),
                    'admin_fees' => $request['admin_fees'],
                    'facility_per_rate' => $request['facility_per_rate'],
                    'hcp_per_rate' => $request['hcp_per_rate'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'final_hours_time' => $request['final_hours_time'],
                    'total_hours_time' => $request['total_hours_time'],
                    'hcp_shift_loading' => $request['hcp_shift_loading'],
                    'hcp_shift_total_loading' => $request['hcp_shift_total_loading'],
                    'facility_shift_loading' => $request['facility_shift_loading'],
                    'facility_shift_total_loading' => $request['facility_shift_total_loading'],
                    'shift_approved_time' => $currentTime,
                    'shift_status' => '6',
                    'updated_by' => $authUser->id,
                ];

                $shift = $this->shift->update($data, ['id' => dv($id)]);

                // Update buddy shift request
                if(!empty($shiftRecord) &&  $shiftRecord['shift_type'] == 'buddy'){
                    $this->buddy_shift_request->update(['status' => 'approved'], ['shift_id' => $shiftRecord->id]);
                }
                //---------------------------

                // Store transaction
                $transactionData = [
                    'facility_amount' => str_replace(",","",$request['facility_amount']),
                    'admin_fees' => $request['admin_amount'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'facility_id' => $shiftRecord->facility_id,
                    'hcp_id' => $shiftRecord->hcp_id,
                    'amount_for' => 'facility',
                    'amount_type' => 'shift',
                    'status' => 'pending',
                ];

                $transaction = $this->transaction->update($transactionData, ['shift_id' => dv($id), 'amount_type' => 'shift']);
                //-------------------

                // Store transaction
                $transactionData = [
                    'shift_id' => $shiftRecord->id,
                    'facility_id' => $shiftRecord->facility_id,
                    'hcp_id' => $shiftRecord->hcp_id,
                    'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                    'admin_fees' => $request['admin_amount'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'amount_for' => 'hcp',
                    'amount_type' => 'shift',
                    'hcp_payment_status' => 'pending',
                ];

                $transaction = $this->transaction->store($transactionData);
                //-------------------

                // Shift Activity
                $shiftActivityData = [
                    'hcp_id'        => $shiftRecord->hcp_id,
                    'shift_id'      => $shiftRecord->id,
                    'activity'      => 'shift-approved',
                    'created_by'    => $authUser->id,
                    'updated_by'    => $authUser->id,
                ];
                $shiftActivity = $this->shift_activity->store($shiftActivityData, ['id' => $shiftRecord->id]);
                //---------------

                if (!empty($shiftRecord['hcp_id'])) {
                    $hcpId = $shiftRecord['hcp_id'];
                    send_shift_push_notification($shiftRecord->id, 'shift-approved', $hcpId);
                }
            } else {
                $shift = null;
            }

            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.completed')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.completed')->with(['notification' => $notification]);
        }
    }

    /**
     * Shift approved.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Yamini
     * @created 26 Nov 2020
     */
    public function updateApprovedShift(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;

        DB::beginTransaction();
        try {

            if(!empty($request['hcp_amount']) && !empty($request['hours']) && !empty($request['working_hours']) && !empty($request['hcp_per_rate'])) {

                // Get Shift
                $shiftRecord = $this->shift->find_shift(dv($id));
                //----------

                // Set time zone
                date_default_timezone_set($shiftRecord->state->time_zone_name);
                //--------------

                // Current date
                $currentDate = Carbon::now($shiftRecord->state->time_zone_name)->toDateString();
                $currentTime = Carbon::now($shiftRecord->state->time_zone_name);
                //-------------

                // Get Hcp First Shift
                $getHcpFirstShift = $this->shift->find_shift_with_where(['hcp_id' => $shiftRecord->hcp_id, ['shift_status', '>=', '4']]);
                //--------------------

                if (!empty($getHcpFirstShift)) {

                    $data = [
                        'shift_type' => $request['shift_types'],
                        'shift_time' => $request['shift_time'],
                        'approved_shift_start_time' => date('Y-m-d H:i', strtotime($request['approved_start_time'])),
                        'approved_shift_end_time' => date('Y-m-d H:i', strtotime($request['approved_end_time'])),
                        'break' => $request['break'],
                        'hours' => $request['hours'],
                        'shift_loading' => $request['shift_loading'],
                        'working_hours' => $request['working_hours'],
                        'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                        'facility_amount' => str_replace(",","",$request['facility_amount']),
                        'admin_fees' => $request['admin_fees'],
                        'facility_per_rate' => $request['facility_per_rate'],
                        'hcp_per_rate' => $request['hcp_per_rate'],
                        'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                        'final_hours_time' => $request['final_hours_time'],
                        'total_hours_time' => $request['total_hours_time'],
                        'hcp_shift_loading' => $request['hcp_shift_loading'],
                        'hcp_shift_total_loading' => $request['hcp_shift_total_loading'],
                        'facility_shift_loading' => $request['facility_shift_loading'],
                        'facility_shift_total_loading' => $request['facility_shift_total_loading'],
                        'notes' => $request['notes'],
                        // 'shift_approved_time' => $currentTime,
                        // 'shift_status' => '6',
                        'updated_by' => $authUser->id,
                    ];

                    $shift = $this->shift->update($data, ['id' => dv($id)]);


                    // Shift Activity
                    $shiftActivityData = [
                        'hcp_id' => $shiftRecord->hcp_id,
                        'shift_id' => $shiftRecord->id,
                        'activity' => 'shift-updated',
                        'created_by' => $authUser->id,
                        'updated_by' => $authUser->id,
                    ];
                    $shiftActivity = $this->shift_activity->store($shiftActivityData, ['id' => $shiftRecord->id]);
                    //---------------

                } else {
                    $shift = null;
                }
            }

            DB::commit();
        } catch (\Exception $exception) {
            p($exception->getMessage());
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------
        }
        echo json_encode($notification);
    }

    /**
     * Get Facility Plan.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 19 Dec 2020
     */
    public function getFacilityPlan(Request $request)
    {
        // Get Facility Plan
        $facilityPlan = $this->facility_plan->get_facility_plan($request['facility_id']);
        //------------------

        // Set response
        if (!empty($facilityPlan)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.record_found', ['record' => 'Profession']),
                '_data' => [],
            ];
        } else {
            $response = [
                '_status' => false,
                '_message' => __('messages.record_not_found', ['record' => 'Profession']),
                '_data' => [],
            ];
        }
        //-------------

        return response()->json($response, 200);
    }

    /**
     * Get professions.
     *
     * @return mixed
     *
     * @author Sumit
     * @created 19 Dec 2020
     */
    public function getProfessions(Request $request)
    {
        $professions = null;

        // Get Facility Plan
        $facilityPlan = $this->facility_plan->get_facility_plan_professions($request['facility_id'], $request);
        //------------------

        if(!empty($facilityPlan)){
            $facilityPlanProfessions = $facilityPlan['plan']['professions'];
            if(!empty($facilityPlanProfessions)){
                $professions = $facilityPlanProfessions;
            } else {
                $professions = null;
            }
        }

        // Set response
        if (!empty($professions)) {
            $response = [
                '_status' => true,
                '_message' => __('messages.record_found', ['record' => 'Profession']),
                '_data' => $professions,
            ];
        } else {
            $response = [
                '_status' => false,
                '_message' => __('messages.record_not_found', ['record' => 'Profession']),
                '_data' => [],
            ];
        }
        //-------------

        return response()->json($response, 200);
    }

    /**
     * Get buddy hcp listing.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 21 Nov 2020
     */
    public function getBuddyHcps(Request $request)
    {
        $hcps = null;
        try {

            $request['facility_id'] = $request['facility'];

            if(!empty($request['facility_id'])){
                $facility = $this->facility->find_facility($request['facility_id']);
                $request['state_id'] = $facility['state_id'];
                $request['country_id'] = $facility['country_id'];
                $request['facility_latitude'] = $facility['latitude'];
                $request['facility_longitude'] = $facility['longitude'];
            }

            // Get Hcps
            $hcps = $this->hcp->get_hcp_listing_for_shift($request);
            //---------

        } catch (\Exception $exception) {
            $hcps = null;
        }

        if (!empty($hcps)) {

            $response = [
                '_status' => true,
                '_message' => __('messages.records_found', ['records' => 'Hcp']),
                '_data' => $hcps,
            ];

        } else {

            $response = [
                '_status' => false,
                '_message' => __('messages.record_not_found', ['record' => 'Hcp']),
                '_data' => [],
            ];
        }

        return response()->json($response, 200);

    }

    /**
     * Get transfer hcp.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 28 Dec 2020
     */
    public function getTransferHcp(Request $request, $id)
    {
        $hcps = null;
        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            // Get transfter shift
            $shiftTransferWhere = ['shift_id' => $shift->id];
            $shiftTransfer = $this->shift_transfer->find_shift_transfer($shiftTransferWhere);
            //--------------------

            $request['shift_id'] = $shift['id'];
            $request['shift_hcp_id'] = $shift['hcp_id'];
            $request['category_id'] = $shift['category_id'];
            $request['profession_id'] = $shift['profession_id'];
            $request['level_id'] = $shift['hcp_level_id'];
            $request['buddy_hcp_id'] = $shift['buddy_hcp_id'];
            $request['facility_id'] = $shift['facility_id'];
            $request['state_id'] = $shift['facility']['state_id'];
            $request['country_id'] = $shift['facility']['country_id'];
            $request['facility_latitude'] = $shift['facility']['latitude'];
            $request['facility_longitude'] = $shift['facility']['longitude'];
            $request['shift_start_time'] = $shift['start_time'];
            $request['shift_end_time'] = $shift['end_time'];
            $request['time_zone_name'] = $shift['state']['time_zone_name'];
            $request['check_transfer_case'] = 'true';
            $request['check_swap_case'] = 'true';

            // Get Hcps
            $hcps = $this->hcp->get_hcp_listing_for_shift($request);
            //---------

            return view('admin-panel.shifts.transfer-hcp-list', compact('hcps', 'shift', 'shiftTransfer'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }

    }

    /**
     * Transfer shift.
     *
     *
     * @author Sumit
     * @created 28 Dec 2020
     */
    public function transferShift(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $errorMessage = null;
        $shiftTransfer = null;
        $penaltyPoint = 0;

        // General Configuration
        $generalConfiguration = get_general_configuration();
        //----------------------

        DB::beginTransaction();
        try {

            // Get Shift
            $shift = $this->shift->find_shift($request['shift_id']);
            //----------

	// Set time zone
            date_default_timezone_set($shift->state->time_zone_name);
            //--------------

            // Get transfter shift
            $shiftTransferWhere = ['shift_id' => $request['shift_id'], 'hcp_id' => $shift['hcp_id']];
            $shiftTransferRecord = $this->shift_transfer->find_shift_transfer($shiftTransferWhere);
            //-------------------

            if(empty($shiftTransferRecord) ) {

                // Shift Transfer
                $shiftTransferData = [
                    'shift_id' => $request['shift_id'],
                    'hcp_id' => $shift['hcp_id'],
                    'transfer_hcp_id' => $request['hcp_ids'],
                    'status' => 'pending',
                    'created_by' => $authUser->id,
                    'updated_by' => $authUser->id,
                    'created_at' => now(),
                    'updated_at' => now(),
                ];
                $shiftTransfer = $this->shift_transfer->store($shiftTransferData);
                //---------------

                // Update Shift
                $shiftData = ['shift_transfer_swap_status' => 'transferred'];
                $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift['id']]);
                //-------------

                // Check Penalty
                $penaltyPoint = $generalConfiguration['penalty_points_for_shift_cancellation'];
                $hcpPoint = $shift->hcp->points-$penaltyPoint;

                // Hcp Activity
                create_hcp_activity($shift->hcp_id, 'points-deduction', __('hcp_activities.points_deduction_transfer', ['point' => $penaltyPoint, 'shiftId' => $shift->shift_prefix.$shift->id]), $authUser->id);
                //-------------

                if($hcpPoint <= 0) {
                    $hcpData = ['points'  => $hcpPoint, 'status' => 'blocked'];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $shift->hcp_id]);

                    // Store Hcp Block
                    $dataBlock = [
                        'hcp_id' => $shift->hcp_id,
                        'created_by' => $authUser->id,
                        'updated_by' => $authUser->id,
                    ];

                    $this->hcp_block_time->store($dataBlock);
                    //----------------

                    // Hcp Activity
                    create_hcp_activity($shift->hcp_id, 'account-blocked', __('hcp_activities.account_blocked'), $authUser->id);
                    //-------------

                } else {
                    $hcpData = ['points'  => $hcpPoint];
                    $hcpUpdate = $this->hcp->update($hcpData, ['id' => $shift->hcp_id]);
                }
                //--------------

                if (!empty($request['hcp_ids']) && !empty($shift['id'])) {
                    $hcpIds = $request['hcp_ids'];
                    send_shift_push_notification($shift['id'], 'shift-transfer', $hcpIds);
                }

                // Shift Activity
                $shiftActivityData = [
                    'hcp_id'        => $shift['hcp_id'],
                    'shift_id'      => $shift['id'],
                    'activity'      => 'shift-transfer-request-create',
                    'created_by'    => $authUser->id,
                    'updated_by'    => $authUser->id,
                ];

                $shiftActivity = $this->shift_activity->store($shiftActivityData);
                //---------------

                $message = __('messages.shift_transfer_successfully');

            } else if($shiftTransferRecord->transfer_hcp_id == $request['hcp_ids']) {

                $shiftTransfer = null;
                $message = __('messages.shift_already_transfer_to_this_hcp');

            } else if($shiftTransferRecord->status != 'pending' && $shiftTransferRecord->status != 'accept') {

                // Shift Transfer
                $shiftTransferData = [
                    'shift_id' => $request['shift_id'],
                    'hcp_id' => $shift['hcp_id'],
                    'transfer_hcp_id' => $request['hcp_ids'],
                    'status' => 'pending',
                    'created_by' => $authUser->id,
                    'updated_by' => $authUser->id,
                    'created_at' => now(),
                    'updated_at' => now(),
                ];
                $shiftTransfer = $this->shift_transfer->store($shiftTransferData);
                //---------------

                // Update Shift
                $shiftData = ['shift_transfer_swap_status' => 'transferred'];
                $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift['id']]);
                //-------------

                if (!empty($request['hcp_ids']) && !empty($shift['id'])) {
                    $hcpIds = $request['hcp_ids'];
                    send_shift_push_notification($shift['id'], 'shift-transfer', $hcpIds);
                }

                // Shift Activity
                $shiftActivityData = [
                    'hcp_id'        => $shift['hcp_id'],
                    'shift_id'      => $shift['id'],
                    'activity'      => 'shift-transfer-request-create',
                    'created_by'    => $authUser->id,
                    'updated_by'    => $authUser->id,
                ];

                $shiftActivity = $this->shift_activity->store($shiftActivityData);
                //---------------

                $message = __('messages.shift_transfer_successfully');

            } else {
                $shiftTransfer = null;
                $message = __('messages.shift_transfer_action_pending');
            }


            DB::commit();
        } catch (\Exception $e) {
            $shiftTransfer = null;
            $message = __('messages.shift_transfer_failed');
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($shiftTransfer)) {



            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.shift_transfer_successfully'),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.getTransferHcp', ['id' => ev($request['shift_id'])])->withInput()->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => $message,
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.getTransferHcp', ['id' => ev($request['shift_id'])])->withInput()->with(['notification' => $notification]);
        }
    }

    /**
     * Export Shift.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 08 Jan 2021
     */
    public function shiftExport(Request $request, $status = '')
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['shift_export'] = true;
            $request['request']['shift_export'] = true;
            unset($request['request']['shift_per_page']);

            if (!empty($authUser->facility)) {
                $where['facility_id'] = $authUser->facility->id;
            } else if(!empty($authUser->sub_admin) && !empty($authUser->sub_admin->facility)) {
                $where['facility_id'] = $authUser->sub_admin->facility_id;
            } else if(isset($request['facilityId']) && !empty($request['facilityId'])) {
                $where['facility_id'] = $request['facilityId'];
            }

            if(isset($request['hcpId']) && !empty($request['hcpId'])) {
                $where['hcp_id'] = $request['hcpId'];
            }

            return Excel::download(new ShiftsExport($this->shift, $where, $request), 'shifts.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Calculate price.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 31 Oct 2020
     */
    public function calculatePrice(Request $request)
    {
        //p($request->all());
        $profession = null;
        $level = null;
        $hcpPerRate = 0;
        $facilityPerRate = 0;
        $adminFees = 0;
        $hcpShiftTotal = 0;
        $facilityShiftTotal = 0;
        $adminFeesTotal = 0;
        $shiftLoading = 0;
        $calculatedPriceArray = [];
        $shiftEstimate = null;
        $adminFeesWithLoadingTotal = 0;
        $hcpShiftLoading = 0;
        $hcpShiftTotalLoading = 0;
        $facilityShiftLoading = 0;
        $facilityShiftTotalLoading = 0;

        // Loading & Time Configuration
        $loadingTimeConfiguration = get_loading_time_configuration();
        //-----------------------------

        // General Configuration
        $generalConfiguration = get_general_configuration();
        //----------------------

        try {

            if(isset($request['approved_screen']) && !empty($request['approved_screen'])) {
                $minShiftHours = 0;
            } else {
                $minShiftHours = $generalConfiguration['min_shift_booking_hours'];
            }

            $maxShiftHours = $generalConfiguration['max_shift_booking_hours'];

            // Get Hours
            $hours = get_hours($request['start_time'], $request['end_time']);
            //----------

            if(($hours >= $minShiftHours && $hours <= $maxShiftHours && empty($request->sleepover_start) || !empty($request->sleepover_start))) {

                // Get Profession
                if(!empty($request['profession_id'])){
                    $profession = $this->profession->find_profession($request['profession_id']);
                }
                //---------------

                // Get Level
                if(!empty($request['level_id'])){
                    $level = $this->level->find_level($request['level_id']);
                }
                //----------

                // Get Facility
                if(!empty($request['facility'])){
                    $facility = $this->facility->find_facility($request['facility']);
                }
                //-------------

                if(!empty($profession) && !empty($level)){
                    $hcpPerRate = $level['hcp_per_rate'];

                    if($request['shift_types'] != 'buddy') {
                        $facilityPerRate = $hcpPerRate + $generalConfiguration['admin_fee'];
                        $adminFees = $generalConfiguration['admin_fee'];
                    }
                } else if(!empty($profession) && empty($level)){
	                if(!empty($profession['hcp_per_rate']))
                    $hcpPerRate = $profession['hcp_per_rate'];

                    if($request['shift_types'] != 'buddy') {
                        $facilityPerRate = $hcpPerRate + $generalConfiguration['admin_fee'];
                        $adminFees = $generalConfiguration['admin_fee'];
                    }
                } else {
                    $hcpPerRate = 0;
                    $facilityPerRate = 0;
                    $adminFees = 0;
                    $adminFeesTotal = 0;
                }

                $userStart = strtotime($request['start_time']);
                $userEnd = strtotime($request['end_time']);

                $userStartDate = strtotime(date('Y-m-d', $userStart));
                $userEndDate = strtotime(date('Y-m-d', $userEnd));

                $morningStartTime = strtotime(date('Y-m-d', $userStart).' '.$loadingTimeConfiguration['morning_shift_time_first']);
                $morningEndTime =  strtotime(date('Y-m-d', $userEnd).' '.$loadingTimeConfiguration['morning_shift_time_second']);

                $afternoonStartTime = strtotime(date('Y-m-d', $userStart).' '.$loadingTimeConfiguration['afternoon_shift_time_first']);
                $afternoonEndTime =  strtotime(date('Y-m-d', $userStart).' '.$loadingTimeConfiguration['afternoon_shift_time_second']);
                $christmasDate = date('Y').'-12-25';


                $hoursArray = [
                    'morning_hours' => '',
                    'afternoon_hours' => '',
                    'night_hours' => '',
                    'next_day_morning_hours' => '',
                    'next_day_afternoon_hours' => '',
                    'next_day_night_hours' => '',
                    'shift_time' => '',
                    'final_hours' => '',
                    'break_time' => '',
                    'shift_type' => '',
                ];
                $hcp_sleepover_rate = 0;
                $facility_sleepover_rate = 0;
	$detailed_calculation = [];
	$sleepoverHoursAsDecimal = 0;
                if(!empty($request->sleepover_start) && ($request->sleepover_end>$request->sleepover_start)){

                    $hcp_sleepover_rate = $generalConfiguration['hcp_sleepover_rate'];
                    $facility_sleepover_rate = $generalConfiguration['facility_sleepover_rate'];
                    $breakTime = 0;
                    //sleepover afternoon shift
                    $afternoonHours = get_hours($userStart, $userEnd);
                    $afternoonHoursAsDecimal = get_hours_in_decimal($afternoonHours);

	 //sleepover night shift
                    $sleepoverNightStart = strtotime($request['sleepover_night_start']);
                    $sleepoverNightEnd = strtotime($request['sleepover_night_end']);
                    $nightHours = get_hours($sleepoverNightStart, $sleepoverNightEnd);
                    $nightHoursAsDecimal = get_hours_in_decimal($nightHours);

	$approvedExtra_sleepover_night_start_time = [];
                    $approvedExtra_sleepover_night_end_time = [];
                    $extraNightHoursAsDecimal = 0;

                    //extra Night hours
                    if(!empty($request->approved_extra_sleepover_night_start_time))
                    {
                        foreach($request->approved_extra_sleepover_night_start_time as $key=>$approved_extra_sleepover_night_start_time){
                            if(!empty($approved_extra_sleepover_night_start_time) && !empty($request->approved_extra_sleepover_night_end_time[$key]))
                            {
                                $approvedExtra_sleepover_night_start_time[] = $approved_extra_sleepover_night_start_time;
                                $approvedExtra_sleepover_night_end_time[] = $request->approved_extra_sleepover_night_end_time[$key];
                                $extraNightStart = strtotime($approved_extra_sleepover_night_start_time);
                                $extraNightEnd = strtotime($request->approved_extra_sleepover_night_end_time[$key]);
                                $extra_night_hours = get_hours($extraNightStart, $extraNightEnd);
                                $extraNightHoursAsDecimal += get_hours_in_decimal($extra_night_hours);
                            }
                        }
                    }
	//p($extraNightHoursAsDecimal);

                    //sleepover morning shift
                    $sleepoverMorningStart = strtotime($request['sleepover_morning_start']);
                    $sleepoverMorningEnd = strtotime($request['sleepover_morning_end']);
                    $morningHours = get_hours($sleepoverMorningStart, $sleepoverMorningEnd);
                    $morningHoursAsDecimal = get_hours_in_decimal($morningHours);

                    //sleepover time
                    $sleepoverStart = strtotime($request['sleepover_start']);
                    $sleepoverEnd = strtotime($request['sleepover_end']);
                    $sleepoverHours = get_hours($sleepoverStart, $sleepoverEnd);
                    $sleepoverHoursAsDecimal = get_hours_in_decimal($sleepoverHours);

                    $totalHours = $afternoonHoursAsDecimal + $morningHoursAsDecimal + $nightHoursAsDecimal + $extraNightHoursAsDecimal;
                    $hoursArray = [
                        'total_hours' => $totalHours,
                        'afternoon_hours' => $afternoonHours,
	  'night_hours' => $nightHours,
                        'morning_hours' => $morningHours,
                        'shift_time' => 'afternoon',
                        'final_hours' => $totalHours,
                        'break_time' => $breakTime,
                        'sleepover_hours' => $sleepoverHours,
                        'hcp_sleepover_rate' => $hcp_sleepover_rate,
                        'facility_sleepover_rate' => $facility_sleepover_rate,
                        'extra_night_hours' => $extraNightHoursAsDecimal,
                    ];

	  $detailed_calculation['afternoon_hours'] = [
                        'total_hours' => $afternoonHours,
                        'afternoon_hours' => $afternoonHours,
                        'shift_time' => 'afternoon',
                        'final_hours' => $afternoonHours,
                    ];

	 $detailed_calculation['night_hours'] = [
                        'total_hours' => $nightHours,
                        'afternoon_hours' => $nightHours,
                        'shift_time' => 'night',
                        'final_hours' => $nightHours,
                    ];

	$detailed_calculation['extra_night_hours'] = [
                        'total_hours' => $extraNightHoursAsDecimal,
                        'afternoon_hours' => $extraNightHoursAsDecimal,
                        'shift_time' => 'night',
                        'final_hours' => $extraNightHoursAsDecimal,
                    ];

                    $detailed_calculation['morning_hours'] = [
                        'total_hours' => $morningHours,
                        'afternoon_hours' => $morningHours,
                        'shift_time' => 'morning',
                        'final_hours' => $morningHours,
                    ];
	//p($detailed_calculation);
                }
                else{
                    // Case 1 = Pure Morning
                    $purMorning = false;
                    if (($morningStartTime <= $userStart) && ($morningEndTime >= $userEnd) && ($userStartDate == $userEndDate)) {
                        $purMorning = true;

                        $morningHours = get_hours($userStart, $userEnd);

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($morningHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($morningHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $morningHours,
                            'morning_hours' => $morningHours,
                            'shift_time' => 'morning',
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    }
                    //----------------------

                    // Case 2 = Pure Afternoon
                    $purAfternoon = false;
                    if (($afternoonStartTime <= $userStart) && ($afternoonEndTime >= $userEnd) && ($userStartDate == $userEndDate)) {
                        $purAfternoon = true;

                        $afternoonHours = get_hours($userStart, $userEnd);

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($afternoonHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($afternoonHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $afternoonHours,
                            'afternoon_hours' => $afternoonHours,
                            'shift_time' => 'afternoon',
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    }
                    //------------------------

                    // Case 3.1/Case 3.2 = Pure Night
                    $purNight = false;
                    if (($userStart <= $morningStartTime) && ($userEnd <= $morningStartTime) && ($userStartDate == $userEndDate)) {
                        $purNight = true;

                        $nightHours = get_hours($userStart, $userEnd);

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($nightHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($nightHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $nightHours,
                            'night_hours' => $nightHours,
                            'shift_time' => 'night',
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    } else if( ($userStart > $afternoonEndTime) && ($userStartDate == $userEndDate)) {
                        $purNight = true;

                        $nightHours = get_hours($userStart, $userEnd);

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($nightHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($nightHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $nightHours,
                            'night_hours' => $nightHours,
                            'shift_time' => 'night',
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    }
                    //-------------------------------

                    // Case 4 = Morning + Afternoon
                    if (($morningStartTime <= $userStart) && ($userEnd <= $afternoonEndTime) && ($userStartDate == $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false)) {

                        $morningHours = get_hours($userStart, $afternoonStartTime);
                        $afternoonHours = get_hours($afternoonStartTime, $userEnd);

                        if($morningHours > $afternoonHours) {
                            $shitTime = 'morning';
                        } else if($morningHours < $afternoonHours) {
                            $shitTime = 'afternoon';
                        } else if($morningHours == $afternoonHours) {
                            $shitTime = 'morning';
                        }

                        // Get Total Hours
                        $totalHours = get_hours($request['start_time'], $request['end_time']);
                        //----------------

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $totalHours,
                            'morning_hours' => $morningHours,
                            'afternoon_hours' => $afternoonHours,
                            'shift_time' => $shitTime,
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    }
                    //-----------------------------

                    // Case 5 = Afternoon + Night
                    $afternoonNight = false;
                    if (($afternoonStartTime <= $userStart) && ($userEnd >= $afternoonEndTime) && ($userStartDate == $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false)) {
                        $afternoonNight = true;

                        $afternoonHours = get_hours($userStart, $afternoonEndTime);
                        $nightHours = get_hours($afternoonEndTime, $userEnd);

                        if($afternoonHours > $nightHours) {
                            $shitTime = 'afternoon';
                        } else if($afternoonHours < $nightHours) {
                            $shitTime = 'night';
                        } else if($afternoonHours == $nightHours) {
                            $shitTime = 'afternoon';
                        }

                        // Get Total Hours
                        $totalHours = get_hours($request['start_time'], $request['end_time']);
                        //----------------

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $totalHours,
                            'afternoon_hours' => $afternoonHours,
                            'night_hours' => $nightHours,
                            'shift_time' => $shitTime,
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    }
                    //---------------------------

                    // Case 6 = Morning + Afternoon + Night
                    if (($userStart >= $morningStartTime ) && ($userEnd >= $afternoonEndTime) && ($userStartDate == $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false && $afternoonNight == false)) {

                        $morningHours = get_hours($userStart, $afternoonStartTime);
                        $afternoonHours = get_hours($afternoonStartTime, $afternoonEndTime);
                        $nightHours = get_hours($afternoonEndTime, $userEnd);

                        if($morningHours > $afternoonHours && $morningHours > $nightHours) {
                            $shitTime = 'morning';
                        } else if($afternoonHours > $morningHours && $afternoonHours > $nightHours) {
                            $shitTime = 'afternoon';
                        } else if($nightHours > $morningHours && $nightHours > $afternoonHours) {
                            $shitTime = 'night';
                        }

                        // Get Total Hours
                        $totalHours = get_hours($request['start_time'], $request['end_time']);
                        //----------------

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $totalHours,
                            'morning_hours' => $morningHours,
                            'afternoon_hours' => $afternoonHours,
                            'night_hours' => $nightHours,
                            'shift_time' => $shitTime,
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    }
                    //-------------------------------------

                    // Case 7 = Night + Morning
                    if (($userStart <= $morningStartTime) && ($userEnd <= $morningEndTime) && ($userStartDate == $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false)) {

                        $nightHours = get_hours($userStart, $morningStartTime);
                        $morningHours = get_hours($morningStartTime, $userEnd);

                        if($nightHours > $morningHours) {
                            $shitTime = 'night';
                        } else if($nightHours < $morningHours) {
                            $shitTime = 'morning';
                        } else if($nightHours == $morningHours) {
                            $shitTime = 'night';
                        }

                        // Get Total Hours
                        $totalHours = get_hours($request['start_time'], $request['end_time']);
                        //----------------

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $totalHours,
                            'morning_hours' => $morningHours,
                            'night_hours' => $nightHours,
                            'shift_time' => $shitTime,
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    }
                    //-------------------------

                    // Case 13 = Night + Morning + Afternoon
                    if (($userStart <= $morningStartTime ) && ($userEnd >= $afternoonStartTime) && ($userStartDate == $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false && $afternoonNight == false)) {

                        $nightHours = get_hours($userStart, $morningStartTime);
                        $morningHours = get_hours($morningStartTime, $afternoonStartTime);
                        $afternoonHours = get_hours($afternoonStartTime, $userEnd);

                        if($morningHours > $afternoonHours && $morningHours > $nightHours) {
                            $shitTime = 'morning';
                        } else if($afternoonHours > $morningHours && $afternoonHours > $nightHours) {
                            $shitTime = 'afternoon';
                        } else if($nightHours > $morningHours && $nightHours > $afternoonHours) {
                            $shitTime = 'night';
                        }

                        // Get Total Hours
                        $totalHours = get_hours($request['start_time'], $request['end_time']);
                        //----------------

                        // Get Break Time
                        $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                        //---------------

                        // Final Hours
                        $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                        //------------

                        $hoursArray = [
                            'total_hours' => $totalHours,
                            'morning_hours' => $morningHours,
                            'afternoon_hours' => $afternoonHours,
                            'night_hours' => $nightHours,
                            'shift_time' => $shitTime,
                            'final_hours' => $finalHours,
                            'break_time' => $breakTime,
                        ];
                    }
                    //--------------------------------------

                    // Date Change Cases
                    if ($userStartDate != $userEndDate) {
                        $midNightTime = date('Y-m-d', $userEnd);
                        $morningStartTimeForDateChange = strtotime(date('Y-m-d', $userEnd).' '.$loadingTimeConfiguration['morning_shift_time_first']);
                        $morningEndTimeForDateChange = strtotime(date('Y-m-d', $userEnd).' '.$loadingTimeConfiguration['morning_shift_time_second']);
                        $afternoonStartTimeForDateChange = strtotime(date('Y-m-d', $userEnd).' '.$loadingTimeConfiguration['afternoon_shift_time_first']);
                        $afternoonEndTimeForDateChange = strtotime(date('Y-m-d', $userEnd).' '.$loadingTimeConfiguration['afternoon_shift_time_second']);

                        $date = date_create($midNightTime);
                        $nightBreakTime = date_format($date, "Y-m-d H:i");

                        // Case 8 = Pure Night
                        $pureNightDayDifferent = false;
                        if (($userStart >= $afternoonEndTime) && ($userEnd <= $morningStartTimeForDateChange) && ($userStartDate != $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false)) {
                            $pureNightDayDifferent = true;

                            $nightHours = get_hours($userStart, $nightBreakTime);
                            $nextDayNightHours = get_hours($nightBreakTime, $userEnd);

                            if($nightHours > $nextDayNightHours) {
                                $shitTime = 'night';
                            } else if($nightHours < $nextDayNightHours) {
                                $shitTime = 'next_day_night';
                            } else if($nightHours == $nextDayNightHours) {
                                $shitTime = 'night';
                            }

                            // Get Total Hours
                            $totalHours = get_hours($request['start_time'], $request['end_time']);
                            //----------------

                            // Get Break Time
                            $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                            //---------------

                            // Final Hours
                            $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                            //------------

                            $hoursArray = [
                                'total_hours' => $totalHours,
                                'next_day_night_hours' => $nextDayNightHours,
                                'night_hours' => $nightHours,
                                'shift_time' => $shitTime,
                                'final_hours' => $finalHours,
                                'break_time' => $breakTime,
                            ];
                        }
                        //--------------------

                        // Case 9 = Morning + Afternoon + Night
                        if (($userStart >= $morningStartTime) && ($userStart <= $afternoonStartTime) && ($userEnd <= $morningStartTimeForDateChange) && ($userStartDate != $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false && $pureNightDayDifferent == false)) {
                            $morningHours = get_hours($userStart, $morningStartTime);
                            $afternoonHours = get_hours($afternoonStartTime, $afternoonEndTime);

                            $nightHours = get_hours($afternoonEndTime, $nightBreakTime);
                            $nextDayNightHours = get_hours($nightBreakTime, $userEnd);

                            if($morningHours > $afternoonHours && $morningHours > $nightHours) {
                                $shitTime = 'morning';
                            } else if($afternoonHours > $morningHours && $afternoonHours > $nightHours) {
                                $shitTime = 'afternoon';
                            } else if($nightHours > $morningHours && $nightHours > $afternoonHours) {
                                $shitTime = 'night';
                            } else if($nextDayNightHours > $morningHours && $nightHours > $afternoonHours && $nextDayNightHours > $nightHours) {
                                $shitTime = 'next_day_night';
                            }

                            // Get Total Hours
                            $totalHours = get_hours($request['start_time'], $request['end_time']);
                            //----------------

                            // Get Break Time
                            $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                            //---------------

                            // Final Hours
                            $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                            //------------

                            $hoursArray = [
                                'total_hours' => $totalHours,
                                'morning_hours' => $morningHours,
                                'afternoon_hours' => $afternoonHours,
                                'night_hours' => $nightHours,
                                'next_day_night_hours' => $nextDayNightHours,
                                'shift_time' => $shitTime,
                                'final_hours' => $finalHours,
                                'break_time' => $breakTime,
                            ];


                        }
                        //-------------------------------------

                        // Case 10 = Afternoon + Night
                        if (($userStart >= $afternoonStartTime) && ($userEnd <= $morningStartTimeForDateChange) && ($userStartDate != $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false && $pureNightDayDifferent == false)) {
                            $afternoonHours = get_hours($userStart, $afternoonEndTime);
                            $nightHours = get_hours($afternoonEndTime, $nightBreakTime);
                            $nextDayNightHours = get_hours($nightBreakTime, $userEnd);


                            if($afternoonHours > $nightHours && $afternoonHours > $nextDayNightHours) {
                                $shitTime = 'afternoon';
                            } else if($nightHours > $afternoonHours && $nightHours > $nextDayNightHours) {
                                $shitTime = 'night';
                            } else if($nextDayNightHours > $nightHours && $nextDayNightHours > $afternoonHours) {
                                $shitTime = 'next_day_night';
                            }else if($nextDayNightHours > $nightHours && $nextDayNightHours == $afternoonHours) {
                                $shitTime = 'afternoon';
                            }

                            // Get Total Hours
                            $totalHours = get_hours($request['start_time'], $request['end_time']);
                            //----------------

                            // Get Break Time
                            $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                            //---------------

                            // Final Hours
                            $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                            //------------

                            $hoursArray = [
                                'total_hours' => $totalHours,
                                'afternoon_hours' => $afternoonHours,
                                'night_hours' => $nightHours,
                                'next_day_night_hours' => $nextDayNightHours,
                                'night_hours' => $nightHours,
                                'shift_time' => $shitTime,
                                'final_hours' => $finalHours,
                                'break_time' => $breakTime,
                            ];
                        }
                        //----------------------------

                        // Case 11 = Night + Morning + Afternoon
                        if (($userStart >= $afternoonEndTime) && ($userEnd >= $afternoonStartTimeForDateChange) && ($userStartDate != $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false && $pureNightDayDifferent == false)) {
                            $nightHours = get_hours($userStart, $nightBreakTime);
                            $nextDayNightHours = get_hours($nightBreakTime, $morningStartTimeForDateChange);
                            $nextDayMorningHours = get_hours($morningStartTimeForDateChange, $morningEndTimeForDateChange);
                            $nextDayAfternoonHours = get_hours($afternoonStartTimeForDateChange, $userEnd);


                            if($nightHours > $nextDayNightHours && $nightHours > $nextDayMorningHours && $nightHours > $nextDayAfternoonHours) {
                                $shitTime = 'night';
                            } else if($nextDayNightHours > $nightHours && $nextDayNightHours > $nextDayMorningHours && $nextDayNightHours > $nextDayAfternoonHours) {
                                $shitTime = 'next_day_night';
                            } else if($nextDayMorningHours > $nightHours && $nextDayMorningHours > $nextDayNightHours && $nextDayMorningHours > $nextDayAfternoonHours) {
                                $shitTime = 'next_day_morning';
                            } else if($nextDayAfternoonHours > $nightHours && $nextDayAfternoonHours > $nextDayNightHours && $nextDayAfternoonHours > $nextDayMorningHours) {
                                $shitTime = 'next_day_afternoon';
                            }

                            // Get Total Hours
                            $totalHours = get_hours($request['start_time'], $request['end_time']);
                            //----------------

                            // Get Break Time
                            $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                            //---------------

                            // Final Hours
                            $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                            //------------

                            $hoursArray = [
                                'total_hours' => $totalHours,
                                'night_hours' => $nightHours,
                                'next_day_night_hours' => $nextDayNightHours,
                                'next_day_morning_hours' => $nextDayMorningHours,
                                'next_day_afternoon_hours' => $nextDayAfternoonHours,
                                'shift_time' => $shitTime,
                                'final_hours' => $finalHours,
                                'break_time' => $breakTime,
                            ];
                        }
                        //--------------------------------------

                        // Case 12 = Night + Morning
                        if (($userStart >= $afternoonEndTime) && ($userEnd <= $morningEndTimeForDateChange) && ($userStartDate != $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false && $pureNightDayDifferent == false)) {
                            $nightHours = get_hours($userStart, $nightBreakTime);
                            $nextDayNightHours = get_hours($nightBreakTime, $morningStartTimeForDateChange);
                            $nextDayMorningHours = get_hours($morningStartTimeForDateChange, $userEnd);

                            $hoursArray = [
                                'night_hours' => $nightHours,
                                'next_day_night_hours' => $nextDayNightHours,
                                'next_day_morning_hours' => $nextDayMorningHours,
                            ];

                            if($nightHours > $nextDayNightHours && $nightHours > $nextDayMorningHours) {
                                $shitTime = 'night';
                            } else if($nextDayNightHours > $nightHours && $nextDayNightHours > $nextDayMorningHours) {
                                $shitTime = 'next_day_night';
                            } else if($nextDayMorningHours > $nightHours && $nextDayMorningHours > $nextDayNightHours) {
                                $shitTime = 'next_day_morning';
                            }

                            // Get Total Hours
                            $totalHours = get_hours($request['start_time'], $request['end_time']);
                            //----------------

                            // Get Break Time
                            $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                            //---------------

                            // Final Hours
                            $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                            //------------

                            $hoursArray = [
                                'total_hours' => $totalHours,
                                'night_hours' => $nightHours,
                                'next_day_night_hours' => $nextDayNightHours,
                                'next_day_morning_hours' => $nextDayMorningHours,
                                'shift_time' => $shitTime,
                                'final_hours' => $finalHours,
                                'break_time' => $breakTime,
                            ];
                        }
                        //--------------------------

                        // Case 13 = Afternoon + Night + Morning
                        if (($userStart >= $afternoonStartTime) && ($userEnd >= $morningStartTimeForDateChange) && ($userStartDate != $userEndDate) && ($purMorning == false && $purAfternoon == false && $purNight == false && $pureNightDayDifferent == false)) {
                            $afternoonHours = get_hours($userStart, $afternoonEndTime);
                            $nightHours = get_hours($afternoonEndTime, $nightBreakTime);
                            $nextDayNightHours = get_hours($nightBreakTime, $morningStartTimeForDateChange);
                            $nextDayMorningHours = get_hours($morningStartTimeForDateChange, $userEnd);

                            if($afternoonHours > $nightHours && $afternoonHours > $nextDayNightHours && $afternoonHours > $nextDayMorningHours){
                                $shitTime = 'afternoon';
                            } else if($nightHours > $afternoonHours && $nightHours > $nextDayNightHours && $nightHours > $nextDayMorningHours) {
                                $shitTime = 'night';
                            } else if($nextDayNightHours > $nightHours && $nextDayNightHours > $afternoonHours && $nextDayNightHours > $nextDayMorningHours) {
                                $shitTime = 'next_day_night';
                            } else if($nextDayMorningHours > $afternoonHours && $nextDayMorningHours > $nightHours && $nextDayMorningHours > $nextDayMorningHours) {
                                $shitTime = 'next_day_morning';
                            }

                            // Get Total Hours
                            $totalHours = get_hours($request['start_time'], $request['end_time']);
                            //----------------

                            // Get Break Time
                            $breakTime = get_break_time(get_hours_in_decimal($totalHours));
                            //---------------

                            // Final Hours
                            $finalHours = date("H:i", strtotime($totalHours) - ($breakTime * 60));
                            //------------

                            $hoursArray = [
                                'total_hours' => $totalHours,
                                'afternoon_hours' => $afternoonHours,
                                'night_hours' => $nightHours,
                                'next_day_night_hours' => $nextDayNightHours,
                                'next_day_morning' => $nextDayMorningHours,
                                'shift_time' => $shitTime,
                                'final_hours' => $finalHours,
                                'break_time' => $breakTime,
                            ];
                        }
                        //--------------------------------------
                    }
                    //------------------
                }



                // Get Public Holiday
                $startDatePublicHolidayWhere = ['holiday_date' => date('Y-m-d', strtotime($request['start_time']))];
                $startDatePublicHoliday = $this->public_holiday->get_public_holiday_by_state($startDatePublicHolidayWhere, $facility['state_id']);

                $endDatePublicHolidayWhere = ['holiday_date' => date('Y-m-d', strtotime($request['end_time']))];
                $endDatePublicHoliday = $this->public_holiday->get_public_holiday_by_state($endDatePublicHolidayWhere, $facility['state_id']);
                //-------------------

                // Calculate price
                if(!empty($hoursArray) && $hoursArray['shift_time'] == 'morning') {

                    if(!empty($startDatePublicHoliday)){
                        $shiftLoading = $loadingTimeConfiguration['loading_public_holiday_shift'];
                        $hoursArray['shift_type'] = 'public-holiday';
                    } else if(date('Y-m-d', strtotime($request['start_time'])) == $christmasDate){
                        $shiftLoading = $loadingTimeConfiguration['loading_christmas_holiday_shift'];
                        $hoursArray['shift_type'] = 'christmas';
                    } else if(date('w', strtotime($request['start_time'])) == '6') {
                        $shiftLoading = $loadingTimeConfiguration['loading_saturday_shift'];
                        $hoursArray['shift_type'] = 'saturday';
                    } else if(date('w', strtotime($request['start_time'])) == '0') {
                        $shiftLoading = $loadingTimeConfiguration['loading_sunday_shift'];
                        $hoursArray['shift_type'] = 'sunday';
                    } else {
                        $hoursArray['shift_type'] = 'morning';
                        $shiftLoading = 0;
                    }

                } else if(!empty($hoursArray) && $hoursArray['shift_time'] == 'afternoon') {

                    if(!empty($startDatePublicHoliday)){
                        $shiftLoading = $loadingTimeConfiguration['loading_public_holiday_shift'];
                        $hoursArray['shift_type'] = 'public-holiday';
                    } else if(date('Y-m-d', strtotime($request['start_time'])) == $christmasDate){
                        $shiftLoading = $loadingTimeConfiguration['loading_christmas_holiday_shift'];
                        $hoursArray['shift_type'] = 'christmas';
                    } else if(date('w', strtotime($request['start_time'])) == '6') {
                        $shiftLoading = $loadingTimeConfiguration['loading_saturday_shift'];
                        $hoursArray['shift_type'] = 'saturday';
                    } else if(date('w', strtotime($request['start_time'])) == '0') {
                        $shiftLoading = $loadingTimeConfiguration['loading_sunday_shift'];
                        $hoursArray['shift_type'] = 'sunday';
                    } else {
                        $shiftLoading = $loadingTimeConfiguration['loading_afternoon_shift'];
                        $hoursArray['shift_type'] = 'afternoon';
                    }

                } else if(!empty($hoursArray) && $hoursArray['shift_time'] == 'night') {

                    if(!empty($startDatePublicHoliday)){
                        $shiftLoading = $loadingTimeConfiguration['loading_public_holiday_shift'];
                        $hoursArray['shift_type'] = 'public-holiday';
                    } else if(date('Y-m-d', strtotime($request['start_time'])) == $christmasDate){
                        $shiftLoading = $loadingTimeConfiguration['loading_christmas_holiday_shift'];
                        $hoursArray['shift_type'] = 'christmas';
                    } else if(date('w', strtotime($request['start_time'])) == '6') {
                        $shiftLoading = $loadingTimeConfiguration['loading_saturday_shift'];
                        $hoursArray['shift_type'] = 'saturday';
                    } else if(date('w', strtotime($request['start_time'])) == '0') {
                        $shiftLoading = $loadingTimeConfiguration['loading_sunday_shift'];
                        $hoursArray['shift_type'] = 'sunday';
                    } else {
                        $shiftLoading = $loadingTimeConfiguration['loading_night_shift'];
                        $hoursArray['shift_type'] = 'night';
                    }

                } else if(!empty($hoursArray) && $hoursArray['shift_time'] == 'next_day_morning') {

                    if(!empty($endDatePublicHoliday)){
                        $shiftLoading = $loadingTimeConfiguration['loading_public_holiday_shift'];
                        $hoursArray['shift_type'] = 'public-holiday';
                    } else if(date('Y-m-d', strtotime($request['end_time'])) == $christmasDate){
                        $shiftLoading = $loadingTimeConfiguration['loading_christmas_holiday_shift'];
                        $hoursArray['shift_type'] = 'christmas';
                    } else if(date('w', strtotime($request['end_time'])) == '6') {
                        $shiftLoading = $loadingTimeConfiguration['loading_saturday_shift'];
                        $hoursArray['shift_type'] = 'saturday';
                    } else if(date('w', strtotime($request['end_time'])) == '0') {
                        $shiftLoading = $loadingTimeConfiguration['loading_sunday_shift'];
                        $hoursArray['shift_type'] = 'sunday';
                    } else {
                        $shiftLoading = 0;
                        $hoursArray['shift_type'] = 'morning';
                    }
                } else if(!empty($hoursArray) && $hoursArray['shift_time'] == 'next_day_afternoon') {

                    if(!empty($endDatePublicHoliday)){
                        $shiftLoading = $loadingTimeConfiguration['loading_public_holiday_shift'];
                        $hoursArray['shift_type'] = 'public-holiday';
                    } else if(date('Y-m-d', strtotime($request['end_time'])) == $christmasDate){
                        $shiftLoading = $loadingTimeConfiguration['loading_christmas_holiday_shift'];
                        $hoursArray['shift_type'] = 'christmas';
                    } else if(date('w', strtotime($request['end_time'])) == '6') {
                        $shiftLoading = $loadingTimeConfiguration['loading_saturday_shift'];
                        $hoursArray['shift_type'] = 'saturday';
                    } else if(date('w', strtotime($request['end_time'])) == '0') {
                        $shiftLoading = $loadingTimeConfiguration['loading_sunday_shift'];
                        $hoursArray['shift_type'] = 'sunday';
                    } else {
                        $shiftLoading = $loadingTimeConfiguration['loading_afternoon_shift'];
                        $hoursArray['shift_type'] = 'afternoon';
                    }
                } else if(!empty($hoursArray) && $hoursArray['shift_time'] == 'next_day_night') {

                    if(!empty($endDatePublicHoliday)){
                        $shiftLoading = $loadingTimeConfiguration['loading_public_holiday_shift'];
                        $hoursArray['shift_type'] = 'public-holiday';
                    } else if(date('Y-m-d', strtotime($request['end_time'])) == $christmasDate){
                        $shiftLoading = $loadingTimeConfiguration['loading_christmas_holiday_shift'];
                        $hoursArray['shift_type'] = 'christmas';
                    } else if(date('w', strtotime($request['end_time'])) == '6') {
                        $shiftLoading = $loadingTimeConfiguration['loading_saturday_shift'];
                        $hoursArray['shift_type'] = 'saturday';
                    } else if(date('w', strtotime($request['end_time'])) == '0') {
                        $shiftLoading = $loadingTimeConfiguration['loading_sunday_shift'];
                        $hoursArray['shift_type'] = 'sunday';
                    } else {
                        $shiftLoading = $loadingTimeConfiguration['loading_night_shift'];
                        $hoursArray['shift_type'] = 'night';
                    }
                }

                if($shiftLoading > 0) {
                    if(!empty($request->sleepover_start) && $sleepoverHoursAsDecimal>0){
                       // p($adminFees);
                        $morning_hours_as_Decimal = get_hours_in_decimal($hoursArray['morning_hours']);
                        $morning_ShiftTotal = ($hcpPerRate * $morning_hours_as_Decimal);

	$night_hours_as_Decimal = get_hours_in_decimal($hoursArray['night_hours']);
		$nightshiftLoading = 0;
                        if($night_hours_as_Decimal>0){
                            $nightshiftLoading = $loadingTimeConfiguration['loading_night_shift'];
                        }

                        $night_ShiftTotal = ($hcpPerRate * $night_hours_as_Decimal);
                        $nightHcpShiftTotalLoading = $nightshiftLoading*($night_ShiftTotal/100);
                        $night_ShiftTotal = $night_ShiftTotal + ($nightshiftLoading*($night_ShiftTotal/100));

                        $afternoon_hours_as_Decimal = get_hours_in_decimal($hoursArray['afternoon_hours']);
                        $afternoon_ShiftTotal = ($hcpPerRate * $afternoon_hours_as_Decimal);
                        $hcpShiftLoading = $shiftLoading*($hcpPerRate/100);
                        $hcpShiftTotalLoading = $shiftLoading*($afternoon_ShiftTotal/100);
                        $afternoon_ShiftTotal = $afternoon_ShiftTotal + ($shiftLoading*($afternoon_ShiftTotal/100));

	 $detailed_calculation['afternoon_hours']['shift_total'] = $afternoon_ShiftTotal;
		$detailed_calculation['afternoon_hours']['hcp_rate'] = $hcpPerRate;
                        $detailed_calculation['afternoon_hours']['shift_loading'] = $shiftLoading;

		$detailed_calculation['night_hours']['shift_total'] = $night_ShiftTotal;
                        $detailed_calculation['night_hours']['hcp_rate'] = $hcpPerRate;
                        $detailed_calculation['night_hours']['shift_loading'] = $nightshiftLoading;

                        $detailed_calculation['morning_hours']['shift_total'] = $morning_ShiftTotal;
		$detailed_calculation['morning_hours']['hcp_rate'] = $hcpPerRate;
                        $detailed_calculation['morning_hours']['shift_loading'] = 0;

		//Extra Night Hours
                        $extra_night_hcp_rate = $generalConfiguration['hcp_extra_night_rate'];
                        $extra_night_facility_rate = $generalConfiguration['facility_extra_night_rate'];
                        $extraNight_ShiftTotal = $hoursArray['extra_night_hours'] * $extra_night_hcp_rate;
                        $detailed_calculation['extra_night_hours']['shift_total'] = $extraNight_ShiftTotal;
                        $detailed_calculation['extra_night_hours']['hcp_rate'] = $extra_night_hcp_rate;
                        $detailed_calculation['extra_night_hours']['shift_loading'] = 0;


                        $hcpShiftTotal = $morning_ShiftTotal + $afternoon_ShiftTotal + $hoursArray['hcp_sleepover_rate']+ $night_ShiftTotal + $extraNight_ShiftTotal;
//                        p($hcpShiftTotal);
                        if($request['shift_types'] != 'buddy') {
                            $morningfacilityShiftTotal = ($facilityPerRate * $morning_hours_as_Decimal);
                            $morningadminFeesTotal = ($adminFees * $morning_hours_as_Decimal);
	$detailed_calculation['morning_hours']['facility_shift_total'] = $morningfacilityShiftTotal;
		$detailed_calculation['morning_hours']['facility_rate'] = $facilityPerRate;
                            $detailed_calculation['morning_hours']['admin_fees'] = $adminFees;


		$nightfacilityShiftTotal = ($facilityPerRate * $night_hours_as_Decimal);
                            $nightadminFeesTotal = ($adminFees * $night_hours_as_Decimal);
                            $facilityShiftLoading = $nightshiftLoading*($facilityPerRate/100);
                            $facilityShiftTotalLoading = $nightshiftLoading*($nightfacilityShiftTotal/100);
                            $nightfacilityShiftTotal = $nightfacilityShiftTotal + ($nightshiftLoading*($nightfacilityShiftTotal/100));
//

                            $detailed_calculation['night_hours']['facility_shift_total'] = $nightfacilityShiftTotal;
                            $detailed_calculation['night_hours']['facility_rate'] = $facilityPerRate;
                            $detailed_calculation['night_hours']['admin_fees'] = $adminFees;

		//Extra Night Hours
                            $extra_nightfacilityShiftTotal = $hoursArray['extra_night_hours'] * $extra_night_facility_rate;
                            $detailed_calculation['extra_night_hours']['facility_shift_total'] = $extra_nightfacilityShiftTotal;
                            $detailed_calculation['extra_night_hours']['facility_rate'] = $extra_night_facility_rate;
                            $detailed_calculation['extra_night_hours']['admin_fees'] = 0;


                            $afternoonfacilityShiftTotal = ($facilityPerRate * $afternoon_hours_as_Decimal);
                            $afternoonadminFeesTotal = ($adminFees * $afternoon_hours_as_Decimal);
                            $facilityShiftLoading = $shiftLoading*($facilityPerRate/100);
                            $facilityShiftTotalLoading = $shiftLoading*($afternoonfacilityShiftTotal/100);
                            $afternoonfacilityShiftTotal = $afternoonfacilityShiftTotal + ($shiftLoading*($afternoonfacilityShiftTotal/100));
//
                            $facilityShiftTotal = $morningfacilityShiftTotal + $afternoonfacilityShiftTotal+ $hoursArray['facility_sleepover_rate']+$nightfacilityShiftTotal + $extra_nightfacilityShiftTotal;

                            $adminFeesWithLoadingTotal = $morningadminFeesTotal +($afternoonadminFeesTotal + ($shiftLoading*($afternoonadminFeesTotal/100))) +($nightadminFeesTotal + ($shiftLoading*($nightadminFeesTotal/100)));
//                            p($facilityShiftTotal.'   '.$adminFeesWithLoadingTotal);
		$detailed_calculation['afternoon_hours']['facility_shift_total'] = $afternoonfacilityShiftTotal;
		$detailed_calculation['afternoon_hours']['facility_rate'] = $facilityPerRate;
                            $detailed_calculation['afternoon_hours']['admin_fees'] = $adminFees;
		$adminFees = $detailed_calculation['afternoon_hours']['admin_fees'] + $detailed_calculation['morning_hours']['admin_fees']+$detailed_calculation['night_hours']['admin_fees'];
		$shiftLoading +=$nightshiftLoading;
                        }
                    }else{
                        $hoursAsDecimal = get_hours_in_decimal($finalHours);
                        $hcpShiftTotal = ($hcpPerRate * $hoursAsDecimal);
                        $hcpShiftLoading = $shiftLoading*($hcpPerRate/100);
                        $hcpShiftTotalLoading = $shiftLoading*($hcpShiftTotal/100);
                        $hcpShiftTotal = $hcpShiftTotal + ($shiftLoading*($hcpShiftTotal/100));

                        if($request['shift_types'] != 'buddy') {
                            $facilityShiftTotal = ($facilityPerRate * $hoursAsDecimal);
                            $adminFeesTotal = ($adminFees * $hoursAsDecimal);
                            $facilityShiftLoading = $shiftLoading*($facilityPerRate/100);
                            $facilityShiftTotalLoading = $shiftLoading*($facilityShiftTotal/100);
                            $facilityShiftTotal = $facilityShiftTotal + ($shiftLoading*($facilityShiftTotal/100));

                            $adminFeesWithLoadingTotal = $adminFeesTotal + ($shiftLoading*($adminFeesTotal/100));
                        }
                    }

                } else {
                    $hoursAsDecimal = get_hours_in_decimal($finalHours);
                    $hcpShiftTotal = ($hcpPerRate * $hoursAsDecimal);

                    if($request['shift_types'] != 'buddy') {
                        $adminFeesTotal = ($adminFees * $hoursAsDecimal);
                        $facilityShiftTotal = ($facilityPerRate * $hoursAsDecimal);

                        $adminFeesWithLoadingTotal = $adminFeesTotal;
                    }
                }
                //----------------

                //if(!empty($hours) && !empty($hcpPerRate) && !empty($hcpShiftTotal)) {
	if($hours>=0 && $hcpPerRate>=0 && $hcpShiftTotal>=0) {
                    if($hoursArray['shift_time'] == 'next_day_morning'){
                        $shiftTime = 'morning';
                    } else if($hoursArray['shift_time'] == 'next_day_afternoon'){
                        $shiftTime = 'afternoon';
                    } else if($hoursArray['shift_time'] == 'next_day_night'){
                        $shiftTime = 'night';
                    } else {
                        $shiftTime = $hoursArray['shift_time'];
                    }

                    if($request['shift_types'] == 'buddy' && ($shiftTime != 'morning' || $shiftLoading > 0) ) {
                        $shiftEstimate = null;
                        $calculatedPriceArray = [];
                        $message = __('messages.shift_estimates_buddy_shift_error');
                    } else {

                        if($request['shift_types'] == 'buddy' && ($shiftTime == 'morning' && $shiftLoading == 0) ) {
                            $shiftTime = 'buddy';
                        }
	//p($detailed_calculation);
	if(!empty($detailed_calculation)){
	$detailed_calculation['afternoon_hours']['afternoon_hours'] = get_hours_in_decimal($detailed_calculation['afternoon_hours']['afternoon_hours']);
	$detailed_calculation['morning_hours']['afternoon_hours'] = get_hours_in_decimal($detailed_calculation['morning_hours']['afternoon_hours']);
	$detailed_calculation['night_hours']['afternoon_hours'] = get_hours_in_decimal($detailed_calculation['night_hours']['afternoon_hours']);
	$detailed_calculation_html = '<div class="table-responsive">
                                    <table class="table" width="100%"  cellpadding="5">';
                        if(!empty($detailed_calculation)){
                            foreach($detailed_calculation as $calulation){
                                $detailed_calculation_html.='
                                        <tr>
                                            <th> Shift Type </th>
                                            <td class="break-time"> <b>'.ucfirst($calulation["shift_time"]).'</b> </td>

                                        </tr>
                                        <tr>
                                            <th> '. __('language.break_time') .' </th>
                                            <td class="break-time"> 0 </td>

                                            <th> Working Hours </th>
                                            <td class="final-hour"> '. $calulation["afternoon_hours"].' </td>
                                        </tr>
                                        <tr>
                                            <th> '. __('language.hcp_rate') .'  </th>
                                            <td class="hcp-rate"> '.number_format($calulation["hcp_rate"],2).' </td>

                                            <th> '. __('language.admin_fees') .' </th>
                                            <td class="admin-fees"> '.number_format($calulation["admin_fees"],2).' </td>
                                        </tr>
                                        <tr>
                                            <th> '. __('language.facility_rate') .' </th>
                                            <td class="facility-rate"> '.number_format($calulation["facility_rate"],2).' </td>

                                            <th> '. __('language.shift_loading') .' </th>
                                            <td class="shift-loading"> '.number_format($calulation["shift_loading"],2).' </td>
                                        </tr>
                                        <tr>
                                            <th> '. __('language.hcp_shift_total') .' </th>
                                            <td class="hcp-shift-total"> '.number_format($calulation["shift_total"],2).' </td>

                                            <th> '. __('language.facility_shift_total') .' </th>
                                            <td class="facility-shift-total"> '.number_format($calulation["facility_shift_total"],2).' </td>
                                        </tr>

                                   ';
                            }

                        }
                        $detailed_calculation_html .= ' </table>';
	}

                        $calculatedPriceArray = [
                            'morning_hours' => isset($hoursArray['morning_hours']) ? $hoursArray['morning_hours'] : '',
                            'afternoon_hours' => isset($hoursArray['afternoon_hours']) ? $hoursArray['afternoon_hours'] : '',
                            'night_hours' => isset($hoursArray['night_hours']) ? $hoursArray['night_hours'] : '',
                            'next_day_morning_hours' => isset($hoursArray['next_day_morning_hours']) ? $hoursArray['next_day_morning_hours'] : '',
                            'next_day_afternoon_hours' => isset($hoursArray['next_day_afternoon_hours']) ? $hoursArray['next_day_afternoon_hours'] : '',
                            'next_day_night_hours' => isset($hoursArray['next_day_night_hours']) ? $hoursArray['next_day_night_hours'] : '',
                            'shift_time' => $shiftTime,
                            'shift_type' => $hoursArray['shift_type'],
                            'total_hours' => !empty($request->sleepover_start)?$hoursArray['total_hours']:get_hours_in_decimal($hoursArray['total_hours']),
                            'break_time'  => $hoursArray['break_time'],
                            'final_hours' => !empty($request->sleepover_start)?$hoursArray['final_hours']:get_hours_in_decimal($hoursArray['final_hours']),
                            'shift_loading' => $shiftLoading,
                            'hcp_per_rate' => number_format($hcpPerRate, 2),
                            'facility_per_rate' => number_format($facilityPerRate, 2),
                            'admin_fees' => number_format($adminFees, 2),
                            'admin_amount' => number_format($adminFeesTotal, 2),
                            'hours_in_decimal' => !empty($request->sleepover_start)?$hoursArray['final_hours']:number_format($hoursAsDecimal, 2),
                            'facility_shift_total' => number_format($facilityShiftTotal, 2),
                            'hcp_shift_total' => number_format($hcpShiftTotal, 2),
                            'admin_fees_with_loading' => number_format($adminFeesWithLoadingTotal, 2),
                            'hcp_shift_loading' => number_format($hcpShiftLoading, 2),
                            'hcp_shift_total_loading' => number_format($hcpShiftTotalLoading, 2),
                            'facility_shift_loading' => number_format($facilityShiftLoading, 2),
                            'facility_shift_total_loading' => number_format($facilityShiftTotalLoading, 2),
                            'final_hours_time' => $hoursArray['final_hours'],
                            'sleepover_hours' => isset($hoursArray['sleepover_hours'])?$hoursArray['sleepover_hours']:"",
                            'hcp_sleepover_rate' => isset($hoursArray['hcp_sleepover_rate'])?$hoursArray['hcp_sleepover_rate']:"",
                            'facility_sleepover_rate' => isset($hoursArray['facility_sleepover_rate'])?$hoursArray['facility_sleepover_rate']:"",
	  'detailed_calculation' => !empty($detailed_calculation)?$detailed_calculation_html:'',
		'detailed_calculation_arr' => $detailed_calculation,
                        ];
                        //p($calculatedPriceArray);
                        $shiftEstimate = true;
                        $message = __('messages.shift_estimates_found');
                    }

                } else {
                    $shiftEstimate = null;
                    $calculatedPriceArray = [];
                    $message = __('messages.shift_estimates_not_found');
                }
            } else {
                $shiftEstimate = null;
                $calculatedPriceArray = [];
                $message = 'Please check your shift hours minimum hours ' . $minShiftHours . ' and maximum hours ' . $maxShiftHours . '.';
            }

            if (!empty($shiftEstimate)) {
                $response = [
                    '_status' => true,
                    '_message' => $message,
                    '_type' => 'success',
                    '_data' => $calculatedPriceArray,
                ];

            } else {
                $response = [
                    '_status' => false,
                    '_message' => $message,
                    '_type' => 'error',
                    '_data' => $calculatedPriceArray,
                    '_total_hours' => get_hours_in_decimal($hours),
                ];
            }

        } catch (\Exception $exception) {
            $message = __('messages.something_went_wrong');
            $response = [
                '_status' => false,
//                '_message' => $message,
                '_message' => $exception->getMessage(),
                '_type' => 'error',
                '_data' => $calculatedPriceArray,
                '_total_hours' => null,
            ];
        }

        return response()->json($response, 200);
    }

    /**
     * Create Buddy Shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 18 Jan 2020
     */
    public function createBuddyShift(Request $request, $id = null, $shiftType = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $shift = null;
        $facilities = null;

        try {

            // General Configuration
            $generalConfiguration = get_general_configuration();
            $radius = $generalConfiguration['radius_km_for_shift_broadcast'];
            //----------------------

            // Loading & Time Configuration
            $loadingTimeConfiguration = get_loading_time_configuration();
            //-----------------------------

            // Get Buddy Shift Request
            $buddyShiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['id' => dv($id)]);
            //------------------------

            // Get Categories
            $categories = $this->category->getAll(['id' => $buddyShiftRequest['category_id']], true);
            //---------------

            // Get Profession
            $professions = $this->profession->get(['id' => $buddyShiftRequest['profession_id']]);
            //---------------

            // Get Levels
            $levels = $this->level->get(['id' => $buddyShiftRequest['level_id']]);
            //-----------

            if ($shiftType == 'scheduled') {

                // Get Shift
                $shift = $this->shift->find_shift_with_where(['id' => $request['shift_id']]);
                //----------

                // Get facility group
                if(!empty($shift['facility_group_id'])) {
                    $facilityGroups = $this->facility_group->get_list(['id' => $shift['facility_group_id']]);
                } else {
                    $facilityGroups = [];
                }
                //-------------------

                // Get Facility
                $request['facility_id'] = $shift['facility_id'];
                $facilities = $this->facility->get_facility_for_shift($request);
                //-------------

            } else {

                // Get Facility
                $request['profession_id'] = $buddyShiftRequest['profession_id'];
                $request['category_id'] = $buddyShiftRequest['category_id'];
                $request['level_id']  = $buddyShiftRequest['level_id'];
                $request['latitude']  = $buddyShiftRequest['buddy_hcp']['latitude'];
                $request['longitude'] = $buddyShiftRequest['buddy_hcp']['longitude'];
                $request['radius'] = $radius;
                $request['state_id'] = $buddyShiftRequest['buddy_hcp']['state_id'];
                $facilities = $this->facility->get_facility_for_shift($request);
                //-------------

                // Get facility group
                $facilityGroups = $this->facility_group->get_list(['status' => 'active']);
                //-------------------

            }


            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.create-buddy-shift', compact('facilities', 'professions', 'levels',  'request', 'authUser', 'facilityGroups', 'buddyShiftRequest', 'generalConfiguration', 'loadingTimeConfiguration', 'categories', 'shift', 'shiftType'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    /**
     * Store buddy shift.
     *
     *
     * @author Sumit
     * @created 18 Jan 2020
     */
    public function storeBuddyShift(ValidateShift $request)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;
        $data = [];
        $buddyShiftRequest = null;
        $traineeHcpName = null;
        $buddyShiftCategory = null;
        $buddyShiftProfession = null;
        $buddyShiftLevel = null;
        $traineeHcpEmail = null;
        $traineeHcpId = null;
        $message = null;

        DB::beginTransaction();
        try {

            // Get Facility
            if(!empty($request['facility'])){
                $facility = $this->facility->find_facility($request['facility']);
            }
            //-------------

            // Check Hcp Shift
            $startTime = date('Y-m-d H:i', strtotime($request['start_time']));
            $endTime = date('Y-m-d H:i', strtotime($request['end_time']));
            $hcpShift = $this->shift->find_shift_with_date($startTime, $endTime, ['hcp_id' => $request['assign_hcp']]);
            //----------------

            // Get buddy shift request
            if(!empty($request['buddy_request_id'])){
                $buddyShiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['id' => $request['buddy_request_id']]);
                $traineeHcpName = $buddyShiftRequest->buddy_hcp->first_name.' '.$buddyShiftRequest->buddy_hcp->last_name;
                $traineeHcpEmail = $buddyShiftRequest->buddy_hcp->user->email;
                $buddyShiftCategory = $buddyShiftRequest->category->name;
                $buddyShiftProfession = $buddyShiftRequest->profession->name;
                $buddyShiftLevel = $buddyShiftRequest->level ? $buddyShiftRequest->level->name : null;
                $traineeHcpId = $buddyShiftRequest->buddy_hcp->id;
            }
            //------------------------

            if(empty($hcpShift)) {
                if(!empty($request['no_of_openings'])) {
                    for ($i = 1; $i <= $request['no_of_openings']; $i++) {

                        $data = [
                            'facility_group_id' => $request['facility_group'],
                            'facility_id' => $request['facility'],
                            'word_wing' => $request['word_wing'],
                            'category_id' => $request['category_id'],
                            'profession_id' => $request['profession_id'],
                            'hcp_level_id' => $request['hcp_level_id'],
                            'booked_by' => $request['booked_by'],
                            'shift_type' => strtolower($request['shift_types']),
                            'start_time' => date('Y-m-d H:i', strtotime($request['start_time'])),
                            'end_time' => date('Y-m-d H:i', strtotime($request['end_time'])),
                            'shift_time' => $request['shift_time'],
                            'break' => $request['break'],
                            'hours' => $request['hours'],
                            'shift_loading' => $request['shift_loading'],
                            'no_of_openings' => $request['no_of_openings'],
                            'notes' => $request['notes'],
                            'working_hours' => $request['working_hours'],
                            'hcp_amount' => $request['hcp_amount'],
                            'facility_amount' => $request['facility_amount'],
                            'admin_fees' => $request['admin_fees'],
                            'facility_per_rate' => $request['facility_per_rate'],
                            'hcp_per_rate' => $request['hcp_per_rate'],
                            'admin_amount' => $request['admin_amount'],
                            'mentor_hcp_name' => $request['mentor_hcp_name'],
                            'mentor_hcp_email' => $request['mentor_hcp_email'],
                            'mentor_hcp_id' => $request['mentor_hcp_id'],
                            'scheduled_shift_id' => $request['scheduled_shift_id'],
                            'address' => $facility['address'],
                            'state_id' => $facility['state_id'],
                            'country_id' => $facility['country_id'],
                            'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                            'final_hours_time' => $request['final_hours_time'],
                            'total_hours_time' => $request['total_hours_time'],
                            'hcp_shift_loading' => $request['hcp_shift_loading'],
                            'hcp_shift_total_loading' => $request['hcp_shift_total_loading'],
                            'facility_shift_loading' => $request['facility_shift_loading'],
                            'facility_shift_total_loading' => $request['facility_shift_total_loading'],
                            'created_by' => $authUser->id,
                            'updated_by' => $authUser->id,
                        ];

                        if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                            $data['hcp_id'] = $request['assign_hcp'];
                            $data['shift_status'] = '1';
                        }

                        $shift = $this->shift->store($data);

                        // Store transaction
                        $transactionData = [
                            'shift_id' => $shift->id,
                            'facility_id' => $request['facility'],
                            'facility_amount' => $request['facility_amount'],
                            'admin_fees' => $request['admin_amount'],
                            'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                            'amount_for' => 'facility',
                            'amount_type' => 'shift',
                            'status' => 'pending',
                        ];

                        $transaction = $this->transaction->store($transactionData);
                        //-------------------

                        // Update Scheduled Shift
                        if(!empty($traineeHcpName) && !empty($traineeHcpEmail)){
                            $this->shift->update(['trainee_hcp_name' => $traineeHcpName, 'trainee_hcp_email' => $traineeHcpEmail, 'trainee_hcp_id' => $traineeHcpId, 'trainee_buddy_shift_id' => $shift->id], ['id' => $request['scheduled_shift_id']]);
                        }
                        //-----------------------

                        // Update buddy shift request
                        if(!empty($request['buddy_request_id'])){
                            $this->buddy_shift_request->update(['status' => 'scheduled', 'shift_id' => $shift->id, 'facility_id' => $shift->facility_id], ['id' => $request['buddy_request_id']]);
                        }
                        //---------------------------

                        // Shift Activity
                        $shiftActivityData = [
                            'shift_id'      => $shift->id,
                            'activity'      => 'shift-created',
                            'created_by'    => $authUser->id,
                            'updated_by'    => $authUser->id,
                        ];

                        if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                            $shiftActivityData['hcp_id'] = $request['assign_hcp'];
                        }

                        $shiftActivity = $this->shift_activity->store($shiftActivityData);
                        //---------------

                        if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                            $hcpIds[] = $request['assign_hcp'];
                            send_shift_push_notification($shift->id, 'buddy-shift-assigned', $hcpIds);
                        }

                        if (isset($request['mentor_hcp_id']) && !empty($request['mentor_hcp_id'])) {
                            $mentorHcpids[] = $request['mentor_hcp_id'];
                            send_shift_push_notification($shift->id, 'trainee-assigned', $mentorHcpids);
                        }

                        // Send email to mentor
                        $emailTemplate = config('constants.admin_email_path') . 'mentor-buddy-shift-email';
                        $emailData = [
                            'template' => $emailTemplate,
                            'data' => [
                                'name' => ucwords($request['mentor_hcp_name']),
                                'email' => $request['mentor_hcp_email'],
                                'subject' => __('subjects.mentor_buddy_shift_assigned'),
                                'trainee_hcp_name' => $traineeHcpName,
                                'category' => $buddyShiftCategory,
                                'profession' => $buddyShiftProfession,
                                'level' => $buddyShiftLevel,
                                'start_time' => $request['start_time'],
                                'end_time' => $request['end_time'],
                                'facility' => $facility['name'],
                                'facility_address' => $facility['address'],
                                'word_wing' => $request['word_wing'],
                                'break' => $request['break'],
                                'hours' => $request['hours'],
                            ],
                        ];

                        if (config('app.server') == 'AWS') {
                            SendEmailJob::dispatch($emailData)->delay(now()->addSeconds(5));
                        } else {
                            $data = $emailData['data'];
                            Mail::send($emailTemplate, $data, function ($message) use ($data) {
                                $message->to($data['email']);
                                $message->subject($data['subject']);
                            });
                        }
                        //---------------------

                    }
                }
            } else {
                $shift = null;
                $message = __('messages.buddy_shift_request_create_time_failed');
            }

            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            $errorMessage = $exception->getMessage();
            $message = __('messages.record_creation_failed', ['record' => 'Shift']);
            DB::rollback();
        }


        if (!is_null($shift)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.record_created', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

            if (isset($request['assign_hcp']) && !empty($request['assign_hcp'])) {
                return redirect()->route('adminPanel.shift.scheduled')->with(['notification' => $notification]);
            } else {
                return redirect()->route('adminPanel.shift.buddy-requests')->with(['notification' => $notification]);
            }

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => $message,
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.buddy-requests')->with(['notification' => $notification]);
        }
    }

    /**
     * Assing Buddy Shift From Scheduled Shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 19 Jan 2020
     */
    public function assingBuddyShiftFromScheduledShift(Request $request, $id = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {

            // General Configuration
            $generalConfiguration = get_general_configuration();
            $radius = $generalConfiguration['radius_km_for_shift_broadcast'];
            //----------------------

            // Get Buddy Shift Request
            $buddyShiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['id' => dv($id)]);
            //------------------------

            $request['profession'] = $buddyShiftRequest['profession_id'];
            $request['category'] = $buddyShiftRequest['category_id'];
            $request['level']  = $buddyShiftRequest['level_id'];
            $request['latitude']  = $buddyShiftRequest['buddy_hcp']['latitude'];
            $request['longitude'] = $buddyShiftRequest['buddy_hcp']['longitude'];
            $request['radius'] = $radius;
            $request['state_id'] = $buddyShiftRequest['buddy_hcp']['state_id'];

            // Get Shift
            $shiftWhere = ['shift_status' => '1', 'shift_type' => 'morning', 'trainee_hcp_name' => null , 'trainee_hcp_email' => null];
            $shifts = $this->shift->getAll($shiftWhere, true, $request);
            //----------

            // Request
            $request = $request->all();
            //--------

            return view('admin-panel.shifts.choose-scheduled-shift', compact('shifts', 'request', 'authUser', 'buddyShiftRequest', 'generalConfiguration'));

        } catch (\Exception $exception){
            return dashboard_redirect($exception);
        }
    }

    /**
     * Export Transferred Shift.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 25 Jan 2021
     */
    public function shiftTransferredExport(Request $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['shift_export'] = true;
            $request['request']['shift_export'] = true;
            unset($request['request']['shift_per_page']);

            if(isset($request['facilityId']) && !empty($request['facilityId'])) {
                $where['facility_id'] = $request['facilityId'];
            }

            if(isset($request['hcpId']) && !empty($request['hcpId'])) {
                $where['hcp_id'] = $request['hcpId'];
            }

            return Excel::download(new TransferredShiftsExport($this->shift_transfer, $where, $request), 'transferred-shifts.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }


    /**
     * Export Swap Shift.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 25 Jan 2021
     */
    public function shiftSwapExport(Request $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['shift_export'] = true;
            $request['request']['shift_export'] = true;
            unset($request['request']['shift_per_page']);

            if(isset($request['facilityId']) && !empty($request['facilityId'])) {
                $where['facility_id'] = $request['facilityId'];
            }

            if(isset($request['hcpId']) && !empty($request['hcpId'])) {
                $where['hcp_id'] = $request['hcpId'];
            }

            return Excel::download(new SwapShiftExport($this->shift_swap_request, $where, $request), 'swapped-shifts.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Export Buddy Request Shift.
     *
     * @return Excel
     *
     * @author Sumit
     * @created 25 Jan 2021
     */
    public function shiftBuddyRequestExport(Request $request)
    {

        // Get users
        $authUser = auth()->user();
        //----------

        try {

            $where = [];
            $request = $request->all();
            $request['shift_export'] = true;
            $request['request']['shift_export'] = true;
            unset($request['request']['shift_per_page']);

            if(isset($request['facilityId']) && !empty($request['facilityId'])) {
                $where['facility_id'] = $request['facilityId'];
            }

            if(isset($request['hcpId']) && !empty($request['hcpId'])) {
                $where['hcp_id'] = $request['hcpId'];
            }

            return Excel::download(new BuddyShiftExport($this->buddy_shift_request, $where, $request), 'buddy-shift-requests.xls');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception->getMessage());
        }
    }

    /**
     * Multiple Shifts modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 24 Nov 2020
     */
    public function multipleShiftsModal(Request $request)
    {
        try {

            return view('admin-panel.includes.shifts.multiple-shifts-modal');

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Mark Complete Buddy Shift Request.
     *
     * @author Sumit
     * @created 06 Feb 2021
     */
    public function markCompleteBuddyShiftRequest(Request $request)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        $errorMessage = null;
        $buddyShiftRequest = null;

        DB::beginTransaction();
        try {

            // Get Buddy Shift Request
            $buddyShiftRequest = $this->buddy_shift_request->find_buddy_shift_request(['id' => $request['id']]);
            //------------------------

            // Update Buddy Shift Request
            $this->buddy_shift_request->update(['status' => 'approved'], ['id' => $request['id']]);
            //---------------------------

            // Send Notification To Hcp
            send_other_push_notification($buddyShiftRequest->hcp_id, 'hcp-buddy-shift-request-approved', 'hcp', null, null, $buddyShiftRequest->profession->name);
            //-------------------------


            DB::commit();
        } catch (\Exception $e) {
            $buddyShiftRequest = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!is_null($buddyShiftRequest)) {

            // Set notification
            $response = [
                '_status' => true,
                '_message' => __('messages.shift_transfer_successfully'),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $response = [
                '_status' => false,
                '_message' => __('messages.shift_transfer_failed'),
                '_type' => 'error',
            ];
            //-----------------
        }

        return response()->json($response, 200);
    }


    /**
     * Shift rate modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 15 Feb 2021
     */
    public function rateShiftModal(Request $request, $id = null)
    {
        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            return view('admin-panel.includes.shifts.rate-shift-modal', compact('shift'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Shift rate.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 15 Feb 2021
     */
    public function rateShift(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $rating = null;
        $currentTime = Carbon::now();

        DB::beginTransaction();
        try {

            // Get Shift
            $shiftRecord = $this->shift->find_shift(dv($id));
            //----------

            // Store Rating
            $where = [
                'shift_id' => $shiftRecord->id,
            ];
            $array = [
                'shift_id'    => $shiftRecord->id,
                'facility_id' => $shiftRecord->facility_id,
                'hcp_id'      => $shiftRecord->hcp_id,
                'category_id' => $shiftRecord->category_id,
                'profession_id' => $shiftRecord->profession_id,
                'hcp_rating'  => $request['rating2'],
                'hcp_comment'  => $request['comment'],
                'date_time'  => null,
                'facility_given_time' => now(),
                'created_by' => $authUser->id,
                'updated_by' => $authUser->id,
            ];
            $rating = $this->ratingReview->update_or_create($where,$array);
            //-------------

            DB::commit();
        } catch (\Exception $exception) {
            $rating = null;
            DB::rollback();
        }

        if (!is_null($rating)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.records_saved', ['record' => 'Rating']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.completed')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.records_saving_failed', ['record' => 'Rating']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.completed')->with(['notification' => $notification]);
        }
    }

    /**
     * Cancel Pending Shift Modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 24 Nov 2020
     */
    public function cancelPendingShiftModal(Request $request, $id = null)
    {
        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            return view('admin-panel.includes.shifts.cancel-pending-shift-modal', compact('shift'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }


    /**
     * Cancel Pending Shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 26 Nov 2020
     */
    public function cancelPendingShift(Request $request, $id = null)
    {
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;
        $penaltyPoint = 0;
        $penaltyAmount = 0;

        DB::beginTransaction();
        try {

            // General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------

            // Set time zone
            date_default_timezone_set($shift->state->time_zone_name);
            //--------------

            $cancelTime = Carbon::now($shift->state->time_zone_name);

            // Update Shift
            $shiftData = ['shift_status' => '3'];
            $shiftUpdate = $this->shift->update($shiftData, ['id' => $shift->id]);
            //-------------

            // Cancel Shift
            $cancelledShiftData = [
                'shift_id'      => $shift->id,
                'hcp_id'        => $shift->hcp_id,
                'cancel_by'     => 'facility',
                'cancel_by_name' => $request['name'],
                'cancel_time'   => $cancelTime,
                'cancel_reason' => $request['cancel_reason'],
                'negative_points' => $penaltyPoint,
                'penalty_amount' => $penaltyAmount,
                'created_by'    => $authUser->id,
                'updated_by'    => $authUser->id,
            ];
            $cancelledShift = $this->cancelled_shift->store($cancelledShiftData);
            //-------------

            // Shift Activity
            $shiftActivityData = [
                'hcp_id'        => $shift->hcp_id,
                'shift_id'      => $shift->id,
                'activity'      => 'shift-cancelled',
                'created_by'    => $authUser->id,
                'updated_by'    => $authUser->id,
            ];
            $shiftActivity = $this->shift_activity->store($shiftActivityData, ['id' => $shift->id]);
            //---------------

            if (!empty($shift['hcp_id'])) {
                $hcpId = $shift['hcp_id'];
                send_shift_push_notification($shift->id, 'shift-cancelled', $hcpId);
            }

            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.pending')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.pending')->with(['notification' => $notification]);
        }
    }


    /**
     * View location modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 24 Nov 2020
     */
    public function viewLocationModal(Request $request, $id = null)
    {
        try {

            // Get Shift
            $shiftTracking = $this->shift_tracking->find_shift_tracking(['shift_id' => dv($id)]);
            //----------

            return view('admin-panel.includes.shifts.view-location-modal', compact('shiftTracking'));

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }


    /**
     * View location modal.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 24 Nov 2020
     */
    public function viewAllShiftNotification(Request $request, $id = null)
    {
        // Get users
        $authUser = auth()->user();
        //----------

        try {
            // Request
            $request = $request->all();
            //--------

            if(isset($request['shift_per_page']) && !empty($request['shift_per_page'])) {
                $paginationLimit = $request['shift_per_page'];
            } else {
                $paginationLimit = config('constants.pagination_limit');
            }

            $shiftId  = $id;
            $notifications = Notification::where(function ($query) use ($request, $shiftId) {
                if(!empty($request['shift_hcp_search'])) {
                    if(is_numeric($request['shift_hcp_search'])) {
                        $query->where('id', 'LIKE', "%{$request['shift_hcp_search']}%");
                    } else {
                        $query->whereHas('hcp', function ($query) use ($request) {
                            $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['shift_hcp_search']).'%');
                        });
                    }
                }

                $query->where('shift_id', $shiftId)->where('notification_type', 'shifts');

            })
            ->with(['hcp' => function ($query) use ($request) {
                if(!empty($request['shift_hcp_search']) && !is_numeric($request['shift_hcp_search'])) {
                    $query->where(DB::raw('concat(first_name," ",last_name)'), 'like', '%'.strtolower($request['shift_hcp_search']).'%');
                }
            }])
            ->paginate($paginationLimit)->fragment('shift')->onEachSide(2);

            return view('admin-panel.shifts.shift-notification',compact('notifications', 'request', 'authUser', 'shiftId'));

        } catch (\Exception $exception) {
            $errorMessage = $exception->getMessage();
            return dashboard_redirect($exception);
        }
    }



    /**
     * Get All shift.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Sumit
     * @created 22 Jan 2020
     */
    public function updateShiftAmount(Request $request)
    {
        try {

            $hcpShiftTotalLoading = 0;
            $hcpShiftTotal = 0;
            $facilityShiftTotal = 0;
            $adminFeesWithLoadingTotal = 0;

            // Get Shift
            $shiftWhere = [];
            $shifts = $this->shift->shift_where($shiftWhere);
            //----------

            if(count($shifts)) {
                $hoursAsDecimal = 0;
                $hcpShiftTotal = 0;
                $facilityShiftTotal = 0;

                $hcpShiftLoading = 0;
                $hcpShiftTotalLoading = 0;
                $facilityShiftLoading = 0;
                $facilityShiftTotalLoading = 0;

                foreach($shifts as $shift) {

                    if(!empty($shift->shift_loading) && $shift->shift_loading !=0) {
                        $hoursAsDecimal = $shift->working_hours;
                        $hcpShiftTotal = ($shift->hcp_per_rate * $hoursAsDecimal);
                        $facilityShiftTotal = ($shift->facility_per_rate * $hoursAsDecimal);

                        $hcpShiftLoading = $shift->shift_loading*($shift->hcp_per_rate/100);
                        $hcpShiftTotalLoading = $shift->shift_loading*($hcpShiftTotal/100);

                        $facilityShiftLoading = $shift->shift_loading*($shift->facility_per_rate/100);
                        $facilityShiftTotalLoading = $shift->shift_loading*($facilityShiftTotal/100);

                        $shift->hcp_shift_loading  = $hcpShiftLoading;
                        $shift->hcp_shift_total_loading  = $hcpShiftTotalLoading;
                        $shift->facility_shift_loading  = $facilityShiftLoading;
                        $shift->facility_shift_total_loading  = $facilityShiftTotalLoading;
                    } else {
                        $shift->hcp_shift_loading = 0;
                        $shift->hcp_shift_total_loading = 0;
                        $shift->facility_shift_loading = 0;
                        $shift->facility_shift_total_loading = 0;
                    }

                    $shift->save();

                }
            }

            p(count($shifts));

            // Request
            $request = $request->all();
            //--------

        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    public function requestBuddyShift($hcp_profession_id){
        // Get User
        $authUser = auth()->user();

        DB::beginTransaction();
        try {
            // Check Profession
            $hcpProfession = $this->hcp_profession->find_last_hcp_profession(['id' => $hcp_profession_id]);
            // p($hcpProfession);
            //-----------------

            if ($hcpProfession->hcp->status == 'active') {
                if (!empty($hcpProfession)) {
                    if ($hcpProfession['status'] != 'pending-approval') {
                        $buddyWhere = [
                            ['hcp_id', '=', $hcpProfession->hcp_id],
                            ['hcp_profession_id', '=', $hcp_profession_id],
                            ['status', '!=', 'cancelled']
                        ];
                        $buddyRequest = $this->buddy_shift_request->find_buddy_shift_request($buddyWhere);

                        if(empty($buddyRequest)) {
                            $data = [
                                'hcp_id'        => $hcpProfession->hcp_id,
                                'category_id'   => $hcpProfession->category_id,
                                'profession_id' => $hcpProfession->profession_id,
                                'level_id'      => $hcpProfession->level_id ?? null,
                                'hcp_profession_id'   => $hcp_profession_id,
                                'status'        => 'requested',
                                'created_by'    => $authUser->id,
                                'updated_by'    => $authUser->id,
                            ];

                            $buddyShiftRequest = $this->buddy_shift_request->store($data);
                            $message = __('messages.buddy_shift_request_create_successfully');
                        } else {
                            $buddyShiftRequest = null;
                            $message = __('messages.buddy_shift_request_create_failed');
                        }
                    } else {
                        $buddyShiftRequest = null;
                        $message = __('messages.buddy_shift_request_profession_pending_approval');
                    }
                } else {
                    $buddyShiftRequest = null;
                    $message = __('messages.buddy_shift_request_create_failed_new');
                }
            } else {
                $buddyShiftRequest = null;
                $message = __('messages.buddy_shift_request_create_hcp_failed');
            }

            DB::commit();
        } catch (\Exception $e) {
            $buddyShiftRequest = null;
            $errorMessage = $e->getMessage();
            DB::rollback();
        }

        if (!empty($buddyShiftRequest)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => $message,
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => $message,
                '_type' => 'error',
            ];
            //-----------------
        }

        return redirect()->back()->with(['notification' => $notification]);
    }

    public function approveSleepoverShift(Request $request, $id){
	// Get users
        $authUser = auth()->user();
        //----------

        try {

            // Get Shift
            $shift = $this->shift->find_shift(dv($id));
            //----------
	// General Configuration
            $generalConfiguration = get_general_configuration();
            //----------------------

            // Loading & Time Configuration
            $loadingTimeConfiguration = get_loading_time_configuration();
            //-----------------------------


            if (!empty($authUser->facility)) {
                $hcps = $this->hcp->get_hcp_listing_for_shift($request);
                return view('admin-panel.shifts.facility-shift-edit', compact('shift', 'facilityGroups', 'facilities', 'categories', 'generalConfiguration', 'loadingTimeConfiguration', 'professions', 'levels', 'buddyShiftRequest', 'authUser', 'hcps'));

            } else {

                return view('admin-panel.shifts.approve-sleepover-shift', compact('shift', 'authUser','generalConfiguration', 'loadingTimeConfiguration'));
            }


        } catch (\Exception $exception) {
            return dashboard_redirect($exception);
        }
    }

    /**
     * Sleepover Shift approved.
     *
     * @return \Illuminate\View\View|\Illuminate\Contracts\View\Factory
     *
     * @author Yamini
     * @created 09 Aug 2024
     */
    public function updateApprovedSleepoverShift(Request $request, $id = null)
    {
        //p($request->all());
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;

        DB::beginTransaction();
        try {

            if(!empty($request['hcp_amount']) && !empty($request['hours']) && !empty($request['working_hours']) && !empty($request['hcp_per_rate'])) {

                // Get Shift
                $shiftRecord = $this->shift->find_shift(dv($id));
                //----------

                // Set time zone
                date_default_timezone_set($shiftRecord->state->time_zone_name);
                //--------------

                // Current date
                $currentDate = Carbon::now($shiftRecord->state->time_zone_name)->toDateString();
                $currentTime = Carbon::now($shiftRecord->state->time_zone_name);
                //-------------

                // Get Hcp First Shift
                $getHcpFirstShift = $this->shift->find_shift_with_where(['hcp_id' => $shiftRecord->hcp_id, ['shift_status', '>=', '4']]);
                //--------------------

                if (!empty($getHcpFirstShift)) {

                    $data = [
                        'shift_type' => $request['shift_types'],
                        'shift_time' => $request['shift_time'],
                        //'approved_shift_start_time' => date('Y-m-d H:i', strtotime($request['approved_start_time'])),
                        //'approved_shift_end_time' => date('Y-m-d H:i', strtotime($request['approved_end_time'])),
                        'break' => $request['break'],
                        'hours' => $request['hours'],
                        'shift_loading' => $request['shift_loading'],
                        'working_hours' => $request['working_hours'],
                        'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                        'facility_amount' => str_replace(",","",$request['facility_amount']),
                        'admin_fees' => $request['admin_fees'],
                        'facility_per_rate' => $request['facility_per_rate'],
                        'hcp_per_rate' => $request['hcp_per_rate'],
                        'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                        'final_hours_time' => $request['final_hours_time'],
                        'total_hours_time' => $request['total_hours_time'],
                        'hcp_shift_loading' => $request['hcp_shift_loading'],
                        'hcp_shift_total_loading' => $request['hcp_shift_total_loading'],
                        'facility_shift_loading' => $request['facility_shift_loading'],
                        'facility_shift_total_loading' => $request['facility_shift_total_loading'],
                        'notes' => $request['notes'],
                        // 'shift_approved_time' => $currentTime,
                        // 'shift_status' => '6',
                        'updated_by' => $authUser->id,
                    ];

	$generalConfiguration = get_general_configuration();
	//extra_night_hours
	$extra_night_hcp_rate = $generalConfiguration['hcp_extra_night_rate'];
                    $extra_night_facility_rate = $generalConfiguration['facility_extra_night_rate'];
                    $extra_night_hours_data = [];
                    if(isset($request->approved_extra_sleepover_night_start_time) && !empty($request->approved_extra_sleepover_night_start_time))
                    {
                        foreach($request->approved_extra_sleepover_night_start_time as $key=>$approved_extra_sleepover_night_start_time){
                            if(!empty($approved_extra_sleepover_night_start_time) && !empty($request->approved_extra_sleepover_night_end_time[$key]))
                            {
                                $extraNightStart = strtotime($approved_extra_sleepover_night_start_time);
                                $extraNightEnd = strtotime($request->approved_extra_sleepover_night_end_time[$key]);
                                $extra_night_hours = get_hours($extraNightStart, $extraNightEnd);
                                $extraNightHoursAsDecimal = get_hours_in_decimal($extra_night_hours);

                                $extra_night_hours_data[] = [
                                                                'approved_extra_sleepover_night_start_time'=>$approved_extra_sleepover_night_start_time,
                                                                'approved_extra_sleepover_night_end_time'=>$request->approved_extra_sleepover_night_end_time[$key],
                                                                'total_hours'=> $extraNightHoursAsDecimal,
                                                                'facility_total_amount' => $extraNightHoursAsDecimal*$extra_night_facility_rate,
                                                                'hcp_total_amount' => $extraNightHoursAsDecimal*$extra_night_hcp_rate
                                                            ];
                            }
                        }
                    }
	$data['extra_night_hours_details'] = json_encode($extra_night_hours_data);
                    //p($extra_night_hours_data);


                    $data['hcp_sleepover_rate'] =$generalConfiguration['hcp_sleepover_rate'];
                    $data['facility_sleepover_rate'] =$generalConfiguration['facility_sleepover_rate'];
                    $data['approved_sleepover_afternoon_start_time'] = Carbon::parse($request['approved_sleepover_afternoon_start_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_afternoon_end_time'] = Carbon::parse($request['approved_sleepover_afternoon_end_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_start_time'] = Carbon::parse($request['approved_sleepover_start_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_end_time'] = Carbon::parse($request['approved_sleepover_end_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_morning_start_time'] = Carbon::parse($request['approved_sleepover_morning_start_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_morning_end_time'] = Carbon::parse($request['approved_sleepover_morning_end_time'])->format('Y-m-d H:i');
	$data['approved_sleepover_night_start_time'] = Carbon::parse($request['approved_sleepover_night_start_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_night_end_time'] = Carbon::parse($request['approved_sleepover_night_end_time'])->format('Y-m-d H:i');

	$data['sleepover_afternoon_admin_fees'] = $request->sleepover_afternoon_admin_fees;
$data['sleepover_afternoon_loading'] = $request->sleepover_afternoon_loading;
$data['sleepover_afternoon_working_hours'] = $request->sleepover_afternoon_working_hours;
$data['sleepover_afternoon_faciliy_amount'] = number_format($request->sleepover_afternoon_faciliy_amount,2);
$data['sleepover_afternoon_hcp_amount'] = number_format($request->sleepover_afternoon_hcp_amount,2);

$data['sleepover_night_admin_fees'] = $request->sleepover_night_admin_fees;
$data['sleepover_night_loading'] = $request->sleepover_night_loading;
$data['sleepover_night_working_hours'] = $request->sleepover_night_working_hours;
$data['sleepover_night_faciliy_amount'] = number_format($request->sleepover_night_faciliy_amount,2);
$data['sleepover_night_hcp_amount'] = number_format($request->sleepover_night_hcp_amount,2);

$data['sleepover_morning_admin_fees'] = $request->sleepover_morning_admin_fees;
$data['sleepover_morning_loading'] = $request->sleepover_morning_loading;
$data['sleepover_morning_working_hours'] = $request->sleepover_morning_working_hours;
$data['sleepover_morning_faciliy_amount'] = number_format($request->sleepover_morning_faciliy_amount,2);
$data['sleepover_morning_hcp_amount'] = number_format($request->sleepover_morning_hcp_amount,2);

                    $shift = $this->shift->update($data, ['id' => dv($id)]);


                    // Shift Activity
                    $shiftActivityData = [
                        'hcp_id' => $shiftRecord->hcp_id,
                        'shift_id' => $shiftRecord->id,
                        'activity' => 'shift-updated',
                        'created_by' => $authUser->id,
                        'updated_by' => $authUser->id,
                    ];
                    $shiftActivity = $this->shift_activity->store($shiftActivityData, ['id' => $shiftRecord->id]);
                    //---------------

                } else {
                    $shift = null;
                }
            }

            DB::commit();
        } catch (\Exception $exception) {
            p($exception->getMessage());
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------
        }
        echo json_encode($notification);
    }

    public function approvedSleepoverShift(Request $request, $id = null)
    {
        // p($request->all());
        // Get User
        $authUser = auth()->user();
        //---------

        $shift = null;

        DB::beginTransaction();
        try {

            if(!empty($request['hcp_amount']) && !empty($request['hours']) && !empty($request['working_hours']) && !empty($request['hcp_per_rate'])) {

                // Get Shift
                $shiftRecord = $this->shift->find_shift(dv($id));
                //----------

                // Set time zone
                date_default_timezone_set($shiftRecord->state->time_zone_name);
                //--------------

                // Current date
                $currentDate = Carbon::now($shiftRecord->state->time_zone_name)->toDateString();
                $currentTime = Carbon::now($shiftRecord->state->time_zone_name);
                //-------------

                // Get Hcp First Shift
                $getHcpFirstShift = $this->shift->find_shift_with_where(['hcp_id' => $shiftRecord->hcp_id, ['shift_status', '>=', '4']]);
                //--------------------

                if (!empty($getHcpFirstShift)) {

                    // Find referee
                    $referee = $this->referral->find_referral_by_code(['referee_hcp_id' => $shiftRecord->hcp_id, 'status' => 'pending']);
                    //-------------

                    if (!empty($referee)) {
                        $this->referral->update(['status' => 'completed', 'referral_completed_date' => $currentDate], ['id' => $referee->id]);

                        // Create transactions for referee
                        $this->transaction->store([
                            'shift_id' => $shiftRecord->id,
                            'hcp_id' => $referee->referee_hcp_id,
                            'referral_id' => $referee->id,
                            'hcp_amount' => str_replace(",","",$referee->referee_amount),
                            'amount_for' => 'hcp',
                            'amount_type' => 'refer-and-earn',
                            'hcp_payment_status' => 'pending',
                            'status' => 'pending',
                        ]);
                        //---------------------------------

                        if (!empty($referee->referee_hcp_id)) {
                            send_other_push_notification($referee->referee_hcp_id, 'refer-and-earn', 'hcp', null, null, null, $referee->referee_amount);
                        }

                        // Create transactions for referrer
                        $this->transaction->store([
                            'shift_id' => $shiftRecord->id,
                            'hcp_id' => $referee->referrer_hcp_id,
                            'referral_id' => $referee->id,
                            'hcp_amount' => str_replace(",","",$referee->referee_amount),
                            'amount_for' => 'hcp',
                            'amount_type' => 'refer-and-earn',
                            'hcp_payment_status' => 'pending',
                            'status' => 'pending',
                        ]);
                        //---------------------------------

                        if (!empty($referee->referrer_hcp_id)) {
                            send_other_push_notification($referee->referrer_hcp_id, 'refer-and-earn', 'hcp', null, null, null, $referee->referrer_amount);
                        }

                    }
                }

                $data = [
                    'shift_type' => $request['shift_types'],
                    'shift_time' => $request['shift_time'],
                    // 'approved_shift_start_time' => date('Y-m-d H:i', strtotime($request['approved_start_time'])),
                    // 'approved_shift_end_time' => date('Y-m-d H:i', strtotime($request['approved_end_time'])),
                    'approved_shift_start_time' => date('Y-m-d H:i', strtotime($request['approved_sleepover_afternoon_start_time'])),
                    'approved_shift_end_time' => date('Y-m-d H:i', strtotime($request['approved_sleepover_morning_end_time'])),
                    'break' => $request['break'],
                    'hours' => $request['hours'],
                    'shift_loading' => $request['shift_loading'],
                    'working_hours' => $request['working_hours'],
                    'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                    'facility_amount' => str_replace(",","",$request['facility_amount']),
                    'admin_fees' => $request['admin_fees'],
                    'facility_per_rate' => $request['facility_per_rate'],
                    'hcp_per_rate' => $request['hcp_per_rate'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'final_hours_time' => $request['final_hours_time'],
                    'total_hours_time' => $request['total_hours_time'],
                    'hcp_shift_loading' => $request['hcp_shift_loading'],
                    'hcp_shift_total_loading' => $request['hcp_shift_total_loading'],
                    'facility_shift_loading' => $request['facility_shift_loading'],
                    'facility_shift_total_loading' => $request['facility_shift_total_loading'],
                    'shift_approved_time' => $currentTime,
                    'shift_status' => '6',
                    'updated_by' => $authUser->id,
                ];

	$generalConfiguration = get_general_configuration();
                    $data['hcp_sleepover_rate'] =$generalConfiguration['hcp_sleepover_rate'];
                    $data['facility_sleepover_rate'] =$generalConfiguration['facility_sleepover_rate'];
                    $data['approved_sleepover_afternoon_start_time'] = Carbon::parse($request['approved_sleepover_afternoon_start_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_afternoon_end_time'] = Carbon::parse($request['approved_sleepover_afternoon_end_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_start_time'] = Carbon::parse($request['approved_sleepover_start_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_end_time'] = Carbon::parse($request['approved_sleepover_end_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_morning_start_time'] = Carbon::parse($request['approved_sleepover_morning_start_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_morning_end_time'] = Carbon::parse($request['approved_sleepover_morning_end_time'])->format('Y-m-d H:i');
	$data['approved_sleepover_night_start_time'] = Carbon::parse($request['approved_sleepover_night_start_time'])->format('Y-m-d H:i');
                    $data['approved_sleepover_night_end_time'] = Carbon::parse($request['approved_sleepover_night_end_time'])->format('Y-m-d H:i');

	$data['sleepover_afternoon_admin_fees'] = $request->sleepover_afternoon_admin_fees;
$data['sleepover_afternoon_loading'] = $request->sleepover_afternoon_loading;
$data['sleepover_afternoon_working_hours'] = $request->sleepover_afternoon_working_hours;
$data['sleepover_afternoon_faciliy_amount'] = number_format($request->sleepover_afternoon_faciliy_amount,2);
$data['sleepover_afternoon_hcp_amount'] = number_format($request->sleepover_afternoon_hcp_amount,2);

$data['sleepover_night_admin_fees'] = $request->sleepover_night_admin_fees;
$data['sleepover_night_loading'] = $request->sleepover_night_loading;
$data['sleepover_night_working_hours'] = $request->sleepover_night_working_hours;
$data['sleepover_night_faciliy_amount'] = number_format($request->sleepover_night_faciliy_amount,2);
$data['sleepover_night_hcp_amount'] = number_format($request->sleepover_night_hcp_amount,2);

$data['sleepover_morning_admin_fees'] = $request->sleepover_morning_admin_fees;
$data['sleepover_morning_loading'] = $request->sleepover_morning_loading;
$data['sleepover_morning_working_hours'] = $request->sleepover_morning_working_hours;
$data['sleepover_morning_faciliy_amount'] = number_format($request->sleepover_morning_faciliy_amount,2);
$data['sleepover_morning_hcp_amount'] = number_format($request->sleepover_morning_hcp_amount,2);


                $shift = $this->shift->update($data, ['id' => dv($id)]);

                // Update buddy shift request
                if(!empty($shiftRecord) &&  $shiftRecord['shift_type'] == 'buddy'){
                    $this->buddy_shift_request->update(['status' => 'approved'], ['shift_id' => $shiftRecord->id]);
                }
                //---------------------------

                // Store transaction
                $transactionData = [
                    'facility_amount' => str_replace(",","",$request['facility_amount']),
                    'admin_fees' => $request['admin_amount'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'facility_id' => $shiftRecord->facility_id,
                    'hcp_id' => $shiftRecord->hcp_id,
                    'amount_for' => 'facility',
                    'amount_type' => 'shift',
                    'status' => 'pending',
                ];

                $transaction = $this->transaction->update($transactionData, ['shift_id' => dv($id), 'amount_type' => 'shift']);
                //-------------------

                // Store transaction
                $transactionData = [
                    'shift_id' => $shiftRecord->id,
                    'facility_id' => $shiftRecord->facility_id,
                    'hcp_id' => $shiftRecord->hcp_id,
                    'hcp_amount' => str_replace(",","",$request['hcp_amount']),
                    'admin_fees' => $request['admin_amount'],
                    'total_admin_fees_with_loading' => $request['admin_fees_with_loading'],
                    'amount_for' => 'hcp',
                    'amount_type' => 'shift',
                    'hcp_payment_status' => 'pending',
                ];

                $transaction = $this->transaction->store($transactionData);
                //-------------------

                // Shift Activity
                $shiftActivityData = [
                    'hcp_id'        => $shiftRecord->hcp_id,
                    'shift_id'      => $shiftRecord->id,
                    'activity'      => 'shift-approved',
                    'created_by'    => $authUser->id,
                    'updated_by'    => $authUser->id,
                ];
                $shiftActivity = $this->shift_activity->store($shiftActivityData, ['id' => $shiftRecord->id]);
                //---------------

                if (!empty($shiftRecord['hcp_id'])) {
                    $hcpId = $shiftRecord['hcp_id'];
                    send_shift_push_notification($shiftRecord->id, 'shift-approved', $hcpId);
                }
            } else {
                $shift = null;
            }

            DB::commit();
        } catch (\Exception $exception) {
            $shift = null;
            DB::rollback();
        }

        if (!is_null($shift)) {

            // Set notification
            $notification = [
                '_status' => true,
                '_message' => __('messages.status_changed', ['record' => 'Shift']),
                '_type' => 'success',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.completed')->with(['notification' => $notification]);

        } else {

            // Set notification
            $notification = [
                '_status' => false,
                '_message' => __('messages.status_change_failed', ['record' => 'Shift']),
                '_type' => 'error',
            ];
            //-----------------

            return redirect()->route('adminPanel.shift.completed')->with(['notification' => $notification]);
        }
    }

}
